-- #########################################################
-- #########################################################
-- ConfigEnv.sql
-- #########################################################
-- #########################################################

SPOOL spool.txt
WHENEVER SQLERROR EXIT FAILURE ROLLBACK
WHENEVER OSERROR EXIT FAILURE ROLLBACK

-- #########################################################
-- #########################################################
-- VersionCheck.sql
-- #########################################################
-- #########################################################

declare
  Major$ NUMBER(10);
  Minor$ NUMBER(10);
begin
  select max(Major) into Major$ from DatabaseVersion;
  select max(Minor) into Minor$ from DatabaseVersion where Major = Major$;
  if (Major$ <> 1130) or (Minor$ <> 00) then
    raise_application_error(-20000, '  [' || TO_CHAR(Major$) || '.' || TO_CHAR(Minor$, 'FM00') || ']    [1130.00]');
  end if;
end;
/

-- #########################################################
-- #########################################################
-- Alter_Users_Wp_add_defInterface.sql
-- #########################################################
-- #########################################################

/*    User_Workplaces ,      /   */
ALTER TABLE TB_User_Workplaces ADD (
  DefaultInterface NUMBER(10),
    CHECK((DefaultInterface<=2147483647)AND(DefaultInterface>-2147483648)),
  constraint UW_FC_DEFAULTINTERFACE foreign key (DefaultInterface) references TB_INTERFACES(ID)
)
/
CREATE INDEX UW_FC_DEFAULTINTERFACE ON TB_User_Workplaces(DefaultInterface)
/

CREATE OR REPLACE VIEW User_Workplaces (
  ID,
  USERS_REF,
  WORKPLACES_REF,
  DEFAULTWORKPLACE,
  UPDATEDATE,
  CREATEDATE,
  CREATERUSER,
  UPDATERUSER,
  DEFAULTINTERFACE)
AS
  SELECT
    ID,
    USERS_REF,
    WORKPLACES_REF,
    DEFAULTWORKPLACE,
    UPDATEDATE,
    CREATEDATE,
    CREATERUSER,
    UPDATERUSER,
    DEFAULTINTERFACE
  FROM TB_User_Workplaces
/

CREATE OR REPLACE TRIGGER TR_USER_WORKPLACES_ID
  INSTEAD OF DELETE
  ON USER_WORKPLACES
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_USER_WORKPLACES_BD)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  --        
  if (:old.id = 0) then
    RaiseException('EX_CANTDELETETHIS');
  end if;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_USER_WORKPLACES
  WHERE id = :old.id;

END;
/

CREATE OR REPLACE TRIGGER TR_USER_WORKPLACES_II
  INSTEAD OF INSERT
  ON USER_WORKPLACES
  FOR EACH ROW
DECLARE
  new$ID USER_WORKPLACES.ID%TYPE := :NEW.ID;
  new$USERS_REF USER_WORKPLACES.USERS_REF%TYPE := :NEW.USERS_REF;
  new$WORKPLACES_REF USER_WORKPLACES.WORKPLACES_REF%TYPE := :NEW.WORKPLACES_REF;
  new$DEFAULTWORKPLACE USER_WORKPLACES.DEFAULTWORKPLACE%TYPE := :NEW.DEFAULTWORKPLACE;
  new$UPDATEDATE USER_WORKPLACES.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CREATEDATE USER_WORKPLACES.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$CREATERUSER USER_WORKPLACES.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER USER_WORKPLACES.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$DEFAULTINTERFACE USER_WORKPLACES.DEFAULTINTERFACE%TYPE := :NEW.DEFAULTINTERFACE;
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_USER_WORKPLACES_BI)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  if (new$id is null) then select g_Shared.NextVal into new$ID from dual; end if;

-- - - - - - - - - - - - -
-- BI_500 (TR_USER_WORKPLACES_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$createdate := SYSDATE;
  new$updatedate := new$createdate;
  new$createruser := user;
  new$updateruser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_USER_WORKPLACES (
    ID,
    USERS_REF,
    WORKPLACES_REF,
    DEFAULTWORKPLACE,
    UPDATEDATE,
    CREATEDATE,
    CREATERUSER,
    UPDATERUSER,
    DEFAULTINTERFACE
  ) VALUES (
    new$ID,
    new$USERS_REF,
    new$WORKPLACES_REF,
    new$DEFAULTWORKPLACE,
    new$UPDATEDATE,
    new$CREATEDATE,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$DEFAULTINTERFACE);

END;
/

CREATE OR REPLACE TRIGGER TR_USER_WORKPLACES_IU
  INSTEAD OF UPDATE
  ON USER_WORKPLACES
  FOR EACH ROW
DECLARE
  new$ID USER_WORKPLACES.ID%TYPE := :NEW.ID;
  new$USERS_REF USER_WORKPLACES.USERS_REF%TYPE := :NEW.USERS_REF;
  new$WORKPLACES_REF USER_WORKPLACES.WORKPLACES_REF%TYPE := :NEW.WORKPLACES_REF;
  new$DEFAULTWORKPLACE USER_WORKPLACES.DEFAULTWORKPLACE%TYPE := :NEW.DEFAULTWORKPLACE;
  new$UPDATEDATE USER_WORKPLACES.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CREATEDATE USER_WORKPLACES.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$CREATERUSER USER_WORKPLACES.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER USER_WORKPLACES.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$DEFAULTINTERFACE USER_WORKPLACES.DEFAULTINTERFACE%TYPE := :NEW.DEFAULTINTERFACE;
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_USER_WORKPLACES_BU)
-- Last update 13.03.2008
-- - - - - - - - - - - - -

  --        
  if ((:old.id = 0) and ((new$Users_ref <> :old.Users_ref) or
    (new$WorkPlaces_ref <> :old.WorkPlaces_ref)))
  then
    RaiseException('EX_CANTUPDATETHIS');
  end if;

-- - - - - - - - - - - - -
-- BU_1 (TR_USER_WORKPLACES_BU_1)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  if ((new$DefaultWorkplace <> :old.DefaultWorkplace) and (new$DefaultWorkplace <> 0)) then
        update tb_user_workplaces
                set
                        DefaultWorkplace = 0
                where
                        (Users_ref = new$Users_ref) and
                        (id <> new$id);
  end if;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_USER_WORKPLACES SET
    ID = new$ID,
    USERS_REF = new$USERS_REF,
    WORKPLACES_REF = new$WORKPLACES_REF,
    DEFAULTWORKPLACE = new$DEFAULTWORKPLACE,
    UPDATEDATE = new$UPDATEDATE,
    CREATEDATE = new$CREATEDATE,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    DEFAULTINTERFACE = new$DEFAULTINTERFACE
  WHERE ID = :OLD.ID;

END;
/
-- CREATE TRIGGER tr_user_workplaces_bu_1
CREATE OR REPLACE TRIGGER TR_USER_WORKPLACES_IU
  INSTEAD OF UPDATE
  ON USER_WORKPLACES
  FOR EACH ROW
DECLARE
  new$ID USER_WORKPLACES.ID%TYPE := :NEW.ID;
  new$USERS_REF USER_WORKPLACES.USERS_REF%TYPE := :NEW.USERS_REF;
  new$WORKPLACES_REF USER_WORKPLACES.WORKPLACES_REF%TYPE := :NEW.WORKPLACES_REF;
  new$DEFAULTWORKPLACE USER_WORKPLACES.DEFAULTWORKPLACE%TYPE := :NEW.DEFAULTWORKPLACE;
  new$UPDATEDATE USER_WORKPLACES.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CREATEDATE USER_WORKPLACES.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$CREATERUSER USER_WORKPLACES.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER USER_WORKPLACES.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$DEFAULTINTERFACE USER_WORKPLACES.DEFAULTINTERFACE%TYPE := :NEW.DEFAULTINTERFACE;
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_USER_WORKPLACES_BU)
-- Last update 13.03.2008
-- - - - - - - - - - - - -

  --        
  if ((:old.id = 0) and ((new$Users_ref <> :old.Users_ref) or
    (new$WorkPlaces_ref <> :old.WorkPlaces_ref)))
  then
    RaiseException('EX_CANTUPDATETHIS');
  end if;

-- - - - - - - - - - - - -
-- BU_1 (TR_USER_WORKPLACES_BU_1)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if (new$DefaultWorkplace <> 0) then
    if ((new$DefaultWorkplace <> :old.DefaultWorkplace) or (:old.DefaultWorkplace is null) ) then 
      update User_Workplaces
      set
      DefaultWorkplace = 0,
      DefaultInterface = null
      where
      (Users_ref = new$Users_ref)
      and
      (id <> new$id);
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_USER_WORKPLACES SET
    ID = new$ID,
    USERS_REF = new$USERS_REF,
    WORKPLACES_REF = new$WORKPLACES_REF,
    DEFAULTWORKPLACE = new$DEFAULTWORKPLACE,
    UPDATEDATE = new$UPDATEDATE,
    CREATEDATE = new$CREATEDATE,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    DEFAULTINTERFACE = new$DEFAULTINTERFACE
  WHERE ID = :OLD.ID;

END;
/
commit work
/

-- #########################################################
-- #########################################################
-- Alter_FacialFinCaption_Add_StoredPaymentContent.sql
-- #########################################################
-- #########################################################

/* 
    STOREDPAYMENTCONTENT ( ,  )
*/
ALTER TABLE TB_FACIALFINCAPTION ADD (
  STOREDPAYMENTCONTENT VARCHAR2(4000)
)
/

CREATE OR REPLACE VIEW FACIALFINCAPTION (
  ID,
  DOCNUMBER,
  SOURCEDOCNUM,
  PAYDATE,
  ACCEPTDATE,
  DOCUMENTDATE,
  REESTRDATE,
  CREDIT,
  SOURCEACCOUNT,
  SOURCEFACIALACC_CLS,
  DESTACCOUNT,
  DESTFACIALACC_CLS,
  PROGINDEX,
  ARHIVEDOC,
  PAYSYMBOLCLS,
  PAYTYPECLS,
  NOTE,
  PERIOD,
  PAYPRIORITY,
  TYPEOPERATIONCLS,
  BUHPAYMENTCLS,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  BUDGETREF,
  RECORDINDEX,
  SENDERID,
  SENDERRECORDID,
  REESTR_REF,
  REJECT_CLS,
  REJECTCAUSE,
  CLIENTBANKNUMBER,
  CRYPTOSTATUS,
  TRUSTNUMBER,
  LINKEDDOCUMENT,
  BNKRECORDID,
  SUBPROGINDEX,
  DOCUMENTSTATE,
  USERSVISA,
  TREASUARYDOCSTATECLS,
  DEPARTMENTCLS,
  NDS,
  TAXNOTE,
  MANAGERBID,
  BIDNUMBER,
  GROUPID,
  GROUPSUMMA,
  DOCSTATEREF,
  LASTEXTRCHANGE,
  FAXDOCCOUNT,
  STIMATEID,
  INTEGRATEDDOCREF,
  REQUESTNUMBER,
  REQUESTDATE,
  RVERSION,
  FEDERALFUNDSREF,
  ELDOCREF,
  BUHOPERATIONCLS,
  CLSTYPE,
  OPERATIONDIRECTION,
  SOURCETYPE,
  DESTTYPE,
  CARDNUMBER,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  CASHIERPERSONALINFO,
  BIDDATE,
  CARDREF,
  SOURCESTOREDPAYMENTPROPS,
  DESTSTOREDPAYMENTPROPS,
  STOREDPAYMENTNOTE,
  DOCCHANGEDATE,
  UINCODE,
  DOCOSN,
  SIGNERS,
  DESTCLSTYPE,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  AUTOSANCTION,
  STOREDPAYMENTCONTENT)
AS
  SELECT
    ID,
    DOCNUMBER,
    SOURCEDOCNUM,
    PAYDATE,
    ACCEPTDATE,
    DOCUMENTDATE,
    REESTRDATE,
    CREDIT,
    SOURCEACCOUNT,
    SOURCEFACIALACC_CLS,
    DESTACCOUNT,
    DESTFACIALACC_CLS,
    PROGINDEX,
    ARHIVEDOC,
    PAYSYMBOLCLS,
    PAYTYPECLS,
    NOTE,
    PERIOD,
    PAYPRIORITY,
    TYPEOPERATIONCLS,
    BUHPAYMENTCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    RECORDINDEX,
    SENDERID,
    SENDERRECORDID,
    REESTR_REF,
    REJECT_CLS,
    REJECTCAUSE,
    CLIENTBANKNUMBER,
    CRYPTOSTATUS,
    TRUSTNUMBER,
    LINKEDDOCUMENT,
    BNKRECORDID,
    SUBPROGINDEX,
    DOCUMENTSTATE,
    USERSVISA,
    TREASUARYDOCSTATECLS,
    DEPARTMENTCLS,
    NDS,
    TAXNOTE,
    MANAGERBID,
    BIDNUMBER,
    GROUPID,
    GROUPSUMMA,
    DOCSTATEREF,
    LASTEXTRCHANGE,
    FAXDOCCOUNT,
    STIMATEID,
    INTEGRATEDDOCREF,
    REQUESTNUMBER,
    REQUESTDATE,
    RVERSION,
    FEDERALFUNDSREF,
    ELDOCREF,
    BUHOPERATIONCLS,
    CLSTYPE,
    OPERATIONDIRECTION,
    SOURCETYPE,
    DESTTYPE,
    CARDNUMBER,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    CASHIERPERSONALINFO,
    BIDDATE,
    CARDREF,
    SOURCESTOREDPAYMENTPROPS,
    DESTSTOREDPAYMENTPROPS,
    STOREDPAYMENTNOTE,
    DOCCHANGEDATE,
    UINCODE,
    DOCOSN,
    SIGNERS,
    DESTCLSTYPE,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    AUTOSANCTION,
    STOREDPAYMENTCONTENT
  FROM TB_FACIALFINCAPTION
/

CREATE OR REPLACE TRIGGER TR_FACIALFINCAPTION_ID
  INSTEAD OF DELETE
  ON FACIALFINCAPTION
  FOR EACH ROW
DECLARE
  reestrAccepted1$ NUMBER(10);
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_FACIALFINCAPTION_BD)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

 /*       */
  DELETE FROM FacialFinDetail
        WHERE (RecordIndex = :OLD.ID);

-- - - - - - - - - - - - -
-- BD_5 (TR_FACIALFINCAPTION_BD_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (((:old.progIndex = 63) or (:old.progIndex = 64) or
  (:old.progIndex = 68) or (:old.progIndex = 70))
  and (:old.REESTR_REF is not null)) then
    BEGIN
      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id = :old.REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrDelete');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BD_6 (TR_FACIALFINCAPTION_BD_6)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(id ) INTO CNT$1
  from paydocexchange where ((paydocref=:old.id)and(status<>0)and(TypeInf BETWEEN 0 and 10)) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    RaiseException('ex_CannotChangeSended');
  else
    delete from PayDocExchange where paydocref = :old.id;
  END IF;

-- - - - - - - - - - - - -
-- BD_430 (TR_FACIALFINCAPTION_BD_430)
-- Create 04.12.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

  /*         */
  UPDATE FaxDocs
     SET OwnerID = NULL
  WHERE OwnerID = :OLD.ID;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_FACIALFINCAPTION
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_70 (TR_FACIALFINCAPTION_AD_70)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

--   /     
  IF (:OLD.SubProgIndex = 416) THEN
    UPDATE Guarantee
       SET SubRecordIndex = NULL,
           SubProgIndex = 0
     WHERE SubRecordIndex = :OLD.ID;
  END IF;

-- - - - - - - - - - - - -
-- AD_200 (TR_FACIALFINCAPTION_AD_200)
-- Create 27.08.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

  /*       */
  delete from StateJumpHistory
    where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_300 (TR_FACIALFINCAPTION_AD_300)
-- Create 24.02.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

  IF (:OLD.FaxDocCount > 0) THEN
--    :old.FaxDocCount := :old.FaxDocCount;
    NULL;
  ELSE
    UPDATE FaxDocs
       SET OwnerID = NULL
     WHERE OwnerID = :OLD.ID;
  END IF;

-- - - - - - - - - - - - -
-- AD_500 (TR_FACIALFINCAPTION_AD_500)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

  INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate, ProgIndex, Summa)
    VALUES (23, :OLD.ID, SYSDATE, :OLD.ProgIndex, :OLD.Credit);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINCAPTION_II
  INSTEAD OF INSERT
  ON FACIALFINCAPTION
  FOR EACH ROW
DECLARE
  new$ID FACIALFINCAPTION.ID%TYPE := :NEW.ID;
  new$DOCNUMBER FACIALFINCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SOURCEDOCNUM FACIALFINCAPTION.SOURCEDOCNUM%TYPE := :NEW.SOURCEDOCNUM;
  new$PAYDATE FACIALFINCAPTION.PAYDATE%TYPE := :NEW.PAYDATE;
  new$ACCEPTDATE FACIALFINCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCUMENTDATE FACIALFINCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$REESTRDATE FACIALFINCAPTION.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$CREDIT FACIALFINCAPTION.CREDIT%TYPE := :NEW.CREDIT;
  new$SOURCEACCOUNT FACIALFINCAPTION.SOURCEACCOUNT%TYPE := :NEW.SOURCEACCOUNT;
  new$SOURCEFACIALACC_CLS FACIALFINCAPTION.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$DESTACCOUNT FACIALFINCAPTION.DESTACCOUNT%TYPE := :NEW.DESTACCOUNT;
  new$DESTFACIALACC_CLS FACIALFINCAPTION.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$PROGINDEX FACIALFINCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$ARHIVEDOC FACIALFINCAPTION.ARHIVEDOC%TYPE := :NEW.ARHIVEDOC;
  new$PAYSYMBOLCLS FACIALFINCAPTION.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$PAYTYPECLS FACIALFINCAPTION.PAYTYPECLS%TYPE := :NEW.PAYTYPECLS;
  new$NOTE FACIALFINCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$PERIOD FACIALFINCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$PAYPRIORITY FACIALFINCAPTION.PAYPRIORITY%TYPE := :NEW.PAYPRIORITY;
  new$TYPEOPERATIONCLS FACIALFINCAPTION.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$BUHPAYMENTCLS FACIALFINCAPTION.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$CREATERUSER FACIALFINCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF FACIALFINCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECORDINDEX FACIALFINCAPTION.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$SENDERID FACIALFINCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REESTR_REF FACIALFINCAPTION.REESTR_REF%TYPE := :NEW.REESTR_REF;
  new$REJECT_CLS FACIALFINCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CLIENTBANKNUMBER FACIALFINCAPTION.CLIENTBANKNUMBER%TYPE := :NEW.CLIENTBANKNUMBER;
  new$CRYPTOSTATUS FACIALFINCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$TRUSTNUMBER FACIALFINCAPTION.TRUSTNUMBER%TYPE := :NEW.TRUSTNUMBER;
  new$LINKEDDOCUMENT FACIALFINCAPTION.LINKEDDOCUMENT%TYPE := :NEW.LINKEDDOCUMENT;
  new$BNKRECORDID FACIALFINCAPTION.BNKRECORDID%TYPE := :NEW.BNKRECORDID;
  new$SUBPROGINDEX FACIALFINCAPTION.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$DOCUMENTSTATE FACIALFINCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA FACIALFINCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$TREASUARYDOCSTATECLS FACIALFINCAPTION.TREASUARYDOCSTATECLS%TYPE := :NEW.TREASUARYDOCSTATECLS;
  new$DEPARTMENTCLS FACIALFINCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$NDS FACIALFINCAPTION.NDS%TYPE := :NEW.NDS;
  new$TAXNOTE FACIALFINCAPTION.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$MANAGERBID FACIALFINCAPTION.MANAGERBID%TYPE := :NEW.MANAGERBID;
  new$BIDNUMBER FACIALFINCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$GROUPID FACIALFINCAPTION.GROUPID%TYPE := :NEW.GROUPID;
  new$GROUPSUMMA FACIALFINCAPTION.GROUPSUMMA%TYPE := :NEW.GROUPSUMMA;
  new$DOCSTATEREF FACIALFINCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$LASTEXTRCHANGE FACIALFINCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$FAXDOCCOUNT FACIALFINCAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$STIMATEID FACIALFINCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$INTEGRATEDDOCREF FACIALFINCAPTION.INTEGRATEDDOCREF%TYPE := :NEW.INTEGRATEDDOCREF;
  new$REQUESTNUMBER FACIALFINCAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$REQUESTDATE FACIALFINCAPTION.REQUESTDATE%TYPE := :NEW.REQUESTDATE;
  new$RVERSION FACIALFINCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$FEDERALFUNDSREF FACIALFINCAPTION.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$ELDOCREF FACIALFINCAPTION.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$BUHOPERATIONCLS FACIALFINCAPTION.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CLSTYPE FACIALFINCAPTION.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$OPERATIONDIRECTION FACIALFINCAPTION.OPERATIONDIRECTION%TYPE := :NEW.OPERATIONDIRECTION;
  new$SOURCETYPE FACIALFINCAPTION.SOURCETYPE%TYPE := :NEW.SOURCETYPE;
  new$DESTTYPE FACIALFINCAPTION.DESTTYPE%TYPE := :NEW.DESTTYPE;
  new$CARDNUMBER FACIALFINCAPTION.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$ISBLOCKED FACIALFINCAPTION.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINCAPTION.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINCAPTION.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINCAPTION.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$CASHIERPERSONALINFO FACIALFINCAPTION.CASHIERPERSONALINFO%TYPE := :NEW.CASHIERPERSONALINFO;
  new$BIDDATE FACIALFINCAPTION.BIDDATE%TYPE := :NEW.BIDDATE;
  new$CARDREF FACIALFINCAPTION.CARDREF%TYPE := :NEW.CARDREF;
  new$SOURCESTOREDPAYMENTPROPS FACIALFINCAPTION.SOURCESTOREDPAYMENTPROPS%TYPE := :NEW.SOURCESTOREDPAYMENTPROPS;
  new$DESTSTOREDPAYMENTPROPS FACIALFINCAPTION.DESTSTOREDPAYMENTPROPS%TYPE := :NEW.DESTSTOREDPAYMENTPROPS;
  new$STOREDPAYMENTNOTE FACIALFINCAPTION.STOREDPAYMENTNOTE%TYPE := :NEW.STOREDPAYMENTNOTE;
  new$DOCCHANGEDATE FACIALFINCAPTION.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$UINCODE FACIALFINCAPTION.UINCODE%TYPE := :NEW.UINCODE;
  new$DOCOSN FACIALFINCAPTION.DOCOSN%TYPE := :NEW.DOCOSN;
  new$SIGNERS FACIALFINCAPTION.SIGNERS%TYPE := :NEW.SIGNERS;
  new$DESTCLSTYPE FACIALFINCAPTION.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SENDERIDKEY FACIALFINCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$AUTOSANCTION FACIALFINCAPTION.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$STOREDPAYMENTCONTENT FACIALFINCAPTION.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
--
  UseFax$ NUMBER(10);
  pdt$ NUMBER(10);
  reestrAccepted1$ NUMBER(10);
  DocNumber$ NUMBER(10);
  CmpFacialAcc_Cls$ NUMBER(10);
  PIndex1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALFINCAPTION_BI)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$credit is null)then 
    new$credit:= 0;
  END IF;
  if (new$ArhiveDoc is null) then 
    new$ArhiveDoc:= 0;
  END IF;
  if (new$PayTypeCls is null) then 
    new$PayTypeCls:= 0;
  END IF;
  if (new$BuhPaymentCls is null) then 
    new$BuhPaymentCls:= 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$ClsType is null) then 
    new$ClsType := 0;
  END IF;
  if (new$DestClsType is null) then 
    new$DestClsType := new$ClsType;
  END IF;
  if (new$SourceFacialAcc_CLS is null) then 
    new$SourceFacialAcc_CLS:= 0;
  END IF;
  if (new$DestFacialAcc_CLS is null) then 
    new$DestFacialAcc_CLS:= 0;
  END IF;
  if (new$FaxDocCount is null) then 
    new$FaxDocCount := 0;
  END IF;
  if (new$OperationDirection is null) then 
    new$OperationDirection := 0;
  END IF;
  if (new$OperationDirection = 0) then
    new$SourceType := 1;
    new$DestType := 1;
     
  else
    if (new$OperationDirection = 1) then
      new$SourceType := 1;
      new$DestType := -1;
         
    else
      if (new$OperationDirection = 2) then
        new$SourceType := -1;
        new$DestType := 1;
             
      else
        new$SourceType := -1;
        new$DestType := -1;
             
      END IF;
    END IF;
  END IF;
  if (new$DepartmentCls is null) then
    GetIntConst(30, 20,DocNumber$); 
    if (DocNumber$ is null) then 
      new$DepartmentCls:= 0;
           
    else 
      new$DepartmentCls:= DocNumber$;
       
    END IF;
  END IF;
   
  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    PIndex1$ := new$ProgIndex;
    if (PIndex1$=60) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*    .*/
    END IF;
    if (PIndex1$=61) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*       */
    END IF;
    if (PIndex1$=62) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*    */
    END IF;
    if (PIndex1$=63) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*     */
    END IF;
    if (PIndex1$=64) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*    */
    END IF;
    if (PIndex1$=65) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*  , */
    END IF;
    if (PIndex1$=66) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*   ,  - */
    END IF;
    if (PIndex1$=67) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*    */
    END IF;
    if (PIndex1$=68) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*   \ */
    END IF;
    if (PIndex1$=69) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*    \ */
    END IF;
    if (PIndex1$=70) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*   \ */
    END IF;
    if (PIndex1$=71) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*    \ */
    END IF;
    if (PIndex1$=73) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*   */
    END IF;
    if (PIndex1$=75) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*  */
    END IF;
    if (PIndex1$=76) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*  */
    END IF;
    BEGIN

      select fa.BudgetRef      into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = CmpFacialAcc_Cls$

      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null )) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_1 (TR_FACIALFINCAPTION_BI_1)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --   -     
   IF (new$GroupID IS NULL) THEN new$GroupID := new$ID; END IF;
   IF (new$GroupSumma IS NULL) THEN new$GroupSumma := 0; END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_FACIALFINCAPTION_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (((new$progIndex = 63) or (new$progIndex = 64) or
  (new$progIndex = 68) or (new$progIndex = 70))
  and (new$REESTR_REF is not null)) then
    BEGIN
      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where 
      id = new$REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
        
    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrInsert');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_FacialFinCaption_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;
        
  else
    new$SenderIDKey := new$SenderID;
  END IF;
      
  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;
        
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_16 (TR_FACIALFINCAPTION_BI_16)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*      .    FacialFinCaption
             */
   IF (new$Reestr_ref IS NULL) THEN
      new$SourceDocNum := '';
      new$ReestrDate := NULL;
   ELSE
      BEGIN
         SELECT ffr.ReestrNumber, ffr.ReestrDate
           INTO new$SourceDocNum, new$ReestrDate
           FROM FacialFinReestr ffr
          WHERE ffr.ID = new$Reestr_ref;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            new$SourceDocNum := NULL;
            new$ReestrDate := NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BI_430 (TR_FACIALFINCAPTION_BI_430)
-- Create 04.12.2004
-- Last update 11.10.2006
-- - - - - - - - - - - - -

  IF (NEW$SenderID IS NOT NULL) THEN
    pdt$ := NULL;
    IF (NEW$progindex = 63) THEN pdt$ := 302; END IF;
    IF (NEW$progindex = 66) THEN pdt$ := 301; END IF;
    IF (NEW$progindex = 64) THEN pdt$ := 304; END IF;

    /*       */
    GetIntConst(30, 19, UseFax$);
    IF ((new$BidNumber IS NULL) AND (UseFax$ = 1)) THEN
      new$BidNumber := new$DocNumber;
    END IF;
    SELECT COUNT(*) INTO new$FaxDocCount
    FROM FaxDocs
      WHERE (OwnerDocNumber=new$BidNumber)
        AND (ClientID=new$SenderID)
        AND (FacialAcc_Cls=new$SourceFacialAcc_CLS)
        AND (OwnerDate = new$DocumentDate)
        AND (PrimaryDocType = PDT$);
  ELSE
    new$FaxDocCount := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALFINCAPTION_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$DocChangeDate := new$UpdateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALFINCAPTION (
    ID,
    DOCNUMBER,
    SOURCEDOCNUM,
    PAYDATE,
    ACCEPTDATE,
    DOCUMENTDATE,
    REESTRDATE,
    CREDIT,
    SOURCEACCOUNT,
    SOURCEFACIALACC_CLS,
    DESTACCOUNT,
    DESTFACIALACC_CLS,
    PROGINDEX,
    ARHIVEDOC,
    PAYSYMBOLCLS,
    PAYTYPECLS,
    NOTE,
    PERIOD,
    PAYPRIORITY,
    TYPEOPERATIONCLS,
    BUHPAYMENTCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    RECORDINDEX,
    SENDERID,
    SENDERRECORDID,
    REESTR_REF,
    REJECT_CLS,
    REJECTCAUSE,
    CLIENTBANKNUMBER,
    CRYPTOSTATUS,
    TRUSTNUMBER,
    LINKEDDOCUMENT,
    BNKRECORDID,
    SUBPROGINDEX,
    DOCUMENTSTATE,
    USERSVISA,
    TREASUARYDOCSTATECLS,
    DEPARTMENTCLS,
    NDS,
    TAXNOTE,
    MANAGERBID,
    BIDNUMBER,
    GROUPID,
    GROUPSUMMA,
    DOCSTATEREF,
    LASTEXTRCHANGE,
    FAXDOCCOUNT,
    STIMATEID,
    INTEGRATEDDOCREF,
    REQUESTNUMBER,
    REQUESTDATE,
    RVERSION,
    FEDERALFUNDSREF,
    ELDOCREF,
    BUHOPERATIONCLS,
    CLSTYPE,
    OPERATIONDIRECTION,
    SOURCETYPE,
    DESTTYPE,
    CARDNUMBER,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    CASHIERPERSONALINFO,
    BIDDATE,
    CARDREF,
    SOURCESTOREDPAYMENTPROPS,
    DESTSTOREDPAYMENTPROPS,
    STOREDPAYMENTNOTE,
    DOCCHANGEDATE,
    UINCODE,
    DOCOSN,
    SIGNERS,
    DESTCLSTYPE,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    AUTOSANCTION,
    STOREDPAYMENTCONTENT
  ) VALUES (
    new$ID,
    new$DOCNUMBER,
    new$SOURCEDOCNUM,
    new$PAYDATE,
    new$ACCEPTDATE,
    new$DOCUMENTDATE,
    new$REESTRDATE,
    new$CREDIT,
    new$SOURCEACCOUNT,
    new$SOURCEFACIALACC_CLS,
    new$DESTACCOUNT,
    new$DESTFACIALACC_CLS,
    new$PROGINDEX,
    new$ARHIVEDOC,
    new$PAYSYMBOLCLS,
    new$PAYTYPECLS,
    new$NOTE,
    new$PERIOD,
    new$PAYPRIORITY,
    new$TYPEOPERATIONCLS,
    new$BUHPAYMENTCLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$RECORDINDEX,
    new$SENDERID,
    new$SENDERRECORDID,
    new$REESTR_REF,
    new$REJECT_CLS,
    new$REJECTCAUSE,
    new$CLIENTBANKNUMBER,
    new$CRYPTOSTATUS,
    new$TRUSTNUMBER,
    new$LINKEDDOCUMENT,
    new$BNKRECORDID,
    new$SUBPROGINDEX,
    new$DOCUMENTSTATE,
    new$USERSVISA,
    new$TREASUARYDOCSTATECLS,
    new$DEPARTMENTCLS,
    new$NDS,
    new$TAXNOTE,
    new$MANAGERBID,
    new$BIDNUMBER,
    new$GROUPID,
    new$GROUPSUMMA,
    new$DOCSTATEREF,
    new$LASTEXTRCHANGE,
    new$FAXDOCCOUNT,
    new$STIMATEID,
    new$INTEGRATEDDOCREF,
    new$REQUESTNUMBER,
    new$REQUESTDATE,
    new$RVERSION,
    new$FEDERALFUNDSREF,
    new$ELDOCREF,
    new$BUHOPERATIONCLS,
    new$CLSTYPE,
    new$OPERATIONDIRECTION,
    new$SOURCETYPE,
    new$DESTTYPE,
    new$CARDNUMBER,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$CASHIERPERSONALINFO,
    new$BIDDATE,
    new$CARDREF,
    new$SOURCESTOREDPAYMENTPROPS,
    new$DESTSTOREDPAYMENTPROPS,
    new$STOREDPAYMENTNOTE,
    new$DOCCHANGEDATE,
    new$UINCODE,
    new$DOCOSN,
    new$SIGNERS,
    new$DESTCLSTYPE,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$AUTOSANCTION,
    new$STOREDPAYMENTCONTENT);

-- - - - - - - - - - - - -
-- AI_430 (TR_FACIALFINCAPTION_AI_430)
-- Create 04.12.2004
-- Last update 11.10.2006
-- - - - - - - - - - - - -

  IF (new$SenderID IS NOT NULL) THEN
      /*       */
      pdt$ := NULL;
      IF (new$progindex = 63) THEN pdt$ := 302; END IF;
      IF (new$progindex = 66) THEN pdt$ := 301; END IF;
      IF (new$progindex = 64) THEN pdt$ := 304; END IF;

        UPDATE FaxDocs
            SET OwnerId=new$id
        WHERE
            (OwnerDocNumber=new$BidNumber)
            AND (ClientID=new$SenderID)
            AND (FacialAcc_Cls=new$SourceFacialAcc_CLS)
            AND (OwnerDate = new$DocumentDate)
            AND (primarydoctype = pdt$);
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALFINCAPTION_AI_500)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
     WHERE (TableID = 23) AND (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINCAPTION_IU
  INSTEAD OF UPDATE
  ON FACIALFINCAPTION
  FOR EACH ROW
DECLARE
  new$ID FACIALFINCAPTION.ID%TYPE := :NEW.ID;
  new$DOCNUMBER FACIALFINCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SOURCEDOCNUM FACIALFINCAPTION.SOURCEDOCNUM%TYPE := :NEW.SOURCEDOCNUM;
  new$PAYDATE FACIALFINCAPTION.PAYDATE%TYPE := :NEW.PAYDATE;
  new$ACCEPTDATE FACIALFINCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCUMENTDATE FACIALFINCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$REESTRDATE FACIALFINCAPTION.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$CREDIT FACIALFINCAPTION.CREDIT%TYPE := :NEW.CREDIT;
  new$SOURCEACCOUNT FACIALFINCAPTION.SOURCEACCOUNT%TYPE := :NEW.SOURCEACCOUNT;
  new$SOURCEFACIALACC_CLS FACIALFINCAPTION.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$DESTACCOUNT FACIALFINCAPTION.DESTACCOUNT%TYPE := :NEW.DESTACCOUNT;
  new$DESTFACIALACC_CLS FACIALFINCAPTION.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$PROGINDEX FACIALFINCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$ARHIVEDOC FACIALFINCAPTION.ARHIVEDOC%TYPE := :NEW.ARHIVEDOC;
  new$PAYSYMBOLCLS FACIALFINCAPTION.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$PAYTYPECLS FACIALFINCAPTION.PAYTYPECLS%TYPE := :NEW.PAYTYPECLS;
  new$NOTE FACIALFINCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$PERIOD FACIALFINCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$PAYPRIORITY FACIALFINCAPTION.PAYPRIORITY%TYPE := :NEW.PAYPRIORITY;
  new$TYPEOPERATIONCLS FACIALFINCAPTION.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$BUHPAYMENTCLS FACIALFINCAPTION.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$CREATERUSER FACIALFINCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF FACIALFINCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECORDINDEX FACIALFINCAPTION.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$SENDERID FACIALFINCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REESTR_REF FACIALFINCAPTION.REESTR_REF%TYPE := :NEW.REESTR_REF;
  new$REJECT_CLS FACIALFINCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CLIENTBANKNUMBER FACIALFINCAPTION.CLIENTBANKNUMBER%TYPE := :NEW.CLIENTBANKNUMBER;
  new$CRYPTOSTATUS FACIALFINCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$TRUSTNUMBER FACIALFINCAPTION.TRUSTNUMBER%TYPE := :NEW.TRUSTNUMBER;
  new$LINKEDDOCUMENT FACIALFINCAPTION.LINKEDDOCUMENT%TYPE := :NEW.LINKEDDOCUMENT;
  new$BNKRECORDID FACIALFINCAPTION.BNKRECORDID%TYPE := :NEW.BNKRECORDID;
  new$SUBPROGINDEX FACIALFINCAPTION.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$DOCUMENTSTATE FACIALFINCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA FACIALFINCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$TREASUARYDOCSTATECLS FACIALFINCAPTION.TREASUARYDOCSTATECLS%TYPE := :NEW.TREASUARYDOCSTATECLS;
  new$DEPARTMENTCLS FACIALFINCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$NDS FACIALFINCAPTION.NDS%TYPE := :NEW.NDS;
  new$TAXNOTE FACIALFINCAPTION.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$MANAGERBID FACIALFINCAPTION.MANAGERBID%TYPE := :NEW.MANAGERBID;
  new$BIDNUMBER FACIALFINCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$GROUPID FACIALFINCAPTION.GROUPID%TYPE := :NEW.GROUPID;
  new$GROUPSUMMA FACIALFINCAPTION.GROUPSUMMA%TYPE := :NEW.GROUPSUMMA;
  new$DOCSTATEREF FACIALFINCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$LASTEXTRCHANGE FACIALFINCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$FAXDOCCOUNT FACIALFINCAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$STIMATEID FACIALFINCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$INTEGRATEDDOCREF FACIALFINCAPTION.INTEGRATEDDOCREF%TYPE := :NEW.INTEGRATEDDOCREF;
  new$REQUESTNUMBER FACIALFINCAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$REQUESTDATE FACIALFINCAPTION.REQUESTDATE%TYPE := :NEW.REQUESTDATE;
  new$RVERSION FACIALFINCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$FEDERALFUNDSREF FACIALFINCAPTION.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$ELDOCREF FACIALFINCAPTION.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$BUHOPERATIONCLS FACIALFINCAPTION.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CLSTYPE FACIALFINCAPTION.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$OPERATIONDIRECTION FACIALFINCAPTION.OPERATIONDIRECTION%TYPE := :NEW.OPERATIONDIRECTION;
  new$SOURCETYPE FACIALFINCAPTION.SOURCETYPE%TYPE := :NEW.SOURCETYPE;
  new$DESTTYPE FACIALFINCAPTION.DESTTYPE%TYPE := :NEW.DESTTYPE;
  new$CARDNUMBER FACIALFINCAPTION.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$ISBLOCKED FACIALFINCAPTION.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINCAPTION.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINCAPTION.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINCAPTION.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$CASHIERPERSONALINFO FACIALFINCAPTION.CASHIERPERSONALINFO%TYPE := :NEW.CASHIERPERSONALINFO;
  new$BIDDATE FACIALFINCAPTION.BIDDATE%TYPE := :NEW.BIDDATE;
  new$CARDREF FACIALFINCAPTION.CARDREF%TYPE := :NEW.CARDREF;
  new$SOURCESTOREDPAYMENTPROPS FACIALFINCAPTION.SOURCESTOREDPAYMENTPROPS%TYPE := :NEW.SOURCESTOREDPAYMENTPROPS;
  new$DESTSTOREDPAYMENTPROPS FACIALFINCAPTION.DESTSTOREDPAYMENTPROPS%TYPE := :NEW.DESTSTOREDPAYMENTPROPS;
  new$STOREDPAYMENTNOTE FACIALFINCAPTION.STOREDPAYMENTNOTE%TYPE := :NEW.STOREDPAYMENTNOTE;
  new$DOCCHANGEDATE FACIALFINCAPTION.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$UINCODE FACIALFINCAPTION.UINCODE%TYPE := :NEW.UINCODE;
  new$DOCOSN FACIALFINCAPTION.DOCOSN%TYPE := :NEW.DOCOSN;
  new$SIGNERS FACIALFINCAPTION.SIGNERS%TYPE := :NEW.SIGNERS;
  new$DESTCLSTYPE FACIALFINCAPTION.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SENDERIDKEY FACIALFINCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$AUTOSANCTION FACIALFINCAPTION.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$STOREDPAYMENTCONTENT FACIALFINCAPTION.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
--
  SourceFacialAcc_CLS$ NUMBER(10);
  DestFacialAcc_CLS$ NUMBER(10);
  CNT$1 NUMBER(10);
  reestrAccepted1$ NUMBER(10);
  IsReject1$ NUMBER(10);
  UseFax$ NUMBER(10);
  DocNumber$ NUMBER(10);
  DetCount$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINCAPTION_BU)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is not null) then
    /*      */
    GetIntConst(30, 19,UseFax$);
    if ((new$BidNumber is null) and (UseFax$ = 1)) then
      new$BidNumber:= new$DocNumber;

    END IF;
  END IF;
  if (new$credit is null)then
    new$credit:= 0;
  END IF;
  if (new$ArhiveDoc is null) then
    new$ArhiveDoc:= 0;
  END IF;
  if (new$PayTypeCls is null) then
    new$PayTypeCls:= 0;
  END IF;
  if (new$BuhPaymentCls is null) then
    new$BuhPaymentCls:= 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$ClsType is null) then
    new$ClsType := 0;
  END IF;
  if (new$DestClsType is null) then
    new$DestClsType := new$ClsType;
  END IF;
  if (new$SourceFacialAcc_CLS is null) then
    new$SourceFacialAcc_CLS:= 0;
  END IF;
  if (new$DestFacialAcc_CLS is null) then
    new$DestFacialAcc_CLS:= 0;
  END IF;
  if (new$FaxDocCount is null) then
    new$FaxDocCount := 0;
  END IF;
  if (new$OperationDirection is null) then
    new$OperationDirection := 0;
  END IF;
  if (new$OperationDirection <> :old.OperationDirection) then
    if (new$OperationDirection = 0) then
      new$SourceType := 1;
      new$DestType := 1;

    else
      if (new$OperationDirection = 1) then
        new$SourceType := 1;
        new$DestType := -1;

      else
        if (new$OperationDirection = 2) then
          new$SourceType := -1;
          new$DestType := 1;

        else
          new$SourceType := -1;
          new$DestType := -1;

        END IF;
      END IF;
    END IF;
  END IF;
  if (new$DepartmentCls is null) then
    GetIntConst(30, 20,DocNumber$);
    if (DocNumber$ is null) then
      new$DepartmentCls:= 0;

    else
      new$DepartmentCls:= DocNumber$;

    END IF;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount$ from FacialFinDetail where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_Cls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_1 (TR_FACIALFINCAPTION_BU_1)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --   -     
   IF (new$GroupID IS NULL) THEN new$GroupID := new$ID; END IF;
   IF (new$GroupSumma IS NULL) THEN new$GroupSumma := 0; END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_FACIALFINCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (not (    ((new$progindex = 63) or (new$progindex = 64) or (new$progindex = 68) or (new$progindex = 70))
  and (   (((new$credit - :old.credit)>0.001)or((new$credit - :old.credit)<-0.001))
  or (new$sourcefacialacc_cls <> :old.sourcefacialacc_cls)
  or (
  ((new$sourceaccount is null) and (:old.sourceaccount is not null)) or
  ((new$sourceaccount is not null) and (:old.sourceaccount is null)) or
  ((new$sourceaccount <> :old.sourceaccount ) and (:old.sourceaccount is not null) and (new$sourceaccount is not null))
  )
  or (
  ((new$destaccount is null) and (:old.destaccount is not null)) or
  ((new$destaccount is not null) and (:old.destaccount is null)) or
  ((new$destaccount <> :old.destaccount ) and (:old.destaccount is not null) and (new$destaccount is not null))
  )
  or (    (:old.reestr_ref is null)
  and (new$reestr_ref is not null)
  )
  or (    (:old.reestr_ref is not null)
  and (new$reestr_ref is null)
  )
  or (:old.reestr_ref <> new$reestr_ref)
  )
  )
  )
  then /*      NULL */
    reestrAccepted1$ := 0;  /*   IB 4.2 */

  else
    BEGIN
      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id=new$REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrUpdate');
    END IF;
    BEGIN

      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id=:old.REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrUpdate');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_6 (TR_FACIALFINCAPTION_BU_6)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (:old.ProgIndex in(63,68,70)) then /*    */
    SELECT COUNT(id ) INTO CNT$1
    from paydocexchange where ((paydocref=:old.id)and(status<>0)and(TypeInf BETWEEN 0 and 10)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      if(/* (new.DOCNUMBER<>old.DOCNUMBER) or ((new.DOCNUMBER is NULL)and(not old.DOCNUMBER is NULL)) or ((old.DOCNUMBER is NULL)and(not new.DOCNUMBER is NULL)) or*/
      (new$SOURCEDOCNUM<>:old.SOURCEDOCNUM) or ((new$SOURCEDOCNUM is NULL)and(not :old.SOURCEDOCNUM is NULL)) or ((:old.SOURCEDOCNUM is NULL)and(not new$SOURCEDOCNUM is NULL)) or
      (new$PAYDATE<>:old.PAYDATE) or ((new$PAYDATE is NULL)and(not :old.PAYDATE is NULL)) or ((:old.PAYDATE is NULL)and(not new$PAYDATE is NULL))or
      /* (new.DOCUMENTDATE<>old.DOCUMENTDATE) or ((new.DOCUMENTDATE is NULL)and(not old.DOCUMENTDATE is NULL)) or ((old.DOCUMENTDATE is NULL)and(not new.DOCUMENTDATE is NULL))or*/
      (new$REESTRDATE<>:old.REESTRDATE) or ((new$REESTRDATE is NULL)and(not :old.REESTRDATE is NULL)) or ((:old.REESTRDATE is NULL)and(not new$REESTRDATE is NULL))or
      (((new$credit - :old.credit)>0.001)or((new$credit - :old.credit)<-0.001)) or
      (new$SOURCEACCOUNT<>:old.SOURCEACCOUNT) or
      (new$DESTACCOUNT<>:old.DESTACCOUNT) or
      (new$PAYTYPECLS<>:old.PAYTYPECLS) or
      (new$NOTE<>:old.NOTE) or  ((new$NOTE is NULL)and(not :old.NOTE is NULL)) or ((:old.NOTE is NULL)and(not new$NOTE is NULL))or
      (new$PAYPRIORITY<>:old.PAYPRIORITY) or ((new$PAYPRIORITY is NULL)and(not :old.PAYPRIORITY is NULL)) or ((:old.PAYPRIORITY is NULL)and(not new$PAYPRIORITY is NULL))or
      (new$REESTR_REF<>:old.REESTR_REF) or ((new$REESTR_REF is NULL)and(not :old.REESTR_REF is NULL)) or ((:old.REESTR_REF is NULL)and(not new$REESTR_REF is NULL))or
      (new$NDS<>:old.NDS) or ((new$NDS is NULL)and(not :old.NDS is NULL)) or ((:old.NDS is NULL)and(not new$NDS is NULL))or
      (new$TAXNOTE<>:old.TAXNOTE) or ((new$TAXNOTE is NULL)and(not :old.TAXNOTE is NULL)) or ((:old.TAXNOTE is NULL)and(not new$TAXNOTE is NULL)) )then
        RaiseException('ex_CannotChangeSended');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_FACIALFINCAPTION_BU_10)
-- Create 16.03.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$IntegratedDocRef IS NOT NULL) THEN
        /*           ,       
      /*    */
      IF (    (   (new$AcceptDate = :OLD.AcceptDate)
               OR ((new$AcceptDate IS NULL) AND (:OLD.AcceptDate IS NULL))
              )
          AND (   (new$Reject_CLS = :OLD.Reject_CLS)
               OR ((new$Reject_CLS IS NULL) AND (:OLD.Reject_CLS IS NULL))
              )
          AND (   (new$RejectCause = :OLD.RejectCause)
               OR ((new$RejectCause IS NULL) AND (:OLD.RejectCause IS NULL))
              )
          AND (   (new$TREASUARYDOCSTATECLS = :OLD.TREASUARYDOCSTATECLS)
               OR (    (new$TREASUARYDOCSTATECLS IS NULL)
                   AND (:OLD.TREASUARYDOCSTATECLS IS NULL)
                  )
              )
          AND (   (new$DOCSTATEREF = :OLD.DOCSTATEREF)
               OR ((new$DOCSTATEREF IS NULL) AND (:OLD.DOCSTATEREF IS NULL))
              )
          AND (   (new$REESTR_REF = :OLD.REESTR_REF)
               OR ((new$REESTR_REF IS NULL) AND (:OLD.REESTR_REF IS NULL))
              )
          AND (new$SOURCEACCOUNT = :OLD.SOURCEACCOUNT)
          AND (new$DESTACCOUNT = :OLD.DESTACCOUNT)
         ) THEN
         new$AcceptDate := :OLD.AcceptDate;
      ELSE
         FOR R$ IN (SELECT fc.AcceptDate, fc.Reject_CLS, fc.RejectCause,
                           fc.TREASUARYDOCSTATECLS, fc.DOCSTATEREF,
                           fc.REESTR_REF, fc.SOURCEACCOUNT, fc.DESTACCOUNT
                      FROM FacialFinCaption fc
                     WHERE (fc.ID = :NEW.IntegratedDocRef)) LOOP
            IF (    (   (new$AcceptDate = R$.AcceptDate)
                     OR ((new$AcceptDate IS NULL) AND (R$.AcceptDate IS NULL)
                        )
                    )
                AND (   (new$Reject_CLS = R$.Reject_CLS)
                     OR ((new$Reject_CLS IS NULL) AND (R$.Reject_CLS IS NULL)
                        )
                    )
                AND (   (new$RejectCause = R$.RejectCause)
                     OR (    (new$RejectCause IS NULL)
                         AND (R$.RejectCause IS NULL)
                        )
                    )
                AND (   (new$TREASUARYDOCSTATECLS = R$.TREASUARYDOCSTATECLS)
                     OR (    (new$TREASUARYDOCSTATECLS IS NULL)
                         AND (R$.TREASUARYDOCSTATECLS IS NULL)
                        )
                    )
                AND (   (new$DOCSTATEREF = R$.DOCSTATEREF)
                     OR (    (new$DOCSTATEREF IS NULL)
                         AND (R$.DOCSTATEREF IS NULL)
                        )
                    )
                AND (   (new$REESTR_REF = R$.REESTR_REF)
                     OR ((new$REESTR_REF IS NULL) AND (R$.REESTR_REF IS NULL)
                        )
                    )
                AND (new$SOURCEACCOUNT = R$.SOURCEACCOUNT)
                AND (new$DESTACCOUNT = R$.DESTACCOUNT)
               ) THEN
               new$AcceptDate := R$.AcceptDate;
            ELSE
               RaiseException ('EX_CANNOTUPDATECHILDDOC');
            END IF;
         END LOOP;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_32 (TR_FACIALFINCAPTION_BU_32)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$Reestr_ref IS NULL)    /*    select ,  */
                              THEN
      new$SourceDocNum := '';
      new$ReestrDate := NULL;
   ELSIF (    (new$Reestr_ref = :OLD.Reestr_ref)
          AND (new$SourceDocNum = :OLD.SourceDocNum)
          AND (new$ReestrDate = :OLD.ReestrDate)
         ) THEN
/*          */
      NULL;
   ELSE
      BEGIN
         SELECT ffr.ReestrNumber, ffr.ReestrDate
           INTO new$SourceDocNum, new$ReestrDate
           FROM FacialFinReestr ffr
          WHERE ffr.ID = new$Reestr_ref;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            new$SourceDocNum := NULL;
            new$ReestrDate := NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BU_60 (T_FACIALFINCAPTION_BU_60)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF ((new$progindex = 60) AND (new$Credit <> :OLD.Credit)) THEN
      UPDATE FacialFinDetail
         SET Credit = new$Credit
       WHERE (RecordIndex = new$ID);
   END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_FACIALFINCAPTION_BU_70)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --         
   IF (new$SubProgIndex = 416) THEN
      UPDATE Guarantee
         SET AcceptDate = new$AcceptDate
       WHERE SubRecordIndex = new$ID;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (T_FACIALFINCAPTION_BU_100)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*   ,    */
   IF (    (   (:OLD.SourceFacialAcc_CLS <> new$SourceFacialAcc_CLS)
            OR (:OLD.DestFacialAcc_CLS <> new$DestFacialAcc_CLS)
           )
       AND ((new$SubProgIndex <> 1) OR (new$SubProgIndex IS NULL))
      ) THEN
      FOR R$ IN (SELECT ID, SourceFacialAcc_CLS, DestFacialAcc_CLS
                   FROM FacialFinDetail
                  WHERE RecordIndex = new$ID) LOOP
         IF (NOT (new$SourceFacialAcc_CLS = 0)) THEN
            SourceFacialAcc_CLS$ := new$SourceFacialAcc_CLS;
         ELSE
            SourceFacialAcc_CLS$ := R$.SourceFacialAcc_CLS;
         END IF;

         IF (NOT (new$DestFacialAcc_CLS = 0)) THEN
            DestFacialAcc_CLS$ := new$DestFacialAcc_CLS;
         ELSE
            DestFacialAcc_CLS$ := R$.DestFacialAcc_CLS;
         END IF;

         IF (:OLD.SourceFacialAcc_CLS <> new$SourceFacialAcc_CLS) THEN
            UPDATE FacialFinDetail
               SET SourceFacialAcc_CLS = SourceFacialAcc_CLS$,
                   RVersion = -1
             WHERE (ID = R$.ID);
         END IF;

         IF (:OLD.DestFacialAcc_CLS <> new$DestFacialAcc_CLS) THEN
            UPDATE FacialFinDetail
               SET DestFacialAcc_CLS = DestFacialAcc_CLS$,
                   RVersion = -1
             WHERE (ID = R$.ID);
         END IF;
      END LOOP;
   END IF;

   /*    / , 
           .*/
  IF (((NEW$IsBlocked <> :OLD.IsBlocked) OR
      ((NEW$IsBlocked IS NULL) AND (:OLD.IsBlocked IS NOT NULL)) OR
      ((NEW$IsBlocked IS NOT NULL) AND (:OLD.IsBlocked IS NULL))
     ) OR
     ((NEW$BlockedCause <> :OLD.BlockedCause) OR
      ((NEW$BlockedCause IS NULL) AND (:OLD.BlockedCause IS NOT NULL)) OR
      ((NEW$BlockedCause IS NOT NULL) AND (:OLD.BlockedCause IS NULL))
     ) OR
     ((NEW$UnBlockedDate <> :OLD.UnBlockedDate) OR
      ((NEW$UnBlockedDate IS NULL) AND (:OLD.UnBlockedDate IS NOT NULL)) OR
      ((NEW$UnBlockedDate IS NOT NULL) AND (:OLD.UnBlockedDate IS NULL))
     ) OR
     ((NEW$UnBlockedCause <> :OLD.UnBlockedCause) OR
      ((NEW$UnBlockedDate IS NULL) AND (:OLD.UnBlockedCause IS NOT NULL)) OR
      ((NEW$UnBlockedCause IS NOT NULL) AND (:OLD.UnBlockedCause IS NULL))
     )) THEN
     UPDATE FacialFinDetail ffd
     SET ffd.IsBlocked = NEW$IsBlocked, ffd.BlockedCause = NEW$BlockedCause,
         ffd.UnBlockedDate = NEW$UnBlockedDate, ffd.UnBlockedCause = NEW$UnBlockedCause
     WHERE ffd.recordindex = NEW$ID;
  end if;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINCAPTION_BU_210)
-- Create 27.08.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*      */
   IF (new$DOCSTATEREF <> :OLD.DOCSTATEREF) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DOCSTATEREF, new$DOCSTATEREF
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (T_FACIALFINCAPTION_BU_300)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  IsReject1$ := -1;
  if ((:old.Reject_CLS is null)and(new$Reject_CLS is not null)) then
    IsReject1$ := 1;

  else
    if ((:old.Reject_CLS is not null)and(new$Reject_CLS is null)) then
      IsReject1$ := 0;
    END IF;
  END IF;
  if (IsReject1$  <> -1) then
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID = new$ID;
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID in (select d.id from FacialFinDetail d where d.RecordIndex = new$id);

  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINCAPTION_BU_700)
-- Create 17.09.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINCAPTION SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    SOURCEDOCNUM = new$SOURCEDOCNUM,
    PAYDATE = new$PAYDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    REESTRDATE = new$REESTRDATE,
    CREDIT = new$CREDIT,
    SOURCEACCOUNT = new$SOURCEACCOUNT,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    DESTACCOUNT = new$DESTACCOUNT,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    PROGINDEX = new$PROGINDEX,
    ARHIVEDOC = new$ARHIVEDOC,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    PAYTYPECLS = new$PAYTYPECLS,
    NOTE = new$NOTE,
    PERIOD = new$PERIOD,
    PAYPRIORITY = new$PAYPRIORITY,
    TYPEOPERATIONCLS = new$TYPEOPERATIONCLS,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    RECORDINDEX = new$RECORDINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REESTR_REF = new$REESTR_REF,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CLIENTBANKNUMBER = new$CLIENTBANKNUMBER,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    TRUSTNUMBER = new$TRUSTNUMBER,
    LINKEDDOCUMENT = new$LINKEDDOCUMENT,
    BNKRECORDID = new$BNKRECORDID,
    SUBPROGINDEX = new$SUBPROGINDEX,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    TREASUARYDOCSTATECLS = new$TREASUARYDOCSTATECLS,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    NDS = new$NDS,
    TAXNOTE = new$TAXNOTE,
    MANAGERBID = new$MANAGERBID,
    BIDNUMBER = new$BIDNUMBER,
    GROUPID = new$GROUPID,
    GROUPSUMMA = new$GROUPSUMMA,
    DOCSTATEREF = new$DOCSTATEREF,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    FAXDOCCOUNT = new$FAXDOCCOUNT,
    STIMATEID = new$STIMATEID,
    INTEGRATEDDOCREF = new$INTEGRATEDDOCREF,
    REQUESTNUMBER = new$REQUESTNUMBER,
    REQUESTDATE = new$REQUESTDATE,
    RVERSION = new$RVERSION,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    ELDOCREF = new$ELDOCREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    CLSTYPE = new$CLSTYPE,
    OPERATIONDIRECTION = new$OPERATIONDIRECTION,
    SOURCETYPE = new$SOURCETYPE,
    DESTTYPE = new$DESTTYPE,
    CARDNUMBER = new$CARDNUMBER,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    CASHIERPERSONALINFO = new$CASHIERPERSONALINFO,
    BIDDATE = new$BIDDATE,
    CARDREF = new$CARDREF,
    SOURCESTOREDPAYMENTPROPS = new$SOURCESTOREDPAYMENTPROPS,
    DESTSTOREDPAYMENTPROPS = new$DESTSTOREDPAYMENTPROPS,
    STOREDPAYMENTNOTE = new$STOREDPAYMENTNOTE,
    DOCCHANGEDATE = new$DOCCHANGEDATE,
    UINCODE = new$UINCODE,
    DOCOSN = new$DOCOSN,
    SIGNERS = new$SIGNERS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    AUTOSANCTION = new$AUTOSANCTION,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_FACIALFINCAPTION_AU_10)
-- Create 05.03.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$ProgIndex = 72) THEN                       /*   */
      IF (    (   (new$AcceptDate = :OLD.AcceptDate)
               OR ((new$AcceptDate IS NULL) AND (:OLD.AcceptDate IS NULL))
              )
          AND (   (new$Reject_CLS = :OLD.Reject_CLS)
               OR ((new$Reject_CLS IS NULL) AND (:OLD.Reject_CLS IS NULL))
              )
          AND (   (new$RejectCause = :OLD.RejectCause)
               OR ((new$RejectCause IS NULL) AND (:OLD.RejectCause IS NULL))
              )
          AND (   (new$TREASUARYDOCSTATECLS = :OLD.TREASUARYDOCSTATECLS)
               OR (    (new$TREASUARYDOCSTATECLS IS NULL)
                   AND (:OLD.TREASUARYDOCSTATECLS IS NULL)
                  )
              )
          AND (   (new$DOCSTATEREF = :OLD.DOCSTATEREF)
               OR ((new$DOCSTATEREF IS NULL) AND (:OLD.DOCSTATEREF IS NULL))
              )
          AND (   (new$REESTR_REF = :OLD.REESTR_REF)
               OR ((new$REESTR_REF IS NULL) AND (:OLD.REESTR_REF IS NULL))
              )
          AND (new$SOURCEACCOUNT = :OLD.SOURCEACCOUNT)
          AND (new$DESTACCOUNT = :OLD.DESTACCOUNT)
         ) THEN
         NULL;                /*      new$AcceptDate := :old.AcceptDate;   */
      ELSE
         /*    ,      */
         UPDATE TB_FacialFinCaption
            SET AcceptDate = new$AcceptDate,
                Reject_CLS = new$Reject_CLS,
                RejectCause = new$RejectCause,
                TREASUARYDOCSTATECLS = new$TREASUARYDOCSTATECLS,
                DOCSTATEREF = new$DOCSTATEREF,
                REESTR_REF = new$REESTR_REF,
                SOURCEACCOUNT = new$SOURCEACCOUNT,
                DESTACCOUNT = new$DESTACCOUNT
          WHERE IntegratedDocRef = new$ID;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- AU_300 (TR_FACIALFINCAPTION_AU_300)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*          ,      */
  if ((new$AcceptDate <> :old.AcceptDate)or((new$AcceptDate is not null)and(:old.AcceptDate is null))
  or((new$AcceptDate is null)and(:old.AcceptDate is not null))) then
    update facialfindetail set
    AcceptDate = new$AcceptDate,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;
  if (new$BuhOperationCLS <> :old.BuhOperationCLS)  then
    update facialfindetail set
    BuhOperationCLS = new$BuhOperationCLS,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;
  if ((new$ClsType <> :old.ClsType)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$ClsType = 0) then
      update facialfindetail set
      SourceKD = 0,
      DestKD = 0,
      SourceIFS = 0,
      DestIFS = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 1) then
      update facialfindetail set
      SourceKD = 0,
      DestKD = 0,
      SourceKVSR = 0,
      SourceKFSR = 0,
      SourceKCSR = 0,
      SourceKVR = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 2) then
      update facialfindetail set
      SourceIFS = 0,
      DestIFS = 0,
      SourceKVSR = 0,
      SourceKFSR = 0,
      SourceKCSR = 0,
      SourceKVR = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);

    END IF;
  END IF;
  if ((new$DestClsType <> :old.DestClsType)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$DestClsType = 0) then
      update facialfindetail set
      DestKD = 0,
      DestIFS = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
    END IF;
    if (new$DestClsType = 1) then
      update facialfindetail set
      DestKD = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
    END IF;
    if (new$DestClsType = 2) then
      update facialfindetail set
      DestIFS = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINCAPTION_AU_500)
-- Create 28.04.2005
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (:NEW.ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (23, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
        WHERE (TableID = 23) AND (RecordId = :NEW.ID);
   END IF;

END;
/
commit work 
/

-- #########################################################
-- #########################################################
-- Alter_StoredAttrDetail_Add_Fields.sql
-- #########################################################
-- #########################################################

/*   NEEDEDS, ISHIDDEN, USERATTRNAME   STOREDATTRIBUTESDETAIL *//*      Name (Note50)  AttrCaption (Note255)*//*   ATTRIBUTE_REF  CONTAINER_REF  ATTRIBUTEFIELD  CONTAINERFIELD*//*   tr_storedattrdet_bi_0     DocFields   ,      */
ALTER TABLE STOREDATTRIBUTESDETAIL ADD (
  ATTRIBUTEFIELD NUMBER(10),/*     DocumentFields*/
    CHECK((ATTRIBUTEFIELD<=2147483647)AND(ATTRIBUTEFIELD>-2147483648)),
  CONTAINERFIELD NUMBER(10),/*     DocumentFields*/
    CHECK((CONTAINERFIELD<=2147483647)AND(CONTAINERFIELD>-2147483648)),
  NEEDEDS NUMBER(10),/*   */
    CHECK((NEEDEDS<=2147483647)AND(NEEDEDS>-2147483648)),
  ISHIDDEN NUMBER(10),/*  */
    CHECK((ISHIDDEN<=2147483647)AND(ISHIDDEN>-2147483648)),
  ATTRCAPTION VARCHAR2(255),/*    */
  USERATTRNAME VARCHAR2(50)/*    */
)
/
ALTER TABLE STOREDATTRIBUTESDETAIL DROP CONSTRAINT FK_STOREDATTRDET_ATTRIBUTE
/
DROP INDEX FK_STOREDATTRDET_ATTRIBUTE
/
ALTER TABLE STOREDATTRIBUTESDETAIL ADD (
  constraint FK_STOREDATTRDET_ATTRIBUTE
  foreign key (ATTRIBUTEFIELD)
  references TB_DOCUMENTFIELDS(ID)
)
/
CREATE INDEX FK_STOREDATTRDET_ATTRIBUTE ON STOREDATTRIBUTESDETAIL(ATTRIBUTEFIELD)
/
ALTER TABLE STOREDATTRIBUTESDETAIL DROP CONSTRAINT FK_STOREDATTRDET_CONTAINER
/
DROP INDEX FK_STOREDATTRDET_CONTAINER
/
ALTER TABLE STOREDATTRIBUTESDETAIL ADD (
  constraint FK_STOREDATTRDET_CONTAINER
  foreign key (CONTAINERFIELD)
  references TB_DOCUMENTFIELDS(ID)
)
/
CREATE INDEX FK_STOREDATTRDET_CONTAINER ON STOREDATTRIBUTESDETAIL(CONTAINERFIELD)
/
-- CREATE TRIGGER tr_storedattrdet_bi_0
CREATE OR REPLACE TRIGGER TR_STOREDATTRIBUTESDETAIL_BI
  BEFORE INSERT
  ON STOREDATTRIBUTESDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_STOREDATTRDET_BI_0)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  if (:new.fieldtype is null) then 
    :new.fieldtype := 1;                           /*       */
  END IF;
  if ((:new.fieldsize is null) and (:new.fieldtype=1)) then 
    :new.fieldsize := 255; /*       255*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_STOREDATTRDET_BI_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  :new.createdate := SYSDATE;
  :new.updatedate := :new.createdate;
  :new.createruser := user;
  :new.updateruser := user;

END;
/
ALTER TABLE STOREDATTRIBUTESDETAIL DROP (NAME)
/
ALTER TABLE STOREDATTRIBUTESDETAIL DROP (ATTRIBUTE_REF)
/
ALTER TABLE STOREDATTRIBUTESDETAIL DROP (CONTAINER_REF)
/
COMMIT WORK
/
ALTER TABLE STOREDATTRIBUTESDETAIL MODIFY(CONTAINERFIELD NOT NULL)
/

-- #########################################################
-- #########################################################
-- alter_DocLock_add_DefaultValue.sql
-- #########################################################
-- #########################################################

/*      */
ALTER TABLE doclock ADD (
  DefaultValue VARCHAR2(512)/*  */
)
/
commit work 
/

-- #########################################################
-- #########################################################
-- Add_StoredPaymentContent_FacialFinDetail.sql
-- #########################################################
-- #########################################################

/*   STOREDPAYMENTCONTENT (  )*/
ALTER TABLE TB_FACIALFINDETAIL ADD (
  STOREDPAYMENTCONTENT VARCHAR2(4000)
)
/

CREATE OR REPLACE VIEW FACIALFINDETAIL (
  ID,
  SOURCEFACIALACC_CLS,
  SOURCEKVR,
  SOURCEKESR,
  DESTFACIALACC_CLS,
  DESTKVR,
  DESTKESR,
  BUDGETREF,
  CREDIT,
  PAYSYMBOLCLS,
  MEMORDERNUM,
  NOTE,
  PROGINDEX,
  RECORDINDEX,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  SOURCEKVSR,
  SOURCEKCSR,
  SOURCEKFSR,
  SOURCESUBKESR,
  SOURCEFACT,
  SOURCEMEANSTYPE,
  SOURCEFINSOURCE,
  SOURCEFINTYPE,
  DESTKVSR,
  DESTKCSR,
  DESTKFSR,
  DESTSUBKESR,
  DESTFACT,
  DESTMEANSTYPE,
  DESTFINSOURCE,
  DESTFINTYPE,
  REQUESTSINDEX,
  SENDERID,
  SENDERRECORDID,
  PROMISE,
  SOURCEDOCTYPE,
  DESTDOCTYPE,
  SOURCEPROMISE,
  DESTPROMISE,
  RECORDINDEX2,
  SOURCEBUDGETPROMISE,
  DESTBUDGETPROMISE,
  SUBPROGINDEX,
  STIMATEID,
  RVERSION,
  SOURCEDIRECTIONCLS,
  DESTDIRECTIONCLS,
  SOURCEDOCBASE,
  DESTDOCBASE,
  SOURCEEXECDOC,
  DESTEXECDOC,
  BUHOPERATIONCLS,
  SOURCEIFS,
  DESTIFS,
  CLSTYPE,
  UNIONNOTIFYREF,
  ACCEPTDATE,
  SOURCEKD,
  DESTKD,
  SOURCEREGIONCLS,
  DESTREGIONCLS,
  DESTFUNDSSOURCE,
  SOURCEFUNDSSOURCE,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  SOURCETRANSFERTCLS,
  DESTTRANSFERTCLS,
  DESTCLSTYPE,
  SOURCEASSIGNMENTKIND,
  DESTASSIGNMENTKIND,
  SOURCEEXECINNERNUMBER,
  DESTEXECINNERNUMBER,
  SOURCESUBSIDYCLS,
  DESTSUBSIDYCLS,
  SOURCEFAORG_TYPE,
  DESTFAORG_TYPE,
  SOURCEBUDALLOCATIONCLS,
  SOURCEPAYPROMISECLS,
  DESTBUDALLOCATIONCLS,
  DESTPAYPROMISECLS,
  SOURCEINVESTOBJECT,
  DESTINVESTOBJECT,
  TRANSFERTORG_REF,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  STOREDPAYMENTCONTENT)
AS
  SELECT
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    NOTE,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT
  FROM TB_FACIALFINDETAIL
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_ID
  INSTEAD OF DELETE
  ON FACIALFINDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_500 (TR_FACIALFINDETAIL_BD_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  Update facialfincaption set
  DocChangeDate = SYSDATE,
  RVersion=-1
  where id=:old.recordindex;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_FACIALFINDETAIL
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_FACIALFINDETAIL_AD_500)
-- Last update 27.08.2004
-- - - - - - - - - - - - -

  INSERT INTO DelRecIndexes
              (TableID, RecordId, DeleteDate, ProgIndex, Summa)
       VALUES (22, :OLD.ID, SYSDATE, :OLD.ProgIndex, :OLD.Credit);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_II
  INSTEAD OF INSERT
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
--
  SourceFacialAcc_CLS$ NUMBER(10);
  DestFacialAcc_CLS$ NUMBER(10);
  CapBuhOperationCLS$ NUMBER(10);
  CapClsType$ NUMBER(10);
  CapAcceptDate$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  PromiseAcceptDate$ NUMBER;
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  BPInnerNum1$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  Promise_Count1$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  PromiseAccepted1$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALFINDETAIL_BI_0)
-- Last update 15.12.2002
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_FacialFinDetail_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;
        
  else
    new$SenderIDKey := new$SenderID;
  END IF;
      
  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;
        
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_FACIALFINDETAIL_BI_100)
-- Last update 12.01.2009
-- - - - - - - - - - - - -

 /*  ,    */
   BEGIN

     select
       ffc.BudgetRef, ffc.BuhOperationCls, ffc.ClsType, ffc.AcceptDate,
       ffc.IsBlocked, ffc.BlockedCause, ffc.UnBlockedDate, ffc.UnBlockedCause
     into new$BudgetRef, CapBuhOperationCls$, CapClsType$, CapAcceptDate$,
       new$IsBlocked, new$BlockedCause, new$UnBlockedDate, new$UnBlockedCause
     from
       FacialFinCaption ffc
     where
       ffc.id = new$RecordIndex;
     
   EXCEPTION
     WHEN NO_DATA_FOUND THEN
       new$BudgetRef := NULL;
       CapBuhOperationCls$ := NULL;
       CapClsType$ := NULL;
       CapAcceptDate$ := NULL;
   END;

   /*      */
   if (new$BuhOperationCls is null) then new$BuhOperationCls := CapBuhOperationCls$; end if;

   /*      */
   if (new$ClsType is null) then new$ClsType := CapClsType$; end if;

   if (new$DestClsType is null) then new$DestClsType := new$ClsType; end if;
   
   /*      */
   if (new$AcceptDate is null) then new$AcceptDate := CapAcceptDate$; end if;

   /*      */
   if ((new$SourceFacialAcc_CLS is null) or (new$DestFacialAcc_CLS is null)) then
     BEGIN
       select SourceFacialAcc_CLS, DestFacialAcc_CLS
         into SourceFacialAcc_CLS$, DestFacialAcc_CLS$
       from FacialFinCaption
       where new$RecordIndex = id;
     EXCEPTION
       WHEN NO_DATA_FOUND THEN
         SourceFacialAcc_CLS$ := NULL;
         DestFacialAcc_CLS$ := NULL;
     END;

     if (new$SourceFacialAcc_CLS is null) then new$SourceFacialAcc_CLS := SourceFacialAcc_CLS$; end if;
     if (new$DestFacialAcc_CLS is null) then new$DestFacialAcc_CLS := DestFacialAcc_CLS$; end if;
   end if;

-- - - - - - - - - - - - -
-- BI_110 (TR_FACIALFINDETAIL_BI_110)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype1$ := -1 ;
  IF (new$SourceFintype IS NULL OR (new$Sourcefintype=0)) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype1$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype1$  ;
     
  END IF;
  IF (new$DestFintype IS NULL OR (new$Destfintype=0)) THEN 
    IF (i_fintype1$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype1$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype1$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 1000;
  END IF;
  IF (new$SourceIFS IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 1000;
  END IF;
  IF (new$DestIFS IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*   Promise null,    */
  IF ((new$Promise IS NULL) AND
  ((new$SourcePromise IS NOT NULL) OR
  (new$DestPromise IS NOT NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND(new$DestPromise IS NOT NULL)AND
        (new$SourcePromise=new$DestPromise)) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*    ,  ,       */
  ELSE
    IF ((new$Promise IS NOT NULL) AND
    (new$SourcePromise IS NULL) AND
    (new$DestPromise IS NULL)) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  BEGIN

    /*     \   */
    SELECT org.Org_Type  INTO new$SourceFAOrg_Type FROM Organizations org
    INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$SourceFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  BEGIN

    SELECT org.Org_Type  INTO new$DestFAOrg_Type FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$DestFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BI_120 (TR_FACIALFINDETAIL_BI_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*  60 :  '   .'; source
          61 :  '      '; dest
          62 :  '   ';dest
          63 :  '    '; source
          64 :  '   '; source
          65 :  ' , ';dest
          66 :  '  ,  - '; source dest
          67 :  '   ';source
          68 :  '  \ ';dest
          69 :  '   \ '; dest
          70 :  '  \ ';source
          71 :  '   \ '; dest */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if ((new$DestClsType is NULL) and
  (
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71))) or (new$ProgIndex = 60)
  )) then
    new$DestClsType := 1; /*       ClsType */
      
  else
    if ((new$DestClsType is NULL) and
    ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    ) then
      new$DestClsType := 2; /*        ClsType */
          
    else
      if (new$DestClsType is null) then
        new$DestClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_FACIALFINDETAIL_BI_200)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode1$);
  /*     */
  if (((new$SourcePromise is not null) or (new$DestPromise is not null)) and (PromiseMode1$ <> 1)) then
    if (new$SourcePromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$         from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    if (new$DestPromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$         from
      promise_detail pr
      where
      (pr.registrnumber = new$DESTPROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;    
    END IF;
  END IF;
  if (PromiseMode1$ = 1) then
    /* source  .    */
    if ((new$SourcePromise is not null) and (new$SourceBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum1$           from PaymentSchedule 
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum1$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* dest  .    */
    if ((new$DestPromise is not null) and (new$DestBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum1$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$DestBudgetPromise := BPInnerNum1$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* source    ,   ,   */
    if ((new$SourceBudgetPromise is not null) and (new$SourcePromise is null)) then
      BEGIN
        select ANumber 
        into BPInnerNum1$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$SourcePromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;
            
    END IF;
    /* dest */
    if ((new$DestBudgetPromise is not null) and (new$DestPromise is null)) then
      BEGIN
        select ANumber 
        into BPInnerNum1$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$DestPromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;
            
    END IF;
    /*     */
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$1
      from PaymentSchedule where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls1$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$2
      from PaymentSchedule where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls1$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_FACIALFINDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$SourceExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*    ,   ,  */
    else 
      if (new$SourceExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$DestExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*    ,   ,  */
    else 
      if (new$DestExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALFINDETAIL_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update facialfincaption set
  DocChangeDate = new$UpdateDate,
  RVersion=-1
  where id=new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALFINDETAIL (
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    NOTE,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT
  ) VALUES (
    new$ID,
    new$SOURCEFACIALACC_CLS,
    new$SOURCEKVR,
    new$SOURCEKESR,
    new$DESTFACIALACC_CLS,
    new$DESTKVR,
    new$DESTKESR,
    new$BUDGETREF,
    new$CREDIT,
    new$PAYSYMBOLCLS,
    new$MEMORDERNUM,
    new$NOTE,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$SOURCEKVSR,
    new$SOURCEKCSR,
    new$SOURCEKFSR,
    new$SOURCESUBKESR,
    new$SOURCEFACT,
    new$SOURCEMEANSTYPE,
    new$SOURCEFINSOURCE,
    new$SOURCEFINTYPE,
    new$DESTKVSR,
    new$DESTKCSR,
    new$DESTKFSR,
    new$DESTSUBKESR,
    new$DESTFACT,
    new$DESTMEANSTYPE,
    new$DESTFINSOURCE,
    new$DESTFINTYPE,
    new$REQUESTSINDEX,
    new$SENDERID,
    new$SENDERRECORDID,
    new$PROMISE,
    new$SOURCEDOCTYPE,
    new$DESTDOCTYPE,
    new$SOURCEPROMISE,
    new$DESTPROMISE,
    new$RECORDINDEX2,
    new$SOURCEBUDGETPROMISE,
    new$DESTBUDGETPROMISE,
    new$SUBPROGINDEX,
    new$STIMATEID,
    new$RVERSION,
    new$SOURCEDIRECTIONCLS,
    new$DESTDIRECTIONCLS,
    new$SOURCEDOCBASE,
    new$DESTDOCBASE,
    new$SOURCEEXECDOC,
    new$DESTEXECDOC,
    new$BUHOPERATIONCLS,
    new$SOURCEIFS,
    new$DESTIFS,
    new$CLSTYPE,
    new$UNIONNOTIFYREF,
    new$ACCEPTDATE,
    new$SOURCEKD,
    new$DESTKD,
    new$SOURCEREGIONCLS,
    new$DESTREGIONCLS,
    new$DESTFUNDSSOURCE,
    new$SOURCEFUNDSSOURCE,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SOURCETRANSFERTCLS,
    new$DESTTRANSFERTCLS,
    new$DESTCLSTYPE,
    new$SOURCEASSIGNMENTKIND,
    new$DESTASSIGNMENTKIND,
    new$SOURCEEXECINNERNUMBER,
    new$DESTEXECINNERNUMBER,
    new$SOURCESUBSIDYCLS,
    new$DESTSUBSIDYCLS,
    new$SOURCEFAORG_TYPE,
    new$DESTFAORG_TYPE,
    new$SOURCEBUDALLOCATIONCLS,
    new$SOURCEPAYPROMISECLS,
    new$DESTBUDALLOCATIONCLS,
    new$DESTPAYPROMISECLS,
    new$SOURCEINVESTOBJECT,
    new$DESTINVESTOBJECT,
    new$TRANSFERTORG_REF,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$STOREDPAYMENTCONTENT);

-- - - - - - - - - - - - -
-- AI_100 (TR_FACIALFINDETAIL_AI_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  update FacialFinCaption set
  ClsType = new$ClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(ClsType <> new$ClsType);
  update FacialFinCaption set
  DestClsType = new$DestClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(DestClsType <> new$DestClsType);

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALFINDETAIL_AI_500)
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID =22 ) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype1$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype1$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype1$  ;
     
  END IF;
  IF (new$DestFintype IS NULL) THEN 
    IF (i_fintype1$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype1$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype1$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*  60 :  '   .'; source
          61 :  '      '; dest
          62 :  '   ';dest
          63 :  '    '; source
          64 :  '   '; source
          65 :  ' , ';dest
          66 :  '  ,  - '; source dest
          67 :  '   ';source
          68 :  '  \ ';dest
          69 :  '   \ '; dest
          70 :  '  \ ';source
          71 :  '   \ '; dest */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  /*     */
  if (PromiseMode$ <> 1) then
    /*          */
    if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /*          */
    if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$DestPromise)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
        
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /*     */
  if (PromiseMode$ = 1) then
    /* source  .    */
    if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
    (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule 
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* dest  .     */
    if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
    (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
          
    /*         NULL,    */
    /* source */
    if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
    (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /* dest */
    if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
    (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /*    ,     */
    if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
      new$SourcePromise := null;
      new$Promise := null;
            
    END IF;
    if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
      new$DestPromise := null;
      new$Promise := null;
            
    END IF;
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$1
      from PaymentSchedule
      where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$2
      from PaymentSchedule
      where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$SourcePromise is not null and (
    (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
    (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$SourceExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null and (
    (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
    (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$DestExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select c.AcceptDate into CapAcceptDate$
      from facialfincaption c
      where c.id = new$RecordIndex;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        CapAcceptDate$ := NULL;
    END;

    if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
      new$AcceptDate := new$AcceptDate;
    else
      RaiseException('ex_wrongacceptdate');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
COMMIT WORK
/


-- #########################################################
-- #########################################################
-- Add_ParentGUID_to_ED_OUTPAYDOC.sql
-- #########################################################
-- #########################################################

/*    ParentGUID   ed_outpaydoc  bankexch_merdoc*/
ALTER TABLE ed_outpaydoc ADD (
  ParentGUID VARCHAR2(36)
)
/
ALTER TABLE bankexch_merdoc ADD (
  ParentGUID VARCHAR2(36)
)
/
commit work 
/

-- #########################################################
-- #########################################################
-- Update_DocBase_unique.sql
-- #########################################################
-- #########################################################

ALTER TABLE DOCBASE DROP CONSTRAINT UQ_DOCBASE_VER_KEY DROP INDEX
/
ALTER TABLE DOCBASE ADD (
  CONSTRAINT UQ_DOCBASE_VER_KEY UNIQUE (code, budgetref, extId)
)
/
ALTER TABLE TargetCls DROP CONSTRAINT UNQ_TARGETCLS_STRCODE DROP INDEX
/
ALTER TABLE TargetCls ADD (
  CONSTRAINT UNQ_TARGETCLS_STRCODE UNIQUE (STRCODE, extId)
)
/
ALTER TABLE CommDirectionExpenceCls DROP CONSTRAINT UQ_CDECLS_CODE DROP INDEX
/
ALTER TABLE CommDirectionExpenceCls ADD (
  CONSTRAINT UQ_CDECLS_CODE UNIQUE (Code, extId)
)
/

commit work 
/




-- #########################################################
-- #########################################################
-- Add_ContractCostsCls.sql
-- #########################################################
-- #########################################################

/*    PurchaseType  ContractCostsCls.      TargetCls  ContractCostsCls       *//*   FacialFinDetail (source  dest), BudgetData, Incomes32, PaymentSchedule, WritExecutionDetail, ReplacementClsDetailInfo,  *//* CorrectionDetail, LimitFinDetail, TENDERPRODUCT, UNIONNOTIFYDETAIL ( ContractCostsCls), BANKEXCH_SUBSTITUTION ( dest) */
/*    */
create table PurchaseType(
  id NUMBER(10) NOT NULL,
    CHECK((id<=2147483647)AND(id>-2147483648)),
  Name VARCHAR2(255),/*  */
  CreateDate DATE NOT NULL,
  UpdateDate DATE NOT NULL,
  CreaterUser VARCHAR2(30) NOT NULL,
  UpdaterUser VARCHAR2(30) NOT NULL,
  constraint PK_PurchaseType_ID primary key (ID)
)
/
-- CREATE TRIGGER tr_PurchaseType_bi_500
CREATE OR REPLACE TRIGGER TR_PurchaseType_BI
  BEFORE INSERT
  ON PurchaseType
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_500 (tr_PurchaseType_bi_500)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- CREATE TRIGGER tr_PurchaseType_bu_500
CREATE OR REPLACE TRIGGER tr_PurchaseType_bu_500
  BEFORE UPDATE
  ON PURCHASETYPE
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_500 (tr_PurchaseType_bu_500)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  :new.UpdateDate := SYSDATE;
  :new.UpdaterUser := user;

END;
/

grant SELECT, INSERT, UPDATE, DELETE on PurchaseType to BUDGET_USERS
/
/*      */
insert into PurchaseType (id, Name) values (0, ' ') 
/
insert into PurchaseType (id, Name) values (1, '  44-') 
/
insert into PurchaseType (id, Name) values (2, '  223-') 
/
insert into PurchaseType (id, Name) values (3, ' ') 
/
insert into PurchaseType (id, Name) values (4, '  ') 
/
/*      */
create table ContractCostsCls (
  id NUMBER(10) NOT NULL,
    CHECK((id<=2147483647)AND(id>-2147483648)),
  Code VARCHAR2(20) NOT NULL,
  Name VARCHAR2(1024),/*  */
  Note VARCHAR2(1024),/*  */
  PurchaseType NUMBER(10) NOT NULL,/*   */
    CHECK((PurchaseType<=2147483647)AND(PurchaseType>-2147483648)),
  BudgetRef NUMBER(10) NOT NULL,/*  */
    CHECK((BudgetRef<=2147483647)AND(BudgetRef>-2147483648)),
  StartDate DATE,/*    -        */
  DeleteDate DATE,/*    -       */
  CreateDate DATE NOT NULL,
  UpdateDate DATE NOT NULL,
  CreaterUser VARCHAR2(30) NOT NULL,
  UpdaterUser VARCHAR2(30) NOT NULL,
  constraint PK_ContrCostsCls_ID primary key (ID),
  constraint FK_ContrCostsCls_PurchaseType foreign key (PurchaseType) references PurchaseType(ID),
  constraint FK_ContrCostsCls_BudgetRef foreign key (BudgetRef) references TB_Budgets_s(ID)
)
/
CREATE INDEX FK_ContrCostsCls_PurchaseType ON ContractCostsCls(PurchaseType)
/
CREATE INDEX FK_ContrCostsCls_BudgetRef ON ContractCostsCls(BudgetRef)
/
-- CREATE TRIGGER tr_ContrCostsCls_bi_500
CREATE OR REPLACE TRIGGER TR_ContractCostsCls_BI
  BEFORE INSERT
  ON ContractCostsCls
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_500 (tr_ContrCostsCls_bi_500)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- CREATE TRIGGER tr_ContrCostsCls_bu_500
CREATE OR REPLACE TRIGGER tr_ContrCostsCls_bu_500
  BEFORE UPDATE
  ON CONTRACTCOSTSCLS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_500 (tr_ContrCostsCls_bu_500)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  :new.UpdateDate := SYSDATE;
  :new.UpdaterUser := user;

END;
/
-- CREATE TRIGGER tr_ContractCostsCls_bi_0
CREATE OR REPLACE TRIGGER TR_ContractCostsCls_BI
  BEFORE INSERT
  ON ContractCostsCls
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (tr_ContractCostsCls_bi_0)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  if (:new.Code is null) then  
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.PurchaseType is null) then 
    :new.PurchaseType := 0;
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (tr_ContrCostsCls_bi_500)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- CREATE TRIGGER tr_ContractCostsCls_bu_0
CREATE OR REPLACE TRIGGER TR_ContractCostsCls_BU
  BEFORE UPDATE
  ON ContractCostsCls
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (tr_ContractCostsCls_bu_0)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  if (:new.Code is null) then  
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.PurchaseType is null) then 
    :new.PurchaseType := 0;
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;

END;
/
-- CREATE TRIGGER Tr_ContractCostsCls_AU_500
CREATE OR REPLACE TRIGGER TR_ContractCostsCls_AU
  AFTER UPDATE
  ON ContractCostsCls
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- AU_500 (Tr_ContractCostsCls_AU_500)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if (:new.ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (98104, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=98104) and (RecordId=:new.ID);
      
  END IF;

END;
/
-- CREATE TRIGGER tr_ContractCostsCls_ai_500
CREATE OR REPLACE TRIGGER TR_ContractCostsCls_AI
  AFTER INSERT
  ON ContractCostsCls
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- AI_500 (tr_ContractCostsCls_ai_500)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 98104)  and (RecordID = :new.ID);

END;
/
-- CREATE TRIGGER tr_ContractCostsCls_ad_500
CREATE OR REPLACE TRIGGER TR_ContractCostsCls_AD
  AFTER DELETE
  ON ContractCostsCls
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- AD_500 (tr_ContractCostsCls_ad_500)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate) values(98104, :old.ID, SYSDATE);

END;
/
grant SELECT, INSERT, UPDATE, DELETE on ContractCostsCls to BUDGET_USERS
/
/*     */
insert into ContractCostsCls (id, Code, Name, PurchaseType) values (0, '000', ' ', 0) 
/
insert into ContractCostsCls (id, Code, Name, PurchaseType) values (100, '100', ' ', 0) 
/
insert into ContractCostsCls (id, Code, Name, PurchaseType) values (110, '110', '    44-', 1) 
/
insert into ContractCostsCls (id, Code, Name, PurchaseType) values (120, '120', '    223-', 2) 
/
insert into ContractCostsCls (id, Code, Name, PurchaseType) values (130, '130', '  ', 3) 
/
insert into ContractCostsCls (id, Code, Name, PurchaseType) values (200, '200', ' ', 4) 
/
/*      */
ALTER TABLE TB_FacialFinDetail ADD (
  SourceContractCostsCls NUMBER(10),
    CHECK((SourceContractCostsCls<=2147483647)AND(SourceContractCostsCls>-2147483648)),
  DestContractCostsCls NUMBER(10),
    CHECK((DestContractCostsCls<=2147483647)AND(DestContractCostsCls>-2147483648)),
  constraint FK_FFC_SourceCCC foreign key (SourceContractCostsCls) references ContractCostsCls(ID),
  constraint FK_FFC_DestCCC foreign key (DestContractCostsCls) references ContractCostsCls(ID)
)
/
CREATE INDEX FK_FFC_SourceCCC ON TB_FacialFinDetail(SourceContractCostsCls)
/
CREATE INDEX FK_FFC_DestCCC ON TB_FacialFinDetail(DestContractCostsCls)
/

CREATE OR REPLACE VIEW FacialFinDetail (
  ID,
  SOURCEFACIALACC_CLS,
  SOURCEKVR,
  SOURCEKESR,
  DESTFACIALACC_CLS,
  DESTKVR,
  DESTKESR,
  BUDGETREF,
  CREDIT,
  PAYSYMBOLCLS,
  MEMORDERNUM,
  NOTE,
  PROGINDEX,
  RECORDINDEX,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  SOURCEKVSR,
  SOURCEKCSR,
  SOURCEKFSR,
  SOURCESUBKESR,
  SOURCEFACT,
  SOURCEMEANSTYPE,
  SOURCEFINSOURCE,
  SOURCEFINTYPE,
  DESTKVSR,
  DESTKCSR,
  DESTKFSR,
  DESTSUBKESR,
  DESTFACT,
  DESTMEANSTYPE,
  DESTFINSOURCE,
  DESTFINTYPE,
  REQUESTSINDEX,
  SENDERID,
  SENDERRECORDID,
  PROMISE,
  SOURCEDOCTYPE,
  DESTDOCTYPE,
  SOURCEPROMISE,
  DESTPROMISE,
  RECORDINDEX2,
  SOURCEBUDGETPROMISE,
  DESTBUDGETPROMISE,
  SUBPROGINDEX,
  STIMATEID,
  RVERSION,
  SOURCEDIRECTIONCLS,
  DESTDIRECTIONCLS,
  SOURCEDOCBASE,
  DESTDOCBASE,
  SOURCEEXECDOC,
  DESTEXECDOC,
  BUHOPERATIONCLS,
  SOURCEIFS,
  DESTIFS,
  CLSTYPE,
  UNIONNOTIFYREF,
  ACCEPTDATE,
  SOURCEKD,
  DESTKD,
  SOURCEREGIONCLS,
  DESTREGIONCLS,
  DESTFUNDSSOURCE,
  SOURCEFUNDSSOURCE,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  SOURCETRANSFERTCLS,
  DESTTRANSFERTCLS,
  DESTCLSTYPE,
  SOURCEASSIGNMENTKIND,
  DESTASSIGNMENTKIND,
  SOURCEEXECINNERNUMBER,
  DESTEXECINNERNUMBER,
  SOURCESUBSIDYCLS,
  DESTSUBSIDYCLS,
  SOURCEFAORG_TYPE,
  DESTFAORG_TYPE,
  SOURCEBUDALLOCATIONCLS,
  SOURCEPAYPROMISECLS,
  DESTBUDALLOCATIONCLS,
  DESTPAYPROMISECLS,
  SOURCEINVESTOBJECT,
  DESTINVESTOBJECT,
  TRANSFERTORG_REF,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  STOREDPAYMENTCONTENT,
  SOURCECONTRACTCOSTSCLS,
  DESTCONTRACTCOSTSCLS)
AS
  SELECT
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    NOTE,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS
  FROM TB_FacialFinDetail
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_ID
  INSTEAD OF DELETE
  ON FACIALFINDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_500 (TR_FACIALFINDETAIL_BD_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  Update facialfincaption set
  DocChangeDate = SYSDATE,
  RVersion=-1
  where id=:old.recordindex;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_FACIALFINDETAIL
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_FACIALFINDETAIL_AD_500)
-- Last update 27.08.2004
-- - - - - - - - - - - - -

  INSERT INTO DelRecIndexes
              (TableID, RecordId, DeleteDate, ProgIndex, Summa)
       VALUES (22, :OLD.ID, SYSDATE, :OLD.ProgIndex, :OLD.Credit);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_II
  INSTEAD OF INSERT
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
--
  SourceFacialAcc_CLS$ NUMBER(10);
  DestFacialAcc_CLS$ NUMBER(10);
  CapBuhOperationCLS$ NUMBER(10);
  CapClsType$ NUMBER(10);
  CapAcceptDate$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  PromiseAcceptDate$ NUMBER;
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  BPInnerNum1$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  Promise_Count1$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  PromiseAccepted1$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALFINDETAIL_BI_0)
-- Last update 15.12.2002
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_FacialFinDetail_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;
        
  else
    new$SenderIDKey := new$SenderID;
  END IF;
      
  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;
        
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_FACIALFINDETAIL_BI_100)
-- Last update 12.01.2009
-- - - - - - - - - - - - -

 /*  ,    */
   BEGIN

     select
       ffc.BudgetRef, ffc.BuhOperationCls, ffc.ClsType, ffc.AcceptDate,
       ffc.IsBlocked, ffc.BlockedCause, ffc.UnBlockedDate, ffc.UnBlockedCause
     into new$BudgetRef, CapBuhOperationCls$, CapClsType$, CapAcceptDate$,
       new$IsBlocked, new$BlockedCause, new$UnBlockedDate, new$UnBlockedCause
     from
       FacialFinCaption ffc
     where
       ffc.id = new$RecordIndex;
     
   EXCEPTION
     WHEN NO_DATA_FOUND THEN
       new$BudgetRef := NULL;
       CapBuhOperationCls$ := NULL;
       CapClsType$ := NULL;
       CapAcceptDate$ := NULL;
   END;

   /*      */
   if (new$BuhOperationCls is null) then new$BuhOperationCls := CapBuhOperationCls$; end if;

   /*      */
   if (new$ClsType is null) then new$ClsType := CapClsType$; end if;

   if (new$DestClsType is null) then new$DestClsType := new$ClsType; end if;
   
   /*      */
   if (new$AcceptDate is null) then new$AcceptDate := CapAcceptDate$; end if;

   /*      */
   if ((new$SourceFacialAcc_CLS is null) or (new$DestFacialAcc_CLS is null)) then
     BEGIN
       select SourceFacialAcc_CLS, DestFacialAcc_CLS
         into SourceFacialAcc_CLS$, DestFacialAcc_CLS$
       from FacialFinCaption
       where new$RecordIndex = id;
     EXCEPTION
       WHEN NO_DATA_FOUND THEN
         SourceFacialAcc_CLS$ := NULL;
         DestFacialAcc_CLS$ := NULL;
     END;

     if (new$SourceFacialAcc_CLS is null) then new$SourceFacialAcc_CLS := SourceFacialAcc_CLS$; end if;
     if (new$DestFacialAcc_CLS is null) then new$DestFacialAcc_CLS := DestFacialAcc_CLS$; end if;
   end if;

-- - - - - - - - - - - - -
-- BI_110 (TR_FACIALFINDETAIL_BI_110)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype1$ := -1 ;
  IF (new$SourceFintype IS NULL OR (new$Sourcefintype=0)) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype1$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype1$  ;
     
  END IF;
  IF (new$DestFintype IS NULL OR (new$Destfintype=0)) THEN 
    IF (i_fintype1$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype1$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype1$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 1000;
  END IF;
  IF (new$SourceIFS IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 1000;
  END IF;
  IF (new$DestIFS IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*   Promise null,    */
  IF ((new$Promise IS NULL) AND
  ((new$SourcePromise IS NOT NULL) OR
  (new$DestPromise IS NOT NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND(new$DestPromise IS NOT NULL)AND
        (new$SourcePromise=new$DestPromise)) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*    ,  ,       */
  ELSE
    IF ((new$Promise IS NOT NULL) AND
    (new$SourcePromise IS NULL) AND
    (new$DestPromise IS NULL)) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  BEGIN

    /*     \   */
    SELECT org.Org_Type  INTO new$SourceFAOrg_Type FROM Organizations org
    INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$SourceFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  BEGIN

    SELECT org.Org_Type  INTO new$DestFAOrg_Type FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$DestFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BI_120 (TR_FACIALFINDETAIL_BI_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*  60 :  '   .'; source
          61 :  '      '; dest
          62 :  '   ';dest
          63 :  '    '; source
          64 :  '   '; source
          65 :  ' , ';dest
          66 :  '  ,  - '; source dest
          67 :  '   ';source
          68 :  '  \ ';dest
          69 :  '   \ '; dest
          70 :  '  \ ';source
          71 :  '   \ '; dest */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if ((new$DestClsType is NULL) and
  (
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71))) or (new$ProgIndex = 60)
  )) then
    new$DestClsType := 1; /*       ClsType */
      
  else
    if ((new$DestClsType is NULL) and
    ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    ) then
      new$DestClsType := 2; /*        ClsType */
          
    else
      if (new$DestClsType is null) then
        new$DestClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_FACIALFINDETAIL_BI_200)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode1$);
  /*     */
  if (((new$SourcePromise is not null) or (new$DestPromise is not null)) and (PromiseMode1$ <> 1)) then
    if (new$SourcePromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$         from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    if (new$DestPromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$         from
      promise_detail pr
      where
      (pr.registrnumber = new$DESTPROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;    
    END IF;
  END IF;
  if (PromiseMode1$ = 1) then
    /* source  .    */
    if ((new$SourcePromise is not null) and (new$SourceBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum1$           from PaymentSchedule 
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum1$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* dest  .    */
    if ((new$DestPromise is not null) and (new$DestBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum1$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$DestBudgetPromise := BPInnerNum1$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* source    ,   ,   */
    if ((new$SourceBudgetPromise is not null) and (new$SourcePromise is null)) then
      BEGIN
        select ANumber 
        into BPInnerNum1$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$SourcePromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;
            
    END IF;
    /* dest */
    if ((new$DestBudgetPromise is not null) and (new$DestPromise is null)) then
      BEGIN
        select ANumber 
        into BPInnerNum1$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$DestPromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;
            
    END IF;
    /*     */
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$1
      from PaymentSchedule where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls1$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$2
      from PaymentSchedule where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls1$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_FACIALFINDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$SourceExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*    ,   ,  */
    else 
      if (new$SourceExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$DestExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*    ,   ,  */
    else 
      if (new$DestExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALFINDETAIL_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update facialfincaption set
  DocChangeDate = new$UpdateDate,
  RVersion=-1
  where id=new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALFINDETAIL (
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    NOTE,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS
  ) VALUES (
    new$ID,
    new$SOURCEFACIALACC_CLS,
    new$SOURCEKVR,
    new$SOURCEKESR,
    new$DESTFACIALACC_CLS,
    new$DESTKVR,
    new$DESTKESR,
    new$BUDGETREF,
    new$CREDIT,
    new$PAYSYMBOLCLS,
    new$MEMORDERNUM,
    new$NOTE,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$SOURCEKVSR,
    new$SOURCEKCSR,
    new$SOURCEKFSR,
    new$SOURCESUBKESR,
    new$SOURCEFACT,
    new$SOURCEMEANSTYPE,
    new$SOURCEFINSOURCE,
    new$SOURCEFINTYPE,
    new$DESTKVSR,
    new$DESTKCSR,
    new$DESTKFSR,
    new$DESTSUBKESR,
    new$DESTFACT,
    new$DESTMEANSTYPE,
    new$DESTFINSOURCE,
    new$DESTFINTYPE,
    new$REQUESTSINDEX,
    new$SENDERID,
    new$SENDERRECORDID,
    new$PROMISE,
    new$SOURCEDOCTYPE,
    new$DESTDOCTYPE,
    new$SOURCEPROMISE,
    new$DESTPROMISE,
    new$RECORDINDEX2,
    new$SOURCEBUDGETPROMISE,
    new$DESTBUDGETPROMISE,
    new$SUBPROGINDEX,
    new$STIMATEID,
    new$RVERSION,
    new$SOURCEDIRECTIONCLS,
    new$DESTDIRECTIONCLS,
    new$SOURCEDOCBASE,
    new$DESTDOCBASE,
    new$SOURCEEXECDOC,
    new$DESTEXECDOC,
    new$BUHOPERATIONCLS,
    new$SOURCEIFS,
    new$DESTIFS,
    new$CLSTYPE,
    new$UNIONNOTIFYREF,
    new$ACCEPTDATE,
    new$SOURCEKD,
    new$DESTKD,
    new$SOURCEREGIONCLS,
    new$DESTREGIONCLS,
    new$DESTFUNDSSOURCE,
    new$SOURCEFUNDSSOURCE,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SOURCETRANSFERTCLS,
    new$DESTTRANSFERTCLS,
    new$DESTCLSTYPE,
    new$SOURCEASSIGNMENTKIND,
    new$DESTASSIGNMENTKIND,
    new$SOURCEEXECINNERNUMBER,
    new$DESTEXECINNERNUMBER,
    new$SOURCESUBSIDYCLS,
    new$DESTSUBSIDYCLS,
    new$SOURCEFAORG_TYPE,
    new$DESTFAORG_TYPE,
    new$SOURCEBUDALLOCATIONCLS,
    new$SOURCEPAYPROMISECLS,
    new$DESTBUDALLOCATIONCLS,
    new$DESTPAYPROMISECLS,
    new$SOURCEINVESTOBJECT,
    new$DESTINVESTOBJECT,
    new$TRANSFERTORG_REF,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$STOREDPAYMENTCONTENT,
    new$SOURCECONTRACTCOSTSCLS,
    new$DESTCONTRACTCOSTSCLS);

-- - - - - - - - - - - - -
-- AI_100 (TR_FACIALFINDETAIL_AI_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  update FacialFinCaption set
  ClsType = new$ClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(ClsType <> new$ClsType);
  update FacialFinCaption set
  DestClsType = new$DestClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(DestClsType <> new$DestClsType);

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALFINDETAIL_AI_500)
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID =22 ) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype1$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype1$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype1$  ;
     
  END IF;
  IF (new$DestFintype IS NULL) THEN 
    IF (i_fintype1$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype1$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype1$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*  60 :  '   .'; source
          61 :  '      '; dest
          62 :  '   ';dest
          63 :  '    '; source
          64 :  '   '; source
          65 :  ' , ';dest
          66 :  '  ,  - '; source dest
          67 :  '   ';source
          68 :  '  \ ';dest
          69 :  '   \ '; dest
          70 :  '  \ ';source
          71 :  '   \ '; dest */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  /*     */
  if (PromiseMode$ <> 1) then
    /*          */
    if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /*          */
    if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$DestPromise)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
        
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /*     */
  if (PromiseMode$ = 1) then
    /* source  .    */
    if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
    (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule 
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* dest  .     */
    if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
    (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
          
    /*         NULL,    */
    /* source */
    if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
    (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /* dest */
    if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
    (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /*    ,     */
    if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
      new$SourcePromise := null;
      new$Promise := null;
            
    END IF;
    if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
      new$DestPromise := null;
      new$Promise := null;
            
    END IF;
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$1
      from PaymentSchedule
      where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$2
      from PaymentSchedule
      where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$SourcePromise is not null and (
    (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
    (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$SourceExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null and (
    (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
    (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$DestExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select c.AcceptDate into CapAcceptDate$
      from facialfincaption c
      where c.id = new$RecordIndex;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        CapAcceptDate$ := NULL;
    END;

    if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
      new$AcceptDate := new$AcceptDate;
    else
      RaiseException('ex_wrongacceptdate');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
ALTER TABLE BudgetData ADD (
  ContractCostsCls NUMBER(10),
    CHECK((ContractCostsCls<=2147483647)AND(ContractCostsCls>-2147483648)),
  constraint FK_BD_ContractCostsCls foreign key (ContractCostsCls) references ContractCostsCls(ID)  
)
/
CREATE INDEX FK_BD_ContractCostsCls ON BudgetData(ContractCostsCls)
/
ALTER TABLE TB_Incomes32 ADD (
  ContractCostsCls NUMBER(10),
    CHECK((ContractCostsCls<=2147483647)AND(ContractCostsCls>-2147483648)),
  constraint FK_Inc_ContractCostsCls foreign key (ContractCostsCls) references ContractCostsCls(ID)    
)
/
CREATE INDEX FK_Inc_ContractCostsCls ON TB_Incomes32(ContractCostsCls)
/

CREATE OR REPLACE VIEW Incomes32 (
  ID,
  DOCNUMBER,
  DOCCOUNT,
  IDATE,
  DEBIT,
  CREDIT,
  DOCTYPE,
  INN,
  ORG_REF,
  ACCOUNTINDEX,
  KD,
  SUBKD,
  REGIONCLS,
  GOSNI,
  INCACCOUNT,
  PROGINDEX,
  RECORDINDEX,
  BUDGETREF,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  NOTE,
  RECORDINDEX2,
  ELNUM,
  NOTEEX,
  BUHPAYMENTCLS,
  ACCOUNTREF,
  ELPACKETNUM,
  FACIALACC_CLS,
  NDS,
  MEANSTYPE,
  RECORDDATE,
  TOTALREF,
  REQUESTSINDEX,
  KVSR,
  TAXNOTE,
  DOCNUM,
  REALPAYERORG_REF,
  DOCDATE,
  DOCBASE,
  FACT,
  RVERSION,
  KFSR,
  KESR,
  KVR,
  KCSR,
  SUMCOMPLETE,
  ELDOCREF,
  REQUESTSINDEX2,
  FEDERALFUNDSREF,
  BUHOPERATIONCLS,
  IFS,
  IFS_CORR,
  CLSTYPE,
  NDSNOTE,
  DOGNUM,
  SENDERID,
  SENDERRECORDID,
  OKATO,
  ADDOKATO,
  REJECTCLS,
  REJECTCAUSE,
  FUNDSSOURCE,
  DIRECTIONCLS,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  STIMATEID,
  TRANSFERTCLS,
  SUBSIDYCLS,
  FAORGTYPE,
  OKTMO,
  UINCODE,
  FINTYPE,
  INVESTOBJECT,
  CONTRACTCOSTSCLS)
AS
  SELECT
    ID,
    DOCNUMBER,
    DOCCOUNT,
    IDATE,
    DEBIT,
    CREDIT,
    DOCTYPE,
    INN,
    ORG_REF,
    ACCOUNTINDEX,
    KD,
    SUBKD,
    REGIONCLS,
    GOSNI,
    INCACCOUNT,
    PROGINDEX,
    RECORDINDEX,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    NOTE,
    RECORDINDEX2,
    ELNUM,
    NOTEEX,
    BUHPAYMENTCLS,
    ACCOUNTREF,
    ELPACKETNUM,
    FACIALACC_CLS,
    NDS,
    MEANSTYPE,
    RECORDDATE,
    TOTALREF,
    REQUESTSINDEX,
    KVSR,
    TAXNOTE,
    DOCNUM,
    REALPAYERORG_REF,
    DOCDATE,
    DOCBASE,
    FACT,
    RVERSION,
    KFSR,
    KESR,
    KVR,
    KCSR,
    SUMCOMPLETE,
    ELDOCREF,
    REQUESTSINDEX2,
    FEDERALFUNDSREF,
    BUHOPERATIONCLS,
    IFS,
    IFS_CORR,
    CLSTYPE,
    NDSNOTE,
    DOGNUM,
    SENDERID,
    SENDERRECORDID,
    OKATO,
    ADDOKATO,
    REJECTCLS,
    REJECTCAUSE,
    FUNDSSOURCE,
    DIRECTIONCLS,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    STIMATEID,
    TRANSFERTCLS,
    SUBSIDYCLS,
    FAORGTYPE,
    OKTMO,
    UINCODE,
    FINTYPE,
    INVESTOBJECT,
    CONTRACTCOSTSCLS
  FROM TB_Incomes32
/

CREATE OR REPLACE TRIGGER TR_INCOMES32_ID
  INSTEAD OF DELETE
  ON INCOMES32
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_10 (TR_INCOMES32_BD10)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

  delete
  from CurrencyIncomes
  where (id = :old.id);

-- - - - - - - - - - - - -
-- BD_20 (T_INCOMES32_BD_20)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

  /*    */
  if (:old.DocType between 1010 and 1019) then
    delete from PayDoc32
    where 
      (ProgIndex = :old.ProgIndex) 
    and 
     (RecordIndex = :old.id);
  end if;

-- - - - - - - - - - - - -
-- BD_500 (TR_INCOMES32_BD_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  Update QuotesTitle set
  DocChangeDate = SYSDATE,
  RVersion = -1
  where id = :old.recordindex;

-- - - - - - - - - - - - -
-- BD_600 (TR_INCOMES32_BD_600)
-- Last update 14.10.2009
-- - - - - - - - - - - - -

    --    
    if (:old.ProgIndex = 41) then
        delete
            from Incomes32
        where
           (ProgIndex=42)and
           (RecordIndex=:old.id);
    end if;

    --  (  )
    if (:old.ProgIndex = 42) then
        delete
            from Incomes32
        where
            (ProgIndex=43)and
            (RecordIndex=:old.id);
    end if;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_INCOMES32
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);
   
  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_500 (TR_INCOMES32_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordID, DeleteDate, ProgIndex, SUMMA) values (161, :old.ID, SYSDATE, :old.ProgIndex, :old.DEBIT + :old.CREDIT);

END;
/

CREATE OR REPLACE TRIGGER TR_INCOMES32_II
  INSTEAD OF INSERT
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
--
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  CapDocNumber VARCHAR2(20);
  unkKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  Kd_Master NUMBER(10);
  idKD$ NUMBER(10);
  unkVKD$ VARCHAR2(20);
  val_DocCount$ NUMBER(10);
  val_DocType$ NUMBER(10);
  val_Org_Ref$ NUMBER(10);
  val_AccountIndex$ NUMBER(10);
  val_SubKD$ NUMBER(10);
  val_RegionCLS$ NUMBER(10);
  val_GosNI$ NUMBER(10);
  val_IncAccount$ NUMBER(10);
  val_BudgetRef$ NUMBER(10);
  val_MEANSTYPE$ NUMBER(10);
  val_FACIALACC_CLS$ NUMBER(10);
  val_TransfertCls$ NUMBER(10);
  CapAcceptDate$ NUMBER;
  CapReestrNumber$ VARCHAR2(20);
  CapProgIndex$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_INCOMES32_BI)
-- Version 10.00.00.2
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN 
    select g_shared.nextval into new$id from dual;
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN 
    new$FACIALACC_CLS := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN 
    new$Gosni := 0;
  END IF;
  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN 
    new$DocBase := 0;
  END IF;
  /* 3 -    */
  IF (new$KD IS NULL) THEN 
    new$KD := 0;
  END IF;
  IF (new$ProgIndex IS NULL) THEN 
    new$ProgIndex := 3;
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN 
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN 
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN 
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN 
    new$AccountIndex := 0;
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN 
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN 
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN 
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN 
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN 
    new$DirectionCLS := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  IF (new$FinType IS NULL) THEN  
    new$FinType := 0;
  END IF;
  /*   .        */
  IF (new$IFS IS NULL) THEN 
    new$IFS := 0;
  END IF;
  IF (new$IFS_CORR IS NULL) THEN 
    new$Ifs_Corr := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
   
  /*  ,    */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0)) THEN
    BEGIN
      SELECT qt.BudgetRef      INTO new$BudgetRef FROM QuotesTitle qt
      WHERE qt.Id = new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    0,     */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0)) THEN
    BEGIN
      SELECT fa.BudgetRef      INTO new$BudgetRef FROM FacialAcc_Cls fa
      WHERE fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    0,    */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0))
  THEN 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
   
  IF (new$ProgIndex = 45) 
  THEN 
    IF (new$IncAccount IS NULL) THEN
      GetDefDFAccRefForBudget(new$BudgetRef,new$IncAccount);
    END IF;
    BEGIN

      /*     */
      SELECT qt.ProgIndex, qt.AcceptDate, qt.IncAccount, qt.ReestrNumber 
      INTO CapProgIndex$, CapAcceptDate$, new$IncAccount, CapReestrNumber$       FROM QuotesTitle qt
      WHERE 
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*           / */
    /*  /   after insert */
    IF (CapProgIndex$ <> 145) THEN 
      new$iDate := CapAcceptDate$;
    END IF;
    IF ((CapProgIndex$ = 145)AND (NOT ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0)OR (new$Credit<0)))) )
    THEN 
      new$Idate := CapAcceptDate$;      
    END IF;
    /*   -    () */
    IF ((CapProgIndex$ = 45) AND (CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN 
      /*        , *//*    */            
                  
      new$FederalFundsRef := new$ID;
      /* if-then */  
    END IF;/* if-then*/
  END IF;
  BEGIN
    /*     \*/
    SELECT org.Org_Type   INTO new$FAOrgType FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$FacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BI_5 (TR_INCOMES_BI_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BI_9 (TR_INCOMES32_BI_VZ)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   IF (new$ProgIndex = 9) THEN
      /*   */
      GetIntConst (9, 1, new$IncAccount);

      BEGIN
        /*      */
        SELECT ACCEPTDATE, BUDGETREF
          INTO new$IDate, new$BudgetRef
          FROM VZ_OFFSET
         WHERE ID = new$RecordIndex;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_INCOMES32_BI_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   BEGIN
      SELECT Inn
        INTO new$Inn
        FROM Organizations o
       WHERE (o.ID = new$Org_Ref);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

/*  .    ,    */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      BEGIN
         SELECT c.BudgetRef
           INTO new$budgetref
           FROM QuotesTitle c
          WHERE c.ID = NEW$RecordIndex;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

   /*  .  ,     */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      BEGIN
         SELECT fa.BudgetRef
           INTO new$budgetref
           FROM FacialAcc_Cls fa
          WHERE fa.ID = NEW$FacialAcc_Cls;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

   /*  ,    */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      GetIntConst (-1, 3, new$budgetref);
   END IF;

-- - - - - - - - - - - - -
-- BI_30 (TR_INCOMES32_BI_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then 
    BEGIN
      select q.BuildDate 
      into 
      new$DocDate        from QuotesTitle q 
      where q.id = new$RecordIndex 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_70 (TR_INCOMES32_BI_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
               */
         new$FederalFundsRef := new$ID;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_INCOMES32_BI_100)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if ((not (newKD$  like unkKD$)) and
    (not (newKD$  like unkVKD$))) then
      /*   (    
            ) ,  
         ,   */

      /*       */
      if (new$Debit <> 0) then 
        RaiseException('ex_UnknownRedirect');
      END IF;
      BEGIN

        /*      */
        select KD,DocCount,DocType,
        Org_Ref,AccountIndex,SubKD,RegionCLS,GosNI,
        IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,
        TransfertCls
        into
        idKD$,
        val_DocCount$,
        val_DocType$,
        val_Org_Ref$,
        val_AccountIndex$,
        val_SubKD$,
        val_RegionCLS$,
        val_GosNI$,
        val_IncAccount$,
        val_BudgetRef$,
        val_MEANSTYPE$  ,
        val_FACIALACC_CLS$,
        val_TransfertCls$         from incomes32 where id=new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
         
      if (not idKD$ is null) then
        insert into
        /* KD=   (      )
              Debit=0
              redit=-new.credit
              ProgIndex=43
              RecordIndex=new.id
              id    Incomes32*/
        Incomes32(CreaterUser, DocNum,DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS, TransfertCls)
        Values(new$CreaterUser, new$DocNum, val_DocCount$, new$iDate, new$DOCDATE, 0, -new$Credit, val_DocType$,
        val_Org_Ref$, val_AccountIndex$, idKD$, val_SubKD$, val_RegionCLS$, val_GosNI$,
        43,new$Id, val_IncAccount$, val_BudgetRef$, new$Note,val_MEANSTYPE$,val_FACIALACC_CLS$,val_TransfertCls$);
        
      END IF; 
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_110 (TR_INCOMES32_BI_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       /*       ClsType */
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                /*  -  */
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_INCOMES32_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update QuotesTitle set
  DocChangeDate = new$UpdateDate,
  RVersion = -1
  where id = new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_INCOMES32 (
    ID,
    DOCNUMBER,
    DOCCOUNT,
    IDATE,
    DEBIT,
    CREDIT,
    DOCTYPE,
    INN,
    ORG_REF,
    ACCOUNTINDEX,
    KD,
    SUBKD,
    REGIONCLS,
    GOSNI,
    INCACCOUNT,
    PROGINDEX,
    RECORDINDEX,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    NOTE,
    RECORDINDEX2,
    ELNUM,
    NOTEEX,
    BUHPAYMENTCLS,
    ACCOUNTREF,
    ELPACKETNUM,
    FACIALACC_CLS,
    NDS,
    MEANSTYPE,
    RECORDDATE,
    TOTALREF,
    REQUESTSINDEX,
    KVSR,
    TAXNOTE,
    DOCNUM,
    REALPAYERORG_REF,
    DOCDATE,
    DOCBASE,
    FACT,
    RVERSION,
    KFSR,
    KESR,
    KVR,
    KCSR,
    SUMCOMPLETE,
    ELDOCREF,
    REQUESTSINDEX2,
    FEDERALFUNDSREF,
    BUHOPERATIONCLS,
    IFS,
    IFS_CORR,
    CLSTYPE,
    NDSNOTE,
    DOGNUM,
    SENDERID,
    SENDERRECORDID,
    OKATO,
    ADDOKATO,
    REJECTCLS,
    REJECTCAUSE,
    FUNDSSOURCE,
    DIRECTIONCLS,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    STIMATEID,
    TRANSFERTCLS,
    SUBSIDYCLS,
    FAORGTYPE,
    OKTMO,
    UINCODE,
    FINTYPE,
    INVESTOBJECT,
    CONTRACTCOSTSCLS
  ) VALUES (
    new$ID,
    new$DOCNUMBER,
    new$DOCCOUNT,
    new$IDATE,
    new$DEBIT,
    new$CREDIT,
    new$DOCTYPE,
    new$INN,
    new$ORG_REF,
    new$ACCOUNTINDEX,
    new$KD,
    new$SUBKD,
    new$REGIONCLS,
    new$GOSNI,
    new$INCACCOUNT,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$BUDGETREF,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$NOTE,
    new$RECORDINDEX2,
    new$ELNUM,
    new$NOTEEX,
    new$BUHPAYMENTCLS,
    new$ACCOUNTREF,
    new$ELPACKETNUM,
    new$FACIALACC_CLS,
    new$NDS,
    new$MEANSTYPE,
    new$RECORDDATE,
    new$TOTALREF,
    new$REQUESTSINDEX,
    new$KVSR,
    new$TAXNOTE,
    new$DOCNUM,
    new$REALPAYERORG_REF,
    new$DOCDATE,
    new$DOCBASE,
    new$FACT,
    new$RVERSION,
    new$KFSR,
    new$KESR,
    new$KVR,
    new$KCSR,
    new$SUMCOMPLETE,
    new$ELDOCREF,
    new$REQUESTSINDEX2,
    new$FEDERALFUNDSREF,
    new$BUHOPERATIONCLS,
    new$IFS,
    new$IFS_CORR,
    new$CLSTYPE,
    new$NDSNOTE,
    new$DOGNUM,
    new$SENDERID,
    new$SENDERRECORDID,
    new$OKATO,
    new$ADDOKATO,
    new$REJECTCLS,
    new$REJECTCAUSE,
    new$FUNDSSOURCE,
    new$DIRECTIONCLS,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$STIMATEID,
    new$TRANSFERTCLS,
    new$SUBSIDYCLS,
    new$FAORGTYPE,
    new$OKTMO,
    new$UINCODE,
    new$FINTYPE,
    new$INVESTOBJECT,
    new$CONTRACTCOSTSCLS);

-- - - - - - - - - - - - -
-- AI_20 (T_INCOMES32_AI_20)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   --     
   if (new$ProgIndex <> 42) then
     BEGIN
       SELECT ProgIndex, DocNumber, AcceptDate
        INTO CapProgIndex, CapDocNumber, CapAcceptDate
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
     EXCEPTION
       WHEN NO_DATA_FOUND THEN NULL;
     END;
   end if;

   --   - ,  
   IF ((CapProgIndex = 145) or (new$ProgIndex=42)) THEN

      If ((new$ProgIndex=42) and (new$DocType between 1010 and 1019) and
         (new$Debit>0) and (new$DOCDATE is not null))
      then
        BEGIN
          select kd into Kd_Master
    From Incomes32 inc
          where inc.id = new$RecordIndex;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;

        if (Kd_Master = new$Kd) then
          CapAcceptDate := new$DOCDATE;
          CapProgIndex  := new$ProgIndex;
          CapDocNumber  := new$DocNum;
        end if;
      end if; --       (         )

      --             
      IF ((CapAcceptDate IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit > 0) OR (new$Credit < 0))) THEN
         --    ( RealPayerOrg_Ref(PayDoc32)=new$RealPayerOrg_Ref(Incomes32))
         INSERT INTO PayDoc32
            (BudgetRef, AccountRef, PayerAttrRef, InputDate,
             Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref, FACIALACC_CLS)
         VALUES (new$BudgetRef, new$AccountRef, new$IncAccount, CapAcceptDate,
             (new$Debit - new$Credit), new$Note, new$ProgIndex, new$id, CapDocNumber, new$TaxNote,
             new$RealPayerOrg_Ref,new$FACIALACC_CLS);
      -- (new$Debit - new$Credit) --- ..      ,    ,
      --             
      END IF;

   END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_INCOMES32_AI_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 161) AND (RecordID = NEW$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 10.00.00.2
-- - - - - - - - - - - - -

  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN 
    new$DocBase := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN 
    new$Gosni := 0;
  END IF;
  /* 3 -    */
  IF (new$ProgIndex IS NULL) THEN 
    new$ProgIndex := 3; 
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0; 
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN 
    new$FACIALACC_CLS := 0; 
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN 
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN 
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN 
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN 
    new$AccountIndex := 0; 
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN 
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN 
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN 
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN 
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN 
    new$DirectionCLS := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  IF (new$FinType IS NULL) THEN  
    new$FinType := 0;
  END IF;
  /*   .        */
  IF (new$IFS_CORR IS NULL) THEN 
    new$Ifs_Corr := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$Ifs := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  BEGIN

    /*     */
    /*   after   ,*/ 
    /*      */
    SELECT ProgIndex, AcceptDate, ReestrNumber
    INTO CapProgIndex1$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
    WHERE
    (qt.ID = new$RecordIndex)
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*              
           (  , , ) */
  /*   -    () */
  IF (CapProgIndex1$ = 45)
  THEN 
    IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN 
      /*        ,
                     */            
      new$FederalFundsRef := new$ID;
      /* if-then*/
    ELSE 
      new$FederalFundsRef := NULL;
      /* if-else*/  
    END IF;/* if (CapProgIndex=45) */
  END IF;
  /*     */
  IF (new$BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
      IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
        RaiseException('Ex_CantModufyBudget');
      END IF;
      IF (new$Progindex = 41) THEN
        SELECT COUNT(inc.id ) INTO CNT$1
        FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
        IF ((CNT$1<> 0)) THEN
          RaiseException('Ex_CantModufyBudget');
        END IF;   
      END IF;
    END IF;
  END IF;
  /*     \*/
  IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
  ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

  BEGIN
    SELECT Inn
     INTO new$Inn
     FROM Organizations o
    WHERE (o.ID = new$Org_Ref);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*      */
  IF (new$ProgIndex <> 42) THEN
    BEGIN
      SELECT ProgIndex, DocNumber, AcceptDate
      INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
      WHERE
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*   -  ,   */
  IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
  THEN 
    IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
    (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
    THEN 
      BEGIN
        SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
        WHERE inc.id = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (Kd_Master$ = new$Kd) THEN 
        CapAcceptDate$ := new$DOCDATE;
        CapProgIndex$  := new$ProgIndex;
        CapDocNumber$  := new$DocNum;
        /*  */        
      END IF;/*       (         )*/
    END IF;
    IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
    THEN 

      /*      */
      /* /      Incomes32, ..      ,     */

      /*     /   */
      SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
      INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
      ;
      /*            ,  .*/
      /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
                      ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
                     ) THEN
                    EXCEPTION EX_CANNOTUPDATENUMBER;*/
                 
                
      IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
      then
        if ((new$DocType <> :old.DocType )
        or (new$Debit <> :old.Debit )
        or (new$Credit <> :old.Credit)
        or (new$org_ref <> :old.org_ref)
        or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
        or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
        )
        then
          RaiseException('EX_CANNOTUPDATENUMBER');
        END IF;
      END IF;
                


      /*           */
      IF (PayDocCount$ = 0)
      THEN 
        /*       */
        GetIntConst(11, 2,ConstPayQueue$);
        /*       */
        GetIntConst(11, 1,ConstSendBy$);

        /*    */
        INSERT INTO PayDoc32
        (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
        Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
        VALUES
        (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
        new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
        /* (new.Debit - new.Credit) --- ..      ,    ,
                                     */

        /* if-then */
      ELSE 
        /*     */
        IF (((new$AccountRef = :old.AccountRef) OR
        ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
        AND (new$IncAccount = :old.IncAccount)
        AND (new$BudgetRef = :old.BudgetRef)
        AND ((new$Note = :old.Note) OR
        ((new$Note IS NULL) AND (:old.Note IS NULL)))
        AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
        ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
        AND ((new$TaxNote = :old.TaxNote) OR
        ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
        )  THEN
          new$AccountRef := new$AccountRef;
                          
        ELSE

          UPDATE PayDoc32 pd
          SET
          pd.AccountRef = new$AccountRef,
          pd.PayerAttrRef = new$IncAccount,
          pd.AcceptorAttrRef = new$AccountRef,
          pd.TextNote = new$Note,
          pd.TaxNote = new$TaxNote,
          pd.BudgetRef = new$BudgetRef,
          pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
          pd.InputDate = CapAcceptDate$,
          pd.SourceDocNumber = CapDocNumber$,
          pd.FACIALACC_CLS = new$FACIALACC_CLS
          WHERE
          (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
        END IF;
        IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
        OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
        THEN  
          IF (Divided$ > 0)
          THEN
            /*  ,      */
            RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
          ELSE
            UPDATE PayDoc32 pd
            SET
            pd.Credit = new$Debit - new$Credit
            WHERE
            (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
          END IF;/* if-then*/            
        END IF;/* if-else*/
      END IF;
      /*     / */
      /*   :     ,     */
      /*  ,     */
      SELECT MAX(pd.AcceptDate)
      INTO Date_Pd$           FROM PayDoc32 pd
      WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
      ;
      new$Idate := Date_Pd$;
      /* if-then*/
    ELSE 
      /*       
                          -
                    . */
      DELETE FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex = new$ProgIndex)
      AND (pd.RecordIndex = new$id);
      /* if-else*/  
    END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then 
    BEGIN
      select q.BuildDate 
      into 
      new$DocDate        from QuotesTitle q 
      where q.id = new$RecordIndex 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
            */
         new$FederalFundsRef := new$ID;
      ELSE
         new$FederalFundsRef := NULL;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN
      select KDValue   into oldKD$ from kd where Id=:old.kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN

      /*     */
      select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
      IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
      into
      idKD1$,
      val_DocCount1$,
      val_DocType1$,
      val_Org_Ref1$,
      val_AccountIndex1$,
      val_SubKD1$,
      val_RegionCLS1$,
      val_GosNI1$,
      val_IncAccount1$,
      val_BudgetRef1$,
      val_MEANSTYPE1$  , 
      val_FACIALACC_CLS1$,
      val_TransfertCls1$         from incomes32 where id=new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not idKD1$ is null) then
      if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
      (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
        /*   ,    */
        delete
        from Incomes32
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      (new$Debit<>0))
      /*       */
      then 
        RaiseException('ex_UnknownRedirect');
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
        /*   ,   ,   */
        insert into
        Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
        Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
        val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
        val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
        new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
      END IF;
      if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
      and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
        /*      ,   */
        update Incomes32
        set
        DocNum = new$DocNum,
        DocCount = val_DocCount1$,
        iDate = new$iDate,
        DOCDATE = new$DOCDATE,
        Debit = 0,
        Credit = -new$Credit,
        DocType = val_DocType1$,
        Org_Ref = val_Org_Ref1$,
        AccountIndex = val_AccountIndex1$,
        KD = idKD1$,
        SubKD = val_SubKD1$,
        RegionCLS = val_RegionCLS1$,
        GosNI = val_GosNI1$,
        ProgIndex = 43,
        RecordIndex = new$Id,
        IncAccount = val_IncAccount1$,
        BudgetRef = val_BudgetRef1$,
        Note = new$Note,
        MEANSTYPE = val_MEANSTYPE1$,
        FACIALACC_CLS = val_FACIALACC_CLS1$,
        TransfertCls = val_TransfertCls1$,
        RVersion = -1
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
         
      END IF; 
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 41)    /*   () */
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    /*       */
    FOR REC$1 IN (SELECT inc.id
     AS val_ID42    FROM Incomes32 inc
    LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
    WHERE (inc.ProgIndex =  42) and
    (inc.RecordIndex =  new$id) and
    (inc.debit = 0) and
    (not(kd.kdvalue like unkKD$)) and
    (not(kd.kdvalue like unkVKD$))
    )
    LOOP
      BEGIN
        /*       */
        select inc.id
        into val_ID431$         FROM Incomes32 inc
        WHERE (inc.ProgIndex =  43) and
        (inc.RecordIndex =  REC$1.val_ID42)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      /*     ,   Credit, ProgIndex, RecordIndex */
      update Incomes32
      set
      DocNum = new$DocNum,
      DocCount = new$DocCount,       
      DOCDATE = new$DOCDATE,
      Debit = 0,
      DocType = new$DocType,
      Org_Ref = new$Org_Ref,
      AccountIndex = new$AccountIndex,
      KD = new$Kd,
      SubKD = new$SubKD,
      RegionCLS = new$RegionCLS,
      GosNI = new$GosNI,
      IncAccount = new$IncAccount,
      BudgetRef = new$BudgetRef,
      Note = new$Note,
      MEANSTYPE = new$MEANSTYPE,
      FACIALACC_CLS = new$FACIALACC_CLS,
      FACT = new$FACT,
      TransfertCls = new$TransfertCls,
      DirectionCls = new$DirectionCls,
      rversion = -1
      where id = val_ID431$;

        
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       --       ClsType
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                --  - 
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      --   
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    REJECTCAUSE = new$REJECTCAUSE,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   IF (NEW$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (161, :OLD.ID, SYSDATE);
      DELETE FROM DelRecIndexes
        WHERE (TableID = 161) AND (RecordId = NEW$ID);
   END IF;

END;
/
ALTER TABLE TB_PaymentSchedule ADD (
  ContractCostsCls NUMBER(10),
    CHECK((ContractCostsCls<=2147483647)AND(ContractCostsCls>-2147483648)),
  constraint FK_PS_ContractCostsCls foreign key (ContractCostsCls) references ContractCostsCls(ID)    
)
/
CREATE INDEX FK_PS_ContractCostsCls ON TB_PaymentSchedule(ContractCostsCls)
/

CREATE OR REPLACE VIEW PaymentSchedule (
  ID,
  ANUMBER,
  PARENTNUMBER,
  KFSR,
  KESR,
  KVSR,
  KCSR,
  KVR,
  MONTH01,
  MONTH02,
  MONTH03,
  MONTH04,
  MONTH05,
  MONTH06,
  MONTH07,
  MONTH08,
  MONTH09,
  MONTH10,
  MONTH11,
  MONTH12,
  SUMMA,
  REGION,
  SUBKESR,
  MEANSTYPE,
  FINSOURCE,
  FINTYPE,
  FACT,
  FACIALACC_CLS,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  BUDGETREF,
  ACCEPTDATE,
  LASTADJUSTMENT,
  ACCEPTED,
  LASTACCEPTED,
  PROMISETYPE,
  ADJUSTMENTREF,
  OLDNUMBER,
  SUMMAPREVIOUSYEAR,
  SUMMAFINPREVIOUSYEAR,
  QUARTER1,
  QUARTER2,
  QUARTER3,
  QUARTER4,
  RECORDINDEX,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  DIRECTIONCLS,
  RVERSION,
  BUHOPERATIONCLS,
  MONTH01DELTA,
  MONTH02DELTA,
  MONTH03DELTA,
  MONTH04DELTA,
  MONTH05DELTA,
  MONTH06DELTA,
  MONTH07DELTA,
  MONTH08DELTA,
  MONTH09DELTA,
  MONTH10DELTA,
  MONTH11DELTA,
  MONTH12DELTA,
  QUARTER1DELTA,
  QUARTER2DELTA,
  QUARTER3DELTA,
  QUARTER4DELTA,
  SUMMADELTA,
  NOTE,
  FINYEAR,
  SUMMAYEAR1,
  SUMMAYEAR2,
  SUMMAYEAR3,
  SUMMAYEAR1DELTA,
  SUMMAYEAR2DELTA,
  SUMMAYEAR3DELTA,
  ASSIGNMENTKIND,
  TRANSFERTCLS,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  EXECUTIONREF,
  INNERPROMISENUM,
  ADJUSTMENTNUMBER,
  PROMISENUMBER,
  SUBSIDYCLS,
  AGREEMENTREF,
  BUDALLOCATIONCLS,
  PAYPROMISECLS,
  PROGINDEX,
  INVESTOBJECT,
  SUMMAYEAR4,
  SUMMAOTHERYEARS,
  SUMMAYEAR4DELTA,
  SUMMAOTHERYEARSDELTA,
  CONTRACTCOSTSCLS)
AS
  SELECT
    ID,
    ANUMBER,
    PARENTNUMBER,
    KFSR,
    KESR,
    KVSR,
    KCSR,
    KVR,
    MONTH01,
    MONTH02,
    MONTH03,
    MONTH04,
    MONTH05,
    MONTH06,
    MONTH07,
    MONTH08,
    MONTH09,
    MONTH10,
    MONTH11,
    MONTH12,
    SUMMA,
    REGION,
    SUBKESR,
    MEANSTYPE,
    FINSOURCE,
    FINTYPE,
    FACT,
    FACIALACC_CLS,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    ACCEPTDATE,
    LASTADJUSTMENT,
    ACCEPTED,
    LASTACCEPTED,
    PROMISETYPE,
    ADJUSTMENTREF,
    OLDNUMBER,
    SUMMAPREVIOUSYEAR,
    SUMMAFINPREVIOUSYEAR,
    QUARTER1,
    QUARTER2,
    QUARTER3,
    QUARTER4,
    RECORDINDEX,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DIRECTIONCLS,
    RVERSION,
    BUHOPERATIONCLS,
    MONTH01DELTA,
    MONTH02DELTA,
    MONTH03DELTA,
    MONTH04DELTA,
    MONTH05DELTA,
    MONTH06DELTA,
    MONTH07DELTA,
    MONTH08DELTA,
    MONTH09DELTA,
    MONTH10DELTA,
    MONTH11DELTA,
    MONTH12DELTA,
    QUARTER1DELTA,
    QUARTER2DELTA,
    QUARTER3DELTA,
    QUARTER4DELTA,
    SUMMADELTA,
    NOTE,
    FINYEAR,
    SUMMAYEAR1,
    SUMMAYEAR2,
    SUMMAYEAR3,
    SUMMAYEAR1DELTA,
    SUMMAYEAR2DELTA,
    SUMMAYEAR3DELTA,
    ASSIGNMENTKIND,
    TRANSFERTCLS,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    EXECUTIONREF,
    INNERPROMISENUM,
    ADJUSTMENTNUMBER,
    PROMISENUMBER,
    SUBSIDYCLS,
    AGREEMENTREF,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    PROGINDEX,
    INVESTOBJECT,
    SUMMAYEAR4,
    SUMMAOTHERYEARS,
    SUMMAYEAR4DELTA,
    SUMMAOTHERYEARSDELTA,
    CONTRACTCOSTSCLS
  FROM TB_PaymentSchedule
/

CREATE OR REPLACE TRIGGER TR_PAYMENTSCHEDULE_ID
  INSTEAD OF DELETE
  ON PAYMENTSCHEDULE
  FOR EACH ROW
DECLARE
  SummInMonths$ NUMBER(15,2);
  cnt1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_PAYMENTSCHEDULE_BD)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*   6.0*/
  select count(ID) into cnt1$ from PaymentSchedule where (AdjustmentRef = :old.ID) ;
  if (cnt1$ > 0) then
    RaiseException('EX_Agr_CantDelAdjustmented');
  END IF;

  select count(ID)
  into cnt1$   from FacialFinDetail
  where (SourceBudgetPromise = :old.InnerPromiseNum and SourcePromise=:old.ANumber)
  or (DestBudgetPromise = :old.InnerPromiseNum and DestPromise=:old.ANumber)
  ;
  if (cnt1$ > 0) then
    RaiseException('ex_CantDeleteAgreement');
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_PAYMENTSCHEDULE
  WHERE Id = :old.id;

-- - - - - - - - - - - - -
-- AD_10 (TR_PAYMENTSCHEDULE_AD_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/
  /*   LastAdjustment     */
  if ((:old.AdjustmentNumber > 0) and (:old.LastAdjustment = 1)) then
    update PaymentSchedule set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;
  /*   LastAccepted     */    
  if ((:old.AdjustmentNumber > 0) and (:old.LastAccepted = 1)) then
    update PaymentSchedule set
    LastAccepted = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);        
  END IF;

-- - - - - - - - - - - - -
-- AD_500 (TR_PAYMENTSCHEDULE_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  SummInMonths$ := :old.Month01+:old.Month02+:old.Month03+:old.Month04+:old.Month05+
  :old.Month06+:old.Month07+:old.Month08+:old.Month09+:old.Month10+:old.Month11+:old.Month12;
  if ((SummInMonths$  < 0.005) and (SummInMonths$  > -0.005)) then
    SummInMonths$ := :old.SummaYear1;
  END IF;
  insert into DelRecIndexes(TableID, RecordID, DeleteDate, ProgIndex, SUMMA) values (113, :old.ID, SYSDATE, :old.ProgIndex, SummInMonths$);

END;
/

CREATE OR REPLACE TRIGGER TR_PAYMENTSCHEDULE_II
  INSTEAD OF INSERT
  ON PAYMENTSCHEDULE
  FOR EACH ROW
DECLARE
  new$ID PAYMENTSCHEDULE.ID%TYPE := :NEW.ID;
  new$ANUMBER PAYMENTSCHEDULE.ANUMBER%TYPE := :NEW.ANUMBER;
  new$PARENTNUMBER PAYMENTSCHEDULE.PARENTNUMBER%TYPE := :NEW.PARENTNUMBER;
  new$KFSR PAYMENTSCHEDULE.KFSR%TYPE := :NEW.KFSR;
  new$KESR PAYMENTSCHEDULE.KESR%TYPE := :NEW.KESR;
  new$KVSR PAYMENTSCHEDULE.KVSR%TYPE := :NEW.KVSR;
  new$KCSR PAYMENTSCHEDULE.KCSR%TYPE := :NEW.KCSR;
  new$KVR PAYMENTSCHEDULE.KVR%TYPE := :NEW.KVR;
  new$MONTH01 PAYMENTSCHEDULE.MONTH01%TYPE := :NEW.MONTH01;
  new$MONTH02 PAYMENTSCHEDULE.MONTH02%TYPE := :NEW.MONTH02;
  new$MONTH03 PAYMENTSCHEDULE.MONTH03%TYPE := :NEW.MONTH03;
  new$MONTH04 PAYMENTSCHEDULE.MONTH04%TYPE := :NEW.MONTH04;
  new$MONTH05 PAYMENTSCHEDULE.MONTH05%TYPE := :NEW.MONTH05;
  new$MONTH06 PAYMENTSCHEDULE.MONTH06%TYPE := :NEW.MONTH06;
  new$MONTH07 PAYMENTSCHEDULE.MONTH07%TYPE := :NEW.MONTH07;
  new$MONTH08 PAYMENTSCHEDULE.MONTH08%TYPE := :NEW.MONTH08;
  new$MONTH09 PAYMENTSCHEDULE.MONTH09%TYPE := :NEW.MONTH09;
  new$MONTH10 PAYMENTSCHEDULE.MONTH10%TYPE := :NEW.MONTH10;
  new$MONTH11 PAYMENTSCHEDULE.MONTH11%TYPE := :NEW.MONTH11;
  new$MONTH12 PAYMENTSCHEDULE.MONTH12%TYPE := :NEW.MONTH12;
  new$SUMMA PAYMENTSCHEDULE.SUMMA%TYPE := :NEW.SUMMA;
  new$REGION PAYMENTSCHEDULE.REGION%TYPE := :NEW.REGION;
  new$SUBKESR PAYMENTSCHEDULE.SUBKESR%TYPE := :NEW.SUBKESR;
  new$MEANSTYPE PAYMENTSCHEDULE.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FINSOURCE PAYMENTSCHEDULE.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE PAYMENTSCHEDULE.FINTYPE%TYPE := :NEW.FINTYPE;
  new$FACT PAYMENTSCHEDULE.FACT%TYPE := :NEW.FACT;
  new$FACIALACC_CLS PAYMENTSCHEDULE.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$CREATERUSER PAYMENTSCHEDULE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYMENTSCHEDULE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PAYMENTSCHEDULE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PAYMENTSCHEDULE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF PAYMENTSCHEDULE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$ACCEPTDATE PAYMENTSCHEDULE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$LASTADJUSTMENT PAYMENTSCHEDULE.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$ACCEPTED PAYMENTSCHEDULE.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED PAYMENTSCHEDULE.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$PROMISETYPE PAYMENTSCHEDULE.PROMISETYPE%TYPE := :NEW.PROMISETYPE;
  new$ADJUSTMENTREF PAYMENTSCHEDULE.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$OLDNUMBER PAYMENTSCHEDULE.OLDNUMBER%TYPE := :NEW.OLDNUMBER;
  new$SUMMAPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAPREVIOUSYEAR%TYPE := :NEW.SUMMAPREVIOUSYEAR;
  new$SUMMAFINPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAFINPREVIOUSYEAR%TYPE := :NEW.SUMMAFINPREVIOUSYEAR;
  new$QUARTER1 PAYMENTSCHEDULE.QUARTER1%TYPE := :NEW.QUARTER1;
  new$QUARTER2 PAYMENTSCHEDULE.QUARTER2%TYPE := :NEW.QUARTER2;
  new$QUARTER3 PAYMENTSCHEDULE.QUARTER3%TYPE := :NEW.QUARTER3;
  new$QUARTER4 PAYMENTSCHEDULE.QUARTER4%TYPE := :NEW.QUARTER4;
  new$RECORDINDEX PAYMENTSCHEDULE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CRYPTOSTATUS PAYMENTSCHEDULE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID PAYMENTSCHEDULE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PAYMENTSCHEDULE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DIRECTIONCLS PAYMENTSCHEDULE.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$RVERSION PAYMENTSCHEDULE.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYMENTSCHEDULE.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MONTH01DELTA PAYMENTSCHEDULE.MONTH01DELTA%TYPE := :NEW.MONTH01DELTA;
  new$MONTH02DELTA PAYMENTSCHEDULE.MONTH02DELTA%TYPE := :NEW.MONTH02DELTA;
  new$MONTH03DELTA PAYMENTSCHEDULE.MONTH03DELTA%TYPE := :NEW.MONTH03DELTA;
  new$MONTH04DELTA PAYMENTSCHEDULE.MONTH04DELTA%TYPE := :NEW.MONTH04DELTA;
  new$MONTH05DELTA PAYMENTSCHEDULE.MONTH05DELTA%TYPE := :NEW.MONTH05DELTA;
  new$MONTH06DELTA PAYMENTSCHEDULE.MONTH06DELTA%TYPE := :NEW.MONTH06DELTA;
  new$MONTH07DELTA PAYMENTSCHEDULE.MONTH07DELTA%TYPE := :NEW.MONTH07DELTA;
  new$MONTH08DELTA PAYMENTSCHEDULE.MONTH08DELTA%TYPE := :NEW.MONTH08DELTA;
  new$MONTH09DELTA PAYMENTSCHEDULE.MONTH09DELTA%TYPE := :NEW.MONTH09DELTA;
  new$MONTH10DELTA PAYMENTSCHEDULE.MONTH10DELTA%TYPE := :NEW.MONTH10DELTA;
  new$MONTH11DELTA PAYMENTSCHEDULE.MONTH11DELTA%TYPE := :NEW.MONTH11DELTA;
  new$MONTH12DELTA PAYMENTSCHEDULE.MONTH12DELTA%TYPE := :NEW.MONTH12DELTA;
  new$QUARTER1DELTA PAYMENTSCHEDULE.QUARTER1DELTA%TYPE := :NEW.QUARTER1DELTA;
  new$QUARTER2DELTA PAYMENTSCHEDULE.QUARTER2DELTA%TYPE := :NEW.QUARTER2DELTA;
  new$QUARTER3DELTA PAYMENTSCHEDULE.QUARTER3DELTA%TYPE := :NEW.QUARTER3DELTA;
  new$QUARTER4DELTA PAYMENTSCHEDULE.QUARTER4DELTA%TYPE := :NEW.QUARTER4DELTA;
  new$SUMMADELTA PAYMENTSCHEDULE.SUMMADELTA%TYPE := :NEW.SUMMADELTA;
  new$NOTE PAYMENTSCHEDULE.NOTE%TYPE := :NEW.NOTE;
  new$FINYEAR PAYMENTSCHEDULE.FINYEAR%TYPE := :NEW.FINYEAR;
  new$SUMMAYEAR1 PAYMENTSCHEDULE.SUMMAYEAR1%TYPE := :NEW.SUMMAYEAR1;
  new$SUMMAYEAR2 PAYMENTSCHEDULE.SUMMAYEAR2%TYPE := :NEW.SUMMAYEAR2;
  new$SUMMAYEAR3 PAYMENTSCHEDULE.SUMMAYEAR3%TYPE := :NEW.SUMMAYEAR3;
  new$SUMMAYEAR1DELTA PAYMENTSCHEDULE.SUMMAYEAR1DELTA%TYPE := :NEW.SUMMAYEAR1DELTA;
  new$SUMMAYEAR2DELTA PAYMENTSCHEDULE.SUMMAYEAR2DELTA%TYPE := :NEW.SUMMAYEAR2DELTA;
  new$SUMMAYEAR3DELTA PAYMENTSCHEDULE.SUMMAYEAR3DELTA%TYPE := :NEW.SUMMAYEAR3DELTA;
  new$ASSIGNMENTKIND PAYMENTSCHEDULE.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$TRANSFERTCLS PAYMENTSCHEDULE.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SENDERIDKEY PAYMENTSCHEDULE.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY PAYMENTSCHEDULE.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXECUTIONREF PAYMENTSCHEDULE.EXECUTIONREF%TYPE := :NEW.EXECUTIONREF;
  new$INNERPROMISENUM PAYMENTSCHEDULE.INNERPROMISENUM%TYPE := :NEW.INNERPROMISENUM;
  new$ADJUSTMENTNUMBER PAYMENTSCHEDULE.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$PROMISENUMBER PAYMENTSCHEDULE.PROMISENUMBER%TYPE := :NEW.PROMISENUMBER;
  new$SUBSIDYCLS PAYMENTSCHEDULE.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$AGREEMENTREF PAYMENTSCHEDULE.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$BUDALLOCATIONCLS PAYMENTSCHEDULE.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS PAYMENTSCHEDULE.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$PROGINDEX PAYMENTSCHEDULE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$INVESTOBJECT PAYMENTSCHEDULE.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$SUMMAYEAR4 PAYMENTSCHEDULE.SUMMAYEAR4%TYPE := :NEW.SUMMAYEAR4;
  new$SUMMAOTHERYEARS PAYMENTSCHEDULE.SUMMAOTHERYEARS%TYPE := :NEW.SUMMAOTHERYEARS;
  new$SUMMAYEAR4DELTA PAYMENTSCHEDULE.SUMMAYEAR4DELTA%TYPE := :NEW.SUMMAYEAR4DELTA;
  new$SUMMAOTHERYEARSDELTA PAYMENTSCHEDULE.SUMMAOTHERYEARSDELTA%TYPE := :NEW.SUMMAOTHERYEARSDELTA;
  new$CONTRACTCOSTSCLS PAYMENTSCHEDULE.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
--
  M01$ NUMBER;
  M02$ NUMBER;
  M03$ NUMBER;
  M04$ NUMBER;
  M05$ NUMBER;
  M06$ NUMBER;
  M07$ NUMBER;
  M08$ NUMBER;
  M09$ NUMBER;
  M10$ NUMBER;
  M11$ NUMBER;
  M12$ NUMBER;
  Q1$ NUMBER;
  Q2$ NUMBER;
  Q3$ NUMBER;
  Q4$ NUMBER;
  S$ NUMBER;
  S1$ NUMBER;
  S2$ NUMBER;
  S3$ NUMBER;
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  Tmp$ NUMBER(10);
  AdjID$ NUMBER(10);
  AdjDocNum$ NUMBER(10);
  InnerNumber_parent$ NUMBER(10);
  InnerNumber_child$ NUMBER(10);
  S4$ NUMBER;
  SOther$ NUMBER;
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_PAYMENTSCHEDULE_BI)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$Accepted is null) then 
    new$Accepted := 1;
  END IF;
  if (new$PromiseType is null) then 
    new$PromiseType := 0;
  END IF;
  if (new$KFSR is null) then 
    new$KFSR := 0;
  END IF;
  if (new$KESR is null) then 
    new$KESR := 0;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$KCSR is null) then 
    new$KCSR := 0;
  END IF;
  if (new$KVR is null) then 
    new$KVR := 0;
  END IF;
  if (new$SubKESR is null) then 
    new$SubKESR := 0;
  END IF;
  if (new$AssignmentKind is null) then 
    new$AssignmentKind := 0;
  END IF;
  if (new$DirectionCls is null) then 
    new$DirectionCls := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Region is null) then 
    new$Region := 0;
  END IF;
  if (new$MeansType is null) then 
    new$MeansType := 0;
  END IF;
  if (new$FinSource is null) then 
    new$FinSource := 0;
  END IF;
  if (new$FinType is null) then 
    new$FinType := 0;
  END IF;
  if (new$Fact is null) then 
    new$Fact := 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$Month01 is null) then 
    new$Month01 := 0;
  END IF;
  if (new$Month02 is null) then 
    new$Month02 := 0;
  END IF;
  if (new$Month03 is null) then 
    new$Month03 := 0;
  END IF;
  if (new$Month04 is null) then 
    new$Month04 := 0;
  END IF;
  if (new$Month05 is null) then 
    new$Month05 := 0;
  END IF;
  if (new$Month06 is null) then 
    new$Month06 := 0;
  END IF;
  if (new$Month07 is null) then 
    new$Month07 := 0;
  END IF;
  if (new$Month08 is null) then 
    new$Month08 := 0;
  END IF;
  if (new$Month09 is null) then 
    new$Month09 := 0;
  END IF;
  if (new$Month10 is null) then 
    new$Month10 := 0;
  END IF;
  if (new$Month11 is null) then 
    new$Month11 := 0;
  END IF;
  if (new$Month12 is null) then 
    new$Month12 := 0;
  END IF;
  if (new$Quarter1 is null) then 
    new$Quarter1 := 0;
  END IF;
  if (new$Quarter2 is null) then 
    new$Quarter2 := 0;
  END IF;
  if (new$Quarter3 is null) then 
    new$Quarter3 := 0;
  END IF;
  if (new$Quarter4 is null) then 
    new$Quarter4 := 0;
  END IF;
  if (new$Summa is null) then 
    new$Summa := 0;
  END IF;
  if (new$Month01Delta is null) then 
    new$Month01Delta := 0;
  END IF;
  if (new$Month02Delta is null) then 
    new$Month02Delta := 0;
  END IF;
  if (new$Month03Delta is null) then 
    new$Month03Delta := 0;
  END IF;
  if (new$Month04Delta is null) then 
    new$Month04Delta := 0;
  END IF;
  if (new$Month05Delta is null) then 
    new$Month05Delta := 0;
  END IF;
  if (new$Month06Delta is null) then 
    new$Month06Delta := 0;
  END IF;
  if (new$Month07Delta is null) then 
    new$Month07Delta := 0;
  END IF;
  if (new$Month08Delta is null) then 
    new$Month08Delta := 0;
  END IF;
  if (new$Month09Delta is null) then 
    new$Month09Delta := 0;
  END IF;
  if (new$Month10Delta is null) then 
    new$Month10Delta := 0;
  END IF;
  if (new$Month11Delta is null) then 
    new$Month11Delta := 0;
  END IF;
  if (new$Month12Delta is null) then 
    new$Month12Delta := 0;
  END IF;
  if (new$Quarter1Delta is null) then 
    new$Quarter1Delta := 0;
  END IF;
  if (new$Quarter2Delta is null) then 
    new$Quarter2Delta := 0;
  END IF;
  if (new$Quarter3Delta is null) then 
    new$Quarter3Delta := 0;
  END IF;
  if (new$Quarter4Delta is null) then 
    new$Quarter4Delta := 0;
  END IF;
  if (new$SummaDelta is null) then 
    new$SummaDelta := 0;
  END IF;
  if (new$SummaPreviousYear is null) then 
    new$SummaPreviousYear := 0;
  END IF;
  if (new$SummaFinPreviousYear is null) then 
    new$SummaFinPreviousYear := 0;
  END IF;
  if (new$SummaYear1 is null) then 
    new$SummaYear1 := 0;
  END IF;
  if (new$SummaYear2 is null) then 
    new$SummaYear2 := 0;
  END IF;
  if (new$SummaYear3 is null) then 
    new$SummaYear3 := 0;
  END IF;
  if (new$SummaYear4 is null) then 
    new$SummaYear4 := 0;
  END IF;
  if (new$SummaOtherYears is null) then 
    new$SummaOtherYears := 0;
  END IF;
  if (new$SummaYear1Delta is null) then 
    new$SummaYear1Delta := 0;
  END IF;
  if (new$SummaYear2Delta is null) then 
    new$SummaYear2Delta := 0;
  END IF;
  if (new$SummaYear3Delta is null) then 
    new$SummaYear3Delta := 0;
  END IF;
  if (new$SummaYear4Delta is null) then 
    new$SummaYear4Delta := 0;
  END IF;
  if (new$SummaOtherYearsDelta is null) then 
    new$SummaOtherYearsDelta := 0;
  END IF;
  /*   ,        */
  if (new$ProgIndex = 304 and new$RecordIndex is not null) then
    SELECT COUNT(*) INTO CNT$1
    from AgreementSteps s where (s.Id = new$RecordIndex and s.RecordIndex = new$AgreementRef) AND (ROWNUM = 1);
    if (not (CNT$1<> 0)) then
      RaiseException('Ex_WrongStep');
    END IF;
  END IF;
  /*       */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    if (new$ProgIndex in (304,314,317,318)) then
      BEGIN
        select a.BudgetRef       into new$BudgetRef from Agreements a
        where a.ID = new$AgreementRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    else 
      if (new$ProgIndex = 308) then
        BEGIN
          select e.BudgetRef
          into new$BudgetRef       from ExecutionDocumentsCaption e
          where e.ID = new$ExecutionRef
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
      END IF;
    END IF;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$ANumber is not null) then
    SELECT COUNT(                    id
    ) INTO CNT$2
    from
    PaymentSchedule ps
    where
    (                    (ps.ANumber = new$ANumber)
    and
    (ps.BudgetRef = new$BudgetRef)) AND (ROWNUM = 1);
    if ((CNT$2<> 0)) then
      RaiseException('ex_Promise_NumUQ');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_1 (TR_PAYMENTSCHEDULE_BI_1)
-- Create 05.03.2004
-- Last update 29.12.2007
-- - - - - - - - - - - - -

/*   1.0*/
    if (new$Quarter1 = 0) then new$Quarter1 := new$Month01 + new$Month02 + new$Month03; end if;
    if (new$Quarter2 = 0) then new$Quarter2 := new$Month04 + new$Month05 + new$Month06; end if;
    if (new$Quarter3 = 0) then new$Quarter3 := new$Month07 + new$Month08 + new$Month09; end if;
    if (new$Quarter4 = 0) then new$Quarter4 := new$Month10 + new$Month11 + new$Month12; end if;
    new$SummaYear1 := new$Quarter1 + new$Quarter2 + new$Quarter3 + new$Quarter4;

-- - - - - - - - - - - - -
-- BI_10 (TR_PAYMENTSCHEDULE_BI_10)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   5.0*/
     
  /*    .*/
  if (new$InnerPromiseNum is null) then
    RaiseException('EX_BP_InnerNumsIsNull');
  END IF;
      
  /*    */
  select max(AdjustmentNumber)
  into Tmp$         from PaymentSchedule 
  where (InnerPromiseNum = new$InnerPromiseNum)
  ;
  /*      ,   0*/
  if (Tmp$ is null) then
    new$AdjustmentNumber := 0;
        
  else
    new$AdjustmentNumber := Tmp$ + 1;
  END IF;
      
  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;
        
  else
    new$LastAdjustment := 1;
  END IF;
      
  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then 
    new$LastAccepted := 1;
        
  else
    new$LastAccepted := 0;
  END IF;
  /*    */
  if (new$AdjustmentNumber > 0) then
    /*      -    */
    select count(ID), max(ID), max(ANumber)
    into Tmp$, AdjID$, AdjDocNum$             from PaymentSchedule
    where (InnerPromiseNum = new$InnerPromiseNum) and (LastAccepted = 1)
    ;
    /*   ,  */
    if (Tmp$ <> 1) then 
      RaiseException('EX_BP_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID) 
    into Tmp$             from PaymentSchedule
    where (InnerPromiseNum = new$InnerPromiseNum) and (AcceptDate is null)
    ;
    if (Tmp$ > 0) then 
      RaiseException('EX_BP_AdjustDuplicate');
    END IF;
    /* ,    ,    */        
    new$AdjustmentRef := AdjID$;
    new$ParentNumber := AdjDocNum$;
    /*   - ,  ,       */
    if (new$ProgIndex in (304, 314)) then
      BEGIN
        /*     */        
        select a.InnerNumber
        into InnerNumber_child$             from Agreements a
        where a.ID = new$AgreementRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN
        /*       */
        select a.InnerNumber
        into InnerNumber_parent$             from PaymentSchedule ps
        left join Agreements a on (a.Id = ps.AgreementRef)
        where (ps.Id = new$AdjustmentRef)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*      */
      if (InnerNumber_parent$ <> InnerNumber_child$) then
        RaiseException('EX_PROMISE_ADJ_INCORRECT');        
      END IF;
    else 
      if (new$ProgIndex = 308) then
        BEGIN
          /*     */        
          select edc.InnerNumber
          into InnerNumber_child$             from ExecutionDocumentsCaption edc
          where edc.ID = new$ExecutionRef
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        BEGIN
          /*       */
          select edc.InnerNumber
          into InnerNumber_parent$             from PaymentSchedule ps
          left join ExecutionDocumentsCaption edc on (edc.id=ps.ExecutionRef)
          where (ps.Id = new$AdjustmentRef)
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        /*      */
        if (InnerNumber_parent$ <> InnerNumber_child$) then
          RaiseException('EX_PROMISE_ADJ_INCORRECT');        
        END IF;
      END IF;    
    END IF;
  else /*     */
    /*       (    )*/        
    new$AdjustmentRef := null;
    new$ParentNumber := null;
        
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_PAYMENTSCHEDULE_BI_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*           */
  if (new$AdjustmentNumber > 0) then
    BEGIN
      select 
      Month01, Month02, Month03, Month04, Month05, Month06,
      Month07, Month08, Month09, Month10, Month11, Month12,
      Quarter1, Quarter2, Quarter3, Quarter4, Summa, 
      SummaYear1, SummaYear2, SummaYear3, SummaYear4, SummaOtherYears
      into
      M01$, M02$, M03$, M04$, M05$, M06$, M07$, M08$, M09$, M10$, M11$, M12$, 
      Q1$, Q2$, Q3$, Q4$, S$, S1$, S2$, S3$, S4$, SOther$         from 
      PaymentSchedule
      where
      ID = new$AdjustmentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
          
    new$Month01Delta := new$Month01 - M01$;
    new$Month02Delta := new$Month02 - M02$;
    new$Month03Delta := new$Month03 - M03$;
    new$Month04Delta := new$Month04 - M04$;
    new$Month05Delta := new$Month05 - M05$;
    new$Month06Delta := new$Month06 - M06$;
    new$Month07Delta := new$Month07 - M07$;
    new$Month08Delta := new$Month08 - M08$;
    new$Month09Delta := new$Month09 - M09$;
    new$Month10Delta := new$Month10 - M10$;
    new$Month11Delta := new$Month11 - M11$;
    new$Month12Delta := new$Month12 - M12$;
    new$Quarter1Delta := new$Quarter1 - Q1$;
    new$Quarter2Delta := new$Quarter2 - Q2$;
    new$Quarter3Delta := new$Quarter3 - Q3$;
    new$Quarter4Delta := new$Quarter4 - Q4$;
    new$SummaDelta := new$Summa - S$;
    new$SummaYear1Delta := new$SummaYear1 - S1$;
    new$SummaYear2Delta := new$SummaYear2 - S2$;
    new$SummaYear3Delta := new$SummaYear3 - S3$;
    new$SummaYear4Delta := new$SummaYear4 - S4$;
    new$SummaOtherYearsDelta := new$SummaOtherYears - SOther$;        
        
  else    /*        */  
    new$Month01Delta := new$Month01;
    new$Month02Delta := new$Month02;
    new$Month03Delta := new$Month03;
    new$Month04Delta := new$Month04;
    new$Month05Delta := new$Month05;
    new$Month06Delta := new$Month06;
    new$Month07Delta := new$Month07;
    new$Month08Delta := new$Month08;
    new$Month09Delta := new$Month09;
    new$Month10Delta := new$Month10;
    new$Month11Delta := new$Month11;
    new$Month12Delta := new$Month12;
    new$Quarter1Delta := new$Quarter1;
    new$Quarter2Delta := new$Quarter2;
    new$Quarter3Delta := new$Quarter3;
    new$Quarter4Delta := new$Quarter4;
    new$SummaDelta := new$Summa;
    new$SummaYear1Delta := new$SummaYear1;
    new$SummaYear2Delta := new$SummaYear2;
    new$SummaYear3Delta := new$SummaYear3;
    new$SummaYear4Delta := new$SummaYear4;
    new$SummaOtherYearsDelta := new$SummaOtherYears;        
        
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_PAYMENTSCHEDULE_BI_200)
-- Create 06.08.2010
-- - - - - - - - - - - - -

  /*      */
  if (new$senderId is null) then 
    new$senderIdKey := -1;
  else
    new$senderIdKey := new$senderId;
  end if;

  if (new$SenderRecordID is null)then
    new$SenderRecordIDKey := new$ID;
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  end if;       

-- - - - - - - - - - - - -
-- BI_500 (TR_PAYMENTSCHEDULE_BI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_PAYMENTSCHEDULE (
    ID,
    ANUMBER,
    PARENTNUMBER,
    KFSR,
    KESR,
    KVSR,
    KCSR,
    KVR,
    MONTH01,
    MONTH02,
    MONTH03,
    MONTH04,
    MONTH05,
    MONTH06,
    MONTH07,
    MONTH08,
    MONTH09,
    MONTH10,
    MONTH11,
    MONTH12,
    SUMMA,
    REGION,
    SUBKESR,
    MEANSTYPE,
    FINSOURCE,
    FINTYPE,
    FACT,
    FACIALACC_CLS,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    ACCEPTDATE,
    LASTADJUSTMENT,
    ACCEPTED,
    LASTACCEPTED,
    PROMISETYPE,
    ADJUSTMENTREF,
    OLDNUMBER,
    SUMMAPREVIOUSYEAR,
    SUMMAFINPREVIOUSYEAR,
    QUARTER1,
    QUARTER2,
    QUARTER3,
    QUARTER4,
    RECORDINDEX,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DIRECTIONCLS,
    RVERSION,
    BUHOPERATIONCLS,
    MONTH01DELTA,
    MONTH02DELTA,
    MONTH03DELTA,
    MONTH04DELTA,
    MONTH05DELTA,
    MONTH06DELTA,
    MONTH07DELTA,
    MONTH08DELTA,
    MONTH09DELTA,
    MONTH10DELTA,
    MONTH11DELTA,
    MONTH12DELTA,
    QUARTER1DELTA,
    QUARTER2DELTA,
    QUARTER3DELTA,
    QUARTER4DELTA,
    SUMMADELTA,
    NOTE,
    FINYEAR,
    SUMMAYEAR1,
    SUMMAYEAR2,
    SUMMAYEAR3,
    SUMMAYEAR1DELTA,
    SUMMAYEAR2DELTA,
    SUMMAYEAR3DELTA,
    ASSIGNMENTKIND,
    TRANSFERTCLS,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    EXECUTIONREF,
    INNERPROMISENUM,
    ADJUSTMENTNUMBER,
    PROMISENUMBER,
    SUBSIDYCLS,
    AGREEMENTREF,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    PROGINDEX,
    INVESTOBJECT,
    SUMMAYEAR4,
    SUMMAOTHERYEARS,
    SUMMAYEAR4DELTA,
    SUMMAOTHERYEARSDELTA,
    CONTRACTCOSTSCLS
  ) VALUES (
    new$ID,
    new$ANUMBER,
    new$PARENTNUMBER,
    new$KFSR,
    new$KESR,
    new$KVSR,
    new$KCSR,
    new$KVR,
    new$MONTH01,
    new$MONTH02,
    new$MONTH03,
    new$MONTH04,
    new$MONTH05,
    new$MONTH06,
    new$MONTH07,
    new$MONTH08,
    new$MONTH09,
    new$MONTH10,
    new$MONTH11,
    new$MONTH12,
    new$SUMMA,
    new$REGION,
    new$SUBKESR,
    new$MEANSTYPE,
    new$FINSOURCE,
    new$FINTYPE,
    new$FACT,
    new$FACIALACC_CLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$ACCEPTDATE,
    new$LASTADJUSTMENT,
    new$ACCEPTED,
    new$LASTACCEPTED,
    new$PROMISETYPE,
    new$ADJUSTMENTREF,
    new$OLDNUMBER,
    new$SUMMAPREVIOUSYEAR,
    new$SUMMAFINPREVIOUSYEAR,
    new$QUARTER1,
    new$QUARTER2,
    new$QUARTER3,
    new$QUARTER4,
    new$RECORDINDEX,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$DIRECTIONCLS,
    new$RVERSION,
    new$BUHOPERATIONCLS,
    new$MONTH01DELTA,
    new$MONTH02DELTA,
    new$MONTH03DELTA,
    new$MONTH04DELTA,
    new$MONTH05DELTA,
    new$MONTH06DELTA,
    new$MONTH07DELTA,
    new$MONTH08DELTA,
    new$MONTH09DELTA,
    new$MONTH10DELTA,
    new$MONTH11DELTA,
    new$MONTH12DELTA,
    new$QUARTER1DELTA,
    new$QUARTER2DELTA,
    new$QUARTER3DELTA,
    new$QUARTER4DELTA,
    new$SUMMADELTA,
    new$NOTE,
    new$FINYEAR,
    new$SUMMAYEAR1,
    new$SUMMAYEAR2,
    new$SUMMAYEAR3,
    new$SUMMAYEAR1DELTA,
    new$SUMMAYEAR2DELTA,
    new$SUMMAYEAR3DELTA,
    new$ASSIGNMENTKIND,
    new$TRANSFERTCLS,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$EXECUTIONREF,
    new$INNERPROMISENUM,
    new$ADJUSTMENTNUMBER,
    new$PROMISENUMBER,
    new$SUBSIDYCLS,
    new$AGREEMENTREF,
    new$BUDALLOCATIONCLS,
    new$PAYPROMISECLS,
    new$PROGINDEX,
    new$INVESTOBJECT,
    new$SUMMAYEAR4,
    new$SUMMAOTHERYEARS,
    new$SUMMAYEAR4DELTA,
    new$SUMMAOTHERYEARSDELTA,
    new$CONTRACTCOSTSCLS);

-- - - - - - - - - - - - -
-- AI_10 (TR_PAYMENTSCHEDULE_AI_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/
  /*      */
  if ((new$AdjustmentNumber > 0) and (new$LastAdjustment = 1)) then
    update PaymentSchedule set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);            
    if (new$LastAccepted = 1) then
      update PaymentSchedule set
      LastAccepted = 0,
      RVersion = -1
      where (ID = new$AdjustmentRef);
        
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_PAYMENTSCHEDULE_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 113) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_PAYMENTSCHEDULE_IU
  INSTEAD OF UPDATE
  ON PAYMENTSCHEDULE
  FOR EACH ROW
DECLARE
  new$ID PAYMENTSCHEDULE.ID%TYPE := :NEW.ID;
  new$ANUMBER PAYMENTSCHEDULE.ANUMBER%TYPE := :NEW.ANUMBER;
  new$PARENTNUMBER PAYMENTSCHEDULE.PARENTNUMBER%TYPE := :NEW.PARENTNUMBER;
  new$KFSR PAYMENTSCHEDULE.KFSR%TYPE := :NEW.KFSR;
  new$KESR PAYMENTSCHEDULE.KESR%TYPE := :NEW.KESR;
  new$KVSR PAYMENTSCHEDULE.KVSR%TYPE := :NEW.KVSR;
  new$KCSR PAYMENTSCHEDULE.KCSR%TYPE := :NEW.KCSR;
  new$KVR PAYMENTSCHEDULE.KVR%TYPE := :NEW.KVR;
  new$MONTH01 PAYMENTSCHEDULE.MONTH01%TYPE := :NEW.MONTH01;
  new$MONTH02 PAYMENTSCHEDULE.MONTH02%TYPE := :NEW.MONTH02;
  new$MONTH03 PAYMENTSCHEDULE.MONTH03%TYPE := :NEW.MONTH03;
  new$MONTH04 PAYMENTSCHEDULE.MONTH04%TYPE := :NEW.MONTH04;
  new$MONTH05 PAYMENTSCHEDULE.MONTH05%TYPE := :NEW.MONTH05;
  new$MONTH06 PAYMENTSCHEDULE.MONTH06%TYPE := :NEW.MONTH06;
  new$MONTH07 PAYMENTSCHEDULE.MONTH07%TYPE := :NEW.MONTH07;
  new$MONTH08 PAYMENTSCHEDULE.MONTH08%TYPE := :NEW.MONTH08;
  new$MONTH09 PAYMENTSCHEDULE.MONTH09%TYPE := :NEW.MONTH09;
  new$MONTH10 PAYMENTSCHEDULE.MONTH10%TYPE := :NEW.MONTH10;
  new$MONTH11 PAYMENTSCHEDULE.MONTH11%TYPE := :NEW.MONTH11;
  new$MONTH12 PAYMENTSCHEDULE.MONTH12%TYPE := :NEW.MONTH12;
  new$SUMMA PAYMENTSCHEDULE.SUMMA%TYPE := :NEW.SUMMA;
  new$REGION PAYMENTSCHEDULE.REGION%TYPE := :NEW.REGION;
  new$SUBKESR PAYMENTSCHEDULE.SUBKESR%TYPE := :NEW.SUBKESR;
  new$MEANSTYPE PAYMENTSCHEDULE.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FINSOURCE PAYMENTSCHEDULE.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE PAYMENTSCHEDULE.FINTYPE%TYPE := :NEW.FINTYPE;
  new$FACT PAYMENTSCHEDULE.FACT%TYPE := :NEW.FACT;
  new$FACIALACC_CLS PAYMENTSCHEDULE.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$CREATERUSER PAYMENTSCHEDULE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYMENTSCHEDULE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PAYMENTSCHEDULE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PAYMENTSCHEDULE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF PAYMENTSCHEDULE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$ACCEPTDATE PAYMENTSCHEDULE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$LASTADJUSTMENT PAYMENTSCHEDULE.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$ACCEPTED PAYMENTSCHEDULE.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED PAYMENTSCHEDULE.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$PROMISETYPE PAYMENTSCHEDULE.PROMISETYPE%TYPE := :NEW.PROMISETYPE;
  new$ADJUSTMENTREF PAYMENTSCHEDULE.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$OLDNUMBER PAYMENTSCHEDULE.OLDNUMBER%TYPE := :NEW.OLDNUMBER;
  new$SUMMAPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAPREVIOUSYEAR%TYPE := :NEW.SUMMAPREVIOUSYEAR;
  new$SUMMAFINPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAFINPREVIOUSYEAR%TYPE := :NEW.SUMMAFINPREVIOUSYEAR;
  new$QUARTER1 PAYMENTSCHEDULE.QUARTER1%TYPE := :NEW.QUARTER1;
  new$QUARTER2 PAYMENTSCHEDULE.QUARTER2%TYPE := :NEW.QUARTER2;
  new$QUARTER3 PAYMENTSCHEDULE.QUARTER3%TYPE := :NEW.QUARTER3;
  new$QUARTER4 PAYMENTSCHEDULE.QUARTER4%TYPE := :NEW.QUARTER4;
  new$RECORDINDEX PAYMENTSCHEDULE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CRYPTOSTATUS PAYMENTSCHEDULE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID PAYMENTSCHEDULE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PAYMENTSCHEDULE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DIRECTIONCLS PAYMENTSCHEDULE.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$RVERSION PAYMENTSCHEDULE.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYMENTSCHEDULE.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MONTH01DELTA PAYMENTSCHEDULE.MONTH01DELTA%TYPE := :NEW.MONTH01DELTA;
  new$MONTH02DELTA PAYMENTSCHEDULE.MONTH02DELTA%TYPE := :NEW.MONTH02DELTA;
  new$MONTH03DELTA PAYMENTSCHEDULE.MONTH03DELTA%TYPE := :NEW.MONTH03DELTA;
  new$MONTH04DELTA PAYMENTSCHEDULE.MONTH04DELTA%TYPE := :NEW.MONTH04DELTA;
  new$MONTH05DELTA PAYMENTSCHEDULE.MONTH05DELTA%TYPE := :NEW.MONTH05DELTA;
  new$MONTH06DELTA PAYMENTSCHEDULE.MONTH06DELTA%TYPE := :NEW.MONTH06DELTA;
  new$MONTH07DELTA PAYMENTSCHEDULE.MONTH07DELTA%TYPE := :NEW.MONTH07DELTA;
  new$MONTH08DELTA PAYMENTSCHEDULE.MONTH08DELTA%TYPE := :NEW.MONTH08DELTA;
  new$MONTH09DELTA PAYMENTSCHEDULE.MONTH09DELTA%TYPE := :NEW.MONTH09DELTA;
  new$MONTH10DELTA PAYMENTSCHEDULE.MONTH10DELTA%TYPE := :NEW.MONTH10DELTA;
  new$MONTH11DELTA PAYMENTSCHEDULE.MONTH11DELTA%TYPE := :NEW.MONTH11DELTA;
  new$MONTH12DELTA PAYMENTSCHEDULE.MONTH12DELTA%TYPE := :NEW.MONTH12DELTA;
  new$QUARTER1DELTA PAYMENTSCHEDULE.QUARTER1DELTA%TYPE := :NEW.QUARTER1DELTA;
  new$QUARTER2DELTA PAYMENTSCHEDULE.QUARTER2DELTA%TYPE := :NEW.QUARTER2DELTA;
  new$QUARTER3DELTA PAYMENTSCHEDULE.QUARTER3DELTA%TYPE := :NEW.QUARTER3DELTA;
  new$QUARTER4DELTA PAYMENTSCHEDULE.QUARTER4DELTA%TYPE := :NEW.QUARTER4DELTA;
  new$SUMMADELTA PAYMENTSCHEDULE.SUMMADELTA%TYPE := :NEW.SUMMADELTA;
  new$NOTE PAYMENTSCHEDULE.NOTE%TYPE := :NEW.NOTE;
  new$FINYEAR PAYMENTSCHEDULE.FINYEAR%TYPE := :NEW.FINYEAR;
  new$SUMMAYEAR1 PAYMENTSCHEDULE.SUMMAYEAR1%TYPE := :NEW.SUMMAYEAR1;
  new$SUMMAYEAR2 PAYMENTSCHEDULE.SUMMAYEAR2%TYPE := :NEW.SUMMAYEAR2;
  new$SUMMAYEAR3 PAYMENTSCHEDULE.SUMMAYEAR3%TYPE := :NEW.SUMMAYEAR3;
  new$SUMMAYEAR1DELTA PAYMENTSCHEDULE.SUMMAYEAR1DELTA%TYPE := :NEW.SUMMAYEAR1DELTA;
  new$SUMMAYEAR2DELTA PAYMENTSCHEDULE.SUMMAYEAR2DELTA%TYPE := :NEW.SUMMAYEAR2DELTA;
  new$SUMMAYEAR3DELTA PAYMENTSCHEDULE.SUMMAYEAR3DELTA%TYPE := :NEW.SUMMAYEAR3DELTA;
  new$ASSIGNMENTKIND PAYMENTSCHEDULE.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$TRANSFERTCLS PAYMENTSCHEDULE.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SENDERIDKEY PAYMENTSCHEDULE.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY PAYMENTSCHEDULE.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXECUTIONREF PAYMENTSCHEDULE.EXECUTIONREF%TYPE := :NEW.EXECUTIONREF;
  new$INNERPROMISENUM PAYMENTSCHEDULE.INNERPROMISENUM%TYPE := :NEW.INNERPROMISENUM;
  new$ADJUSTMENTNUMBER PAYMENTSCHEDULE.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$PROMISENUMBER PAYMENTSCHEDULE.PROMISENUMBER%TYPE := :NEW.PROMISENUMBER;
  new$SUBSIDYCLS PAYMENTSCHEDULE.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$AGREEMENTREF PAYMENTSCHEDULE.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$BUDALLOCATIONCLS PAYMENTSCHEDULE.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS PAYMENTSCHEDULE.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$PROGINDEX PAYMENTSCHEDULE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$INVESTOBJECT PAYMENTSCHEDULE.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$SUMMAYEAR4 PAYMENTSCHEDULE.SUMMAYEAR4%TYPE := :NEW.SUMMAYEAR4;
  new$SUMMAOTHERYEARS PAYMENTSCHEDULE.SUMMAOTHERYEARS%TYPE := :NEW.SUMMAOTHERYEARS;
  new$SUMMAYEAR4DELTA PAYMENTSCHEDULE.SUMMAYEAR4DELTA%TYPE := :NEW.SUMMAYEAR4DELTA;
  new$SUMMAOTHERYEARSDELTA PAYMENTSCHEDULE.SUMMAOTHERYEARSDELTA%TYPE := :NEW.SUMMAOTHERYEARSDELTA;
  new$CONTRACTCOSTSCLS PAYMENTSCHEDULE.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
--
  M01$ NUMBER;
  M02$ NUMBER;
  M03$ NUMBER;
  M04$ NUMBER;
  M05$ NUMBER;
  M06$ NUMBER;
  M07$ NUMBER;
  M08$ NUMBER;
  M09$ NUMBER;
  M10$ NUMBER;
  M11$ NUMBER;
  M12$ NUMBER;
  Q1$ NUMBER;
  Q2$ NUMBER;
  Q3$ NUMBER;
  Q4$ NUMBER;
  S$ NUMBER;
  S1$ NUMBER;
  S2$ NUMBER;
  S3$ NUMBER;
  MaxNumber1$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  S4$ NUMBER;
  SOther$ NUMBER;
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_PAYMENTSCHEDULE_BU)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*   2.4*/
  /*    -*/
  if (new$Accepted is null) then 
    new$Accepted := 1;
  END IF;
  if (new$PromiseType is null) then 
    new$PromiseType := 0;
  END IF;
  if (new$KFSR is null) then 
    new$KFSR := 0;
  END IF;
  if (new$KESR is null) then 
    new$KESR := 0;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$KCSR is null) then 
    new$KCSR := 0;
  END IF;
  if (new$KVR is null) then 
    new$KVR := 0;
  END IF;
  if (new$SubKESR is null) then 
    new$SubKESR := 0;
  END IF;
  if (new$AssignmentKind is null) then 
    new$AssignmentKind := 0;
  END IF;
   
  if (new$DirectionCls is null) then 
    new$DirectionCls := 0;
  END IF;
   
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Region is null) then 
    new$Region := 0;
  END IF;
  if (new$MeansType is null) then 
    new$MeansType := 0;
  END IF;
  if (new$FinSource is null) then 
    new$FinSource := 0;
  END IF;
  if (new$FinType is null) then 
    new$FinType := 0;
  END IF;
  if (new$Fact is null) then 
    new$Fact := 0;
  END IF;
  if (new$BuhOperationCLS is null) then 
    GetIntConst(60, 15,new$BuhOperationCLS); 
  END IF;
  if (new$Month01 is null) then 
    new$Month01 := 0;
  END IF;
  if (new$Month02 is null) then 
    new$Month02 := 0;
  END IF;
  if (new$Month03 is null) then 
    new$Month03 := 0;
  END IF;
  if (new$Month04 is null) then 
    new$Month04 := 0;
  END IF;
  if (new$Month05 is null) then 
    new$Month05 := 0;
  END IF;
  if (new$Month06 is null) then 
    new$Month06 := 0;
  END IF;
  if (new$Month07 is null) then 
    new$Month07 := 0;
  END IF;
  if (new$Month08 is null) then 
    new$Month08 := 0;
  END IF;
  if (new$Month09 is null) then 
    new$Month09 := 0;
  END IF;
  if (new$Month10 is null) then 
    new$Month10 := 0;
  END IF;
  if (new$Month11 is null) then 
    new$Month11 := 0;
  END IF;
  if (new$Month12 is null) then 
    new$Month12 := 0;
  END IF;
  if (new$Quarter1 is null) then 
    new$Quarter1 := 0;
  END IF;
  if (new$Quarter2 is null) then 
    new$Quarter2 := 0;
  END IF;
  if (new$Quarter3 is null) then 
    new$Quarter3 := 0;
  END IF;
  if (new$Quarter4 is null) then 
    new$Quarter4 := 0;
  END IF;
  if (new$Summa is null) then 
    new$Summa := 0;
  END IF;
  if (new$Month01Delta is null) then 
    new$Month01Delta := 0;
  END IF;
  if (new$Month02Delta is null) then 
    new$Month02Delta := 0;
  END IF;
  if (new$Month03Delta is null) then 
    new$Month03Delta := 0;
  END IF;
  if (new$Month04Delta is null) then 
    new$Month04Delta := 0;
  END IF;
  if (new$Month05Delta is null) then 
    new$Month05Delta := 0;
  END IF;
  if (new$Month06Delta is null) then 
    new$Month06Delta := 0;
  END IF;
  if (new$Month07Delta is null) then 
    new$Month07Delta := 0;
  END IF;
  if (new$Month08Delta is null) then 
    new$Month08Delta := 0;
  END IF;
  if (new$Month09Delta is null) then 
    new$Month09Delta := 0;
  END IF;
  if (new$Month10Delta is null) then 
    new$Month10Delta := 0;
  END IF;
  if (new$Month11Delta is null) then 
    new$Month11Delta := 0;
  END IF;
  if (new$Month12Delta is null) then 
    new$Month12Delta := 0;
  END IF;
  if (new$Quarter1Delta is null) then 
    new$Quarter1Delta := 0;
  END IF;
  if (new$Quarter2Delta is null) then 
    new$Quarter2Delta := 0;
  END IF;
  if (new$Quarter3Delta is null) then 
    new$Quarter3Delta := 0;
  END IF;
  if (new$Quarter4Delta is null) then 
    new$Quarter4Delta := 0;
  END IF;
  if (new$SummaDelta is null) then 
    new$SummaDelta := 0; 
  END IF;
  if (new$SummaPreviousYear is null) then 
    new$SummaPreviousYear := 0;
  END IF;
  if (new$SummaFinPreviousYear is null) then 
    new$SummaFinPreviousYear := 0;
  END IF;
   
  if (new$SummaYear1 is null) then 
    new$SummaYear1 := 0;
  END IF;
  if (new$SummaYear2 is null) then 
    new$SummaYear2 := 0;
  END IF;
  if (new$SummaYear3 is null) then 
    new$SummaYear3 := 0;
  END IF;
  if (new$SummaYear4 is null) then 
    new$SummaYear4 := 0;
  END IF;
  if (new$SummaOtherYears is null) then 
    new$SummaOtherYears := 0;
  END IF;
   
  if (new$SummaYear1Delta is null) then 
    new$SummaYear1Delta := 0;
  END IF;
  if (new$SummaYear2Delta is null) then 
    new$SummaYear2Delta := 0;
  END IF;
  if (new$SummaYear3Delta is null) then 
    new$SummaYear3Delta := 0;
  END IF;
  if (new$SummaYear4Delta is null) then 
    new$SummaYear4Delta := 0;
  END IF;
  if (new$SummaOtherYearsDelta is null) then 
    new$SummaOtherYearsDelta := 0;
  END IF;
   
  /*   ,        */
  if (new$ProgIndex = 304 and new$RecordIndex is not null and (:old.RecordIndex is null or :old.RecordIndex <> new$RecordIndex)) then
    SELECT COUNT(*) INTO CNT$1
    from AgreementSteps s where (s.Id = new$RecordIndex and s.RecordIndex = new$AgreementRef) AND (ROWNUM = 1);
    if (not (CNT$1<> 0)) then
      RaiseException('Ex_WrongStep');
    END IF;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      RaiseException('Ex_CantModufyBudget');
    END IF;
  END IF;
  if ((:old.ANumber is null) and (new$ANumber is not Null)) then
    SELECT COUNT(                    id
    ) INTO CNT$2
    from
    PaymentSchedule ps
    where
    (                    (ps.ANumber = new$ANumber)
    and
    (ps.BudgetRef = new$BudgetRef)) AND (ROWNUM = 1);
    if ((CNT$2<> 0)) then
      RaiseException('ex_Promise_NumUQ');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_1 (TR_PAYMENTSCHEDULE_BU_1)
-- Create 05.03.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  /*   1.0*/
    if (new$Quarter1 = 0) then new$Quarter1 := new$Month01 + new$Month02 + new$Month03; end if;
    if (new$Quarter2 = 0) then new$Quarter2 := new$Month04 + new$Month05 + new$Month06; end if;
    if (new$Quarter3 = 0) then new$Quarter3 := new$Month07 + new$Month08 + new$Month09; end if;
    if (new$Quarter4 = 0) then new$Quarter4 := new$Month10 + new$Month11 + new$Month12; end if;
    new$SummaYear1 := new$Quarter1 + new$Quarter2 + new$Quarter3 + new$Quarter4;

-- - - - - - - - - - - - -
-- BU_3 (TR_PAYMENTSCHEDULE_BU_3)
-- Create 03.12.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

    /*            */
    new$AdjustmentRef := :old.AdjustmentRef;

-- - - - - - - - - - - - -
-- BU_10 (TR_PAYMENTSCHEDULE_BU_10)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*   5.0*/
  /* ,      ,   */
  if ((new$ANumber <> :old.ANumber) or
  (new$InnerPromiseNum <> :old.InnerPromiseNum) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber)) then
    RaiseException('EX_AGR_ChangeInnerNums');
  END IF;
      
  /*   !!!*/
  if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and 
  ((new$Accepted = 1) or (new$AcceptDate is null))) then
    RaiseException('EX_RollbackCancel');
  END IF;
  /*   ,     LastAccepted*/
  if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) or 
  ((:old.Accepted = 0) and (new$Accepted = 1) and (new$AcceptDate is not null))) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;
              
    else
      RaiseException('EX_BP_ChangeStateAdjust');    
    END IF;
  END IF;
      
  /*    ,     LastAccepted*/
  if (((:old.AcceptDate is not null) and (:old.Accepted = 1)) and
  ((new$Accepted = 0) or (new$AcceptDate is null))) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 0;
              
    else
      RaiseException('EX_BP_ChangeStateAdjust');    
    END IF;
  END IF;
      
  /*   ,     LastAdjustment*/
  if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 0)) or 
  ((:old.Accepted = 1) and (new$Accepted = 0) and (new$AcceptDate is not null))) then
    if (new$LastAdjustment = 1) then
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
              
    else
      RaiseException('EX_AGR_ChangeStateAdjust');
    END IF;

    select max(AdjustmentNumber) into MaxNumber1$ from PaymentSchedule 
    where (InnerPromiseNum = new$InnerPromiseNum) ;
    /*    ,     */
    if ((new$adjustmentNumber=0) and (MaxNumber1$<>0))
    then 
      RaiseException('EX_BP_PrimaryBPHasNotify');    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_PAYMENTSCHEDULE_BU_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*           */  
  if (new$AdjustmentNumber > 0) then
    BEGIN
      select 
      Month01, Month02, Month03, Month04, Month05, Month06,
      Month07, Month08, Month09, Month10, Month11, Month12,
      Quarter1, Quarter2, Quarter3, Quarter4, Summa,
      SummaYear1, SummaYear2, SummaYear3, SummaYear4, SummaOtherYears
      into
      M01$, M02$, M03$, M04$, M05$, M06$, M07$, M08$, M09$, M10$, M11$, M12$, 
      Q1$, Q2$, Q3$, Q4$, S$, S1$, S2$, S3$, S4$, SOther$         from 
      PaymentSchedule
      where
      ID = new$AdjustmentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
          
    new$Month01Delta := new$Month01 - M01$;
    new$Month02Delta := new$Month02 - M02$;
    new$Month03Delta := new$Month03 - M03$;
    new$Month04Delta := new$Month04 - M04$;
    new$Month05Delta := new$Month05 - M05$;
    new$Month06Delta := new$Month06 - M06$;
    new$Month07Delta := new$Month07 - M07$;
    new$Month08Delta := new$Month08 - M08$;
    new$Month09Delta := new$Month09 - M09$;
    new$Month10Delta := new$Month10 - M10$;
    new$Month11Delta := new$Month11 - M11$;
    new$Month12Delta := new$Month12 - M12$;
    new$Quarter1Delta := new$Quarter1 - Q1$;
    new$Quarter2Delta := new$Quarter2 - Q2$;
    new$Quarter3Delta := new$Quarter3 - Q3$;
    new$Quarter4Delta := new$Quarter4 - Q4$;
    new$SummaDelta := new$Summa - S$;
    new$SummaYear1Delta := new$SummaYear1 - S1$;
    new$SummaYear2Delta := new$SummaYear2 - S2$;
    new$SummaYear3Delta := new$SummaYear3 - S3$;
    new$SummaYear4Delta := new$SummaYear4 - S4$;
    new$SummaOtherYearsDelta := new$SummaOtherYears - SOther$;
        
  else /*        */  
    new$Month01Delta := new$Month01;
    new$Month02Delta := new$Month02;
    new$Month03Delta := new$Month03;
    new$Month04Delta := new$Month04;
    new$Month05Delta := new$Month05;
    new$Month06Delta := new$Month06;
    new$Month07Delta := new$Month07;
    new$Month08Delta := new$Month08;
    new$Month09Delta := new$Month09;
    new$Month10Delta := new$Month10;
    new$Month11Delta := new$Month11;
    new$Month12Delta := new$Month12;
    new$Quarter1Delta := new$Quarter1;
    new$Quarter2Delta := new$Quarter2;
    new$Quarter3Delta := new$Quarter3;
    new$Quarter4Delta := new$Quarter4;
    new$SummaDelta := new$Summa;
    new$SummaYear1Delta := new$SummaYear1;
    new$SummaYear2Delta := new$SummaYear2;
    new$SummaYear3Delta := new$SummaYear3;
    new$SummaYear4Delta := new$SummaYear4;
    new$SummaOtherYearsDelta := new$SummaOtherYears;        
        
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_PAYMENTSCHEDULE_BU_200)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*    */
  if (new$Accepted = 0 and new$AcceptDate is not null and :old.Accepted = 1) then
    /*   ,     
         *    ,      */
    FOR REC$1 IN (      select ffc.Reject_Cls  AS DocumentRejectCls from FacialFinDetail ffd
    left join FacialFinCaption ffc on (ffc.ID = ffd.RecordIndex)
    where SourcePromise = new$ANumber and SourceBudgetPromise = new$InnerPromiseNum
    or DestPromise = new$ANumber and DestBudgetPromise = new$InnerPromiseNum
    )
    LOOP
      if (REC$1.DocumentRejectCls is null) then
        RaiseException('Ex_BP_CannotReject');    
      END IF;
    END LOOP;
    /* ,         */
    FOR REC$1 IN (      SELECT Count(ps_in.ID)  AS AdjCount FROM PaymentSchedule ps_in
    WHERE (ps_in.InnerPromiseNum = new$InnerPromiseNum)and(ps_in.AdjustmentNumber > new$AdjustmentNumber)
    and (ps_in.Accepted<>0) 
    )
    LOOP
      if (REC$1.AdjCount > 0) then
        RaiseException('EX_BP_AdjustmentedCANNOTREJECT');    
      END IF;
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (tr_PaymentSchedule_BU_400)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$AgreementRef <> :old.AgreementRef or new$ExecutionRef <> :old.ExecutionRef) then
    RaiseException('EX_CANTCHANGECAPTIONREF');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_PAYMENTSCHEDULE_BU_700)
-- Create 14.10.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$RVersion is null) then
    new$RVersion := 1;
  elsif ((new$RVersion = -1) and (:Old.RVersion <> -1)) then
    new$RVersion := :Old.RVersion;
  else
    new$RVersion := :Old.RVersion + 1;
  end if;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_PAYMENTSCHEDULE SET
    ID = new$ID,
    ANUMBER = new$ANUMBER,
    PARENTNUMBER = new$PARENTNUMBER,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVSR = new$KVSR,
    KCSR = new$KCSR,
    KVR = new$KVR,
    MONTH01 = new$MONTH01,
    MONTH02 = new$MONTH02,
    MONTH03 = new$MONTH03,
    MONTH04 = new$MONTH04,
    MONTH05 = new$MONTH05,
    MONTH06 = new$MONTH06,
    MONTH07 = new$MONTH07,
    MONTH08 = new$MONTH08,
    MONTH09 = new$MONTH09,
    MONTH10 = new$MONTH10,
    MONTH11 = new$MONTH11,
    MONTH12 = new$MONTH12,
    SUMMA = new$SUMMA,
    REGION = new$REGION,
    SUBKESR = new$SUBKESR,
    MEANSTYPE = new$MEANSTYPE,
    FINSOURCE = new$FINSOURCE,
    FINTYPE = new$FINTYPE,
    FACT = new$FACT,
    FACIALACC_CLS = new$FACIALACC_CLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    ACCEPTDATE = new$ACCEPTDATE,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    ACCEPTED = new$ACCEPTED,
    LASTACCEPTED = new$LASTACCEPTED,
    PROMISETYPE = new$PROMISETYPE,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    OLDNUMBER = new$OLDNUMBER,
    SUMMAPREVIOUSYEAR = new$SUMMAPREVIOUSYEAR,
    SUMMAFINPREVIOUSYEAR = new$SUMMAFINPREVIOUSYEAR,
    QUARTER1 = new$QUARTER1,
    QUARTER2 = new$QUARTER2,
    QUARTER3 = new$QUARTER3,
    QUARTER4 = new$QUARTER4,
    RECORDINDEX = new$RECORDINDEX,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DIRECTIONCLS = new$DIRECTIONCLS,
    RVERSION = new$RVERSION,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    MONTH01DELTA = new$MONTH01DELTA,
    MONTH02DELTA = new$MONTH02DELTA,
    MONTH03DELTA = new$MONTH03DELTA,
    MONTH04DELTA = new$MONTH04DELTA,
    MONTH05DELTA = new$MONTH05DELTA,
    MONTH06DELTA = new$MONTH06DELTA,
    MONTH07DELTA = new$MONTH07DELTA,
    MONTH08DELTA = new$MONTH08DELTA,
    MONTH09DELTA = new$MONTH09DELTA,
    MONTH10DELTA = new$MONTH10DELTA,
    MONTH11DELTA = new$MONTH11DELTA,
    MONTH12DELTA = new$MONTH12DELTA,
    QUARTER1DELTA = new$QUARTER1DELTA,
    QUARTER2DELTA = new$QUARTER2DELTA,
    QUARTER3DELTA = new$QUARTER3DELTA,
    QUARTER4DELTA = new$QUARTER4DELTA,
    SUMMADELTA = new$SUMMADELTA,
    NOTE = new$NOTE,
    FINYEAR = new$FINYEAR,
    SUMMAYEAR1 = new$SUMMAYEAR1,
    SUMMAYEAR2 = new$SUMMAYEAR2,
    SUMMAYEAR3 = new$SUMMAYEAR3,
    SUMMAYEAR1DELTA = new$SUMMAYEAR1DELTA,
    SUMMAYEAR2DELTA = new$SUMMAYEAR2DELTA,
    SUMMAYEAR3DELTA = new$SUMMAYEAR3DELTA,
    ASSIGNMENTKIND = new$ASSIGNMENTKIND,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    EXECUTIONREF = new$EXECUTIONREF,
    INNERPROMISENUM = new$INNERPROMISENUM,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    PROMISENUMBER = new$PROMISENUMBER,
    SUBSIDYCLS = new$SUBSIDYCLS,
    AGREEMENTREF = new$AGREEMENTREF,
    BUDALLOCATIONCLS = new$BUDALLOCATIONCLS,
    PAYPROMISECLS = new$PAYPROMISECLS,
    PROGINDEX = new$PROGINDEX,
    INVESTOBJECT = new$INVESTOBJECT,
    SUMMAYEAR4 = new$SUMMAYEAR4,
    SUMMAOTHERYEARS = new$SUMMAOTHERYEARS,
    SUMMAYEAR4DELTA = new$SUMMAYEAR4DELTA,
    SUMMAOTHERYEARSDELTA = new$SUMMAOTHERYEARSDELTA,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_10 (TR_PAYMENTSCHEDULE_AU_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/

  /*      */
  /*     ,       */
  if ((new$AdjustmentNumber > 0) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update PaymentSchedule set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment    */
  if ((new$AdjustmentNumber > 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and 
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update PaymentSchedule set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_PAYMENTSCHEDULE_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (113, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=113) and (RecordId=new$ID);
  end if;

END;
/
ALTER TABLE WritExecutionDetail ADD (
  ContractCostsCls NUMBER(10),
    CHECK((ContractCostsCls<=2147483647)AND(ContractCostsCls>-2147483648)),
  constraint FK_WED_ContractCostsCls foreign key (ContractCostsCls) references ContractCostsCls(ID)    
)
/
CREATE INDEX FK_WED_ContractCostsCls ON WritExecutionDetail(ContractCostsCls)
/
ALTER TABLE ReplacementClsDetailInfo ADD (
  ContractCostsCls NUMBER(10),
    CHECK((ContractCostsCls<=2147483647)AND(ContractCostsCls>-2147483648)),
  constraint FK_RCDI_ContractCostsCls foreign key (ContractCostsCls) references ContractCostsCls(ID)    
)
/
CREATE INDEX FK_RCDI_ContractCostsCls ON ReplacementClsDetailInfo(ContractCostsCls)
/
ALTER TABLE TB_CorrectionDetail ADD (
  ContractCostsCls NUMBER(10),
    CHECK((ContractCostsCls<=2147483647)AND(ContractCostsCls>-2147483648)),
  constraint FK_CD_ContractCostsCls foreign key (ContractCostsCls) references ContractCostsCls(ID)    
)
/
CREATE INDEX FK_CD_ContractCostsCls ON TB_CorrectionDetail(ContractCostsCls)
/

CREATE OR REPLACE VIEW CorrectionDetail (
  ID,
  PARENTID,
  BUDGETREF,
  SUMMA,
  CLSTYPE,
  FACIALACC_CLS,
  KVSR,
  KFSR,
  KCSR,
  KVR,
  KESR,
  DIRECTIONCLS,
  MEANSTYPE,
  FACT,
  REGIONCLS,
  FINSOURCE,
  FINTYPE,
  DOCTYPE,
  SUBKESR,
  FUNDSSOURCE,
  KD,
  IFS,
  BUHOPERATIONCLS,
  CHANGEACC_REF,
  CHANGEACC,
  CHANGEORGINN,
  CHANGEORGINN20,
  PROGINDEX,
  RECORDINDEX,
  DOCUMENTPROGINDEX,
  DOCUMENTRECORDINDEX,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  SENDERID,
  SENDERRECORDID,
  RVERSION,
  CREATERUSER,
  CREATEDATE,
  UPDATERUSER,
  UPDATEDATE,
  NOTE,
  ISCLSCHANGED,
  PROMISE,
  BUDGETPROMISE,
  EXECDOC,
  OKATO,
  ADDOKATO,
  TRANSFERTCLS,
  ORIGINALCLSSUMMA,
  NOTECLS,
  OPERATIONTYPE,
  REVERSEFLAG,
  EXECINNERNUMBER,
  CLSFIELFCHANGED,
  FAORGTYPE,
  SUBSIDYCLS,
  BUDALLOCATIONCLS,
  PAYPROMISECLS,
  NOTEQUALEX,
  OKTMO,
  UINCODE,
  INVESTOBJECT,
  CHANGEORGNAME,
  CONTRACTCOSTSCLS)
AS
  SELECT
    ID,
    PARENTID,
    BUDGETREF,
    SUMMA,
    CLSTYPE,
    FACIALACC_CLS,
    KVSR,
    KFSR,
    KCSR,
    KVR,
    KESR,
    DIRECTIONCLS,
    MEANSTYPE,
    FACT,
    REGIONCLS,
    FINSOURCE,
    FINTYPE,
    DOCTYPE,
    SUBKESR,
    FUNDSSOURCE,
    KD,
    IFS,
    BUHOPERATIONCLS,
    CHANGEACC_REF,
    CHANGEACC,
    CHANGEORGINN,
    CHANGEORGINN20,
    PROGINDEX,
    RECORDINDEX,
    DOCUMENTPROGINDEX,
    DOCUMENTRECORDINDEX,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SENDERID,
    SENDERRECORDID,
    RVERSION,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    NOTE,
    ISCLSCHANGED,
    PROMISE,
    BUDGETPROMISE,
    EXECDOC,
    OKATO,
    ADDOKATO,
    TRANSFERTCLS,
    ORIGINALCLSSUMMA,
    NOTECLS,
    OPERATIONTYPE,
    REVERSEFLAG,
    EXECINNERNUMBER,
    CLSFIELFCHANGED,
    FAORGTYPE,
    SUBSIDYCLS,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    NOTEQUALEX,
    OKTMO,
    UINCODE,
    INVESTOBJECT,
    CHANGEORGNAME,
    CONTRACTCOSTSCLS
  FROM TB_CorrectionDetail
/

CREATE OR REPLACE TRIGGER TR_CORRECTIONDETAIL_ID
  INSTEAD OF DELETE
  ON CORRECTIONDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_500 (TR_CORRECTIONDETAIL_BD_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  Update CorrectionCaption set
  DocChangeDate = SYSDATE,
  RVersion = -1
  where id = :old.recordindex;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_CORRECTIONDETAIL
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_500 (TR_CORRECTIONDETAIL_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate, ProgIndex, SUMMA) values(5504,:old.ID,SYSDATE,:old.ProgIndex, :old.SUMMA);

END;
/

CREATE OR REPLACE TRIGGER TR_CORRECTIONDETAIL_II
  INSTEAD OF INSERT
  ON CORRECTIONDETAIL
  FOR EACH ROW
DECLARE
  new$ID CORRECTIONDETAIL.ID%TYPE := :NEW.ID;
  new$PARENTID CORRECTIONDETAIL.PARENTID%TYPE := :NEW.PARENTID;
  new$BUDGETREF CORRECTIONDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUMMA CORRECTIONDETAIL.SUMMA%TYPE := :NEW.SUMMA;
  new$CLSTYPE CORRECTIONDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$FACIALACC_CLS CORRECTIONDETAIL.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$KVSR CORRECTIONDETAIL.KVSR%TYPE := :NEW.KVSR;
  new$KFSR CORRECTIONDETAIL.KFSR%TYPE := :NEW.KFSR;
  new$KCSR CORRECTIONDETAIL.KCSR%TYPE := :NEW.KCSR;
  new$KVR CORRECTIONDETAIL.KVR%TYPE := :NEW.KVR;
  new$KESR CORRECTIONDETAIL.KESR%TYPE := :NEW.KESR;
  new$DIRECTIONCLS CORRECTIONDETAIL.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$MEANSTYPE CORRECTIONDETAIL.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FACT CORRECTIONDETAIL.FACT%TYPE := :NEW.FACT;
  new$REGIONCLS CORRECTIONDETAIL.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$FINSOURCE CORRECTIONDETAIL.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE CORRECTIONDETAIL.FINTYPE%TYPE := :NEW.FINTYPE;
  new$DOCTYPE CORRECTIONDETAIL.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SUBKESR CORRECTIONDETAIL.SUBKESR%TYPE := :NEW.SUBKESR;
  new$FUNDSSOURCE CORRECTIONDETAIL.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$KD CORRECTIONDETAIL.KD%TYPE := :NEW.KD;
  new$IFS CORRECTIONDETAIL.IFS%TYPE := :NEW.IFS;
  new$BUHOPERATIONCLS CORRECTIONDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CHANGEACC_REF CORRECTIONDETAIL.CHANGEACC_REF%TYPE := :NEW.CHANGEACC_REF;
  new$CHANGEACC CORRECTIONDETAIL.CHANGEACC%TYPE := :NEW.CHANGEACC;
  new$CHANGEORGINN CORRECTIONDETAIL.CHANGEORGINN%TYPE := :NEW.CHANGEORGINN;
  new$CHANGEORGINN20 CORRECTIONDETAIL.CHANGEORGINN20%TYPE := :NEW.CHANGEORGINN20;
  new$PROGINDEX CORRECTIONDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX CORRECTIONDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$DOCUMENTPROGINDEX CORRECTIONDETAIL.DOCUMENTPROGINDEX%TYPE := :NEW.DOCUMENTPROGINDEX;
  new$DOCUMENTRECORDINDEX CORRECTIONDETAIL.DOCUMENTRECORDINDEX%TYPE := :NEW.DOCUMENTRECORDINDEX;
  new$ISBLOCKED CORRECTIONDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE CORRECTIONDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE CORRECTIONDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE CORRECTIONDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SENDERID CORRECTIONDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID CORRECTIONDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$RVERSION CORRECTIONDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$CREATERUSER CORRECTIONDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE CORRECTIONDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER CORRECTIONDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE CORRECTIONDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$NOTE CORRECTIONDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$ISCLSCHANGED CORRECTIONDETAIL.ISCLSCHANGED%TYPE := :NEW.ISCLSCHANGED;
  new$PROMISE CORRECTIONDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$BUDGETPROMISE CORRECTIONDETAIL.BUDGETPROMISE%TYPE := :NEW.BUDGETPROMISE;
  new$EXECDOC CORRECTIONDETAIL.EXECDOC%TYPE := :NEW.EXECDOC;
  new$OKATO CORRECTIONDETAIL.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO CORRECTIONDETAIL.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$TRANSFERTCLS CORRECTIONDETAIL.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$ORIGINALCLSSUMMA CORRECTIONDETAIL.ORIGINALCLSSUMMA%TYPE := :NEW.ORIGINALCLSSUMMA;
  new$NOTECLS CORRECTIONDETAIL.NOTECLS%TYPE := :NEW.NOTECLS;
  new$OPERATIONTYPE CORRECTIONDETAIL.OPERATIONTYPE%TYPE := :NEW.OPERATIONTYPE;
  new$REVERSEFLAG CORRECTIONDETAIL.REVERSEFLAG%TYPE := :NEW.REVERSEFLAG;
  new$EXECINNERNUMBER CORRECTIONDETAIL.EXECINNERNUMBER%TYPE := :NEW.EXECINNERNUMBER;
  new$CLSFIELFCHANGED CORRECTIONDETAIL.CLSFIELFCHANGED%TYPE := :NEW.CLSFIELFCHANGED;
  new$FAORGTYPE CORRECTIONDETAIL.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$SUBSIDYCLS CORRECTIONDETAIL.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$BUDALLOCATIONCLS CORRECTIONDETAIL.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS CORRECTIONDETAIL.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$NOTEQUALEX CORRECTIONDETAIL.NOTEQUALEX%TYPE := :NEW.NOTEQUALEX;
  new$OKTMO CORRECTIONDETAIL.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE CORRECTIONDETAIL.UINCODE%TYPE := :NEW.UINCODE;
  new$INVESTOBJECT CORRECTIONDETAIL.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CHANGEORGNAME CORRECTIONDETAIL.CHANGEORGNAME%TYPE := :NEW.CHANGEORGNAME;
  new$CONTRACTCOSTSCLS CORRECTIONDETAIL.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
--
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  ConstCheck$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  vOperationTypeS1$ NUMBER(10);
  vOperationTypeD1$ NUMBER(10);
  vOperationType1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_CORRECTIONDETAIL_BI)
-- Version 11.20.00.1
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN 
    select g_shared.nextval into new$id from dual;
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$IFS := 0;
  END IF;
  IF (new$FacialAcc_Cls IS NULL) THEN 
    new$FacialAcc_Cls := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DirectionCls IS NULL) THEN 
    new$DirectionCls := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$Finsource IS NULL) THEN 
    new$Finsource := 0;
  END IF;
  IF (new$FinType IS NULL) THEN 
    new$FinType := 0;
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;  
  END IF;
  IF (new$SubKesr IS NULL) THEN 
    new$SubKesr := 0;
  END IF;
  IF (new$buhoperationCls IS NULL) THEN 
    new$buhoperationCls := 0;
  END IF;
  IF (new$ReverseFlag IS NULL) THEN 
    new$ReverseFlag := 1;
  END IF;
  IF (new$OperationType IS NULL) THEN 
    BEGIN
      SELECT CorCap.SourceType, CorCap.DestType
      INTO
      vOperationTypeS1$, vOperationTypeD1$       FROM correctioncaption CorCap
      WHERE
      (CorCap.id = new$recordindex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    IF (new$ProgIndex = 315) THEN 
      vOperationType1$ := vOperationTypeS1$;
          
    ELSE 
      vOperationType1$ := vOperationTypeD1$;
    END IF;
    new$OperationType := vOperationType1$;
      
  END IF;
  BEGIN

    SELECT org.Org_Type   INTO new$FAOrgType FROM Organizations org
    INNER JOIN FacialAcc_Cls fac  ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$FacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BI_100 (tr_correctiondetail_bi_100)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$progindex = 316) then
    update correctiondetail set
    buhoperationcls = new$buhoperationcls
    where ID = new$parentid;
  END IF;

-- - - - - - - - - - - - -
-- BI_120 (TR_CORRECTIONDETAIL_BI_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((new$ClsType is NULL) and (new$IFS <> 0)) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$KD <> 0)) then
      new$ClsType := 2; /*        ClsType */
            
    else
      if (new$ClsType is null)
      then 
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND ((new$IFS <> 0) or (new$KD <> 0)))THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ( (new$ClsType = 1) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0) OR
  (new$KD <> 0)
  ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0) OR
  (new$IFS <> 0)
  ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_CORRECTIONDETAIL_BI_200)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  getintconst(30, 35,ConstCheck$);
  /* ( )      ,    */
  if ((PromiseMode$ <> 1) and (ConstCheck$ = 1)) then
    if (new$Promise is not null) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$        from
      promise_detail pr
      where
      (pr.registrnumber = new$PROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');    
      END IF;  
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /* ( )      ,    */
  /*         */
  if (PromiseMode$ = 1) then
    if ((new$Promise is not null) and (new$BudgetPromise is null)) then
      select 
      max(InnerPromiseNum) 
      into BPInnerNum$       from 
      PaymentSchedule 
      where 
      (ANumber = new$Promise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$BudgetPromise := BPInnerNum$;
              
      else
        RaiseException('EX_BP_NotExist');    
      END IF;
    END IF;
    /*    ,   ,   */
    if ((new$BudgetPromise is not null) and (new$Promise is null)) then
      BEGIN
        select 
        ANumber 
        into BPInnerNum$       from 
        PaymentSchedule
        where 
        (InnerPromiseNum = new$BudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
            
      new$Promise := BPInnerNum$;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_CORRECTIONDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$Promise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$Promise and ps.InnerPromiseNum = new$BudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$ExecDoc := ExecID$;
        new$ExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$ExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$ExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$ExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*    ,   ,  */
    else 
      if (new$ExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$ExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$ExecInnerNumber := ExecInnerNumber$;
            
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_CORRECTIONDETAIL_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update CorrectionCaption set
  DocChangeDate = new$UpdateDate,
  RVersion = -1
  where id = new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_CORRECTIONDETAIL (
    ID,
    PARENTID,
    BUDGETREF,
    SUMMA,
    CLSTYPE,
    FACIALACC_CLS,
    KVSR,
    KFSR,
    KCSR,
    KVR,
    KESR,
    DIRECTIONCLS,
    MEANSTYPE,
    FACT,
    REGIONCLS,
    FINSOURCE,
    FINTYPE,
    DOCTYPE,
    SUBKESR,
    FUNDSSOURCE,
    KD,
    IFS,
    BUHOPERATIONCLS,
    CHANGEACC_REF,
    CHANGEACC,
    CHANGEORGINN,
    CHANGEORGINN20,
    PROGINDEX,
    RECORDINDEX,
    DOCUMENTPROGINDEX,
    DOCUMENTRECORDINDEX,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SENDERID,
    SENDERRECORDID,
    RVERSION,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    NOTE,
    ISCLSCHANGED,
    PROMISE,
    BUDGETPROMISE,
    EXECDOC,
    OKATO,
    ADDOKATO,
    TRANSFERTCLS,
    ORIGINALCLSSUMMA,
    NOTECLS,
    OPERATIONTYPE,
    REVERSEFLAG,
    EXECINNERNUMBER,
    CLSFIELFCHANGED,
    FAORGTYPE,
    SUBSIDYCLS,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    NOTEQUALEX,
    OKTMO,
    UINCODE,
    INVESTOBJECT,
    CHANGEORGNAME,
    CONTRACTCOSTSCLS
  ) VALUES (
    new$ID,
    new$PARENTID,
    new$BUDGETREF,
    new$SUMMA,
    new$CLSTYPE,
    new$FACIALACC_CLS,
    new$KVSR,
    new$KFSR,
    new$KCSR,
    new$KVR,
    new$KESR,
    new$DIRECTIONCLS,
    new$MEANSTYPE,
    new$FACT,
    new$REGIONCLS,
    new$FINSOURCE,
    new$FINTYPE,
    new$DOCTYPE,
    new$SUBKESR,
    new$FUNDSSOURCE,
    new$KD,
    new$IFS,
    new$BUHOPERATIONCLS,
    new$CHANGEACC_REF,
    new$CHANGEACC,
    new$CHANGEORGINN,
    new$CHANGEORGINN20,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$DOCUMENTPROGINDEX,
    new$DOCUMENTRECORDINDEX,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SENDERID,
    new$SENDERRECORDID,
    new$RVERSION,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$NOTE,
    new$ISCLSCHANGED,
    new$PROMISE,
    new$BUDGETPROMISE,
    new$EXECDOC,
    new$OKATO,
    new$ADDOKATO,
    new$TRANSFERTCLS,
    new$ORIGINALCLSSUMMA,
    new$NOTECLS,
    new$OPERATIONTYPE,
    new$REVERSEFLAG,
    new$EXECINNERNUMBER,
    new$CLSFIELFCHANGED,
    new$FAORGTYPE,
    new$SUBSIDYCLS,
    new$BUDALLOCATIONCLS,
    new$PAYPROMISECLS,
    new$NOTEQUALEX,
    new$OKTMO,
    new$UINCODE,
    new$INVESTOBJECT,
    new$CHANGEORGNAME,
    new$CONTRACTCOSTSCLS);

-- - - - - - - - - - - - -
-- AI_500 (TR_CORRECTIONDETAIL_AI_500)
-- Create 29.12.2009
-- - - - - - - - - - - - -

 delete from DelRecIndexes where (TableID =5504 ) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_CORRECTIONDETAIL_IU
  INSTEAD OF UPDATE
  ON CORRECTIONDETAIL
  FOR EACH ROW
DECLARE
  new$ID CORRECTIONDETAIL.ID%TYPE := :NEW.ID;
  new$PARENTID CORRECTIONDETAIL.PARENTID%TYPE := :NEW.PARENTID;
  new$BUDGETREF CORRECTIONDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUMMA CORRECTIONDETAIL.SUMMA%TYPE := :NEW.SUMMA;
  new$CLSTYPE CORRECTIONDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$FACIALACC_CLS CORRECTIONDETAIL.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$KVSR CORRECTIONDETAIL.KVSR%TYPE := :NEW.KVSR;
  new$KFSR CORRECTIONDETAIL.KFSR%TYPE := :NEW.KFSR;
  new$KCSR CORRECTIONDETAIL.KCSR%TYPE := :NEW.KCSR;
  new$KVR CORRECTIONDETAIL.KVR%TYPE := :NEW.KVR;
  new$KESR CORRECTIONDETAIL.KESR%TYPE := :NEW.KESR;
  new$DIRECTIONCLS CORRECTIONDETAIL.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$MEANSTYPE CORRECTIONDETAIL.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FACT CORRECTIONDETAIL.FACT%TYPE := :NEW.FACT;
  new$REGIONCLS CORRECTIONDETAIL.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$FINSOURCE CORRECTIONDETAIL.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE CORRECTIONDETAIL.FINTYPE%TYPE := :NEW.FINTYPE;
  new$DOCTYPE CORRECTIONDETAIL.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SUBKESR CORRECTIONDETAIL.SUBKESR%TYPE := :NEW.SUBKESR;
  new$FUNDSSOURCE CORRECTIONDETAIL.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$KD CORRECTIONDETAIL.KD%TYPE := :NEW.KD;
  new$IFS CORRECTIONDETAIL.IFS%TYPE := :NEW.IFS;
  new$BUHOPERATIONCLS CORRECTIONDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CHANGEACC_REF CORRECTIONDETAIL.CHANGEACC_REF%TYPE := :NEW.CHANGEACC_REF;
  new$CHANGEACC CORRECTIONDETAIL.CHANGEACC%TYPE := :NEW.CHANGEACC;
  new$CHANGEORGINN CORRECTIONDETAIL.CHANGEORGINN%TYPE := :NEW.CHANGEORGINN;
  new$CHANGEORGINN20 CORRECTIONDETAIL.CHANGEORGINN20%TYPE := :NEW.CHANGEORGINN20;
  new$PROGINDEX CORRECTIONDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX CORRECTIONDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$DOCUMENTPROGINDEX CORRECTIONDETAIL.DOCUMENTPROGINDEX%TYPE := :NEW.DOCUMENTPROGINDEX;
  new$DOCUMENTRECORDINDEX CORRECTIONDETAIL.DOCUMENTRECORDINDEX%TYPE := :NEW.DOCUMENTRECORDINDEX;
  new$ISBLOCKED CORRECTIONDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE CORRECTIONDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE CORRECTIONDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE CORRECTIONDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SENDERID CORRECTIONDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID CORRECTIONDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$RVERSION CORRECTIONDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$CREATERUSER CORRECTIONDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE CORRECTIONDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER CORRECTIONDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE CORRECTIONDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$NOTE CORRECTIONDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$ISCLSCHANGED CORRECTIONDETAIL.ISCLSCHANGED%TYPE := :NEW.ISCLSCHANGED;
  new$PROMISE CORRECTIONDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$BUDGETPROMISE CORRECTIONDETAIL.BUDGETPROMISE%TYPE := :NEW.BUDGETPROMISE;
  new$EXECDOC CORRECTIONDETAIL.EXECDOC%TYPE := :NEW.EXECDOC;
  new$OKATO CORRECTIONDETAIL.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO CORRECTIONDETAIL.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$TRANSFERTCLS CORRECTIONDETAIL.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$ORIGINALCLSSUMMA CORRECTIONDETAIL.ORIGINALCLSSUMMA%TYPE := :NEW.ORIGINALCLSSUMMA;
  new$NOTECLS CORRECTIONDETAIL.NOTECLS%TYPE := :NEW.NOTECLS;
  new$OPERATIONTYPE CORRECTIONDETAIL.OPERATIONTYPE%TYPE := :NEW.OPERATIONTYPE;
  new$REVERSEFLAG CORRECTIONDETAIL.REVERSEFLAG%TYPE := :NEW.REVERSEFLAG;
  new$EXECINNERNUMBER CORRECTIONDETAIL.EXECINNERNUMBER%TYPE := :NEW.EXECINNERNUMBER;
  new$CLSFIELFCHANGED CORRECTIONDETAIL.CLSFIELFCHANGED%TYPE := :NEW.CLSFIELFCHANGED;
  new$FAORGTYPE CORRECTIONDETAIL.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$SUBSIDYCLS CORRECTIONDETAIL.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$BUDALLOCATIONCLS CORRECTIONDETAIL.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS CORRECTIONDETAIL.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$NOTEQUALEX CORRECTIONDETAIL.NOTEQUALEX%TYPE := :NEW.NOTEQUALEX;
  new$OKTMO CORRECTIONDETAIL.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE CORRECTIONDETAIL.UINCODE%TYPE := :NEW.UINCODE;
  new$INVESTOBJECT CORRECTIONDETAIL.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CHANGEORGNAME CORRECTIONDETAIL.CHANGEORGNAME%TYPE := :NEW.CHANGEORGNAME;
  new$CONTRACTCOSTSCLS CORRECTIONDETAIL.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
--
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  ConstCheck$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  vOperationTypeS$ NUMBER(10);
  vOperationTypeD$ NUMBER(10);
  vOperationType$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_CORRECTIONDETAIL_BU)
-- Version 11.20.00.1
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN 
    select g_shared.nextval into new$id from dual;
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$IFS := 0;
  END IF;
  IF (new$FacialAcc_Cls IS NULL) THEN 
    new$FacialAcc_Cls := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DirectionCls IS NULL) THEN 
    new$DirectionCls := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$Finsource IS NULL) THEN 
    new$Finsource := 0;
  END IF;
  IF (new$FinType IS NULL) THEN 
    new$FinType := 0;
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKesr IS NULL) THEN 
    new$SubKesr := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$buhoperationCls IS NULL) THEN 
    new$buhoperationCls := 0;
  END IF;
  IF (new$ReverseFlag IS NULL) THEN 
    new$ReverseFlag := 1;
  END IF;
  IF (new$OperationType IS NULL) THEN 
    BEGIN
      SELECT CorCap.SourceType, CorCap.DestType
      INTO
      vOperationTypeS$, vOperationTypeD$       FROM correctioncaption CorCap
      WHERE
      (CorCap.id = new$recordindex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    IF (new$ProgIndex = 315) THEN 
      vOperationType$ := vOperationTypeS$;
          
    ELSE 
      vOperationType$ := vOperationTypeD$;
    END IF;
    new$OperationType := vOperationType$;
      
  END IF;
  /*     \*/
  IF ((new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType IS NULL)) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  ON (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (tr_correctiondetail_bu_100)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$buhoperationcls <> :old.buhoperationcls) and (new$progindex = 316)) then
    update correctiondetail set
    buhoperationcls = new$buhoperationcls
    where ID = new$parentid;
  END IF;

-- - - - - - - - - - - - -
-- BU_120 (TR_CORRECTIONDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((new$ClsType is NULL) and (new$IFS <> 0)) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$KD <> 0)) then
      new$ClsType := 2; /*        ClsType */
            
    else
      if (new$ClsType is null)
      then 
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND ((new$IFS <> 0) or (new$KD <> 0)))THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ( (new$ClsType = 1) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0) OR
  (new$KD <> 0)
  ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0) OR
  (new$IFS <> 0)
  ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_CORRECTIONDETAIL_BU_200)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  getintconst(30, 35,ConstCheck$);
  /* ( )      ,    */
  if ((PromiseMode$ <> 1) and (ConstCheck$ = 1)) then
    if ((new$Promise is not null)and((:old.Promise is null)or(:old.Promise <> new$Promise ))) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$        from
      promise_detail pr
      where
      (pr.registrnumber = new$PROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');    
      END IF;  
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /* ( )      ,    */
  /*         */
  if (PromiseMode$ = 1) then
    if ((new$Promise is not null)and((:old.Promise is null)or(:old.Promise <> new$Promise )) and 
    (new$BudgetPromise is null) and (:old.BudgetPromise is null)) then
      select 
      max(InnerPromiseNum) 
      into BPInnerNum$       from 
      PaymentSchedule 
      where 
      (ANumber = new$Promise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$BudgetPromise := BPInnerNum$;
              
      else
        RaiseException('EX_BP_NotExist');    
      END IF;
    END IF;
        
    /*    ,   */
    if (((new$BudgetPromise is not null) and (:old.BudgetPromise is null)) or 
    (new$BudgetPromise <> :old.BudgetPromise)) then
      BEGIN
        select 
        ANumber 
        into BPInnerNum$       from 
        PaymentSchedule
        where 
        (InnerPromiseNum = new$BudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
            
      new$Promise := BPInnerNum$;
          
    END IF;
        
    /*    ,     */
    if ((new$BudgetPromise is null) and (:old.BudgetPromise is not null)) then
      new$Promise := null;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_CORRECTIONDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$Promise is not null and (
    (:old.Promise is null or :old.Promise <> new$Promise) or
    (:old.ExecDoc is null or new$ExecDoc is null or :old.ExecDoc <> new$ExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$Promise and ps.InnerPromiseNum = new$BudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$ExecDoc := ExecID$;
        new$ExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$ExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$ExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$ExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$ExecDoc is null or :old.ExecDoc is null or new$ExecDoc <> :old.ExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$ExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$ExecInnerNumber := ExecInnerNumber$;
            
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_CORRECTIONDETAIL_BU_700)
-- Create 13.08.2007
-- - - - - - - - - - - - -

 if (new$RVersion is null) then
   new$RVersion:=1;
 else
   if ((new$RVersion = -1) and (:Old.RVersion <> -1)) then
     new$RVersion:=:Old.RVersion;
   else
     new$RVersion:=:Old.RVersion+1;
   end if;
 end if;  

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_CORRECTIONDETAIL SET
    ID = new$ID,
    PARENTID = new$PARENTID,
    BUDGETREF = new$BUDGETREF,
    SUMMA = new$SUMMA,
    CLSTYPE = new$CLSTYPE,
    FACIALACC_CLS = new$FACIALACC_CLS,
    KVSR = new$KVSR,
    KFSR = new$KFSR,
    KCSR = new$KCSR,
    KVR = new$KVR,
    KESR = new$KESR,
    DIRECTIONCLS = new$DIRECTIONCLS,
    MEANSTYPE = new$MEANSTYPE,
    FACT = new$FACT,
    REGIONCLS = new$REGIONCLS,
    FINSOURCE = new$FINSOURCE,
    FINTYPE = new$FINTYPE,
    DOCTYPE = new$DOCTYPE,
    SUBKESR = new$SUBKESR,
    FUNDSSOURCE = new$FUNDSSOURCE,
    KD = new$KD,
    IFS = new$IFS,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    CHANGEACC_REF = new$CHANGEACC_REF,
    CHANGEACC = new$CHANGEACC,
    CHANGEORGINN = new$CHANGEORGINN,
    CHANGEORGINN20 = new$CHANGEORGINN20,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    DOCUMENTPROGINDEX = new$DOCUMENTPROGINDEX,
    DOCUMENTRECORDINDEX = new$DOCUMENTRECORDINDEX,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    RVERSION = new$RVERSION,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    NOTE = new$NOTE,
    ISCLSCHANGED = new$ISCLSCHANGED,
    PROMISE = new$PROMISE,
    BUDGETPROMISE = new$BUDGETPROMISE,
    EXECDOC = new$EXECDOC,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    TRANSFERTCLS = new$TRANSFERTCLS,
    ORIGINALCLSSUMMA = new$ORIGINALCLSSUMMA,
    NOTECLS = new$NOTECLS,
    OPERATIONTYPE = new$OPERATIONTYPE,
    REVERSEFLAG = new$REVERSEFLAG,
    EXECINNERNUMBER = new$EXECINNERNUMBER,
    CLSFIELFCHANGED = new$CLSFIELFCHANGED,
    FAORGTYPE = new$FAORGTYPE,
    SUBSIDYCLS = new$SUBSIDYCLS,
    BUDALLOCATIONCLS = new$BUDALLOCATIONCLS,
    PAYPROMISECLS = new$PAYPROMISECLS,
    NOTEQUALEX = new$NOTEQUALEX,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    INVESTOBJECT = new$INVESTOBJECT,
    CHANGEORGNAME = new$CHANGEORGNAME,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_CORRECTIONDETAIL_AU_500)
-- Create 29.12.2009
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (5504, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=5504) and (RecordId=new$ID);
  end if;

END;
/
ALTER TABLE LimitFinDetail ADD (
  ContractCostsCls NUMBER(10),
    CHECK((ContractCostsCls<=2147483647)AND(ContractCostsCls>-2147483648)),
  constraint FK_LFD_ContractCostsCls foreign key (ContractCostsCls) references ContractCostsCls(ID)    
)
/
CREATE INDEX FK_LFD_ContractCostsCls ON LimitFinDetail(ContractCostsCls)
/
ALTER TABLE TENDERPRODUCT ADD (
  ContractCostsCls NUMBER(10),
    CHECK((ContractCostsCls<=2147483647)AND(ContractCostsCls>-2147483648)),
  constraint FK_TP_ContractCostsCls foreign key (ContractCostsCls) references ContractCostsCls(ID)    
)
/
CREATE INDEX FK_TP_ContractCostsCls ON TENDERPRODUCT(ContractCostsCls)
/
ALTER TABLE UNIONNOTIFYDETAIL ADD (
  ContractCostsCls NUMBER(10),
    CHECK((ContractCostsCls<=2147483647)AND(ContractCostsCls>-2147483648)),
  constraint FK_UND_ContractCostsCls foreign key (ContractCostsCls) references ContractCostsCls(ID)    
)
/
CREATE INDEX FK_UND_ContractCostsCls ON UNIONNOTIFYDETAIL(ContractCostsCls)
/
ALTER TABLE BANKEXCH_SUBSTITUTION ADD (
  DestContractCostsCls NUMBER(10),
    CHECK((DestContractCostsCls<=2147483647)AND(DestContractCostsCls>-2147483648)),
  constraint FK_BankExchSubst_DCCC foreign key (DestContractCostsCls) references ContractCostsCls(ID)
)
/
CREATE INDEX FK_BankExchSubst_DCCC ON BANKEXCH_SUBSTITUTION(DestContractCostsCls)
/
/*        */
ALTER TABLE TB_FacialFinDetail ADD (
  SourceTargetCls NUMBER(10),
    CHECK((SourceTargetCls<=2147483647)AND(SourceTargetCls>-2147483648)),
  DestTargetCls NUMBER(10),
    CHECK((DestTargetCls<=2147483647)AND(DestTargetCls>-2147483648)),
  constraint FK_FFC_SourceTarC foreign key (SourceTargetCls) references TargetCls(ID),
  constraint FK_FFC_DestTarC foreign key (DestTargetCls) references TargetCls(ID)
)
/
CREATE INDEX FK_FFC_SourceTarC ON TB_FacialFinDetail(SourceTargetCls)
/
CREATE INDEX FK_FFC_DestTarC ON TB_FacialFinDetail(DestTargetCls)
/

CREATE OR REPLACE VIEW FacialFinDetail (
  ID,
  SOURCEFACIALACC_CLS,
  SOURCEKVR,
  SOURCEKESR,
  DESTFACIALACC_CLS,
  DESTKVR,
  DESTKESR,
  BUDGETREF,
  CREDIT,
  PAYSYMBOLCLS,
  MEMORDERNUM,
  NOTE,
  PROGINDEX,
  RECORDINDEX,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  SOURCEKVSR,
  SOURCEKCSR,
  SOURCEKFSR,
  SOURCESUBKESR,
  SOURCEFACT,
  SOURCEMEANSTYPE,
  SOURCEFINSOURCE,
  SOURCEFINTYPE,
  DESTKVSR,
  DESTKCSR,
  DESTKFSR,
  DESTSUBKESR,
  DESTFACT,
  DESTMEANSTYPE,
  DESTFINSOURCE,
  DESTFINTYPE,
  REQUESTSINDEX,
  SENDERID,
  SENDERRECORDID,
  PROMISE,
  SOURCEDOCTYPE,
  DESTDOCTYPE,
  SOURCEPROMISE,
  DESTPROMISE,
  RECORDINDEX2,
  SOURCEBUDGETPROMISE,
  DESTBUDGETPROMISE,
  SUBPROGINDEX,
  STIMATEID,
  RVERSION,
  SOURCEDIRECTIONCLS,
  DESTDIRECTIONCLS,
  SOURCEDOCBASE,
  DESTDOCBASE,
  SOURCEEXECDOC,
  DESTEXECDOC,
  BUHOPERATIONCLS,
  SOURCEIFS,
  DESTIFS,
  CLSTYPE,
  UNIONNOTIFYREF,
  ACCEPTDATE,
  SOURCEKD,
  DESTKD,
  SOURCEREGIONCLS,
  DESTREGIONCLS,
  DESTFUNDSSOURCE,
  SOURCEFUNDSSOURCE,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  SOURCETRANSFERTCLS,
  DESTTRANSFERTCLS,
  DESTCLSTYPE,
  SOURCEASSIGNMENTKIND,
  DESTASSIGNMENTKIND,
  SOURCEEXECINNERNUMBER,
  DESTEXECINNERNUMBER,
  SOURCESUBSIDYCLS,
  DESTSUBSIDYCLS,
  SOURCEFAORG_TYPE,
  DESTFAORG_TYPE,
  SOURCEBUDALLOCATIONCLS,
  SOURCEPAYPROMISECLS,
  DESTBUDALLOCATIONCLS,
  DESTPAYPROMISECLS,
  SOURCEINVESTOBJECT,
  DESTINVESTOBJECT,
  TRANSFERTORG_REF,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  STOREDPAYMENTCONTENT,
  SOURCECONTRACTCOSTSCLS,
  DESTCONTRACTCOSTSCLS,
  SOURCETARGETCLS,
  DESTTARGETCLS)
AS
  SELECT
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    NOTE,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS,
    DESTTARGETCLS
  FROM TB_FacialFinDetail
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_ID
  INSTEAD OF DELETE
  ON FACIALFINDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_500 (TR_FACIALFINDETAIL_BD_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  Update facialfincaption set
  DocChangeDate = SYSDATE,
  RVersion=-1
  where id=:old.recordindex;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_FACIALFINDETAIL
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_FACIALFINDETAIL_AD_500)
-- Last update 27.08.2004
-- - - - - - - - - - - - -

  INSERT INTO DelRecIndexes
              (TableID, RecordId, DeleteDate, ProgIndex, Summa)
       VALUES (22, :OLD.ID, SYSDATE, :OLD.ProgIndex, :OLD.Credit);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_II
  INSTEAD OF INSERT
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
--
  SourceFacialAcc_CLS$ NUMBER(10);
  DestFacialAcc_CLS$ NUMBER(10);
  CapBuhOperationCLS$ NUMBER(10);
  CapClsType$ NUMBER(10);
  CapAcceptDate$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  PromiseAcceptDate$ NUMBER;
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  BPInnerNum1$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  Promise_Count1$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  PromiseAccepted1$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALFINDETAIL_BI_0)
-- Last update 15.12.2002
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_FacialFinDetail_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;
        
  else
    new$SenderIDKey := new$SenderID;
  END IF;
      
  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;
        
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_FACIALFINDETAIL_BI_100)
-- Last update 12.01.2009
-- - - - - - - - - - - - -

 /*  ,    */
   BEGIN

     select
       ffc.BudgetRef, ffc.BuhOperationCls, ffc.ClsType, ffc.AcceptDate,
       ffc.IsBlocked, ffc.BlockedCause, ffc.UnBlockedDate, ffc.UnBlockedCause
     into new$BudgetRef, CapBuhOperationCls$, CapClsType$, CapAcceptDate$,
       new$IsBlocked, new$BlockedCause, new$UnBlockedDate, new$UnBlockedCause
     from
       FacialFinCaption ffc
     where
       ffc.id = new$RecordIndex;
     
   EXCEPTION
     WHEN NO_DATA_FOUND THEN
       new$BudgetRef := NULL;
       CapBuhOperationCls$ := NULL;
       CapClsType$ := NULL;
       CapAcceptDate$ := NULL;
   END;

   /*      */
   if (new$BuhOperationCls is null) then new$BuhOperationCls := CapBuhOperationCls$; end if;

   /*      */
   if (new$ClsType is null) then new$ClsType := CapClsType$; end if;

   if (new$DestClsType is null) then new$DestClsType := new$ClsType; end if;
   
   /*      */
   if (new$AcceptDate is null) then new$AcceptDate := CapAcceptDate$; end if;

   /*      */
   if ((new$SourceFacialAcc_CLS is null) or (new$DestFacialAcc_CLS is null)) then
     BEGIN
       select SourceFacialAcc_CLS, DestFacialAcc_CLS
         into SourceFacialAcc_CLS$, DestFacialAcc_CLS$
       from FacialFinCaption
       where new$RecordIndex = id;
     EXCEPTION
       WHEN NO_DATA_FOUND THEN
         SourceFacialAcc_CLS$ := NULL;
         DestFacialAcc_CLS$ := NULL;
     END;

     if (new$SourceFacialAcc_CLS is null) then new$SourceFacialAcc_CLS := SourceFacialAcc_CLS$; end if;
     if (new$DestFacialAcc_CLS is null) then new$DestFacialAcc_CLS := DestFacialAcc_CLS$; end if;
   end if;

-- - - - - - - - - - - - -
-- BI_110 (TR_FACIALFINDETAIL_BI_110)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype1$ := -1 ;
  IF (new$SourceFintype IS NULL OR (new$Sourcefintype=0)) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype1$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype1$  ;
     
  END IF;
  IF (new$DestFintype IS NULL OR (new$Destfintype=0)) THEN 
    IF (i_fintype1$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype1$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype1$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 1000;
  END IF;
  IF (new$SourceIFS IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 1000;
  END IF;
  IF (new$DestIFS IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*   Promise null,    */
  IF ((new$Promise IS NULL) AND
  ((new$SourcePromise IS NOT NULL) OR
  (new$DestPromise IS NOT NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND(new$DestPromise IS NOT NULL)AND
        (new$SourcePromise=new$DestPromise)) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*    ,  ,       */
  ELSE
    IF ((new$Promise IS NOT NULL) AND
    (new$SourcePromise IS NULL) AND
    (new$DestPromise IS NULL)) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  BEGIN

    /*     \   */
    SELECT org.Org_Type  INTO new$SourceFAOrg_Type FROM Organizations org
    INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$SourceFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  BEGIN

    SELECT org.Org_Type  INTO new$DestFAOrg_Type FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$DestFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BI_120 (TR_FACIALFINDETAIL_BI_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*  60 :  '   .'; source
          61 :  '      '; dest
          62 :  '   ';dest
          63 :  '    '; source
          64 :  '   '; source
          65 :  ' , ';dest
          66 :  '  ,  - '; source dest
          67 :  '   ';source
          68 :  '  \ ';dest
          69 :  '   \ '; dest
          70 :  '  \ ';source
          71 :  '   \ '; dest */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if ((new$DestClsType is NULL) and
  (
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71))) or (new$ProgIndex = 60)
  )) then
    new$DestClsType := 1; /*       ClsType */
      
  else
    if ((new$DestClsType is NULL) and
    ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    ) then
      new$DestClsType := 2; /*        ClsType */
          
    else
      if (new$DestClsType is null) then
        new$DestClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_FACIALFINDETAIL_BI_200)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode1$);
  /*     */
  if (((new$SourcePromise is not null) or (new$DestPromise is not null)) and (PromiseMode1$ <> 1)) then
    if (new$SourcePromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$         from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    if (new$DestPromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$         from
      promise_detail pr
      where
      (pr.registrnumber = new$DESTPROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;    
    END IF;
  END IF;
  if (PromiseMode1$ = 1) then
    /* source  .    */
    if ((new$SourcePromise is not null) and (new$SourceBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum1$           from PaymentSchedule 
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum1$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* dest  .    */
    if ((new$DestPromise is not null) and (new$DestBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum1$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$DestBudgetPromise := BPInnerNum1$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* source    ,   ,   */
    if ((new$SourceBudgetPromise is not null) and (new$SourcePromise is null)) then
      BEGIN
        select ANumber 
        into BPInnerNum1$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$SourcePromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;
            
    END IF;
    /* dest */
    if ((new$DestBudgetPromise is not null) and (new$DestPromise is null)) then
      BEGIN
        select ANumber 
        into BPInnerNum1$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$DestPromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;
            
    END IF;
    /*     */
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$1
      from PaymentSchedule where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls1$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$2
      from PaymentSchedule where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls1$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_FACIALFINDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$SourceExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*    ,   ,  */
    else 
      if (new$SourceExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$DestExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*    ,   ,  */
    else 
      if (new$DestExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALFINDETAIL_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update facialfincaption set
  DocChangeDate = new$UpdateDate,
  RVersion=-1
  where id=new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALFINDETAIL (
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    NOTE,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS,
    DESTTARGETCLS
  ) VALUES (
    new$ID,
    new$SOURCEFACIALACC_CLS,
    new$SOURCEKVR,
    new$SOURCEKESR,
    new$DESTFACIALACC_CLS,
    new$DESTKVR,
    new$DESTKESR,
    new$BUDGETREF,
    new$CREDIT,
    new$PAYSYMBOLCLS,
    new$MEMORDERNUM,
    new$NOTE,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$SOURCEKVSR,
    new$SOURCEKCSR,
    new$SOURCEKFSR,
    new$SOURCESUBKESR,
    new$SOURCEFACT,
    new$SOURCEMEANSTYPE,
    new$SOURCEFINSOURCE,
    new$SOURCEFINTYPE,
    new$DESTKVSR,
    new$DESTKCSR,
    new$DESTKFSR,
    new$DESTSUBKESR,
    new$DESTFACT,
    new$DESTMEANSTYPE,
    new$DESTFINSOURCE,
    new$DESTFINTYPE,
    new$REQUESTSINDEX,
    new$SENDERID,
    new$SENDERRECORDID,
    new$PROMISE,
    new$SOURCEDOCTYPE,
    new$DESTDOCTYPE,
    new$SOURCEPROMISE,
    new$DESTPROMISE,
    new$RECORDINDEX2,
    new$SOURCEBUDGETPROMISE,
    new$DESTBUDGETPROMISE,
    new$SUBPROGINDEX,
    new$STIMATEID,
    new$RVERSION,
    new$SOURCEDIRECTIONCLS,
    new$DESTDIRECTIONCLS,
    new$SOURCEDOCBASE,
    new$DESTDOCBASE,
    new$SOURCEEXECDOC,
    new$DESTEXECDOC,
    new$BUHOPERATIONCLS,
    new$SOURCEIFS,
    new$DESTIFS,
    new$CLSTYPE,
    new$UNIONNOTIFYREF,
    new$ACCEPTDATE,
    new$SOURCEKD,
    new$DESTKD,
    new$SOURCEREGIONCLS,
    new$DESTREGIONCLS,
    new$DESTFUNDSSOURCE,
    new$SOURCEFUNDSSOURCE,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SOURCETRANSFERTCLS,
    new$DESTTRANSFERTCLS,
    new$DESTCLSTYPE,
    new$SOURCEASSIGNMENTKIND,
    new$DESTASSIGNMENTKIND,
    new$SOURCEEXECINNERNUMBER,
    new$DESTEXECINNERNUMBER,
    new$SOURCESUBSIDYCLS,
    new$DESTSUBSIDYCLS,
    new$SOURCEFAORG_TYPE,
    new$DESTFAORG_TYPE,
    new$SOURCEBUDALLOCATIONCLS,
    new$SOURCEPAYPROMISECLS,
    new$DESTBUDALLOCATIONCLS,
    new$DESTPAYPROMISECLS,
    new$SOURCEINVESTOBJECT,
    new$DESTINVESTOBJECT,
    new$TRANSFERTORG_REF,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$STOREDPAYMENTCONTENT,
    new$SOURCECONTRACTCOSTSCLS,
    new$DESTCONTRACTCOSTSCLS,
    new$SOURCETARGETCLS,
    new$DESTTARGETCLS);

-- - - - - - - - - - - - -
-- AI_100 (TR_FACIALFINDETAIL_AI_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  update FacialFinCaption set
  ClsType = new$ClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(ClsType <> new$ClsType);
  update FacialFinCaption set
  DestClsType = new$DestClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(DestClsType <> new$DestClsType);

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALFINDETAIL_AI_500)
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID =22 ) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype1$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype1$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype1$  ;
     
  END IF;
  IF (new$DestFintype IS NULL) THEN 
    IF (i_fintype1$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype1$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype1$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*  60 :  '   .'; source
          61 :  '      '; dest
          62 :  '   ';dest
          63 :  '    '; source
          64 :  '   '; source
          65 :  ' , ';dest
          66 :  '  ,  - '; source dest
          67 :  '   ';source
          68 :  '  \ ';dest
          69 :  '   \ '; dest
          70 :  '  \ ';source
          71 :  '   \ '; dest */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  /*     */
  if (PromiseMode$ <> 1) then
    /*          */
    if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /*          */
    if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$DestPromise)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
        
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /*     */
  if (PromiseMode$ = 1) then
    /* source  .    */
    if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
    (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule 
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* dest  .     */
    if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
    (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
          
    /*         NULL,    */
    /* source */
    if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
    (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /* dest */
    if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
    (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /*    ,     */
    if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
      new$SourcePromise := null;
      new$Promise := null;
            
    END IF;
    if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
      new$DestPromise := null;
      new$Promise := null;
            
    END IF;
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$1
      from PaymentSchedule
      where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$2
      from PaymentSchedule
      where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$SourcePromise is not null and (
    (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
    (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$SourceExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null and (
    (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
    (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$DestExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select c.AcceptDate into CapAcceptDate$
      from facialfincaption c
      where c.id = new$RecordIndex;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        CapAcceptDate$ := NULL;
    END;

    if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
      new$AcceptDate := new$AcceptDate;
    else
      RaiseException('ex_wrongacceptdate');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
ALTER TABLE BudgetData ADD (
  TargetCls NUMBER(10),
    CHECK((TargetCls<=2147483647)AND(TargetCls>-2147483648)),
  constraint FK_BD_TargetCls foreign key (TargetCls) references TargetCls(ID)  
)
/
CREATE INDEX FK_BD_TargetCls ON BudgetData(TargetCls)
/
ALTER TABLE TB_Incomes32 ADD (
  TargetCls NUMBER(10),
    CHECK((TargetCls<=2147483647)AND(TargetCls>-2147483648)),
  constraint FK_Inc_TargetCls foreign key (TargetCls) references TargetCls(ID)    
)
/
CREATE INDEX FK_Inc_TargetCls ON TB_Incomes32(TargetCls)
/

CREATE OR REPLACE VIEW Incomes32 (
  ID,
  DOCNUMBER,
  DOCCOUNT,
  IDATE,
  DEBIT,
  CREDIT,
  DOCTYPE,
  INN,
  ORG_REF,
  ACCOUNTINDEX,
  KD,
  SUBKD,
  REGIONCLS,
  GOSNI,
  INCACCOUNT,
  PROGINDEX,
  RECORDINDEX,
  BUDGETREF,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  NOTE,
  RECORDINDEX2,
  ELNUM,
  NOTEEX,
  BUHPAYMENTCLS,
  ACCOUNTREF,
  ELPACKETNUM,
  FACIALACC_CLS,
  NDS,
  MEANSTYPE,
  RECORDDATE,
  TOTALREF,
  REQUESTSINDEX,
  KVSR,
  TAXNOTE,
  DOCNUM,
  REALPAYERORG_REF,
  DOCDATE,
  DOCBASE,
  FACT,
  RVERSION,
  KFSR,
  KESR,
  KVR,
  KCSR,
  SUMCOMPLETE,
  ELDOCREF,
  REQUESTSINDEX2,
  FEDERALFUNDSREF,
  BUHOPERATIONCLS,
  IFS,
  IFS_CORR,
  CLSTYPE,
  NDSNOTE,
  DOGNUM,
  SENDERID,
  SENDERRECORDID,
  OKATO,
  ADDOKATO,
  REJECTCLS,
  REJECTCAUSE,
  FUNDSSOURCE,
  DIRECTIONCLS,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  STIMATEID,
  TRANSFERTCLS,
  SUBSIDYCLS,
  FAORGTYPE,
  OKTMO,
  UINCODE,
  FINTYPE,
  INVESTOBJECT,
  CONTRACTCOSTSCLS,
  TARGETCLS)
AS
  SELECT
    ID,
    DOCNUMBER,
    DOCCOUNT,
    IDATE,
    DEBIT,
    CREDIT,
    DOCTYPE,
    INN,
    ORG_REF,
    ACCOUNTINDEX,
    KD,
    SUBKD,
    REGIONCLS,
    GOSNI,
    INCACCOUNT,
    PROGINDEX,
    RECORDINDEX,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    NOTE,
    RECORDINDEX2,
    ELNUM,
    NOTEEX,
    BUHPAYMENTCLS,
    ACCOUNTREF,
    ELPACKETNUM,
    FACIALACC_CLS,
    NDS,
    MEANSTYPE,
    RECORDDATE,
    TOTALREF,
    REQUESTSINDEX,
    KVSR,
    TAXNOTE,
    DOCNUM,
    REALPAYERORG_REF,
    DOCDATE,
    DOCBASE,
    FACT,
    RVERSION,
    KFSR,
    KESR,
    KVR,
    KCSR,
    SUMCOMPLETE,
    ELDOCREF,
    REQUESTSINDEX2,
    FEDERALFUNDSREF,
    BUHOPERATIONCLS,
    IFS,
    IFS_CORR,
    CLSTYPE,
    NDSNOTE,
    DOGNUM,
    SENDERID,
    SENDERRECORDID,
    OKATO,
    ADDOKATO,
    REJECTCLS,
    REJECTCAUSE,
    FUNDSSOURCE,
    DIRECTIONCLS,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    STIMATEID,
    TRANSFERTCLS,
    SUBSIDYCLS,
    FAORGTYPE,
    OKTMO,
    UINCODE,
    FINTYPE,
    INVESTOBJECT,
    CONTRACTCOSTSCLS,
    TARGETCLS
  FROM TB_Incomes32
/

CREATE OR REPLACE TRIGGER TR_INCOMES32_ID
  INSTEAD OF DELETE
  ON INCOMES32
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_10 (TR_INCOMES32_BD10)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

  delete
  from CurrencyIncomes
  where (id = :old.id);

-- - - - - - - - - - - - -
-- BD_20 (T_INCOMES32_BD_20)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

  /*    */
  if (:old.DocType between 1010 and 1019) then
    delete from PayDoc32
    where 
      (ProgIndex = :old.ProgIndex) 
    and 
     (RecordIndex = :old.id);
  end if;

-- - - - - - - - - - - - -
-- BD_500 (TR_INCOMES32_BD_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  Update QuotesTitle set
  DocChangeDate = SYSDATE,
  RVersion = -1
  where id = :old.recordindex;

-- - - - - - - - - - - - -
-- BD_600 (TR_INCOMES32_BD_600)
-- Last update 14.10.2009
-- - - - - - - - - - - - -

    --    
    if (:old.ProgIndex = 41) then
        delete
            from Incomes32
        where
           (ProgIndex=42)and
           (RecordIndex=:old.id);
    end if;

    --  (  )
    if (:old.ProgIndex = 42) then
        delete
            from Incomes32
        where
            (ProgIndex=43)and
            (RecordIndex=:old.id);
    end if;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_INCOMES32
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);
   
  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_500 (TR_INCOMES32_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordID, DeleteDate, ProgIndex, SUMMA) values (161, :old.ID, SYSDATE, :old.ProgIndex, :old.DEBIT + :old.CREDIT);

END;
/

CREATE OR REPLACE TRIGGER TR_INCOMES32_II
  INSTEAD OF INSERT
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
--
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  CapDocNumber VARCHAR2(20);
  unkKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  Kd_Master NUMBER(10);
  idKD$ NUMBER(10);
  unkVKD$ VARCHAR2(20);
  val_DocCount$ NUMBER(10);
  val_DocType$ NUMBER(10);
  val_Org_Ref$ NUMBER(10);
  val_AccountIndex$ NUMBER(10);
  val_SubKD$ NUMBER(10);
  val_RegionCLS$ NUMBER(10);
  val_GosNI$ NUMBER(10);
  val_IncAccount$ NUMBER(10);
  val_BudgetRef$ NUMBER(10);
  val_MEANSTYPE$ NUMBER(10);
  val_FACIALACC_CLS$ NUMBER(10);
  val_TransfertCls$ NUMBER(10);
  CapAcceptDate$ NUMBER;
  CapReestrNumber$ VARCHAR2(20);
  CapProgIndex$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_INCOMES32_BI)
-- Version 10.00.00.2
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN 
    select g_shared.nextval into new$id from dual;
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN 
    new$FACIALACC_CLS := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN 
    new$Gosni := 0;
  END IF;
  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN 
    new$DocBase := 0;
  END IF;
  /* 3 -    */
  IF (new$KD IS NULL) THEN 
    new$KD := 0;
  END IF;
  IF (new$ProgIndex IS NULL) THEN 
    new$ProgIndex := 3;
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN 
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN 
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN 
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN 
    new$AccountIndex := 0;
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN 
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN 
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN 
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN 
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN 
    new$DirectionCLS := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  IF (new$FinType IS NULL) THEN  
    new$FinType := 0;
  END IF;
  /*   .        */
  IF (new$IFS IS NULL) THEN 
    new$IFS := 0;
  END IF;
  IF (new$IFS_CORR IS NULL) THEN 
    new$Ifs_Corr := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
   
  /*  ,    */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0)) THEN
    BEGIN
      SELECT qt.BudgetRef      INTO new$BudgetRef FROM QuotesTitle qt
      WHERE qt.Id = new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    0,     */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0)) THEN
    BEGIN
      SELECT fa.BudgetRef      INTO new$BudgetRef FROM FacialAcc_Cls fa
      WHERE fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    0,    */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0))
  THEN 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
   
  IF (new$ProgIndex = 45) 
  THEN 
    IF (new$IncAccount IS NULL) THEN
      GetDefDFAccRefForBudget(new$BudgetRef,new$IncAccount);
    END IF;
    BEGIN

      /*     */
      SELECT qt.ProgIndex, qt.AcceptDate, qt.IncAccount, qt.ReestrNumber 
      INTO CapProgIndex$, CapAcceptDate$, new$IncAccount, CapReestrNumber$       FROM QuotesTitle qt
      WHERE 
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*           / */
    /*  /   after insert */
    IF (CapProgIndex$ <> 145) THEN 
      new$iDate := CapAcceptDate$;
    END IF;
    IF ((CapProgIndex$ = 145)AND (NOT ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0)OR (new$Credit<0)))) )
    THEN 
      new$Idate := CapAcceptDate$;      
    END IF;
    /*   -    () */
    IF ((CapProgIndex$ = 45) AND (CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN 
      /*        , *//*    */            
                  
      new$FederalFundsRef := new$ID;
      /* if-then */  
    END IF;/* if-then*/
  END IF;
  BEGIN
    /*     \*/
    SELECT org.Org_Type   INTO new$FAOrgType FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$FacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BI_5 (TR_INCOMES_BI_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BI_9 (TR_INCOMES32_BI_VZ)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   IF (new$ProgIndex = 9) THEN
      /*   */
      GetIntConst (9, 1, new$IncAccount);

      BEGIN
        /*      */
        SELECT ACCEPTDATE, BUDGETREF
          INTO new$IDate, new$BudgetRef
          FROM VZ_OFFSET
         WHERE ID = new$RecordIndex;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_INCOMES32_BI_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   BEGIN
      SELECT Inn
        INTO new$Inn
        FROM Organizations o
       WHERE (o.ID = new$Org_Ref);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

/*  .    ,    */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      BEGIN
         SELECT c.BudgetRef
           INTO new$budgetref
           FROM QuotesTitle c
          WHERE c.ID = NEW$RecordIndex;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

   /*  .  ,     */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      BEGIN
         SELECT fa.BudgetRef
           INTO new$budgetref
           FROM FacialAcc_Cls fa
          WHERE fa.ID = NEW$FacialAcc_Cls;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

   /*  ,    */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      GetIntConst (-1, 3, new$budgetref);
   END IF;

-- - - - - - - - - - - - -
-- BI_30 (TR_INCOMES32_BI_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then 
    BEGIN
      select q.BuildDate 
      into 
      new$DocDate        from QuotesTitle q 
      where q.id = new$RecordIndex 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_70 (TR_INCOMES32_BI_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
               */
         new$FederalFundsRef := new$ID;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_INCOMES32_BI_100)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if ((not (newKD$  like unkKD$)) and
    (not (newKD$  like unkVKD$))) then
      /*   (    
            ) ,  
         ,   */

      /*       */
      if (new$Debit <> 0) then 
        RaiseException('ex_UnknownRedirect');
      END IF;
      BEGIN

        /*      */
        select KD,DocCount,DocType,
        Org_Ref,AccountIndex,SubKD,RegionCLS,GosNI,
        IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,
        TransfertCls
        into
        idKD$,
        val_DocCount$,
        val_DocType$,
        val_Org_Ref$,
        val_AccountIndex$,
        val_SubKD$,
        val_RegionCLS$,
        val_GosNI$,
        val_IncAccount$,
        val_BudgetRef$,
        val_MEANSTYPE$  ,
        val_FACIALACC_CLS$,
        val_TransfertCls$         from incomes32 where id=new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
         
      if (not idKD$ is null) then
        insert into
        /* KD=   (      )
              Debit=0
              redit=-new.credit
              ProgIndex=43
              RecordIndex=new.id
              id    Incomes32*/
        Incomes32(CreaterUser, DocNum,DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS, TransfertCls)
        Values(new$CreaterUser, new$DocNum, val_DocCount$, new$iDate, new$DOCDATE, 0, -new$Credit, val_DocType$,
        val_Org_Ref$, val_AccountIndex$, idKD$, val_SubKD$, val_RegionCLS$, val_GosNI$,
        43,new$Id, val_IncAccount$, val_BudgetRef$, new$Note,val_MEANSTYPE$,val_FACIALACC_CLS$,val_TransfertCls$);
        
      END IF; 
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_110 (TR_INCOMES32_BI_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       /*       ClsType */
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                /*  -  */
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_INCOMES32_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update QuotesTitle set
  DocChangeDate = new$UpdateDate,
  RVersion = -1
  where id = new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_INCOMES32 (
    ID,
    DOCNUMBER,
    DOCCOUNT,
    IDATE,
    DEBIT,
    CREDIT,
    DOCTYPE,
    INN,
    ORG_REF,
    ACCOUNTINDEX,
    KD,
    SUBKD,
    REGIONCLS,
    GOSNI,
    INCACCOUNT,
    PROGINDEX,
    RECORDINDEX,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    NOTE,
    RECORDINDEX2,
    ELNUM,
    NOTEEX,
    BUHPAYMENTCLS,
    ACCOUNTREF,
    ELPACKETNUM,
    FACIALACC_CLS,
    NDS,
    MEANSTYPE,
    RECORDDATE,
    TOTALREF,
    REQUESTSINDEX,
    KVSR,
    TAXNOTE,
    DOCNUM,
    REALPAYERORG_REF,
    DOCDATE,
    DOCBASE,
    FACT,
    RVERSION,
    KFSR,
    KESR,
    KVR,
    KCSR,
    SUMCOMPLETE,
    ELDOCREF,
    REQUESTSINDEX2,
    FEDERALFUNDSREF,
    BUHOPERATIONCLS,
    IFS,
    IFS_CORR,
    CLSTYPE,
    NDSNOTE,
    DOGNUM,
    SENDERID,
    SENDERRECORDID,
    OKATO,
    ADDOKATO,
    REJECTCLS,
    REJECTCAUSE,
    FUNDSSOURCE,
    DIRECTIONCLS,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    STIMATEID,
    TRANSFERTCLS,
    SUBSIDYCLS,
    FAORGTYPE,
    OKTMO,
    UINCODE,
    FINTYPE,
    INVESTOBJECT,
    CONTRACTCOSTSCLS,
    TARGETCLS
  ) VALUES (
    new$ID,
    new$DOCNUMBER,
    new$DOCCOUNT,
    new$IDATE,
    new$DEBIT,
    new$CREDIT,
    new$DOCTYPE,
    new$INN,
    new$ORG_REF,
    new$ACCOUNTINDEX,
    new$KD,
    new$SUBKD,
    new$REGIONCLS,
    new$GOSNI,
    new$INCACCOUNT,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$BUDGETREF,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$NOTE,
    new$RECORDINDEX2,
    new$ELNUM,
    new$NOTEEX,
    new$BUHPAYMENTCLS,
    new$ACCOUNTREF,
    new$ELPACKETNUM,
    new$FACIALACC_CLS,
    new$NDS,
    new$MEANSTYPE,
    new$RECORDDATE,
    new$TOTALREF,
    new$REQUESTSINDEX,
    new$KVSR,
    new$TAXNOTE,
    new$DOCNUM,
    new$REALPAYERORG_REF,
    new$DOCDATE,
    new$DOCBASE,
    new$FACT,
    new$RVERSION,
    new$KFSR,
    new$KESR,
    new$KVR,
    new$KCSR,
    new$SUMCOMPLETE,
    new$ELDOCREF,
    new$REQUESTSINDEX2,
    new$FEDERALFUNDSREF,
    new$BUHOPERATIONCLS,
    new$IFS,
    new$IFS_CORR,
    new$CLSTYPE,
    new$NDSNOTE,
    new$DOGNUM,
    new$SENDERID,
    new$SENDERRECORDID,
    new$OKATO,
    new$ADDOKATO,
    new$REJECTCLS,
    new$REJECTCAUSE,
    new$FUNDSSOURCE,
    new$DIRECTIONCLS,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$STIMATEID,
    new$TRANSFERTCLS,
    new$SUBSIDYCLS,
    new$FAORGTYPE,
    new$OKTMO,
    new$UINCODE,
    new$FINTYPE,
    new$INVESTOBJECT,
    new$CONTRACTCOSTSCLS,
    new$TARGETCLS);

-- - - - - - - - - - - - -
-- AI_20 (T_INCOMES32_AI_20)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   --     
   if (new$ProgIndex <> 42) then
     BEGIN
       SELECT ProgIndex, DocNumber, AcceptDate
        INTO CapProgIndex, CapDocNumber, CapAcceptDate
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
     EXCEPTION
       WHEN NO_DATA_FOUND THEN NULL;
     END;
   end if;

   --   - ,  
   IF ((CapProgIndex = 145) or (new$ProgIndex=42)) THEN

      If ((new$ProgIndex=42) and (new$DocType between 1010 and 1019) and
         (new$Debit>0) and (new$DOCDATE is not null))
      then
        BEGIN
          select kd into Kd_Master
    From Incomes32 inc
          where inc.id = new$RecordIndex;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;

        if (Kd_Master = new$Kd) then
          CapAcceptDate := new$DOCDATE;
          CapProgIndex  := new$ProgIndex;
          CapDocNumber  := new$DocNum;
        end if;
      end if; --       (         )

      --             
      IF ((CapAcceptDate IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit > 0) OR (new$Credit < 0))) THEN
         --    ( RealPayerOrg_Ref(PayDoc32)=new$RealPayerOrg_Ref(Incomes32))
         INSERT INTO PayDoc32
            (BudgetRef, AccountRef, PayerAttrRef, InputDate,
             Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref, FACIALACC_CLS)
         VALUES (new$BudgetRef, new$AccountRef, new$IncAccount, CapAcceptDate,
             (new$Debit - new$Credit), new$Note, new$ProgIndex, new$id, CapDocNumber, new$TaxNote,
             new$RealPayerOrg_Ref,new$FACIALACC_CLS);
      -- (new$Debit - new$Credit) --- ..      ,    ,
      --             
      END IF;

   END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_INCOMES32_AI_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 161) AND (RecordID = NEW$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 10.00.00.2
-- - - - - - - - - - - - -

  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN 
    new$DocBase := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN 
    new$Gosni := 0;
  END IF;
  /* 3 -    */
  IF (new$ProgIndex IS NULL) THEN 
    new$ProgIndex := 3; 
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0; 
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN 
    new$FACIALACC_CLS := 0; 
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN 
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN 
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN 
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN 
    new$AccountIndex := 0; 
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN 
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN 
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN 
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN 
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN 
    new$DirectionCLS := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  IF (new$FinType IS NULL) THEN  
    new$FinType := 0;
  END IF;
  /*   .        */
  IF (new$IFS_CORR IS NULL) THEN 
    new$Ifs_Corr := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$Ifs := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  BEGIN

    /*     */
    /*   after   ,*/ 
    /*      */
    SELECT ProgIndex, AcceptDate, ReestrNumber
    INTO CapProgIndex1$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
    WHERE
    (qt.ID = new$RecordIndex)
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*              
           (  , , ) */
  /*   -    () */
  IF (CapProgIndex1$ = 45)
  THEN 
    IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN 
      /*        ,
                     */            
      new$FederalFundsRef := new$ID;
      /* if-then*/
    ELSE 
      new$FederalFundsRef := NULL;
      /* if-else*/  
    END IF;/* if (CapProgIndex=45) */
  END IF;
  /*     */
  IF (new$BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
      IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
        RaiseException('Ex_CantModufyBudget');
      END IF;
      IF (new$Progindex = 41) THEN
        SELECT COUNT(inc.id ) INTO CNT$1
        FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
        IF ((CNT$1<> 0)) THEN
          RaiseException('Ex_CantModufyBudget');
        END IF;   
      END IF;
    END IF;
  END IF;
  /*     \*/
  IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
  ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

  BEGIN
    SELECT Inn
     INTO new$Inn
     FROM Organizations o
    WHERE (o.ID = new$Org_Ref);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*      */
  IF (new$ProgIndex <> 42) THEN
    BEGIN
      SELECT ProgIndex, DocNumber, AcceptDate
      INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
      WHERE
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*   -  ,   */
  IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
  THEN 
    IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
    (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
    THEN 
      BEGIN
        SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
        WHERE inc.id = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (Kd_Master$ = new$Kd) THEN 
        CapAcceptDate$ := new$DOCDATE;
        CapProgIndex$  := new$ProgIndex;
        CapDocNumber$  := new$DocNum;
        /*  */        
      END IF;/*       (         )*/
    END IF;
    IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
    THEN 

      /*      */
      /* /      Incomes32, ..      ,     */

      /*     /   */
      SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
      INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
      ;
      /*            ,  .*/
      /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
                      ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
                     ) THEN
                    EXCEPTION EX_CANNOTUPDATENUMBER;*/
                 
                
      IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
      then
        if ((new$DocType <> :old.DocType )
        or (new$Debit <> :old.Debit )
        or (new$Credit <> :old.Credit)
        or (new$org_ref <> :old.org_ref)
        or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
        or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
        )
        then
          RaiseException('EX_CANNOTUPDATENUMBER');
        END IF;
      END IF;
                


      /*           */
      IF (PayDocCount$ = 0)
      THEN 
        /*       */
        GetIntConst(11, 2,ConstPayQueue$);
        /*       */
        GetIntConst(11, 1,ConstSendBy$);

        /*    */
        INSERT INTO PayDoc32
        (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
        Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
        VALUES
        (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
        new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
        /* (new.Debit - new.Credit) --- ..      ,    ,
                                     */

        /* if-then */
      ELSE 
        /*     */
        IF (((new$AccountRef = :old.AccountRef) OR
        ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
        AND (new$IncAccount = :old.IncAccount)
        AND (new$BudgetRef = :old.BudgetRef)
        AND ((new$Note = :old.Note) OR
        ((new$Note IS NULL) AND (:old.Note IS NULL)))
        AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
        ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
        AND ((new$TaxNote = :old.TaxNote) OR
        ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
        )  THEN
          new$AccountRef := new$AccountRef;
                          
        ELSE

          UPDATE PayDoc32 pd
          SET
          pd.AccountRef = new$AccountRef,
          pd.PayerAttrRef = new$IncAccount,
          pd.AcceptorAttrRef = new$AccountRef,
          pd.TextNote = new$Note,
          pd.TaxNote = new$TaxNote,
          pd.BudgetRef = new$BudgetRef,
          pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
          pd.InputDate = CapAcceptDate$,
          pd.SourceDocNumber = CapDocNumber$,
          pd.FACIALACC_CLS = new$FACIALACC_CLS
          WHERE
          (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
        END IF;
        IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
        OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
        THEN  
          IF (Divided$ > 0)
          THEN
            /*  ,      */
            RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
          ELSE
            UPDATE PayDoc32 pd
            SET
            pd.Credit = new$Debit - new$Credit
            WHERE
            (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
          END IF;/* if-then*/            
        END IF;/* if-else*/
      END IF;
      /*     / */
      /*   :     ,     */
      /*  ,     */
      SELECT MAX(pd.AcceptDate)
      INTO Date_Pd$           FROM PayDoc32 pd
      WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
      ;
      new$Idate := Date_Pd$;
      /* if-then*/
    ELSE 
      /*       
                          -
                    . */
      DELETE FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex = new$ProgIndex)
      AND (pd.RecordIndex = new$id);
      /* if-else*/  
    END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then 
    BEGIN
      select q.BuildDate 
      into 
      new$DocDate        from QuotesTitle q 
      where q.id = new$RecordIndex 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
            */
         new$FederalFundsRef := new$ID;
      ELSE
         new$FederalFundsRef := NULL;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN
      select KDValue   into oldKD$ from kd where Id=:old.kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN

      /*     */
      select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
      IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
      into
      idKD1$,
      val_DocCount1$,
      val_DocType1$,
      val_Org_Ref1$,
      val_AccountIndex1$,
      val_SubKD1$,
      val_RegionCLS1$,
      val_GosNI1$,
      val_IncAccount1$,
      val_BudgetRef1$,
      val_MEANSTYPE1$  , 
      val_FACIALACC_CLS1$,
      val_TransfertCls1$         from incomes32 where id=new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not idKD1$ is null) then
      if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
      (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
        /*   ,    */
        delete
        from Incomes32
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      (new$Debit<>0))
      /*       */
      then 
        RaiseException('ex_UnknownRedirect');
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
        /*   ,   ,   */
        insert into
        Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
        Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
        val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
        val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
        new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
      END IF;
      if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
      and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
        /*      ,   */
        update Incomes32
        set
        DocNum = new$DocNum,
        DocCount = val_DocCount1$,
        iDate = new$iDate,
        DOCDATE = new$DOCDATE,
        Debit = 0,
        Credit = -new$Credit,
        DocType = val_DocType1$,
        Org_Ref = val_Org_Ref1$,
        AccountIndex = val_AccountIndex1$,
        KD = idKD1$,
        SubKD = val_SubKD1$,
        RegionCLS = val_RegionCLS1$,
        GosNI = val_GosNI1$,
        ProgIndex = 43,
        RecordIndex = new$Id,
        IncAccount = val_IncAccount1$,
        BudgetRef = val_BudgetRef1$,
        Note = new$Note,
        MEANSTYPE = val_MEANSTYPE1$,
        FACIALACC_CLS = val_FACIALACC_CLS1$,
        TransfertCls = val_TransfertCls1$,
        RVersion = -1
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
         
      END IF; 
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 41)    /*   () */
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    /*       */
    FOR REC$1 IN (SELECT inc.id
     AS val_ID42    FROM Incomes32 inc
    LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
    WHERE (inc.ProgIndex =  42) and
    (inc.RecordIndex =  new$id) and
    (inc.debit = 0) and
    (not(kd.kdvalue like unkKD$)) and
    (not(kd.kdvalue like unkVKD$))
    )
    LOOP
      BEGIN
        /*       */
        select inc.id
        into val_ID431$         FROM Incomes32 inc
        WHERE (inc.ProgIndex =  43) and
        (inc.RecordIndex =  REC$1.val_ID42)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      /*     ,   Credit, ProgIndex, RecordIndex */
      update Incomes32
      set
      DocNum = new$DocNum,
      DocCount = new$DocCount,       
      DOCDATE = new$DOCDATE,
      Debit = 0,
      DocType = new$DocType,
      Org_Ref = new$Org_Ref,
      AccountIndex = new$AccountIndex,
      KD = new$Kd,
      SubKD = new$SubKD,
      RegionCLS = new$RegionCLS,
      GosNI = new$GosNI,
      IncAccount = new$IncAccount,
      BudgetRef = new$BudgetRef,
      Note = new$Note,
      MEANSTYPE = new$MEANSTYPE,
      FACIALACC_CLS = new$FACIALACC_CLS,
      FACT = new$FACT,
      TransfertCls = new$TransfertCls,
      DirectionCls = new$DirectionCls,
      rversion = -1
      where id = val_ID431$;

        
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       --       ClsType
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                --  - 
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      --   
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    REJECTCAUSE = new$REJECTCAUSE,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   IF (NEW$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (161, :OLD.ID, SYSDATE);
      DELETE FROM DelRecIndexes
        WHERE (TableID = 161) AND (RecordId = NEW$ID);
   END IF;

END;
/
ALTER TABLE TB_PaymentSchedule ADD (
  TargetCls NUMBER(10),
    CHECK((TargetCls<=2147483647)AND(TargetCls>-2147483648)),
  constraint FK_PS_TargetCls foreign key (TargetCls) references TargetCls(ID)    
)
/
CREATE INDEX FK_PS_TargetCls ON TB_PaymentSchedule(TargetCls)
/

CREATE OR REPLACE VIEW PaymentSchedule (
  ID,
  ANUMBER,
  PARENTNUMBER,
  KFSR,
  KESR,
  KVSR,
  KCSR,
  KVR,
  MONTH01,
  MONTH02,
  MONTH03,
  MONTH04,
  MONTH05,
  MONTH06,
  MONTH07,
  MONTH08,
  MONTH09,
  MONTH10,
  MONTH11,
  MONTH12,
  SUMMA,
  REGION,
  SUBKESR,
  MEANSTYPE,
  FINSOURCE,
  FINTYPE,
  FACT,
  FACIALACC_CLS,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  BUDGETREF,
  ACCEPTDATE,
  LASTADJUSTMENT,
  ACCEPTED,
  LASTACCEPTED,
  PROMISETYPE,
  ADJUSTMENTREF,
  OLDNUMBER,
  SUMMAPREVIOUSYEAR,
  SUMMAFINPREVIOUSYEAR,
  QUARTER1,
  QUARTER2,
  QUARTER3,
  QUARTER4,
  RECORDINDEX,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  DIRECTIONCLS,
  RVERSION,
  BUHOPERATIONCLS,
  MONTH01DELTA,
  MONTH02DELTA,
  MONTH03DELTA,
  MONTH04DELTA,
  MONTH05DELTA,
  MONTH06DELTA,
  MONTH07DELTA,
  MONTH08DELTA,
  MONTH09DELTA,
  MONTH10DELTA,
  MONTH11DELTA,
  MONTH12DELTA,
  QUARTER1DELTA,
  QUARTER2DELTA,
  QUARTER3DELTA,
  QUARTER4DELTA,
  SUMMADELTA,
  NOTE,
  FINYEAR,
  SUMMAYEAR1,
  SUMMAYEAR2,
  SUMMAYEAR3,
  SUMMAYEAR1DELTA,
  SUMMAYEAR2DELTA,
  SUMMAYEAR3DELTA,
  ASSIGNMENTKIND,
  TRANSFERTCLS,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  EXECUTIONREF,
  INNERPROMISENUM,
  ADJUSTMENTNUMBER,
  PROMISENUMBER,
  SUBSIDYCLS,
  AGREEMENTREF,
  BUDALLOCATIONCLS,
  PAYPROMISECLS,
  PROGINDEX,
  INVESTOBJECT,
  SUMMAYEAR4,
  SUMMAOTHERYEARS,
  SUMMAYEAR4DELTA,
  SUMMAOTHERYEARSDELTA,
  CONTRACTCOSTSCLS,
  TARGETCLS)
AS
  SELECT
    ID,
    ANUMBER,
    PARENTNUMBER,
    KFSR,
    KESR,
    KVSR,
    KCSR,
    KVR,
    MONTH01,
    MONTH02,
    MONTH03,
    MONTH04,
    MONTH05,
    MONTH06,
    MONTH07,
    MONTH08,
    MONTH09,
    MONTH10,
    MONTH11,
    MONTH12,
    SUMMA,
    REGION,
    SUBKESR,
    MEANSTYPE,
    FINSOURCE,
    FINTYPE,
    FACT,
    FACIALACC_CLS,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    ACCEPTDATE,
    LASTADJUSTMENT,
    ACCEPTED,
    LASTACCEPTED,
    PROMISETYPE,
    ADJUSTMENTREF,
    OLDNUMBER,
    SUMMAPREVIOUSYEAR,
    SUMMAFINPREVIOUSYEAR,
    QUARTER1,
    QUARTER2,
    QUARTER3,
    QUARTER4,
    RECORDINDEX,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DIRECTIONCLS,
    RVERSION,
    BUHOPERATIONCLS,
    MONTH01DELTA,
    MONTH02DELTA,
    MONTH03DELTA,
    MONTH04DELTA,
    MONTH05DELTA,
    MONTH06DELTA,
    MONTH07DELTA,
    MONTH08DELTA,
    MONTH09DELTA,
    MONTH10DELTA,
    MONTH11DELTA,
    MONTH12DELTA,
    QUARTER1DELTA,
    QUARTER2DELTA,
    QUARTER3DELTA,
    QUARTER4DELTA,
    SUMMADELTA,
    NOTE,
    FINYEAR,
    SUMMAYEAR1,
    SUMMAYEAR2,
    SUMMAYEAR3,
    SUMMAYEAR1DELTA,
    SUMMAYEAR2DELTA,
    SUMMAYEAR3DELTA,
    ASSIGNMENTKIND,
    TRANSFERTCLS,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    EXECUTIONREF,
    INNERPROMISENUM,
    ADJUSTMENTNUMBER,
    PROMISENUMBER,
    SUBSIDYCLS,
    AGREEMENTREF,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    PROGINDEX,
    INVESTOBJECT,
    SUMMAYEAR4,
    SUMMAOTHERYEARS,
    SUMMAYEAR4DELTA,
    SUMMAOTHERYEARSDELTA,
    CONTRACTCOSTSCLS,
    TARGETCLS
  FROM TB_PaymentSchedule
/

CREATE OR REPLACE TRIGGER TR_PAYMENTSCHEDULE_ID
  INSTEAD OF DELETE
  ON PAYMENTSCHEDULE
  FOR EACH ROW
DECLARE
  SummInMonths$ NUMBER(15,2);
  cnt1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_PAYMENTSCHEDULE_BD)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*   6.0*/
  select count(ID) into cnt1$ from PaymentSchedule where (AdjustmentRef = :old.ID) ;
  if (cnt1$ > 0) then
    RaiseException('EX_Agr_CantDelAdjustmented');
  END IF;

  select count(ID)
  into cnt1$   from FacialFinDetail
  where (SourceBudgetPromise = :old.InnerPromiseNum and SourcePromise=:old.ANumber)
  or (DestBudgetPromise = :old.InnerPromiseNum and DestPromise=:old.ANumber)
  ;
  if (cnt1$ > 0) then
    RaiseException('ex_CantDeleteAgreement');
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_PAYMENTSCHEDULE
  WHERE Id = :old.id;

-- - - - - - - - - - - - -
-- AD_10 (TR_PAYMENTSCHEDULE_AD_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/
  /*   LastAdjustment     */
  if ((:old.AdjustmentNumber > 0) and (:old.LastAdjustment = 1)) then
    update PaymentSchedule set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;
  /*   LastAccepted     */    
  if ((:old.AdjustmentNumber > 0) and (:old.LastAccepted = 1)) then
    update PaymentSchedule set
    LastAccepted = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);        
  END IF;

-- - - - - - - - - - - - -
-- AD_500 (TR_PAYMENTSCHEDULE_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  SummInMonths$ := :old.Month01+:old.Month02+:old.Month03+:old.Month04+:old.Month05+
  :old.Month06+:old.Month07+:old.Month08+:old.Month09+:old.Month10+:old.Month11+:old.Month12;
  if ((SummInMonths$  < 0.005) and (SummInMonths$  > -0.005)) then
    SummInMonths$ := :old.SummaYear1;
  END IF;
  insert into DelRecIndexes(TableID, RecordID, DeleteDate, ProgIndex, SUMMA) values (113, :old.ID, SYSDATE, :old.ProgIndex, SummInMonths$);

END;
/

CREATE OR REPLACE TRIGGER TR_PAYMENTSCHEDULE_II
  INSTEAD OF INSERT
  ON PAYMENTSCHEDULE
  FOR EACH ROW
DECLARE
  new$ID PAYMENTSCHEDULE.ID%TYPE := :NEW.ID;
  new$ANUMBER PAYMENTSCHEDULE.ANUMBER%TYPE := :NEW.ANUMBER;
  new$PARENTNUMBER PAYMENTSCHEDULE.PARENTNUMBER%TYPE := :NEW.PARENTNUMBER;
  new$KFSR PAYMENTSCHEDULE.KFSR%TYPE := :NEW.KFSR;
  new$KESR PAYMENTSCHEDULE.KESR%TYPE := :NEW.KESR;
  new$KVSR PAYMENTSCHEDULE.KVSR%TYPE := :NEW.KVSR;
  new$KCSR PAYMENTSCHEDULE.KCSR%TYPE := :NEW.KCSR;
  new$KVR PAYMENTSCHEDULE.KVR%TYPE := :NEW.KVR;
  new$MONTH01 PAYMENTSCHEDULE.MONTH01%TYPE := :NEW.MONTH01;
  new$MONTH02 PAYMENTSCHEDULE.MONTH02%TYPE := :NEW.MONTH02;
  new$MONTH03 PAYMENTSCHEDULE.MONTH03%TYPE := :NEW.MONTH03;
  new$MONTH04 PAYMENTSCHEDULE.MONTH04%TYPE := :NEW.MONTH04;
  new$MONTH05 PAYMENTSCHEDULE.MONTH05%TYPE := :NEW.MONTH05;
  new$MONTH06 PAYMENTSCHEDULE.MONTH06%TYPE := :NEW.MONTH06;
  new$MONTH07 PAYMENTSCHEDULE.MONTH07%TYPE := :NEW.MONTH07;
  new$MONTH08 PAYMENTSCHEDULE.MONTH08%TYPE := :NEW.MONTH08;
  new$MONTH09 PAYMENTSCHEDULE.MONTH09%TYPE := :NEW.MONTH09;
  new$MONTH10 PAYMENTSCHEDULE.MONTH10%TYPE := :NEW.MONTH10;
  new$MONTH11 PAYMENTSCHEDULE.MONTH11%TYPE := :NEW.MONTH11;
  new$MONTH12 PAYMENTSCHEDULE.MONTH12%TYPE := :NEW.MONTH12;
  new$SUMMA PAYMENTSCHEDULE.SUMMA%TYPE := :NEW.SUMMA;
  new$REGION PAYMENTSCHEDULE.REGION%TYPE := :NEW.REGION;
  new$SUBKESR PAYMENTSCHEDULE.SUBKESR%TYPE := :NEW.SUBKESR;
  new$MEANSTYPE PAYMENTSCHEDULE.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FINSOURCE PAYMENTSCHEDULE.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE PAYMENTSCHEDULE.FINTYPE%TYPE := :NEW.FINTYPE;
  new$FACT PAYMENTSCHEDULE.FACT%TYPE := :NEW.FACT;
  new$FACIALACC_CLS PAYMENTSCHEDULE.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$CREATERUSER PAYMENTSCHEDULE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYMENTSCHEDULE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PAYMENTSCHEDULE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PAYMENTSCHEDULE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF PAYMENTSCHEDULE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$ACCEPTDATE PAYMENTSCHEDULE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$LASTADJUSTMENT PAYMENTSCHEDULE.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$ACCEPTED PAYMENTSCHEDULE.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED PAYMENTSCHEDULE.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$PROMISETYPE PAYMENTSCHEDULE.PROMISETYPE%TYPE := :NEW.PROMISETYPE;
  new$ADJUSTMENTREF PAYMENTSCHEDULE.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$OLDNUMBER PAYMENTSCHEDULE.OLDNUMBER%TYPE := :NEW.OLDNUMBER;
  new$SUMMAPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAPREVIOUSYEAR%TYPE := :NEW.SUMMAPREVIOUSYEAR;
  new$SUMMAFINPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAFINPREVIOUSYEAR%TYPE := :NEW.SUMMAFINPREVIOUSYEAR;
  new$QUARTER1 PAYMENTSCHEDULE.QUARTER1%TYPE := :NEW.QUARTER1;
  new$QUARTER2 PAYMENTSCHEDULE.QUARTER2%TYPE := :NEW.QUARTER2;
  new$QUARTER3 PAYMENTSCHEDULE.QUARTER3%TYPE := :NEW.QUARTER3;
  new$QUARTER4 PAYMENTSCHEDULE.QUARTER4%TYPE := :NEW.QUARTER4;
  new$RECORDINDEX PAYMENTSCHEDULE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CRYPTOSTATUS PAYMENTSCHEDULE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID PAYMENTSCHEDULE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PAYMENTSCHEDULE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DIRECTIONCLS PAYMENTSCHEDULE.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$RVERSION PAYMENTSCHEDULE.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYMENTSCHEDULE.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MONTH01DELTA PAYMENTSCHEDULE.MONTH01DELTA%TYPE := :NEW.MONTH01DELTA;
  new$MONTH02DELTA PAYMENTSCHEDULE.MONTH02DELTA%TYPE := :NEW.MONTH02DELTA;
  new$MONTH03DELTA PAYMENTSCHEDULE.MONTH03DELTA%TYPE := :NEW.MONTH03DELTA;
  new$MONTH04DELTA PAYMENTSCHEDULE.MONTH04DELTA%TYPE := :NEW.MONTH04DELTA;
  new$MONTH05DELTA PAYMENTSCHEDULE.MONTH05DELTA%TYPE := :NEW.MONTH05DELTA;
  new$MONTH06DELTA PAYMENTSCHEDULE.MONTH06DELTA%TYPE := :NEW.MONTH06DELTA;
  new$MONTH07DELTA PAYMENTSCHEDULE.MONTH07DELTA%TYPE := :NEW.MONTH07DELTA;
  new$MONTH08DELTA PAYMENTSCHEDULE.MONTH08DELTA%TYPE := :NEW.MONTH08DELTA;
  new$MONTH09DELTA PAYMENTSCHEDULE.MONTH09DELTA%TYPE := :NEW.MONTH09DELTA;
  new$MONTH10DELTA PAYMENTSCHEDULE.MONTH10DELTA%TYPE := :NEW.MONTH10DELTA;
  new$MONTH11DELTA PAYMENTSCHEDULE.MONTH11DELTA%TYPE := :NEW.MONTH11DELTA;
  new$MONTH12DELTA PAYMENTSCHEDULE.MONTH12DELTA%TYPE := :NEW.MONTH12DELTA;
  new$QUARTER1DELTA PAYMENTSCHEDULE.QUARTER1DELTA%TYPE := :NEW.QUARTER1DELTA;
  new$QUARTER2DELTA PAYMENTSCHEDULE.QUARTER2DELTA%TYPE := :NEW.QUARTER2DELTA;
  new$QUARTER3DELTA PAYMENTSCHEDULE.QUARTER3DELTA%TYPE := :NEW.QUARTER3DELTA;
  new$QUARTER4DELTA PAYMENTSCHEDULE.QUARTER4DELTA%TYPE := :NEW.QUARTER4DELTA;
  new$SUMMADELTA PAYMENTSCHEDULE.SUMMADELTA%TYPE := :NEW.SUMMADELTA;
  new$NOTE PAYMENTSCHEDULE.NOTE%TYPE := :NEW.NOTE;
  new$FINYEAR PAYMENTSCHEDULE.FINYEAR%TYPE := :NEW.FINYEAR;
  new$SUMMAYEAR1 PAYMENTSCHEDULE.SUMMAYEAR1%TYPE := :NEW.SUMMAYEAR1;
  new$SUMMAYEAR2 PAYMENTSCHEDULE.SUMMAYEAR2%TYPE := :NEW.SUMMAYEAR2;
  new$SUMMAYEAR3 PAYMENTSCHEDULE.SUMMAYEAR3%TYPE := :NEW.SUMMAYEAR3;
  new$SUMMAYEAR1DELTA PAYMENTSCHEDULE.SUMMAYEAR1DELTA%TYPE := :NEW.SUMMAYEAR1DELTA;
  new$SUMMAYEAR2DELTA PAYMENTSCHEDULE.SUMMAYEAR2DELTA%TYPE := :NEW.SUMMAYEAR2DELTA;
  new$SUMMAYEAR3DELTA PAYMENTSCHEDULE.SUMMAYEAR3DELTA%TYPE := :NEW.SUMMAYEAR3DELTA;
  new$ASSIGNMENTKIND PAYMENTSCHEDULE.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$TRANSFERTCLS PAYMENTSCHEDULE.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SENDERIDKEY PAYMENTSCHEDULE.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY PAYMENTSCHEDULE.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXECUTIONREF PAYMENTSCHEDULE.EXECUTIONREF%TYPE := :NEW.EXECUTIONREF;
  new$INNERPROMISENUM PAYMENTSCHEDULE.INNERPROMISENUM%TYPE := :NEW.INNERPROMISENUM;
  new$ADJUSTMENTNUMBER PAYMENTSCHEDULE.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$PROMISENUMBER PAYMENTSCHEDULE.PROMISENUMBER%TYPE := :NEW.PROMISENUMBER;
  new$SUBSIDYCLS PAYMENTSCHEDULE.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$AGREEMENTREF PAYMENTSCHEDULE.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$BUDALLOCATIONCLS PAYMENTSCHEDULE.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS PAYMENTSCHEDULE.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$PROGINDEX PAYMENTSCHEDULE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$INVESTOBJECT PAYMENTSCHEDULE.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$SUMMAYEAR4 PAYMENTSCHEDULE.SUMMAYEAR4%TYPE := :NEW.SUMMAYEAR4;
  new$SUMMAOTHERYEARS PAYMENTSCHEDULE.SUMMAOTHERYEARS%TYPE := :NEW.SUMMAOTHERYEARS;
  new$SUMMAYEAR4DELTA PAYMENTSCHEDULE.SUMMAYEAR4DELTA%TYPE := :NEW.SUMMAYEAR4DELTA;
  new$SUMMAOTHERYEARSDELTA PAYMENTSCHEDULE.SUMMAOTHERYEARSDELTA%TYPE := :NEW.SUMMAOTHERYEARSDELTA;
  new$CONTRACTCOSTSCLS PAYMENTSCHEDULE.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS PAYMENTSCHEDULE.TARGETCLS%TYPE := :NEW.TARGETCLS;
--
  M01$ NUMBER;
  M02$ NUMBER;
  M03$ NUMBER;
  M04$ NUMBER;
  M05$ NUMBER;
  M06$ NUMBER;
  M07$ NUMBER;
  M08$ NUMBER;
  M09$ NUMBER;
  M10$ NUMBER;
  M11$ NUMBER;
  M12$ NUMBER;
  Q1$ NUMBER;
  Q2$ NUMBER;
  Q3$ NUMBER;
  Q4$ NUMBER;
  S$ NUMBER;
  S1$ NUMBER;
  S2$ NUMBER;
  S3$ NUMBER;
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  Tmp$ NUMBER(10);
  AdjID$ NUMBER(10);
  AdjDocNum$ NUMBER(10);
  InnerNumber_parent$ NUMBER(10);
  InnerNumber_child$ NUMBER(10);
  S4$ NUMBER;
  SOther$ NUMBER;
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_PAYMENTSCHEDULE_BI)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$Accepted is null) then 
    new$Accepted := 1;
  END IF;
  if (new$PromiseType is null) then 
    new$PromiseType := 0;
  END IF;
  if (new$KFSR is null) then 
    new$KFSR := 0;
  END IF;
  if (new$KESR is null) then 
    new$KESR := 0;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$KCSR is null) then 
    new$KCSR := 0;
  END IF;
  if (new$KVR is null) then 
    new$KVR := 0;
  END IF;
  if (new$SubKESR is null) then 
    new$SubKESR := 0;
  END IF;
  if (new$AssignmentKind is null) then 
    new$AssignmentKind := 0;
  END IF;
  if (new$DirectionCls is null) then 
    new$DirectionCls := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Region is null) then 
    new$Region := 0;
  END IF;
  if (new$MeansType is null) then 
    new$MeansType := 0;
  END IF;
  if (new$FinSource is null) then 
    new$FinSource := 0;
  END IF;
  if (new$FinType is null) then 
    new$FinType := 0;
  END IF;
  if (new$Fact is null) then 
    new$Fact := 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$Month01 is null) then 
    new$Month01 := 0;
  END IF;
  if (new$Month02 is null) then 
    new$Month02 := 0;
  END IF;
  if (new$Month03 is null) then 
    new$Month03 := 0;
  END IF;
  if (new$Month04 is null) then 
    new$Month04 := 0;
  END IF;
  if (new$Month05 is null) then 
    new$Month05 := 0;
  END IF;
  if (new$Month06 is null) then 
    new$Month06 := 0;
  END IF;
  if (new$Month07 is null) then 
    new$Month07 := 0;
  END IF;
  if (new$Month08 is null) then 
    new$Month08 := 0;
  END IF;
  if (new$Month09 is null) then 
    new$Month09 := 0;
  END IF;
  if (new$Month10 is null) then 
    new$Month10 := 0;
  END IF;
  if (new$Month11 is null) then 
    new$Month11 := 0;
  END IF;
  if (new$Month12 is null) then 
    new$Month12 := 0;
  END IF;
  if (new$Quarter1 is null) then 
    new$Quarter1 := 0;
  END IF;
  if (new$Quarter2 is null) then 
    new$Quarter2 := 0;
  END IF;
  if (new$Quarter3 is null) then 
    new$Quarter3 := 0;
  END IF;
  if (new$Quarter4 is null) then 
    new$Quarter4 := 0;
  END IF;
  if (new$Summa is null) then 
    new$Summa := 0;
  END IF;
  if (new$Month01Delta is null) then 
    new$Month01Delta := 0;
  END IF;
  if (new$Month02Delta is null) then 
    new$Month02Delta := 0;
  END IF;
  if (new$Month03Delta is null) then 
    new$Month03Delta := 0;
  END IF;
  if (new$Month04Delta is null) then 
    new$Month04Delta := 0;
  END IF;
  if (new$Month05Delta is null) then 
    new$Month05Delta := 0;
  END IF;
  if (new$Month06Delta is null) then 
    new$Month06Delta := 0;
  END IF;
  if (new$Month07Delta is null) then 
    new$Month07Delta := 0;
  END IF;
  if (new$Month08Delta is null) then 
    new$Month08Delta := 0;
  END IF;
  if (new$Month09Delta is null) then 
    new$Month09Delta := 0;
  END IF;
  if (new$Month10Delta is null) then 
    new$Month10Delta := 0;
  END IF;
  if (new$Month11Delta is null) then 
    new$Month11Delta := 0;
  END IF;
  if (new$Month12Delta is null) then 
    new$Month12Delta := 0;
  END IF;
  if (new$Quarter1Delta is null) then 
    new$Quarter1Delta := 0;
  END IF;
  if (new$Quarter2Delta is null) then 
    new$Quarter2Delta := 0;
  END IF;
  if (new$Quarter3Delta is null) then 
    new$Quarter3Delta := 0;
  END IF;
  if (new$Quarter4Delta is null) then 
    new$Quarter4Delta := 0;
  END IF;
  if (new$SummaDelta is null) then 
    new$SummaDelta := 0;
  END IF;
  if (new$SummaPreviousYear is null) then 
    new$SummaPreviousYear := 0;
  END IF;
  if (new$SummaFinPreviousYear is null) then 
    new$SummaFinPreviousYear := 0;
  END IF;
  if (new$SummaYear1 is null) then 
    new$SummaYear1 := 0;
  END IF;
  if (new$SummaYear2 is null) then 
    new$SummaYear2 := 0;
  END IF;
  if (new$SummaYear3 is null) then 
    new$SummaYear3 := 0;
  END IF;
  if (new$SummaYear4 is null) then 
    new$SummaYear4 := 0;
  END IF;
  if (new$SummaOtherYears is null) then 
    new$SummaOtherYears := 0;
  END IF;
  if (new$SummaYear1Delta is null) then 
    new$SummaYear1Delta := 0;
  END IF;
  if (new$SummaYear2Delta is null) then 
    new$SummaYear2Delta := 0;
  END IF;
  if (new$SummaYear3Delta is null) then 
    new$SummaYear3Delta := 0;
  END IF;
  if (new$SummaYear4Delta is null) then 
    new$SummaYear4Delta := 0;
  END IF;
  if (new$SummaOtherYearsDelta is null) then 
    new$SummaOtherYearsDelta := 0;
  END IF;
  /*   ,        */
  if (new$ProgIndex = 304 and new$RecordIndex is not null) then
    SELECT COUNT(*) INTO CNT$1
    from AgreementSteps s where (s.Id = new$RecordIndex and s.RecordIndex = new$AgreementRef) AND (ROWNUM = 1);
    if (not (CNT$1<> 0)) then
      RaiseException('Ex_WrongStep');
    END IF;
  END IF;
  /*       */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    if (new$ProgIndex in (304,314,317,318)) then
      BEGIN
        select a.BudgetRef       into new$BudgetRef from Agreements a
        where a.ID = new$AgreementRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    else 
      if (new$ProgIndex = 308) then
        BEGIN
          select e.BudgetRef
          into new$BudgetRef       from ExecutionDocumentsCaption e
          where e.ID = new$ExecutionRef
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
      END IF;
    END IF;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$ANumber is not null) then
    SELECT COUNT(                    id
    ) INTO CNT$2
    from
    PaymentSchedule ps
    where
    (                    (ps.ANumber = new$ANumber)
    and
    (ps.BudgetRef = new$BudgetRef)) AND (ROWNUM = 1);
    if ((CNT$2<> 0)) then
      RaiseException('ex_Promise_NumUQ');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_1 (TR_PAYMENTSCHEDULE_BI_1)
-- Create 05.03.2004
-- Last update 29.12.2007
-- - - - - - - - - - - - -

/*   1.0*/
    if (new$Quarter1 = 0) then new$Quarter1 := new$Month01 + new$Month02 + new$Month03; end if;
    if (new$Quarter2 = 0) then new$Quarter2 := new$Month04 + new$Month05 + new$Month06; end if;
    if (new$Quarter3 = 0) then new$Quarter3 := new$Month07 + new$Month08 + new$Month09; end if;
    if (new$Quarter4 = 0) then new$Quarter4 := new$Month10 + new$Month11 + new$Month12; end if;
    new$SummaYear1 := new$Quarter1 + new$Quarter2 + new$Quarter3 + new$Quarter4;

-- - - - - - - - - - - - -
-- BI_10 (TR_PAYMENTSCHEDULE_BI_10)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   5.0*/
     
  /*    .*/
  if (new$InnerPromiseNum is null) then
    RaiseException('EX_BP_InnerNumsIsNull');
  END IF;
      
  /*    */
  select max(AdjustmentNumber)
  into Tmp$         from PaymentSchedule 
  where (InnerPromiseNum = new$InnerPromiseNum)
  ;
  /*      ,   0*/
  if (Tmp$ is null) then
    new$AdjustmentNumber := 0;
        
  else
    new$AdjustmentNumber := Tmp$ + 1;
  END IF;
      
  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;
        
  else
    new$LastAdjustment := 1;
  END IF;
      
  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then 
    new$LastAccepted := 1;
        
  else
    new$LastAccepted := 0;
  END IF;
  /*    */
  if (new$AdjustmentNumber > 0) then
    /*      -    */
    select count(ID), max(ID), max(ANumber)
    into Tmp$, AdjID$, AdjDocNum$             from PaymentSchedule
    where (InnerPromiseNum = new$InnerPromiseNum) and (LastAccepted = 1)
    ;
    /*   ,  */
    if (Tmp$ <> 1) then 
      RaiseException('EX_BP_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID) 
    into Tmp$             from PaymentSchedule
    where (InnerPromiseNum = new$InnerPromiseNum) and (AcceptDate is null)
    ;
    if (Tmp$ > 0) then 
      RaiseException('EX_BP_AdjustDuplicate');
    END IF;
    /* ,    ,    */        
    new$AdjustmentRef := AdjID$;
    new$ParentNumber := AdjDocNum$;
    /*   - ,  ,       */
    if (new$ProgIndex in (304, 314)) then
      BEGIN
        /*     */        
        select a.InnerNumber
        into InnerNumber_child$             from Agreements a
        where a.ID = new$AgreementRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN
        /*       */
        select a.InnerNumber
        into InnerNumber_parent$             from PaymentSchedule ps
        left join Agreements a on (a.Id = ps.AgreementRef)
        where (ps.Id = new$AdjustmentRef)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*      */
      if (InnerNumber_parent$ <> InnerNumber_child$) then
        RaiseException('EX_PROMISE_ADJ_INCORRECT');        
      END IF;
    else 
      if (new$ProgIndex = 308) then
        BEGIN
          /*     */        
          select edc.InnerNumber
          into InnerNumber_child$             from ExecutionDocumentsCaption edc
          where edc.ID = new$ExecutionRef
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        BEGIN
          /*       */
          select edc.InnerNumber
          into InnerNumber_parent$             from PaymentSchedule ps
          left join ExecutionDocumentsCaption edc on (edc.id=ps.ExecutionRef)
          where (ps.Id = new$AdjustmentRef)
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        /*      */
        if (InnerNumber_parent$ <> InnerNumber_child$) then
          RaiseException('EX_PROMISE_ADJ_INCORRECT');        
        END IF;
      END IF;    
    END IF;
  else /*     */
    /*       (    )*/        
    new$AdjustmentRef := null;
    new$ParentNumber := null;
        
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_PAYMENTSCHEDULE_BI_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*           */
  if (new$AdjustmentNumber > 0) then
    BEGIN
      select 
      Month01, Month02, Month03, Month04, Month05, Month06,
      Month07, Month08, Month09, Month10, Month11, Month12,
      Quarter1, Quarter2, Quarter3, Quarter4, Summa, 
      SummaYear1, SummaYear2, SummaYear3, SummaYear4, SummaOtherYears
      into
      M01$, M02$, M03$, M04$, M05$, M06$, M07$, M08$, M09$, M10$, M11$, M12$, 
      Q1$, Q2$, Q3$, Q4$, S$, S1$, S2$, S3$, S4$, SOther$         from 
      PaymentSchedule
      where
      ID = new$AdjustmentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
          
    new$Month01Delta := new$Month01 - M01$;
    new$Month02Delta := new$Month02 - M02$;
    new$Month03Delta := new$Month03 - M03$;
    new$Month04Delta := new$Month04 - M04$;
    new$Month05Delta := new$Month05 - M05$;
    new$Month06Delta := new$Month06 - M06$;
    new$Month07Delta := new$Month07 - M07$;
    new$Month08Delta := new$Month08 - M08$;
    new$Month09Delta := new$Month09 - M09$;
    new$Month10Delta := new$Month10 - M10$;
    new$Month11Delta := new$Month11 - M11$;
    new$Month12Delta := new$Month12 - M12$;
    new$Quarter1Delta := new$Quarter1 - Q1$;
    new$Quarter2Delta := new$Quarter2 - Q2$;
    new$Quarter3Delta := new$Quarter3 - Q3$;
    new$Quarter4Delta := new$Quarter4 - Q4$;
    new$SummaDelta := new$Summa - S$;
    new$SummaYear1Delta := new$SummaYear1 - S1$;
    new$SummaYear2Delta := new$SummaYear2 - S2$;
    new$SummaYear3Delta := new$SummaYear3 - S3$;
    new$SummaYear4Delta := new$SummaYear4 - S4$;
    new$SummaOtherYearsDelta := new$SummaOtherYears - SOther$;        
        
  else    /*        */  
    new$Month01Delta := new$Month01;
    new$Month02Delta := new$Month02;
    new$Month03Delta := new$Month03;
    new$Month04Delta := new$Month04;
    new$Month05Delta := new$Month05;
    new$Month06Delta := new$Month06;
    new$Month07Delta := new$Month07;
    new$Month08Delta := new$Month08;
    new$Month09Delta := new$Month09;
    new$Month10Delta := new$Month10;
    new$Month11Delta := new$Month11;
    new$Month12Delta := new$Month12;
    new$Quarter1Delta := new$Quarter1;
    new$Quarter2Delta := new$Quarter2;
    new$Quarter3Delta := new$Quarter3;
    new$Quarter4Delta := new$Quarter4;
    new$SummaDelta := new$Summa;
    new$SummaYear1Delta := new$SummaYear1;
    new$SummaYear2Delta := new$SummaYear2;
    new$SummaYear3Delta := new$SummaYear3;
    new$SummaYear4Delta := new$SummaYear4;
    new$SummaOtherYearsDelta := new$SummaOtherYears;        
        
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_PAYMENTSCHEDULE_BI_200)
-- Create 06.08.2010
-- - - - - - - - - - - - -

  /*      */
  if (new$senderId is null) then 
    new$senderIdKey := -1;
  else
    new$senderIdKey := new$senderId;
  end if;

  if (new$SenderRecordID is null)then
    new$SenderRecordIDKey := new$ID;
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  end if;       

-- - - - - - - - - - - - -
-- BI_500 (TR_PAYMENTSCHEDULE_BI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_PAYMENTSCHEDULE (
    ID,
    ANUMBER,
    PARENTNUMBER,
    KFSR,
    KESR,
    KVSR,
    KCSR,
    KVR,
    MONTH01,
    MONTH02,
    MONTH03,
    MONTH04,
    MONTH05,
    MONTH06,
    MONTH07,
    MONTH08,
    MONTH09,
    MONTH10,
    MONTH11,
    MONTH12,
    SUMMA,
    REGION,
    SUBKESR,
    MEANSTYPE,
    FINSOURCE,
    FINTYPE,
    FACT,
    FACIALACC_CLS,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    ACCEPTDATE,
    LASTADJUSTMENT,
    ACCEPTED,
    LASTACCEPTED,
    PROMISETYPE,
    ADJUSTMENTREF,
    OLDNUMBER,
    SUMMAPREVIOUSYEAR,
    SUMMAFINPREVIOUSYEAR,
    QUARTER1,
    QUARTER2,
    QUARTER3,
    QUARTER4,
    RECORDINDEX,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DIRECTIONCLS,
    RVERSION,
    BUHOPERATIONCLS,
    MONTH01DELTA,
    MONTH02DELTA,
    MONTH03DELTA,
    MONTH04DELTA,
    MONTH05DELTA,
    MONTH06DELTA,
    MONTH07DELTA,
    MONTH08DELTA,
    MONTH09DELTA,
    MONTH10DELTA,
    MONTH11DELTA,
    MONTH12DELTA,
    QUARTER1DELTA,
    QUARTER2DELTA,
    QUARTER3DELTA,
    QUARTER4DELTA,
    SUMMADELTA,
    NOTE,
    FINYEAR,
    SUMMAYEAR1,
    SUMMAYEAR2,
    SUMMAYEAR3,
    SUMMAYEAR1DELTA,
    SUMMAYEAR2DELTA,
    SUMMAYEAR3DELTA,
    ASSIGNMENTKIND,
    TRANSFERTCLS,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    EXECUTIONREF,
    INNERPROMISENUM,
    ADJUSTMENTNUMBER,
    PROMISENUMBER,
    SUBSIDYCLS,
    AGREEMENTREF,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    PROGINDEX,
    INVESTOBJECT,
    SUMMAYEAR4,
    SUMMAOTHERYEARS,
    SUMMAYEAR4DELTA,
    SUMMAOTHERYEARSDELTA,
    CONTRACTCOSTSCLS,
    TARGETCLS
  ) VALUES (
    new$ID,
    new$ANUMBER,
    new$PARENTNUMBER,
    new$KFSR,
    new$KESR,
    new$KVSR,
    new$KCSR,
    new$KVR,
    new$MONTH01,
    new$MONTH02,
    new$MONTH03,
    new$MONTH04,
    new$MONTH05,
    new$MONTH06,
    new$MONTH07,
    new$MONTH08,
    new$MONTH09,
    new$MONTH10,
    new$MONTH11,
    new$MONTH12,
    new$SUMMA,
    new$REGION,
    new$SUBKESR,
    new$MEANSTYPE,
    new$FINSOURCE,
    new$FINTYPE,
    new$FACT,
    new$FACIALACC_CLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$ACCEPTDATE,
    new$LASTADJUSTMENT,
    new$ACCEPTED,
    new$LASTACCEPTED,
    new$PROMISETYPE,
    new$ADJUSTMENTREF,
    new$OLDNUMBER,
    new$SUMMAPREVIOUSYEAR,
    new$SUMMAFINPREVIOUSYEAR,
    new$QUARTER1,
    new$QUARTER2,
    new$QUARTER3,
    new$QUARTER4,
    new$RECORDINDEX,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$DIRECTIONCLS,
    new$RVERSION,
    new$BUHOPERATIONCLS,
    new$MONTH01DELTA,
    new$MONTH02DELTA,
    new$MONTH03DELTA,
    new$MONTH04DELTA,
    new$MONTH05DELTA,
    new$MONTH06DELTA,
    new$MONTH07DELTA,
    new$MONTH08DELTA,
    new$MONTH09DELTA,
    new$MONTH10DELTA,
    new$MONTH11DELTA,
    new$MONTH12DELTA,
    new$QUARTER1DELTA,
    new$QUARTER2DELTA,
    new$QUARTER3DELTA,
    new$QUARTER4DELTA,
    new$SUMMADELTA,
    new$NOTE,
    new$FINYEAR,
    new$SUMMAYEAR1,
    new$SUMMAYEAR2,
    new$SUMMAYEAR3,
    new$SUMMAYEAR1DELTA,
    new$SUMMAYEAR2DELTA,
    new$SUMMAYEAR3DELTA,
    new$ASSIGNMENTKIND,
    new$TRANSFERTCLS,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$EXECUTIONREF,
    new$INNERPROMISENUM,
    new$ADJUSTMENTNUMBER,
    new$PROMISENUMBER,
    new$SUBSIDYCLS,
    new$AGREEMENTREF,
    new$BUDALLOCATIONCLS,
    new$PAYPROMISECLS,
    new$PROGINDEX,
    new$INVESTOBJECT,
    new$SUMMAYEAR4,
    new$SUMMAOTHERYEARS,
    new$SUMMAYEAR4DELTA,
    new$SUMMAOTHERYEARSDELTA,
    new$CONTRACTCOSTSCLS,
    new$TARGETCLS);

-- - - - - - - - - - - - -
-- AI_10 (TR_PAYMENTSCHEDULE_AI_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/
  /*      */
  if ((new$AdjustmentNumber > 0) and (new$LastAdjustment = 1)) then
    update PaymentSchedule set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);            
    if (new$LastAccepted = 1) then
      update PaymentSchedule set
      LastAccepted = 0,
      RVersion = -1
      where (ID = new$AdjustmentRef);
        
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_PAYMENTSCHEDULE_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 113) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_PAYMENTSCHEDULE_IU
  INSTEAD OF UPDATE
  ON PAYMENTSCHEDULE
  FOR EACH ROW
DECLARE
  new$ID PAYMENTSCHEDULE.ID%TYPE := :NEW.ID;
  new$ANUMBER PAYMENTSCHEDULE.ANUMBER%TYPE := :NEW.ANUMBER;
  new$PARENTNUMBER PAYMENTSCHEDULE.PARENTNUMBER%TYPE := :NEW.PARENTNUMBER;
  new$KFSR PAYMENTSCHEDULE.KFSR%TYPE := :NEW.KFSR;
  new$KESR PAYMENTSCHEDULE.KESR%TYPE := :NEW.KESR;
  new$KVSR PAYMENTSCHEDULE.KVSR%TYPE := :NEW.KVSR;
  new$KCSR PAYMENTSCHEDULE.KCSR%TYPE := :NEW.KCSR;
  new$KVR PAYMENTSCHEDULE.KVR%TYPE := :NEW.KVR;
  new$MONTH01 PAYMENTSCHEDULE.MONTH01%TYPE := :NEW.MONTH01;
  new$MONTH02 PAYMENTSCHEDULE.MONTH02%TYPE := :NEW.MONTH02;
  new$MONTH03 PAYMENTSCHEDULE.MONTH03%TYPE := :NEW.MONTH03;
  new$MONTH04 PAYMENTSCHEDULE.MONTH04%TYPE := :NEW.MONTH04;
  new$MONTH05 PAYMENTSCHEDULE.MONTH05%TYPE := :NEW.MONTH05;
  new$MONTH06 PAYMENTSCHEDULE.MONTH06%TYPE := :NEW.MONTH06;
  new$MONTH07 PAYMENTSCHEDULE.MONTH07%TYPE := :NEW.MONTH07;
  new$MONTH08 PAYMENTSCHEDULE.MONTH08%TYPE := :NEW.MONTH08;
  new$MONTH09 PAYMENTSCHEDULE.MONTH09%TYPE := :NEW.MONTH09;
  new$MONTH10 PAYMENTSCHEDULE.MONTH10%TYPE := :NEW.MONTH10;
  new$MONTH11 PAYMENTSCHEDULE.MONTH11%TYPE := :NEW.MONTH11;
  new$MONTH12 PAYMENTSCHEDULE.MONTH12%TYPE := :NEW.MONTH12;
  new$SUMMA PAYMENTSCHEDULE.SUMMA%TYPE := :NEW.SUMMA;
  new$REGION PAYMENTSCHEDULE.REGION%TYPE := :NEW.REGION;
  new$SUBKESR PAYMENTSCHEDULE.SUBKESR%TYPE := :NEW.SUBKESR;
  new$MEANSTYPE PAYMENTSCHEDULE.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FINSOURCE PAYMENTSCHEDULE.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE PAYMENTSCHEDULE.FINTYPE%TYPE := :NEW.FINTYPE;
  new$FACT PAYMENTSCHEDULE.FACT%TYPE := :NEW.FACT;
  new$FACIALACC_CLS PAYMENTSCHEDULE.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$CREATERUSER PAYMENTSCHEDULE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYMENTSCHEDULE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PAYMENTSCHEDULE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PAYMENTSCHEDULE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF PAYMENTSCHEDULE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$ACCEPTDATE PAYMENTSCHEDULE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$LASTADJUSTMENT PAYMENTSCHEDULE.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$ACCEPTED PAYMENTSCHEDULE.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED PAYMENTSCHEDULE.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$PROMISETYPE PAYMENTSCHEDULE.PROMISETYPE%TYPE := :NEW.PROMISETYPE;
  new$ADJUSTMENTREF PAYMENTSCHEDULE.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$OLDNUMBER PAYMENTSCHEDULE.OLDNUMBER%TYPE := :NEW.OLDNUMBER;
  new$SUMMAPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAPREVIOUSYEAR%TYPE := :NEW.SUMMAPREVIOUSYEAR;
  new$SUMMAFINPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAFINPREVIOUSYEAR%TYPE := :NEW.SUMMAFINPREVIOUSYEAR;
  new$QUARTER1 PAYMENTSCHEDULE.QUARTER1%TYPE := :NEW.QUARTER1;
  new$QUARTER2 PAYMENTSCHEDULE.QUARTER2%TYPE := :NEW.QUARTER2;
  new$QUARTER3 PAYMENTSCHEDULE.QUARTER3%TYPE := :NEW.QUARTER3;
  new$QUARTER4 PAYMENTSCHEDULE.QUARTER4%TYPE := :NEW.QUARTER4;
  new$RECORDINDEX PAYMENTSCHEDULE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CRYPTOSTATUS PAYMENTSCHEDULE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID PAYMENTSCHEDULE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PAYMENTSCHEDULE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DIRECTIONCLS PAYMENTSCHEDULE.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$RVERSION PAYMENTSCHEDULE.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYMENTSCHEDULE.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MONTH01DELTA PAYMENTSCHEDULE.MONTH01DELTA%TYPE := :NEW.MONTH01DELTA;
  new$MONTH02DELTA PAYMENTSCHEDULE.MONTH02DELTA%TYPE := :NEW.MONTH02DELTA;
  new$MONTH03DELTA PAYMENTSCHEDULE.MONTH03DELTA%TYPE := :NEW.MONTH03DELTA;
  new$MONTH04DELTA PAYMENTSCHEDULE.MONTH04DELTA%TYPE := :NEW.MONTH04DELTA;
  new$MONTH05DELTA PAYMENTSCHEDULE.MONTH05DELTA%TYPE := :NEW.MONTH05DELTA;
  new$MONTH06DELTA PAYMENTSCHEDULE.MONTH06DELTA%TYPE := :NEW.MONTH06DELTA;
  new$MONTH07DELTA PAYMENTSCHEDULE.MONTH07DELTA%TYPE := :NEW.MONTH07DELTA;
  new$MONTH08DELTA PAYMENTSCHEDULE.MONTH08DELTA%TYPE := :NEW.MONTH08DELTA;
  new$MONTH09DELTA PAYMENTSCHEDULE.MONTH09DELTA%TYPE := :NEW.MONTH09DELTA;
  new$MONTH10DELTA PAYMENTSCHEDULE.MONTH10DELTA%TYPE := :NEW.MONTH10DELTA;
  new$MONTH11DELTA PAYMENTSCHEDULE.MONTH11DELTA%TYPE := :NEW.MONTH11DELTA;
  new$MONTH12DELTA PAYMENTSCHEDULE.MONTH12DELTA%TYPE := :NEW.MONTH12DELTA;
  new$QUARTER1DELTA PAYMENTSCHEDULE.QUARTER1DELTA%TYPE := :NEW.QUARTER1DELTA;
  new$QUARTER2DELTA PAYMENTSCHEDULE.QUARTER2DELTA%TYPE := :NEW.QUARTER2DELTA;
  new$QUARTER3DELTA PAYMENTSCHEDULE.QUARTER3DELTA%TYPE := :NEW.QUARTER3DELTA;
  new$QUARTER4DELTA PAYMENTSCHEDULE.QUARTER4DELTA%TYPE := :NEW.QUARTER4DELTA;
  new$SUMMADELTA PAYMENTSCHEDULE.SUMMADELTA%TYPE := :NEW.SUMMADELTA;
  new$NOTE PAYMENTSCHEDULE.NOTE%TYPE := :NEW.NOTE;
  new$FINYEAR PAYMENTSCHEDULE.FINYEAR%TYPE := :NEW.FINYEAR;
  new$SUMMAYEAR1 PAYMENTSCHEDULE.SUMMAYEAR1%TYPE := :NEW.SUMMAYEAR1;
  new$SUMMAYEAR2 PAYMENTSCHEDULE.SUMMAYEAR2%TYPE := :NEW.SUMMAYEAR2;
  new$SUMMAYEAR3 PAYMENTSCHEDULE.SUMMAYEAR3%TYPE := :NEW.SUMMAYEAR3;
  new$SUMMAYEAR1DELTA PAYMENTSCHEDULE.SUMMAYEAR1DELTA%TYPE := :NEW.SUMMAYEAR1DELTA;
  new$SUMMAYEAR2DELTA PAYMENTSCHEDULE.SUMMAYEAR2DELTA%TYPE := :NEW.SUMMAYEAR2DELTA;
  new$SUMMAYEAR3DELTA PAYMENTSCHEDULE.SUMMAYEAR3DELTA%TYPE := :NEW.SUMMAYEAR3DELTA;
  new$ASSIGNMENTKIND PAYMENTSCHEDULE.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$TRANSFERTCLS PAYMENTSCHEDULE.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SENDERIDKEY PAYMENTSCHEDULE.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY PAYMENTSCHEDULE.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXECUTIONREF PAYMENTSCHEDULE.EXECUTIONREF%TYPE := :NEW.EXECUTIONREF;
  new$INNERPROMISENUM PAYMENTSCHEDULE.INNERPROMISENUM%TYPE := :NEW.INNERPROMISENUM;
  new$ADJUSTMENTNUMBER PAYMENTSCHEDULE.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$PROMISENUMBER PAYMENTSCHEDULE.PROMISENUMBER%TYPE := :NEW.PROMISENUMBER;
  new$SUBSIDYCLS PAYMENTSCHEDULE.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$AGREEMENTREF PAYMENTSCHEDULE.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$BUDALLOCATIONCLS PAYMENTSCHEDULE.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS PAYMENTSCHEDULE.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$PROGINDEX PAYMENTSCHEDULE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$INVESTOBJECT PAYMENTSCHEDULE.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$SUMMAYEAR4 PAYMENTSCHEDULE.SUMMAYEAR4%TYPE := :NEW.SUMMAYEAR4;
  new$SUMMAOTHERYEARS PAYMENTSCHEDULE.SUMMAOTHERYEARS%TYPE := :NEW.SUMMAOTHERYEARS;
  new$SUMMAYEAR4DELTA PAYMENTSCHEDULE.SUMMAYEAR4DELTA%TYPE := :NEW.SUMMAYEAR4DELTA;
  new$SUMMAOTHERYEARSDELTA PAYMENTSCHEDULE.SUMMAOTHERYEARSDELTA%TYPE := :NEW.SUMMAOTHERYEARSDELTA;
  new$CONTRACTCOSTSCLS PAYMENTSCHEDULE.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS PAYMENTSCHEDULE.TARGETCLS%TYPE := :NEW.TARGETCLS;
--
  M01$ NUMBER;
  M02$ NUMBER;
  M03$ NUMBER;
  M04$ NUMBER;
  M05$ NUMBER;
  M06$ NUMBER;
  M07$ NUMBER;
  M08$ NUMBER;
  M09$ NUMBER;
  M10$ NUMBER;
  M11$ NUMBER;
  M12$ NUMBER;
  Q1$ NUMBER;
  Q2$ NUMBER;
  Q3$ NUMBER;
  Q4$ NUMBER;
  S$ NUMBER;
  S1$ NUMBER;
  S2$ NUMBER;
  S3$ NUMBER;
  MaxNumber1$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  S4$ NUMBER;
  SOther$ NUMBER;
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_PAYMENTSCHEDULE_BU)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*   2.4*/
  /*    -*/
  if (new$Accepted is null) then 
    new$Accepted := 1;
  END IF;
  if (new$PromiseType is null) then 
    new$PromiseType := 0;
  END IF;
  if (new$KFSR is null) then 
    new$KFSR := 0;
  END IF;
  if (new$KESR is null) then 
    new$KESR := 0;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$KCSR is null) then 
    new$KCSR := 0;
  END IF;
  if (new$KVR is null) then 
    new$KVR := 0;
  END IF;
  if (new$SubKESR is null) then 
    new$SubKESR := 0;
  END IF;
  if (new$AssignmentKind is null) then 
    new$AssignmentKind := 0;
  END IF;
   
  if (new$DirectionCls is null) then 
    new$DirectionCls := 0;
  END IF;
   
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Region is null) then 
    new$Region := 0;
  END IF;
  if (new$MeansType is null) then 
    new$MeansType := 0;
  END IF;
  if (new$FinSource is null) then 
    new$FinSource := 0;
  END IF;
  if (new$FinType is null) then 
    new$FinType := 0;
  END IF;
  if (new$Fact is null) then 
    new$Fact := 0;
  END IF;
  if (new$BuhOperationCLS is null) then 
    GetIntConst(60, 15,new$BuhOperationCLS); 
  END IF;
  if (new$Month01 is null) then 
    new$Month01 := 0;
  END IF;
  if (new$Month02 is null) then 
    new$Month02 := 0;
  END IF;
  if (new$Month03 is null) then 
    new$Month03 := 0;
  END IF;
  if (new$Month04 is null) then 
    new$Month04 := 0;
  END IF;
  if (new$Month05 is null) then 
    new$Month05 := 0;
  END IF;
  if (new$Month06 is null) then 
    new$Month06 := 0;
  END IF;
  if (new$Month07 is null) then 
    new$Month07 := 0;
  END IF;
  if (new$Month08 is null) then 
    new$Month08 := 0;
  END IF;
  if (new$Month09 is null) then 
    new$Month09 := 0;
  END IF;
  if (new$Month10 is null) then 
    new$Month10 := 0;
  END IF;
  if (new$Month11 is null) then 
    new$Month11 := 0;
  END IF;
  if (new$Month12 is null) then 
    new$Month12 := 0;
  END IF;
  if (new$Quarter1 is null) then 
    new$Quarter1 := 0;
  END IF;
  if (new$Quarter2 is null) then 
    new$Quarter2 := 0;
  END IF;
  if (new$Quarter3 is null) then 
    new$Quarter3 := 0;
  END IF;
  if (new$Quarter4 is null) then 
    new$Quarter4 := 0;
  END IF;
  if (new$Summa is null) then 
    new$Summa := 0;
  END IF;
  if (new$Month01Delta is null) then 
    new$Month01Delta := 0;
  END IF;
  if (new$Month02Delta is null) then 
    new$Month02Delta := 0;
  END IF;
  if (new$Month03Delta is null) then 
    new$Month03Delta := 0;
  END IF;
  if (new$Month04Delta is null) then 
    new$Month04Delta := 0;
  END IF;
  if (new$Month05Delta is null) then 
    new$Month05Delta := 0;
  END IF;
  if (new$Month06Delta is null) then 
    new$Month06Delta := 0;
  END IF;
  if (new$Month07Delta is null) then 
    new$Month07Delta := 0;
  END IF;
  if (new$Month08Delta is null) then 
    new$Month08Delta := 0;
  END IF;
  if (new$Month09Delta is null) then 
    new$Month09Delta := 0;
  END IF;
  if (new$Month10Delta is null) then 
    new$Month10Delta := 0;
  END IF;
  if (new$Month11Delta is null) then 
    new$Month11Delta := 0;
  END IF;
  if (new$Month12Delta is null) then 
    new$Month12Delta := 0;
  END IF;
  if (new$Quarter1Delta is null) then 
    new$Quarter1Delta := 0;
  END IF;
  if (new$Quarter2Delta is null) then 
    new$Quarter2Delta := 0;
  END IF;
  if (new$Quarter3Delta is null) then 
    new$Quarter3Delta := 0;
  END IF;
  if (new$Quarter4Delta is null) then 
    new$Quarter4Delta := 0;
  END IF;
  if (new$SummaDelta is null) then 
    new$SummaDelta := 0; 
  END IF;
  if (new$SummaPreviousYear is null) then 
    new$SummaPreviousYear := 0;
  END IF;
  if (new$SummaFinPreviousYear is null) then 
    new$SummaFinPreviousYear := 0;
  END IF;
   
  if (new$SummaYear1 is null) then 
    new$SummaYear1 := 0;
  END IF;
  if (new$SummaYear2 is null) then 
    new$SummaYear2 := 0;
  END IF;
  if (new$SummaYear3 is null) then 
    new$SummaYear3 := 0;
  END IF;
  if (new$SummaYear4 is null) then 
    new$SummaYear4 := 0;
  END IF;
  if (new$SummaOtherYears is null) then 
    new$SummaOtherYears := 0;
  END IF;
   
  if (new$SummaYear1Delta is null) then 
    new$SummaYear1Delta := 0;
  END IF;
  if (new$SummaYear2Delta is null) then 
    new$SummaYear2Delta := 0;
  END IF;
  if (new$SummaYear3Delta is null) then 
    new$SummaYear3Delta := 0;
  END IF;
  if (new$SummaYear4Delta is null) then 
    new$SummaYear4Delta := 0;
  END IF;
  if (new$SummaOtherYearsDelta is null) then 
    new$SummaOtherYearsDelta := 0;
  END IF;
   
  /*   ,        */
  if (new$ProgIndex = 304 and new$RecordIndex is not null and (:old.RecordIndex is null or :old.RecordIndex <> new$RecordIndex)) then
    SELECT COUNT(*) INTO CNT$1
    from AgreementSteps s where (s.Id = new$RecordIndex and s.RecordIndex = new$AgreementRef) AND (ROWNUM = 1);
    if (not (CNT$1<> 0)) then
      RaiseException('Ex_WrongStep');
    END IF;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      RaiseException('Ex_CantModufyBudget');
    END IF;
  END IF;
  if ((:old.ANumber is null) and (new$ANumber is not Null)) then
    SELECT COUNT(                    id
    ) INTO CNT$2
    from
    PaymentSchedule ps
    where
    (                    (ps.ANumber = new$ANumber)
    and
    (ps.BudgetRef = new$BudgetRef)) AND (ROWNUM = 1);
    if ((CNT$2<> 0)) then
      RaiseException('ex_Promise_NumUQ');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_1 (TR_PAYMENTSCHEDULE_BU_1)
-- Create 05.03.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  /*   1.0*/
    if (new$Quarter1 = 0) then new$Quarter1 := new$Month01 + new$Month02 + new$Month03; end if;
    if (new$Quarter2 = 0) then new$Quarter2 := new$Month04 + new$Month05 + new$Month06; end if;
    if (new$Quarter3 = 0) then new$Quarter3 := new$Month07 + new$Month08 + new$Month09; end if;
    if (new$Quarter4 = 0) then new$Quarter4 := new$Month10 + new$Month11 + new$Month12; end if;
    new$SummaYear1 := new$Quarter1 + new$Quarter2 + new$Quarter3 + new$Quarter4;

-- - - - - - - - - - - - -
-- BU_3 (TR_PAYMENTSCHEDULE_BU_3)
-- Create 03.12.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

    /*            */
    new$AdjustmentRef := :old.AdjustmentRef;

-- - - - - - - - - - - - -
-- BU_10 (TR_PAYMENTSCHEDULE_BU_10)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*   5.0*/
  /* ,      ,   */
  if ((new$ANumber <> :old.ANumber) or
  (new$InnerPromiseNum <> :old.InnerPromiseNum) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber)) then
    RaiseException('EX_AGR_ChangeInnerNums');
  END IF;
      
  /*   !!!*/
  if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and 
  ((new$Accepted = 1) or (new$AcceptDate is null))) then
    RaiseException('EX_RollbackCancel');
  END IF;
  /*   ,     LastAccepted*/
  if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) or 
  ((:old.Accepted = 0) and (new$Accepted = 1) and (new$AcceptDate is not null))) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;
              
    else
      RaiseException('EX_BP_ChangeStateAdjust');    
    END IF;
  END IF;
      
  /*    ,     LastAccepted*/
  if (((:old.AcceptDate is not null) and (:old.Accepted = 1)) and
  ((new$Accepted = 0) or (new$AcceptDate is null))) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 0;
              
    else
      RaiseException('EX_BP_ChangeStateAdjust');    
    END IF;
  END IF;
      
  /*   ,     LastAdjustment*/
  if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 0)) or 
  ((:old.Accepted = 1) and (new$Accepted = 0) and (new$AcceptDate is not null))) then
    if (new$LastAdjustment = 1) then
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
              
    else
      RaiseException('EX_AGR_ChangeStateAdjust');
    END IF;

    select max(AdjustmentNumber) into MaxNumber1$ from PaymentSchedule 
    where (InnerPromiseNum = new$InnerPromiseNum) ;
    /*    ,     */
    if ((new$adjustmentNumber=0) and (MaxNumber1$<>0))
    then 
      RaiseException('EX_BP_PrimaryBPHasNotify');    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_PAYMENTSCHEDULE_BU_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*           */  
  if (new$AdjustmentNumber > 0) then
    BEGIN
      select 
      Month01, Month02, Month03, Month04, Month05, Month06,
      Month07, Month08, Month09, Month10, Month11, Month12,
      Quarter1, Quarter2, Quarter3, Quarter4, Summa,
      SummaYear1, SummaYear2, SummaYear3, SummaYear4, SummaOtherYears
      into
      M01$, M02$, M03$, M04$, M05$, M06$, M07$, M08$, M09$, M10$, M11$, M12$, 
      Q1$, Q2$, Q3$, Q4$, S$, S1$, S2$, S3$, S4$, SOther$         from 
      PaymentSchedule
      where
      ID = new$AdjustmentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
          
    new$Month01Delta := new$Month01 - M01$;
    new$Month02Delta := new$Month02 - M02$;
    new$Month03Delta := new$Month03 - M03$;
    new$Month04Delta := new$Month04 - M04$;
    new$Month05Delta := new$Month05 - M05$;
    new$Month06Delta := new$Month06 - M06$;
    new$Month07Delta := new$Month07 - M07$;
    new$Month08Delta := new$Month08 - M08$;
    new$Month09Delta := new$Month09 - M09$;
    new$Month10Delta := new$Month10 - M10$;
    new$Month11Delta := new$Month11 - M11$;
    new$Month12Delta := new$Month12 - M12$;
    new$Quarter1Delta := new$Quarter1 - Q1$;
    new$Quarter2Delta := new$Quarter2 - Q2$;
    new$Quarter3Delta := new$Quarter3 - Q3$;
    new$Quarter4Delta := new$Quarter4 - Q4$;
    new$SummaDelta := new$Summa - S$;
    new$SummaYear1Delta := new$SummaYear1 - S1$;
    new$SummaYear2Delta := new$SummaYear2 - S2$;
    new$SummaYear3Delta := new$SummaYear3 - S3$;
    new$SummaYear4Delta := new$SummaYear4 - S4$;
    new$SummaOtherYearsDelta := new$SummaOtherYears - SOther$;
        
  else /*        */  
    new$Month01Delta := new$Month01;
    new$Month02Delta := new$Month02;
    new$Month03Delta := new$Month03;
    new$Month04Delta := new$Month04;
    new$Month05Delta := new$Month05;
    new$Month06Delta := new$Month06;
    new$Month07Delta := new$Month07;
    new$Month08Delta := new$Month08;
    new$Month09Delta := new$Month09;
    new$Month10Delta := new$Month10;
    new$Month11Delta := new$Month11;
    new$Month12Delta := new$Month12;
    new$Quarter1Delta := new$Quarter1;
    new$Quarter2Delta := new$Quarter2;
    new$Quarter3Delta := new$Quarter3;
    new$Quarter4Delta := new$Quarter4;
    new$SummaDelta := new$Summa;
    new$SummaYear1Delta := new$SummaYear1;
    new$SummaYear2Delta := new$SummaYear2;
    new$SummaYear3Delta := new$SummaYear3;
    new$SummaYear4Delta := new$SummaYear4;
    new$SummaOtherYearsDelta := new$SummaOtherYears;        
        
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_PAYMENTSCHEDULE_BU_200)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*    */
  if (new$Accepted = 0 and new$AcceptDate is not null and :old.Accepted = 1) then
    /*   ,     
         *    ,      */
    FOR REC$1 IN (      select ffc.Reject_Cls  AS DocumentRejectCls from FacialFinDetail ffd
    left join FacialFinCaption ffc on (ffc.ID = ffd.RecordIndex)
    where SourcePromise = new$ANumber and SourceBudgetPromise = new$InnerPromiseNum
    or DestPromise = new$ANumber and DestBudgetPromise = new$InnerPromiseNum
    )
    LOOP
      if (REC$1.DocumentRejectCls is null) then
        RaiseException('Ex_BP_CannotReject');    
      END IF;
    END LOOP;
    /* ,         */
    FOR REC$1 IN (      SELECT Count(ps_in.ID)  AS AdjCount FROM PaymentSchedule ps_in
    WHERE (ps_in.InnerPromiseNum = new$InnerPromiseNum)and(ps_in.AdjustmentNumber > new$AdjustmentNumber)
    and (ps_in.Accepted<>0) 
    )
    LOOP
      if (REC$1.AdjCount > 0) then
        RaiseException('EX_BP_AdjustmentedCANNOTREJECT');    
      END IF;
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (tr_PaymentSchedule_BU_400)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$AgreementRef <> :old.AgreementRef or new$ExecutionRef <> :old.ExecutionRef) then
    RaiseException('EX_CANTCHANGECAPTIONREF');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_PAYMENTSCHEDULE_BU_700)
-- Create 14.10.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$RVersion is null) then
    new$RVersion := 1;
  elsif ((new$RVersion = -1) and (:Old.RVersion <> -1)) then
    new$RVersion := :Old.RVersion;
  else
    new$RVersion := :Old.RVersion + 1;
  end if;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_PAYMENTSCHEDULE SET
    ID = new$ID,
    ANUMBER = new$ANUMBER,
    PARENTNUMBER = new$PARENTNUMBER,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVSR = new$KVSR,
    KCSR = new$KCSR,
    KVR = new$KVR,
    MONTH01 = new$MONTH01,
    MONTH02 = new$MONTH02,
    MONTH03 = new$MONTH03,
    MONTH04 = new$MONTH04,
    MONTH05 = new$MONTH05,
    MONTH06 = new$MONTH06,
    MONTH07 = new$MONTH07,
    MONTH08 = new$MONTH08,
    MONTH09 = new$MONTH09,
    MONTH10 = new$MONTH10,
    MONTH11 = new$MONTH11,
    MONTH12 = new$MONTH12,
    SUMMA = new$SUMMA,
    REGION = new$REGION,
    SUBKESR = new$SUBKESR,
    MEANSTYPE = new$MEANSTYPE,
    FINSOURCE = new$FINSOURCE,
    FINTYPE = new$FINTYPE,
    FACT = new$FACT,
    FACIALACC_CLS = new$FACIALACC_CLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    ACCEPTDATE = new$ACCEPTDATE,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    ACCEPTED = new$ACCEPTED,
    LASTACCEPTED = new$LASTACCEPTED,
    PROMISETYPE = new$PROMISETYPE,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    OLDNUMBER = new$OLDNUMBER,
    SUMMAPREVIOUSYEAR = new$SUMMAPREVIOUSYEAR,
    SUMMAFINPREVIOUSYEAR = new$SUMMAFINPREVIOUSYEAR,
    QUARTER1 = new$QUARTER1,
    QUARTER2 = new$QUARTER2,
    QUARTER3 = new$QUARTER3,
    QUARTER4 = new$QUARTER4,
    RECORDINDEX = new$RECORDINDEX,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DIRECTIONCLS = new$DIRECTIONCLS,
    RVERSION = new$RVERSION,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    MONTH01DELTA = new$MONTH01DELTA,
    MONTH02DELTA = new$MONTH02DELTA,
    MONTH03DELTA = new$MONTH03DELTA,
    MONTH04DELTA = new$MONTH04DELTA,
    MONTH05DELTA = new$MONTH05DELTA,
    MONTH06DELTA = new$MONTH06DELTA,
    MONTH07DELTA = new$MONTH07DELTA,
    MONTH08DELTA = new$MONTH08DELTA,
    MONTH09DELTA = new$MONTH09DELTA,
    MONTH10DELTA = new$MONTH10DELTA,
    MONTH11DELTA = new$MONTH11DELTA,
    MONTH12DELTA = new$MONTH12DELTA,
    QUARTER1DELTA = new$QUARTER1DELTA,
    QUARTER2DELTA = new$QUARTER2DELTA,
    QUARTER3DELTA = new$QUARTER3DELTA,
    QUARTER4DELTA = new$QUARTER4DELTA,
    SUMMADELTA = new$SUMMADELTA,
    NOTE = new$NOTE,
    FINYEAR = new$FINYEAR,
    SUMMAYEAR1 = new$SUMMAYEAR1,
    SUMMAYEAR2 = new$SUMMAYEAR2,
    SUMMAYEAR3 = new$SUMMAYEAR3,
    SUMMAYEAR1DELTA = new$SUMMAYEAR1DELTA,
    SUMMAYEAR2DELTA = new$SUMMAYEAR2DELTA,
    SUMMAYEAR3DELTA = new$SUMMAYEAR3DELTA,
    ASSIGNMENTKIND = new$ASSIGNMENTKIND,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    EXECUTIONREF = new$EXECUTIONREF,
    INNERPROMISENUM = new$INNERPROMISENUM,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    PROMISENUMBER = new$PROMISENUMBER,
    SUBSIDYCLS = new$SUBSIDYCLS,
    AGREEMENTREF = new$AGREEMENTREF,
    BUDALLOCATIONCLS = new$BUDALLOCATIONCLS,
    PAYPROMISECLS = new$PAYPROMISECLS,
    PROGINDEX = new$PROGINDEX,
    INVESTOBJECT = new$INVESTOBJECT,
    SUMMAYEAR4 = new$SUMMAYEAR4,
    SUMMAOTHERYEARS = new$SUMMAOTHERYEARS,
    SUMMAYEAR4DELTA = new$SUMMAYEAR4DELTA,
    SUMMAOTHERYEARSDELTA = new$SUMMAOTHERYEARSDELTA,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_10 (TR_PAYMENTSCHEDULE_AU_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/

  /*      */
  /*     ,       */
  if ((new$AdjustmentNumber > 0) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update PaymentSchedule set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment    */
  if ((new$AdjustmentNumber > 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and 
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update PaymentSchedule set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_PAYMENTSCHEDULE_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (113, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=113) and (RecordId=new$ID);
  end if;

END;
/
ALTER TABLE WritExecutionDetail ADD (
  TargetCls NUMBER(10),
    CHECK((TargetCls<=2147483647)AND(TargetCls>-2147483648)),
  constraint FK_WED_TargetCls foreign key (TargetCls) references TargetCls(ID)    
)
/
CREATE INDEX FK_WED_TargetCls ON WritExecutionDetail(TargetCls)
/
ALTER TABLE ReplacementClsDetailInfo ADD (
  TargetCls NUMBER(10),
    CHECK((TargetCls<=2147483647)AND(TargetCls>-2147483648)),
  constraint FK_RCDI_TargetCls foreign key (TargetCls) references TargetCls(ID)    
)
/
CREATE INDEX FK_RCDI_TargetCls ON ReplacementClsDetailInfo(TargetCls)
/
ALTER TABLE TB_CorrectionDetail ADD (
  TargetCls NUMBER(10),
    CHECK((TargetCls<=2147483647)AND(TargetCls>-2147483648)),
  constraint FK_CD_TargetCls foreign key (TargetCls) references TargetCls(ID)    
)
/
CREATE INDEX FK_CD_TargetCls ON TB_CorrectionDetail(TargetCls)
/

CREATE OR REPLACE VIEW CorrectionDetail (
  ID,
  PARENTID,
  BUDGETREF,
  SUMMA,
  CLSTYPE,
  FACIALACC_CLS,
  KVSR,
  KFSR,
  KCSR,
  KVR,
  KESR,
  DIRECTIONCLS,
  MEANSTYPE,
  FACT,
  REGIONCLS,
  FINSOURCE,
  FINTYPE,
  DOCTYPE,
  SUBKESR,
  FUNDSSOURCE,
  KD,
  IFS,
  BUHOPERATIONCLS,
  CHANGEACC_REF,
  CHANGEACC,
  CHANGEORGINN,
  CHANGEORGINN20,
  PROGINDEX,
  RECORDINDEX,
  DOCUMENTPROGINDEX,
  DOCUMENTRECORDINDEX,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  SENDERID,
  SENDERRECORDID,
  RVERSION,
  CREATERUSER,
  CREATEDATE,
  UPDATERUSER,
  UPDATEDATE,
  NOTE,
  ISCLSCHANGED,
  PROMISE,
  BUDGETPROMISE,
  EXECDOC,
  OKATO,
  ADDOKATO,
  TRANSFERTCLS,
  ORIGINALCLSSUMMA,
  NOTECLS,
  OPERATIONTYPE,
  REVERSEFLAG,
  EXECINNERNUMBER,
  CLSFIELFCHANGED,
  FAORGTYPE,
  SUBSIDYCLS,
  BUDALLOCATIONCLS,
  PAYPROMISECLS,
  NOTEQUALEX,
  OKTMO,
  UINCODE,
  INVESTOBJECT,
  CHANGEORGNAME,
  CONTRACTCOSTSCLS,
  TARGETCLS)
AS
  SELECT
    ID,
    PARENTID,
    BUDGETREF,
    SUMMA,
    CLSTYPE,
    FACIALACC_CLS,
    KVSR,
    KFSR,
    KCSR,
    KVR,
    KESR,
    DIRECTIONCLS,
    MEANSTYPE,
    FACT,
    REGIONCLS,
    FINSOURCE,
    FINTYPE,
    DOCTYPE,
    SUBKESR,
    FUNDSSOURCE,
    KD,
    IFS,
    BUHOPERATIONCLS,
    CHANGEACC_REF,
    CHANGEACC,
    CHANGEORGINN,
    CHANGEORGINN20,
    PROGINDEX,
    RECORDINDEX,
    DOCUMENTPROGINDEX,
    DOCUMENTRECORDINDEX,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SENDERID,
    SENDERRECORDID,
    RVERSION,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    NOTE,
    ISCLSCHANGED,
    PROMISE,
    BUDGETPROMISE,
    EXECDOC,
    OKATO,
    ADDOKATO,
    TRANSFERTCLS,
    ORIGINALCLSSUMMA,
    NOTECLS,
    OPERATIONTYPE,
    REVERSEFLAG,
    EXECINNERNUMBER,
    CLSFIELFCHANGED,
    FAORGTYPE,
    SUBSIDYCLS,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    NOTEQUALEX,
    OKTMO,
    UINCODE,
    INVESTOBJECT,
    CHANGEORGNAME,
    CONTRACTCOSTSCLS,
    TARGETCLS
  FROM TB_CorrectionDetail
/

CREATE OR REPLACE TRIGGER TR_CORRECTIONDETAIL_ID
  INSTEAD OF DELETE
  ON CORRECTIONDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_500 (TR_CORRECTIONDETAIL_BD_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  Update CorrectionCaption set
  DocChangeDate = SYSDATE,
  RVersion = -1
  where id = :old.recordindex;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_CORRECTIONDETAIL
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_500 (TR_CORRECTIONDETAIL_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate, ProgIndex, SUMMA) values(5504,:old.ID,SYSDATE,:old.ProgIndex, :old.SUMMA);

END;
/

CREATE OR REPLACE TRIGGER TR_CORRECTIONDETAIL_II
  INSTEAD OF INSERT
  ON CORRECTIONDETAIL
  FOR EACH ROW
DECLARE
  new$ID CORRECTIONDETAIL.ID%TYPE := :NEW.ID;
  new$PARENTID CORRECTIONDETAIL.PARENTID%TYPE := :NEW.PARENTID;
  new$BUDGETREF CORRECTIONDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUMMA CORRECTIONDETAIL.SUMMA%TYPE := :NEW.SUMMA;
  new$CLSTYPE CORRECTIONDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$FACIALACC_CLS CORRECTIONDETAIL.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$KVSR CORRECTIONDETAIL.KVSR%TYPE := :NEW.KVSR;
  new$KFSR CORRECTIONDETAIL.KFSR%TYPE := :NEW.KFSR;
  new$KCSR CORRECTIONDETAIL.KCSR%TYPE := :NEW.KCSR;
  new$KVR CORRECTIONDETAIL.KVR%TYPE := :NEW.KVR;
  new$KESR CORRECTIONDETAIL.KESR%TYPE := :NEW.KESR;
  new$DIRECTIONCLS CORRECTIONDETAIL.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$MEANSTYPE CORRECTIONDETAIL.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FACT CORRECTIONDETAIL.FACT%TYPE := :NEW.FACT;
  new$REGIONCLS CORRECTIONDETAIL.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$FINSOURCE CORRECTIONDETAIL.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE CORRECTIONDETAIL.FINTYPE%TYPE := :NEW.FINTYPE;
  new$DOCTYPE CORRECTIONDETAIL.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SUBKESR CORRECTIONDETAIL.SUBKESR%TYPE := :NEW.SUBKESR;
  new$FUNDSSOURCE CORRECTIONDETAIL.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$KD CORRECTIONDETAIL.KD%TYPE := :NEW.KD;
  new$IFS CORRECTIONDETAIL.IFS%TYPE := :NEW.IFS;
  new$BUHOPERATIONCLS CORRECTIONDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CHANGEACC_REF CORRECTIONDETAIL.CHANGEACC_REF%TYPE := :NEW.CHANGEACC_REF;
  new$CHANGEACC CORRECTIONDETAIL.CHANGEACC%TYPE := :NEW.CHANGEACC;
  new$CHANGEORGINN CORRECTIONDETAIL.CHANGEORGINN%TYPE := :NEW.CHANGEORGINN;
  new$CHANGEORGINN20 CORRECTIONDETAIL.CHANGEORGINN20%TYPE := :NEW.CHANGEORGINN20;
  new$PROGINDEX CORRECTIONDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX CORRECTIONDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$DOCUMENTPROGINDEX CORRECTIONDETAIL.DOCUMENTPROGINDEX%TYPE := :NEW.DOCUMENTPROGINDEX;
  new$DOCUMENTRECORDINDEX CORRECTIONDETAIL.DOCUMENTRECORDINDEX%TYPE := :NEW.DOCUMENTRECORDINDEX;
  new$ISBLOCKED CORRECTIONDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE CORRECTIONDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE CORRECTIONDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE CORRECTIONDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SENDERID CORRECTIONDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID CORRECTIONDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$RVERSION CORRECTIONDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$CREATERUSER CORRECTIONDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE CORRECTIONDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER CORRECTIONDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE CORRECTIONDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$NOTE CORRECTIONDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$ISCLSCHANGED CORRECTIONDETAIL.ISCLSCHANGED%TYPE := :NEW.ISCLSCHANGED;
  new$PROMISE CORRECTIONDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$BUDGETPROMISE CORRECTIONDETAIL.BUDGETPROMISE%TYPE := :NEW.BUDGETPROMISE;
  new$EXECDOC CORRECTIONDETAIL.EXECDOC%TYPE := :NEW.EXECDOC;
  new$OKATO CORRECTIONDETAIL.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO CORRECTIONDETAIL.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$TRANSFERTCLS CORRECTIONDETAIL.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$ORIGINALCLSSUMMA CORRECTIONDETAIL.ORIGINALCLSSUMMA%TYPE := :NEW.ORIGINALCLSSUMMA;
  new$NOTECLS CORRECTIONDETAIL.NOTECLS%TYPE := :NEW.NOTECLS;
  new$OPERATIONTYPE CORRECTIONDETAIL.OPERATIONTYPE%TYPE := :NEW.OPERATIONTYPE;
  new$REVERSEFLAG CORRECTIONDETAIL.REVERSEFLAG%TYPE := :NEW.REVERSEFLAG;
  new$EXECINNERNUMBER CORRECTIONDETAIL.EXECINNERNUMBER%TYPE := :NEW.EXECINNERNUMBER;
  new$CLSFIELFCHANGED CORRECTIONDETAIL.CLSFIELFCHANGED%TYPE := :NEW.CLSFIELFCHANGED;
  new$FAORGTYPE CORRECTIONDETAIL.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$SUBSIDYCLS CORRECTIONDETAIL.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$BUDALLOCATIONCLS CORRECTIONDETAIL.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS CORRECTIONDETAIL.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$NOTEQUALEX CORRECTIONDETAIL.NOTEQUALEX%TYPE := :NEW.NOTEQUALEX;
  new$OKTMO CORRECTIONDETAIL.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE CORRECTIONDETAIL.UINCODE%TYPE := :NEW.UINCODE;
  new$INVESTOBJECT CORRECTIONDETAIL.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CHANGEORGNAME CORRECTIONDETAIL.CHANGEORGNAME%TYPE := :NEW.CHANGEORGNAME;
  new$CONTRACTCOSTSCLS CORRECTIONDETAIL.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS CORRECTIONDETAIL.TARGETCLS%TYPE := :NEW.TARGETCLS;
--
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  ConstCheck$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  vOperationTypeS1$ NUMBER(10);
  vOperationTypeD1$ NUMBER(10);
  vOperationType1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_CORRECTIONDETAIL_BI)
-- Version 11.20.00.1
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN 
    select g_shared.nextval into new$id from dual;
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$IFS := 0;
  END IF;
  IF (new$FacialAcc_Cls IS NULL) THEN 
    new$FacialAcc_Cls := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DirectionCls IS NULL) THEN 
    new$DirectionCls := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$Finsource IS NULL) THEN 
    new$Finsource := 0;
  END IF;
  IF (new$FinType IS NULL) THEN 
    new$FinType := 0;
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;  
  END IF;
  IF (new$SubKesr IS NULL) THEN 
    new$SubKesr := 0;
  END IF;
  IF (new$buhoperationCls IS NULL) THEN 
    new$buhoperationCls := 0;
  END IF;
  IF (new$ReverseFlag IS NULL) THEN 
    new$ReverseFlag := 1;
  END IF;
  IF (new$OperationType IS NULL) THEN 
    BEGIN
      SELECT CorCap.SourceType, CorCap.DestType
      INTO
      vOperationTypeS1$, vOperationTypeD1$       FROM correctioncaption CorCap
      WHERE
      (CorCap.id = new$recordindex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    IF (new$ProgIndex = 315) THEN 
      vOperationType1$ := vOperationTypeS1$;
          
    ELSE 
      vOperationType1$ := vOperationTypeD1$;
    END IF;
    new$OperationType := vOperationType1$;
      
  END IF;
  BEGIN

    SELECT org.Org_Type   INTO new$FAOrgType FROM Organizations org
    INNER JOIN FacialAcc_Cls fac  ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$FacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BI_100 (tr_correctiondetail_bi_100)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$progindex = 316) then
    update correctiondetail set
    buhoperationcls = new$buhoperationcls
    where ID = new$parentid;
  END IF;

-- - - - - - - - - - - - -
-- BI_120 (TR_CORRECTIONDETAIL_BI_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((new$ClsType is NULL) and (new$IFS <> 0)) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$KD <> 0)) then
      new$ClsType := 2; /*        ClsType */
            
    else
      if (new$ClsType is null)
      then 
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND ((new$IFS <> 0) or (new$KD <> 0)))THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ( (new$ClsType = 1) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0) OR
  (new$KD <> 0)
  ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0) OR
  (new$IFS <> 0)
  ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_CORRECTIONDETAIL_BI_200)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  getintconst(30, 35,ConstCheck$);
  /* ( )      ,    */
  if ((PromiseMode$ <> 1) and (ConstCheck$ = 1)) then
    if (new$Promise is not null) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$        from
      promise_detail pr
      where
      (pr.registrnumber = new$PROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');    
      END IF;  
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /* ( )      ,    */
  /*         */
  if (PromiseMode$ = 1) then
    if ((new$Promise is not null) and (new$BudgetPromise is null)) then
      select 
      max(InnerPromiseNum) 
      into BPInnerNum$       from 
      PaymentSchedule 
      where 
      (ANumber = new$Promise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$BudgetPromise := BPInnerNum$;
              
      else
        RaiseException('EX_BP_NotExist');    
      END IF;
    END IF;
    /*    ,   ,   */
    if ((new$BudgetPromise is not null) and (new$Promise is null)) then
      BEGIN
        select 
        ANumber 
        into BPInnerNum$       from 
        PaymentSchedule
        where 
        (InnerPromiseNum = new$BudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
            
      new$Promise := BPInnerNum$;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_CORRECTIONDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$Promise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$Promise and ps.InnerPromiseNum = new$BudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$ExecDoc := ExecID$;
        new$ExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$ExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$ExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$ExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*    ,   ,  */
    else 
      if (new$ExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$ExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$ExecInnerNumber := ExecInnerNumber$;
            
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_CORRECTIONDETAIL_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update CorrectionCaption set
  DocChangeDate = new$UpdateDate,
  RVersion = -1
  where id = new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_CORRECTIONDETAIL (
    ID,
    PARENTID,
    BUDGETREF,
    SUMMA,
    CLSTYPE,
    FACIALACC_CLS,
    KVSR,
    KFSR,
    KCSR,
    KVR,
    KESR,
    DIRECTIONCLS,
    MEANSTYPE,
    FACT,
    REGIONCLS,
    FINSOURCE,
    FINTYPE,
    DOCTYPE,
    SUBKESR,
    FUNDSSOURCE,
    KD,
    IFS,
    BUHOPERATIONCLS,
    CHANGEACC_REF,
    CHANGEACC,
    CHANGEORGINN,
    CHANGEORGINN20,
    PROGINDEX,
    RECORDINDEX,
    DOCUMENTPROGINDEX,
    DOCUMENTRECORDINDEX,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SENDERID,
    SENDERRECORDID,
    RVERSION,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    NOTE,
    ISCLSCHANGED,
    PROMISE,
    BUDGETPROMISE,
    EXECDOC,
    OKATO,
    ADDOKATO,
    TRANSFERTCLS,
    ORIGINALCLSSUMMA,
    NOTECLS,
    OPERATIONTYPE,
    REVERSEFLAG,
    EXECINNERNUMBER,
    CLSFIELFCHANGED,
    FAORGTYPE,
    SUBSIDYCLS,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    NOTEQUALEX,
    OKTMO,
    UINCODE,
    INVESTOBJECT,
    CHANGEORGNAME,
    CONTRACTCOSTSCLS,
    TARGETCLS
  ) VALUES (
    new$ID,
    new$PARENTID,
    new$BUDGETREF,
    new$SUMMA,
    new$CLSTYPE,
    new$FACIALACC_CLS,
    new$KVSR,
    new$KFSR,
    new$KCSR,
    new$KVR,
    new$KESR,
    new$DIRECTIONCLS,
    new$MEANSTYPE,
    new$FACT,
    new$REGIONCLS,
    new$FINSOURCE,
    new$FINTYPE,
    new$DOCTYPE,
    new$SUBKESR,
    new$FUNDSSOURCE,
    new$KD,
    new$IFS,
    new$BUHOPERATIONCLS,
    new$CHANGEACC_REF,
    new$CHANGEACC,
    new$CHANGEORGINN,
    new$CHANGEORGINN20,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$DOCUMENTPROGINDEX,
    new$DOCUMENTRECORDINDEX,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SENDERID,
    new$SENDERRECORDID,
    new$RVERSION,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$NOTE,
    new$ISCLSCHANGED,
    new$PROMISE,
    new$BUDGETPROMISE,
    new$EXECDOC,
    new$OKATO,
    new$ADDOKATO,
    new$TRANSFERTCLS,
    new$ORIGINALCLSSUMMA,
    new$NOTECLS,
    new$OPERATIONTYPE,
    new$REVERSEFLAG,
    new$EXECINNERNUMBER,
    new$CLSFIELFCHANGED,
    new$FAORGTYPE,
    new$SUBSIDYCLS,
    new$BUDALLOCATIONCLS,
    new$PAYPROMISECLS,
    new$NOTEQUALEX,
    new$OKTMO,
    new$UINCODE,
    new$INVESTOBJECT,
    new$CHANGEORGNAME,
    new$CONTRACTCOSTSCLS,
    new$TARGETCLS);

-- - - - - - - - - - - - -
-- AI_500 (TR_CORRECTIONDETAIL_AI_500)
-- Create 29.12.2009
-- - - - - - - - - - - - -

 delete from DelRecIndexes where (TableID =5504 ) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_CORRECTIONDETAIL_IU
  INSTEAD OF UPDATE
  ON CORRECTIONDETAIL
  FOR EACH ROW
DECLARE
  new$ID CORRECTIONDETAIL.ID%TYPE := :NEW.ID;
  new$PARENTID CORRECTIONDETAIL.PARENTID%TYPE := :NEW.PARENTID;
  new$BUDGETREF CORRECTIONDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUMMA CORRECTIONDETAIL.SUMMA%TYPE := :NEW.SUMMA;
  new$CLSTYPE CORRECTIONDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$FACIALACC_CLS CORRECTIONDETAIL.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$KVSR CORRECTIONDETAIL.KVSR%TYPE := :NEW.KVSR;
  new$KFSR CORRECTIONDETAIL.KFSR%TYPE := :NEW.KFSR;
  new$KCSR CORRECTIONDETAIL.KCSR%TYPE := :NEW.KCSR;
  new$KVR CORRECTIONDETAIL.KVR%TYPE := :NEW.KVR;
  new$KESR CORRECTIONDETAIL.KESR%TYPE := :NEW.KESR;
  new$DIRECTIONCLS CORRECTIONDETAIL.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$MEANSTYPE CORRECTIONDETAIL.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FACT CORRECTIONDETAIL.FACT%TYPE := :NEW.FACT;
  new$REGIONCLS CORRECTIONDETAIL.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$FINSOURCE CORRECTIONDETAIL.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE CORRECTIONDETAIL.FINTYPE%TYPE := :NEW.FINTYPE;
  new$DOCTYPE CORRECTIONDETAIL.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SUBKESR CORRECTIONDETAIL.SUBKESR%TYPE := :NEW.SUBKESR;
  new$FUNDSSOURCE CORRECTIONDETAIL.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$KD CORRECTIONDETAIL.KD%TYPE := :NEW.KD;
  new$IFS CORRECTIONDETAIL.IFS%TYPE := :NEW.IFS;
  new$BUHOPERATIONCLS CORRECTIONDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CHANGEACC_REF CORRECTIONDETAIL.CHANGEACC_REF%TYPE := :NEW.CHANGEACC_REF;
  new$CHANGEACC CORRECTIONDETAIL.CHANGEACC%TYPE := :NEW.CHANGEACC;
  new$CHANGEORGINN CORRECTIONDETAIL.CHANGEORGINN%TYPE := :NEW.CHANGEORGINN;
  new$CHANGEORGINN20 CORRECTIONDETAIL.CHANGEORGINN20%TYPE := :NEW.CHANGEORGINN20;
  new$PROGINDEX CORRECTIONDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX CORRECTIONDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$DOCUMENTPROGINDEX CORRECTIONDETAIL.DOCUMENTPROGINDEX%TYPE := :NEW.DOCUMENTPROGINDEX;
  new$DOCUMENTRECORDINDEX CORRECTIONDETAIL.DOCUMENTRECORDINDEX%TYPE := :NEW.DOCUMENTRECORDINDEX;
  new$ISBLOCKED CORRECTIONDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE CORRECTIONDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE CORRECTIONDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE CORRECTIONDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SENDERID CORRECTIONDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID CORRECTIONDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$RVERSION CORRECTIONDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$CREATERUSER CORRECTIONDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE CORRECTIONDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER CORRECTIONDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE CORRECTIONDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$NOTE CORRECTIONDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$ISCLSCHANGED CORRECTIONDETAIL.ISCLSCHANGED%TYPE := :NEW.ISCLSCHANGED;
  new$PROMISE CORRECTIONDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$BUDGETPROMISE CORRECTIONDETAIL.BUDGETPROMISE%TYPE := :NEW.BUDGETPROMISE;
  new$EXECDOC CORRECTIONDETAIL.EXECDOC%TYPE := :NEW.EXECDOC;
  new$OKATO CORRECTIONDETAIL.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO CORRECTIONDETAIL.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$TRANSFERTCLS CORRECTIONDETAIL.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$ORIGINALCLSSUMMA CORRECTIONDETAIL.ORIGINALCLSSUMMA%TYPE := :NEW.ORIGINALCLSSUMMA;
  new$NOTECLS CORRECTIONDETAIL.NOTECLS%TYPE := :NEW.NOTECLS;
  new$OPERATIONTYPE CORRECTIONDETAIL.OPERATIONTYPE%TYPE := :NEW.OPERATIONTYPE;
  new$REVERSEFLAG CORRECTIONDETAIL.REVERSEFLAG%TYPE := :NEW.REVERSEFLAG;
  new$EXECINNERNUMBER CORRECTIONDETAIL.EXECINNERNUMBER%TYPE := :NEW.EXECINNERNUMBER;
  new$CLSFIELFCHANGED CORRECTIONDETAIL.CLSFIELFCHANGED%TYPE := :NEW.CLSFIELFCHANGED;
  new$FAORGTYPE CORRECTIONDETAIL.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$SUBSIDYCLS CORRECTIONDETAIL.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$BUDALLOCATIONCLS CORRECTIONDETAIL.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS CORRECTIONDETAIL.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$NOTEQUALEX CORRECTIONDETAIL.NOTEQUALEX%TYPE := :NEW.NOTEQUALEX;
  new$OKTMO CORRECTIONDETAIL.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE CORRECTIONDETAIL.UINCODE%TYPE := :NEW.UINCODE;
  new$INVESTOBJECT CORRECTIONDETAIL.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CHANGEORGNAME CORRECTIONDETAIL.CHANGEORGNAME%TYPE := :NEW.CHANGEORGNAME;
  new$CONTRACTCOSTSCLS CORRECTIONDETAIL.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS CORRECTIONDETAIL.TARGETCLS%TYPE := :NEW.TARGETCLS;
--
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  ConstCheck$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  vOperationTypeS$ NUMBER(10);
  vOperationTypeD$ NUMBER(10);
  vOperationType$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_CORRECTIONDETAIL_BU)
-- Version 11.20.00.1
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN 
    select g_shared.nextval into new$id from dual;
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$IFS := 0;
  END IF;
  IF (new$FacialAcc_Cls IS NULL) THEN 
    new$FacialAcc_Cls := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DirectionCls IS NULL) THEN 
    new$DirectionCls := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$Finsource IS NULL) THEN 
    new$Finsource := 0;
  END IF;
  IF (new$FinType IS NULL) THEN 
    new$FinType := 0;
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKesr IS NULL) THEN 
    new$SubKesr := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$buhoperationCls IS NULL) THEN 
    new$buhoperationCls := 0;
  END IF;
  IF (new$ReverseFlag IS NULL) THEN 
    new$ReverseFlag := 1;
  END IF;
  IF (new$OperationType IS NULL) THEN 
    BEGIN
      SELECT CorCap.SourceType, CorCap.DestType
      INTO
      vOperationTypeS$, vOperationTypeD$       FROM correctioncaption CorCap
      WHERE
      (CorCap.id = new$recordindex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    IF (new$ProgIndex = 315) THEN 
      vOperationType$ := vOperationTypeS$;
          
    ELSE 
      vOperationType$ := vOperationTypeD$;
    END IF;
    new$OperationType := vOperationType$;
      
  END IF;
  /*     \*/
  IF ((new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType IS NULL)) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  ON (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (tr_correctiondetail_bu_100)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$buhoperationcls <> :old.buhoperationcls) and (new$progindex = 316)) then
    update correctiondetail set
    buhoperationcls = new$buhoperationcls
    where ID = new$parentid;
  END IF;

-- - - - - - - - - - - - -
-- BU_120 (TR_CORRECTIONDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((new$ClsType is NULL) and (new$IFS <> 0)) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$KD <> 0)) then
      new$ClsType := 2; /*        ClsType */
            
    else
      if (new$ClsType is null)
      then 
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND ((new$IFS <> 0) or (new$KD <> 0)))THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ( (new$ClsType = 1) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0) OR
  (new$KD <> 0)
  ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0) OR
  (new$IFS <> 0)
  ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_CORRECTIONDETAIL_BU_200)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  getintconst(30, 35,ConstCheck$);
  /* ( )      ,    */
  if ((PromiseMode$ <> 1) and (ConstCheck$ = 1)) then
    if ((new$Promise is not null)and((:old.Promise is null)or(:old.Promise <> new$Promise ))) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$        from
      promise_detail pr
      where
      (pr.registrnumber = new$PROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');    
      END IF;  
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /* ( )      ,    */
  /*         */
  if (PromiseMode$ = 1) then
    if ((new$Promise is not null)and((:old.Promise is null)or(:old.Promise <> new$Promise )) and 
    (new$BudgetPromise is null) and (:old.BudgetPromise is null)) then
      select 
      max(InnerPromiseNum) 
      into BPInnerNum$       from 
      PaymentSchedule 
      where 
      (ANumber = new$Promise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$BudgetPromise := BPInnerNum$;
              
      else
        RaiseException('EX_BP_NotExist');    
      END IF;
    END IF;
        
    /*    ,   */
    if (((new$BudgetPromise is not null) and (:old.BudgetPromise is null)) or 
    (new$BudgetPromise <> :old.BudgetPromise)) then
      BEGIN
        select 
        ANumber 
        into BPInnerNum$       from 
        PaymentSchedule
        where 
        (InnerPromiseNum = new$BudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
            
      new$Promise := BPInnerNum$;
          
    END IF;
        
    /*    ,     */
    if ((new$BudgetPromise is null) and (:old.BudgetPromise is not null)) then
      new$Promise := null;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_CORRECTIONDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$Promise is not null and (
    (:old.Promise is null or :old.Promise <> new$Promise) or
    (:old.ExecDoc is null or new$ExecDoc is null or :old.ExecDoc <> new$ExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$Promise and ps.InnerPromiseNum = new$BudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$ExecDoc := ExecID$;
        new$ExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$ExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$ExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$ExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$ExecDoc is null or :old.ExecDoc is null or new$ExecDoc <> :old.ExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$ExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$ExecInnerNumber := ExecInnerNumber$;
            
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_CORRECTIONDETAIL_BU_700)
-- Create 13.08.2007
-- - - - - - - - - - - - -

 if (new$RVersion is null) then
   new$RVersion:=1;
 else
   if ((new$RVersion = -1) and (:Old.RVersion <> -1)) then
     new$RVersion:=:Old.RVersion;
   else
     new$RVersion:=:Old.RVersion+1;
   end if;
 end if;  

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_CORRECTIONDETAIL SET
    ID = new$ID,
    PARENTID = new$PARENTID,
    BUDGETREF = new$BUDGETREF,
    SUMMA = new$SUMMA,
    CLSTYPE = new$CLSTYPE,
    FACIALACC_CLS = new$FACIALACC_CLS,
    KVSR = new$KVSR,
    KFSR = new$KFSR,
    KCSR = new$KCSR,
    KVR = new$KVR,
    KESR = new$KESR,
    DIRECTIONCLS = new$DIRECTIONCLS,
    MEANSTYPE = new$MEANSTYPE,
    FACT = new$FACT,
    REGIONCLS = new$REGIONCLS,
    FINSOURCE = new$FINSOURCE,
    FINTYPE = new$FINTYPE,
    DOCTYPE = new$DOCTYPE,
    SUBKESR = new$SUBKESR,
    FUNDSSOURCE = new$FUNDSSOURCE,
    KD = new$KD,
    IFS = new$IFS,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    CHANGEACC_REF = new$CHANGEACC_REF,
    CHANGEACC = new$CHANGEACC,
    CHANGEORGINN = new$CHANGEORGINN,
    CHANGEORGINN20 = new$CHANGEORGINN20,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    DOCUMENTPROGINDEX = new$DOCUMENTPROGINDEX,
    DOCUMENTRECORDINDEX = new$DOCUMENTRECORDINDEX,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    RVERSION = new$RVERSION,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    NOTE = new$NOTE,
    ISCLSCHANGED = new$ISCLSCHANGED,
    PROMISE = new$PROMISE,
    BUDGETPROMISE = new$BUDGETPROMISE,
    EXECDOC = new$EXECDOC,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    TRANSFERTCLS = new$TRANSFERTCLS,
    ORIGINALCLSSUMMA = new$ORIGINALCLSSUMMA,
    NOTECLS = new$NOTECLS,
    OPERATIONTYPE = new$OPERATIONTYPE,
    REVERSEFLAG = new$REVERSEFLAG,
    EXECINNERNUMBER = new$EXECINNERNUMBER,
    CLSFIELFCHANGED = new$CLSFIELFCHANGED,
    FAORGTYPE = new$FAORGTYPE,
    SUBSIDYCLS = new$SUBSIDYCLS,
    BUDALLOCATIONCLS = new$BUDALLOCATIONCLS,
    PAYPROMISECLS = new$PAYPROMISECLS,
    NOTEQUALEX = new$NOTEQUALEX,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    INVESTOBJECT = new$INVESTOBJECT,
    CHANGEORGNAME = new$CHANGEORGNAME,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_CORRECTIONDETAIL_AU_500)
-- Create 29.12.2009
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (5504, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=5504) and (RecordId=new$ID);
  end if;

END;
/
ALTER TABLE LimitFinDetail ADD (
  TargetCls NUMBER(10),
    CHECK((TargetCls<=2147483647)AND(TargetCls>-2147483648)),
  constraint FK_LFD_TargetCls foreign key (TargetCls) references TargetCls(ID)    
)
/
CREATE INDEX FK_LFD_TargetCls ON LimitFinDetail(TargetCls)
/
ALTER TABLE TENDERPRODUCT ADD (
  TargetCls NUMBER(10),
    CHECK((TargetCls<=2147483647)AND(TargetCls>-2147483648)),
  constraint FK_TP_TargetCls foreign key (TargetCls) references TargetCls(ID)    
)
/
CREATE INDEX FK_TP_TargetCls ON TENDERPRODUCT(TargetCls)
/
ALTER TABLE BANKEXCH_SUBSTITUTION ADD (
  DestTargetCls NUMBER(10),
    CHECK((DestTargetCls<=2147483647)AND(DestTargetCls>-2147483648)),
  constraint FK_BankExchSubst_DTarC foreign key (DestTargetCls) references TargetCls(ID)
)
/
CREATE INDEX FK_BankExchSubst_DTarC ON BANKEXCH_SUBSTITUTION(DestTargetCls)
/
commit work
/

-- #########################################################
-- #########################################################
-- Alter_LayerData_ContractCostCls.sql
-- #########################################################
-- #########################################################


/* <TRANS_COMMAND>
ALTER TABLE LAYERDATA
  ADD CONTRACTCOSTCLS VARCHAR2(20)
/  

CREATE INDEX IDX_LAYERDATA_CONTRACTCOSTCLS ON LAYERDATA (CONTRACTCOSTCLS)
/

COMMIT WORK
/
*/
-- <TRANS_IGNORE>
DECLARE 
  v_exists integer;
BEGIN
  SELECT count(*) 
    INTO v_exists
    FROM USER_TAB_COLUMNS 
    WHERE TABLE_NAME='LAYERDATA' AND COLUMN_NAME='CONTRACTCOSTCLS';
  IF (v_exists=0) THEN
    EXECUTE IMMEDIATE 'ALTER TABLE LAYERDATA
      ADD CONTRACTCOSTCLS VARCHAR2(20)';

    EXECUTE IMMEDIATE 'CREATE INDEX IDX_LAYERDATA_CONTRACTCOSTCLS ON LAYERDATA (CONTRACTCOSTCLS)';
    EXECUTE IMMEDIATE 'COMMIT WORK';
  END IF;
END;
/


-- #########################################################
-- #########################################################
-- AlterAgrTrigger.sql
-- #########################################################
-- #########################################################

/*          */
-- CREATE TRIGGER tr_paymentschedule_bu_200
CREATE OR REPLACE TRIGGER TR_PAYMENTSCHEDULE_IU
  INSTEAD OF UPDATE
  ON PAYMENTSCHEDULE
  FOR EACH ROW
DECLARE
  new$ID PAYMENTSCHEDULE.ID%TYPE := :NEW.ID;
  new$ANUMBER PAYMENTSCHEDULE.ANUMBER%TYPE := :NEW.ANUMBER;
  new$PARENTNUMBER PAYMENTSCHEDULE.PARENTNUMBER%TYPE := :NEW.PARENTNUMBER;
  new$KFSR PAYMENTSCHEDULE.KFSR%TYPE := :NEW.KFSR;
  new$KESR PAYMENTSCHEDULE.KESR%TYPE := :NEW.KESR;
  new$KVSR PAYMENTSCHEDULE.KVSR%TYPE := :NEW.KVSR;
  new$KCSR PAYMENTSCHEDULE.KCSR%TYPE := :NEW.KCSR;
  new$KVR PAYMENTSCHEDULE.KVR%TYPE := :NEW.KVR;
  new$MONTH01 PAYMENTSCHEDULE.MONTH01%TYPE := :NEW.MONTH01;
  new$MONTH02 PAYMENTSCHEDULE.MONTH02%TYPE := :NEW.MONTH02;
  new$MONTH03 PAYMENTSCHEDULE.MONTH03%TYPE := :NEW.MONTH03;
  new$MONTH04 PAYMENTSCHEDULE.MONTH04%TYPE := :NEW.MONTH04;
  new$MONTH05 PAYMENTSCHEDULE.MONTH05%TYPE := :NEW.MONTH05;
  new$MONTH06 PAYMENTSCHEDULE.MONTH06%TYPE := :NEW.MONTH06;
  new$MONTH07 PAYMENTSCHEDULE.MONTH07%TYPE := :NEW.MONTH07;
  new$MONTH08 PAYMENTSCHEDULE.MONTH08%TYPE := :NEW.MONTH08;
  new$MONTH09 PAYMENTSCHEDULE.MONTH09%TYPE := :NEW.MONTH09;
  new$MONTH10 PAYMENTSCHEDULE.MONTH10%TYPE := :NEW.MONTH10;
  new$MONTH11 PAYMENTSCHEDULE.MONTH11%TYPE := :NEW.MONTH11;
  new$MONTH12 PAYMENTSCHEDULE.MONTH12%TYPE := :NEW.MONTH12;
  new$SUMMA PAYMENTSCHEDULE.SUMMA%TYPE := :NEW.SUMMA;
  new$REGION PAYMENTSCHEDULE.REGION%TYPE := :NEW.REGION;
  new$SUBKESR PAYMENTSCHEDULE.SUBKESR%TYPE := :NEW.SUBKESR;
  new$MEANSTYPE PAYMENTSCHEDULE.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FINSOURCE PAYMENTSCHEDULE.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE PAYMENTSCHEDULE.FINTYPE%TYPE := :NEW.FINTYPE;
  new$FACT PAYMENTSCHEDULE.FACT%TYPE := :NEW.FACT;
  new$FACIALACC_CLS PAYMENTSCHEDULE.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$CREATERUSER PAYMENTSCHEDULE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYMENTSCHEDULE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PAYMENTSCHEDULE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PAYMENTSCHEDULE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF PAYMENTSCHEDULE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$ACCEPTDATE PAYMENTSCHEDULE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$LASTADJUSTMENT PAYMENTSCHEDULE.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$ACCEPTED PAYMENTSCHEDULE.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED PAYMENTSCHEDULE.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$PROMISETYPE PAYMENTSCHEDULE.PROMISETYPE%TYPE := :NEW.PROMISETYPE;
  new$ADJUSTMENTREF PAYMENTSCHEDULE.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$OLDNUMBER PAYMENTSCHEDULE.OLDNUMBER%TYPE := :NEW.OLDNUMBER;
  new$SUMMAPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAPREVIOUSYEAR%TYPE := :NEW.SUMMAPREVIOUSYEAR;
  new$SUMMAFINPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAFINPREVIOUSYEAR%TYPE := :NEW.SUMMAFINPREVIOUSYEAR;
  new$QUARTER1 PAYMENTSCHEDULE.QUARTER1%TYPE := :NEW.QUARTER1;
  new$QUARTER2 PAYMENTSCHEDULE.QUARTER2%TYPE := :NEW.QUARTER2;
  new$QUARTER3 PAYMENTSCHEDULE.QUARTER3%TYPE := :NEW.QUARTER3;
  new$QUARTER4 PAYMENTSCHEDULE.QUARTER4%TYPE := :NEW.QUARTER4;
  new$RECORDINDEX PAYMENTSCHEDULE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CRYPTOSTATUS PAYMENTSCHEDULE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID PAYMENTSCHEDULE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PAYMENTSCHEDULE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DIRECTIONCLS PAYMENTSCHEDULE.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$RVERSION PAYMENTSCHEDULE.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYMENTSCHEDULE.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MONTH01DELTA PAYMENTSCHEDULE.MONTH01DELTA%TYPE := :NEW.MONTH01DELTA;
  new$MONTH02DELTA PAYMENTSCHEDULE.MONTH02DELTA%TYPE := :NEW.MONTH02DELTA;
  new$MONTH03DELTA PAYMENTSCHEDULE.MONTH03DELTA%TYPE := :NEW.MONTH03DELTA;
  new$MONTH04DELTA PAYMENTSCHEDULE.MONTH04DELTA%TYPE := :NEW.MONTH04DELTA;
  new$MONTH05DELTA PAYMENTSCHEDULE.MONTH05DELTA%TYPE := :NEW.MONTH05DELTA;
  new$MONTH06DELTA PAYMENTSCHEDULE.MONTH06DELTA%TYPE := :NEW.MONTH06DELTA;
  new$MONTH07DELTA PAYMENTSCHEDULE.MONTH07DELTA%TYPE := :NEW.MONTH07DELTA;
  new$MONTH08DELTA PAYMENTSCHEDULE.MONTH08DELTA%TYPE := :NEW.MONTH08DELTA;
  new$MONTH09DELTA PAYMENTSCHEDULE.MONTH09DELTA%TYPE := :NEW.MONTH09DELTA;
  new$MONTH10DELTA PAYMENTSCHEDULE.MONTH10DELTA%TYPE := :NEW.MONTH10DELTA;
  new$MONTH11DELTA PAYMENTSCHEDULE.MONTH11DELTA%TYPE := :NEW.MONTH11DELTA;
  new$MONTH12DELTA PAYMENTSCHEDULE.MONTH12DELTA%TYPE := :NEW.MONTH12DELTA;
  new$QUARTER1DELTA PAYMENTSCHEDULE.QUARTER1DELTA%TYPE := :NEW.QUARTER1DELTA;
  new$QUARTER2DELTA PAYMENTSCHEDULE.QUARTER2DELTA%TYPE := :NEW.QUARTER2DELTA;
  new$QUARTER3DELTA PAYMENTSCHEDULE.QUARTER3DELTA%TYPE := :NEW.QUARTER3DELTA;
  new$QUARTER4DELTA PAYMENTSCHEDULE.QUARTER4DELTA%TYPE := :NEW.QUARTER4DELTA;
  new$SUMMADELTA PAYMENTSCHEDULE.SUMMADELTA%TYPE := :NEW.SUMMADELTA;
  new$NOTE PAYMENTSCHEDULE.NOTE%TYPE := :NEW.NOTE;
  new$FINYEAR PAYMENTSCHEDULE.FINYEAR%TYPE := :NEW.FINYEAR;
  new$SUMMAYEAR1 PAYMENTSCHEDULE.SUMMAYEAR1%TYPE := :NEW.SUMMAYEAR1;
  new$SUMMAYEAR2 PAYMENTSCHEDULE.SUMMAYEAR2%TYPE := :NEW.SUMMAYEAR2;
  new$SUMMAYEAR3 PAYMENTSCHEDULE.SUMMAYEAR3%TYPE := :NEW.SUMMAYEAR3;
  new$SUMMAYEAR1DELTA PAYMENTSCHEDULE.SUMMAYEAR1DELTA%TYPE := :NEW.SUMMAYEAR1DELTA;
  new$SUMMAYEAR2DELTA PAYMENTSCHEDULE.SUMMAYEAR2DELTA%TYPE := :NEW.SUMMAYEAR2DELTA;
  new$SUMMAYEAR3DELTA PAYMENTSCHEDULE.SUMMAYEAR3DELTA%TYPE := :NEW.SUMMAYEAR3DELTA;
  new$ASSIGNMENTKIND PAYMENTSCHEDULE.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$TRANSFERTCLS PAYMENTSCHEDULE.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SENDERIDKEY PAYMENTSCHEDULE.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY PAYMENTSCHEDULE.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXECUTIONREF PAYMENTSCHEDULE.EXECUTIONREF%TYPE := :NEW.EXECUTIONREF;
  new$INNERPROMISENUM PAYMENTSCHEDULE.INNERPROMISENUM%TYPE := :NEW.INNERPROMISENUM;
  new$ADJUSTMENTNUMBER PAYMENTSCHEDULE.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$PROMISENUMBER PAYMENTSCHEDULE.PROMISENUMBER%TYPE := :NEW.PROMISENUMBER;
  new$SUBSIDYCLS PAYMENTSCHEDULE.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$AGREEMENTREF PAYMENTSCHEDULE.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$BUDALLOCATIONCLS PAYMENTSCHEDULE.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS PAYMENTSCHEDULE.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$PROGINDEX PAYMENTSCHEDULE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$INVESTOBJECT PAYMENTSCHEDULE.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$SUMMAYEAR4 PAYMENTSCHEDULE.SUMMAYEAR4%TYPE := :NEW.SUMMAYEAR4;
  new$SUMMAOTHERYEARS PAYMENTSCHEDULE.SUMMAOTHERYEARS%TYPE := :NEW.SUMMAOTHERYEARS;
  new$SUMMAYEAR4DELTA PAYMENTSCHEDULE.SUMMAYEAR4DELTA%TYPE := :NEW.SUMMAYEAR4DELTA;
  new$SUMMAOTHERYEARSDELTA PAYMENTSCHEDULE.SUMMAOTHERYEARSDELTA%TYPE := :NEW.SUMMAOTHERYEARSDELTA;
  new$CONTRACTCOSTSCLS PAYMENTSCHEDULE.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS PAYMENTSCHEDULE.TARGETCLS%TYPE := :NEW.TARGETCLS;
--
  M01$ NUMBER;
  M02$ NUMBER;
  M03$ NUMBER;
  M04$ NUMBER;
  M05$ NUMBER;
  M06$ NUMBER;
  M07$ NUMBER;
  M08$ NUMBER;
  M09$ NUMBER;
  M10$ NUMBER;
  M11$ NUMBER;
  M12$ NUMBER;
  Q1$ NUMBER;
  Q2$ NUMBER;
  Q3$ NUMBER;
  Q4$ NUMBER;
  S$ NUMBER;
  S1$ NUMBER;
  S2$ NUMBER;
  S3$ NUMBER;
  MaxNumber1$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  S4$ NUMBER;
  SOther$ NUMBER;
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_PAYMENTSCHEDULE_BU)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*   2.4*/
  /*    -*/
  if (new$Accepted is null) then 
    new$Accepted := 1;
  END IF;
  if (new$PromiseType is null) then 
    new$PromiseType := 0;
  END IF;
  if (new$KFSR is null) then 
    new$KFSR := 0;
  END IF;
  if (new$KESR is null) then 
    new$KESR := 0;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$KCSR is null) then 
    new$KCSR := 0;
  END IF;
  if (new$KVR is null) then 
    new$KVR := 0;
  END IF;
  if (new$SubKESR is null) then 
    new$SubKESR := 0;
  END IF;
  if (new$AssignmentKind is null) then 
    new$AssignmentKind := 0;
  END IF;
   
  if (new$DirectionCls is null) then 
    new$DirectionCls := 0;
  END IF;
   
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Region is null) then 
    new$Region := 0;
  END IF;
  if (new$MeansType is null) then 
    new$MeansType := 0;
  END IF;
  if (new$FinSource is null) then 
    new$FinSource := 0;
  END IF;
  if (new$FinType is null) then 
    new$FinType := 0;
  END IF;
  if (new$Fact is null) then 
    new$Fact := 0;
  END IF;
  if (new$BuhOperationCLS is null) then 
    GetIntConst(60, 15,new$BuhOperationCLS); 
  END IF;
  if (new$Month01 is null) then 
    new$Month01 := 0;
  END IF;
  if (new$Month02 is null) then 
    new$Month02 := 0;
  END IF;
  if (new$Month03 is null) then 
    new$Month03 := 0;
  END IF;
  if (new$Month04 is null) then 
    new$Month04 := 0;
  END IF;
  if (new$Month05 is null) then 
    new$Month05 := 0;
  END IF;
  if (new$Month06 is null) then 
    new$Month06 := 0;
  END IF;
  if (new$Month07 is null) then 
    new$Month07 := 0;
  END IF;
  if (new$Month08 is null) then 
    new$Month08 := 0;
  END IF;
  if (new$Month09 is null) then 
    new$Month09 := 0;
  END IF;
  if (new$Month10 is null) then 
    new$Month10 := 0;
  END IF;
  if (new$Month11 is null) then 
    new$Month11 := 0;
  END IF;
  if (new$Month12 is null) then 
    new$Month12 := 0;
  END IF;
  if (new$Quarter1 is null) then 
    new$Quarter1 := 0;
  END IF;
  if (new$Quarter2 is null) then 
    new$Quarter2 := 0;
  END IF;
  if (new$Quarter3 is null) then 
    new$Quarter3 := 0;
  END IF;
  if (new$Quarter4 is null) then 
    new$Quarter4 := 0;
  END IF;
  if (new$Summa is null) then 
    new$Summa := 0;
  END IF;
  if (new$Month01Delta is null) then 
    new$Month01Delta := 0;
  END IF;
  if (new$Month02Delta is null) then 
    new$Month02Delta := 0;
  END IF;
  if (new$Month03Delta is null) then 
    new$Month03Delta := 0;
  END IF;
  if (new$Month04Delta is null) then 
    new$Month04Delta := 0;
  END IF;
  if (new$Month05Delta is null) then 
    new$Month05Delta := 0;
  END IF;
  if (new$Month06Delta is null) then 
    new$Month06Delta := 0;
  END IF;
  if (new$Month07Delta is null) then 
    new$Month07Delta := 0;
  END IF;
  if (new$Month08Delta is null) then 
    new$Month08Delta := 0;
  END IF;
  if (new$Month09Delta is null) then 
    new$Month09Delta := 0;
  END IF;
  if (new$Month10Delta is null) then 
    new$Month10Delta := 0;
  END IF;
  if (new$Month11Delta is null) then 
    new$Month11Delta := 0;
  END IF;
  if (new$Month12Delta is null) then 
    new$Month12Delta := 0;
  END IF;
  if (new$Quarter1Delta is null) then 
    new$Quarter1Delta := 0;
  END IF;
  if (new$Quarter2Delta is null) then 
    new$Quarter2Delta := 0;
  END IF;
  if (new$Quarter3Delta is null) then 
    new$Quarter3Delta := 0;
  END IF;
  if (new$Quarter4Delta is null) then 
    new$Quarter4Delta := 0;
  END IF;
  if (new$SummaDelta is null) then 
    new$SummaDelta := 0; 
  END IF;
  if (new$SummaPreviousYear is null) then 
    new$SummaPreviousYear := 0;
  END IF;
  if (new$SummaFinPreviousYear is null) then 
    new$SummaFinPreviousYear := 0;
  END IF;
   
  if (new$SummaYear1 is null) then 
    new$SummaYear1 := 0;
  END IF;
  if (new$SummaYear2 is null) then 
    new$SummaYear2 := 0;
  END IF;
  if (new$SummaYear3 is null) then 
    new$SummaYear3 := 0;
  END IF;
  if (new$SummaYear4 is null) then 
    new$SummaYear4 := 0;
  END IF;
  if (new$SummaOtherYears is null) then 
    new$SummaOtherYears := 0;
  END IF;
   
  if (new$SummaYear1Delta is null) then 
    new$SummaYear1Delta := 0;
  END IF;
  if (new$SummaYear2Delta is null) then 
    new$SummaYear2Delta := 0;
  END IF;
  if (new$SummaYear3Delta is null) then 
    new$SummaYear3Delta := 0;
  END IF;
  if (new$SummaYear4Delta is null) then 
    new$SummaYear4Delta := 0;
  END IF;
  if (new$SummaOtherYearsDelta is null) then 
    new$SummaOtherYearsDelta := 0;
  END IF;
   
  /*   ,        */
  if (new$ProgIndex = 304 and new$RecordIndex is not null and (:old.RecordIndex is null or :old.RecordIndex <> new$RecordIndex)) then
    SELECT COUNT(*) INTO CNT$1
    from AgreementSteps s where (s.Id = new$RecordIndex and s.RecordIndex = new$AgreementRef) AND (ROWNUM = 1);
    if (not (CNT$1<> 0)) then
      RaiseException('Ex_WrongStep');
    END IF;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      RaiseException('Ex_CantModufyBudget');
    END IF;
  END IF;
  if ((:old.ANumber is null) and (new$ANumber is not Null)) then
    SELECT COUNT(                    id
    ) INTO CNT$2
    from
    PaymentSchedule ps
    where
    (                    (ps.ANumber = new$ANumber)
    and
    (ps.BudgetRef = new$BudgetRef)) AND (ROWNUM = 1);
    if ((CNT$2<> 0)) then
      RaiseException('ex_Promise_NumUQ');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_1 (TR_PAYMENTSCHEDULE_BU_1)
-- Create 05.03.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  /*   1.0*/
    if (new$Quarter1 = 0) then new$Quarter1 := new$Month01 + new$Month02 + new$Month03; end if;
    if (new$Quarter2 = 0) then new$Quarter2 := new$Month04 + new$Month05 + new$Month06; end if;
    if (new$Quarter3 = 0) then new$Quarter3 := new$Month07 + new$Month08 + new$Month09; end if;
    if (new$Quarter4 = 0) then new$Quarter4 := new$Month10 + new$Month11 + new$Month12; end if;
    new$SummaYear1 := new$Quarter1 + new$Quarter2 + new$Quarter3 + new$Quarter4;

-- - - - - - - - - - - - -
-- BU_3 (TR_PAYMENTSCHEDULE_BU_3)
-- Create 03.12.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

    /*            */
    new$AdjustmentRef := :old.AdjustmentRef;

-- - - - - - - - - - - - -
-- BU_10 (TR_PAYMENTSCHEDULE_BU_10)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*   5.0*/
  /* ,      ,   */
  if ((new$ANumber <> :old.ANumber) or
  (new$InnerPromiseNum <> :old.InnerPromiseNum) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber)) then
    RaiseException('EX_AGR_ChangeInnerNums');
  END IF;
      
  /*   !!!*/
  if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and 
  ((new$Accepted = 1) or (new$AcceptDate is null))) then
    RaiseException('EX_RollbackCancel');
  END IF;
  /*   ,     LastAccepted*/
  if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) or 
  ((:old.Accepted = 0) and (new$Accepted = 1) and (new$AcceptDate is not null))) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;
              
    else
      RaiseException('EX_BP_ChangeStateAdjust');    
    END IF;
  END IF;
      
  /*    ,     LastAccepted*/
  if (((:old.AcceptDate is not null) and (:old.Accepted = 1)) and
  ((new$Accepted = 0) or (new$AcceptDate is null))) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 0;
              
    else
      RaiseException('EX_BP_ChangeStateAdjust');    
    END IF;
  END IF;
      
  /*   ,     LastAdjustment*/
  if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 0)) or 
  ((:old.Accepted = 1) and (new$Accepted = 0) and (new$AcceptDate is not null))) then
    if (new$LastAdjustment = 1) then
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
              
    else
      RaiseException('EX_AGR_ChangeStateAdjust');
    END IF;

    select max(AdjustmentNumber) into MaxNumber1$ from PaymentSchedule 
    where (InnerPromiseNum = new$InnerPromiseNum) ;
    /*    ,     */
    if ((new$adjustmentNumber=0) and (MaxNumber1$<>0))
    then 
      RaiseException('EX_BP_PrimaryBPHasNotify');    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_PAYMENTSCHEDULE_BU_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*           */  
  if (new$AdjustmentNumber > 0) then
    BEGIN
      select 
      Month01, Month02, Month03, Month04, Month05, Month06,
      Month07, Month08, Month09, Month10, Month11, Month12,
      Quarter1, Quarter2, Quarter3, Quarter4, Summa,
      SummaYear1, SummaYear2, SummaYear3, SummaYear4, SummaOtherYears
      into
      M01$, M02$, M03$, M04$, M05$, M06$, M07$, M08$, M09$, M10$, M11$, M12$, 
      Q1$, Q2$, Q3$, Q4$, S$, S1$, S2$, S3$, S4$, SOther$         from 
      PaymentSchedule
      where
      ID = new$AdjustmentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
          
    new$Month01Delta := new$Month01 - M01$;
    new$Month02Delta := new$Month02 - M02$;
    new$Month03Delta := new$Month03 - M03$;
    new$Month04Delta := new$Month04 - M04$;
    new$Month05Delta := new$Month05 - M05$;
    new$Month06Delta := new$Month06 - M06$;
    new$Month07Delta := new$Month07 - M07$;
    new$Month08Delta := new$Month08 - M08$;
    new$Month09Delta := new$Month09 - M09$;
    new$Month10Delta := new$Month10 - M10$;
    new$Month11Delta := new$Month11 - M11$;
    new$Month12Delta := new$Month12 - M12$;
    new$Quarter1Delta := new$Quarter1 - Q1$;
    new$Quarter2Delta := new$Quarter2 - Q2$;
    new$Quarter3Delta := new$Quarter3 - Q3$;
    new$Quarter4Delta := new$Quarter4 - Q4$;
    new$SummaDelta := new$Summa - S$;
    new$SummaYear1Delta := new$SummaYear1 - S1$;
    new$SummaYear2Delta := new$SummaYear2 - S2$;
    new$SummaYear3Delta := new$SummaYear3 - S3$;
    new$SummaYear4Delta := new$SummaYear4 - S4$;
    new$SummaOtherYearsDelta := new$SummaOtherYears - SOther$;
        
  else /*        */  
    new$Month01Delta := new$Month01;
    new$Month02Delta := new$Month02;
    new$Month03Delta := new$Month03;
    new$Month04Delta := new$Month04;
    new$Month05Delta := new$Month05;
    new$Month06Delta := new$Month06;
    new$Month07Delta := new$Month07;
    new$Month08Delta := new$Month08;
    new$Month09Delta := new$Month09;
    new$Month10Delta := new$Month10;
    new$Month11Delta := new$Month11;
    new$Month12Delta := new$Month12;
    new$Quarter1Delta := new$Quarter1;
    new$Quarter2Delta := new$Quarter2;
    new$Quarter3Delta := new$Quarter3;
    new$Quarter4Delta := new$Quarter4;
    new$SummaDelta := new$Summa;
    new$SummaYear1Delta := new$SummaYear1;
    new$SummaYear2Delta := new$SummaYear2;
    new$SummaYear3Delta := new$SummaYear3;
    new$SummaYear4Delta := new$SummaYear4;
    new$SummaOtherYearsDelta := new$SummaOtherYears;        
        
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_PAYMENTSCHEDULE_BU_200)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*    */
  if (new$Accepted = 0 and new$AcceptDate is not null and :old.Accepted = 1) then
    /*   ,     
         *    ,      */
    FOR REC$1 IN (      select ffc.Reject_Cls  AS DocumentRejectCls from FacialFinDetail ffd
    left join FacialFinCaption ffc on (ffc.ID = ffd.RecordIndex)
    where SourcePromise = new$ANumber and SourceBudgetPromise = new$InnerPromiseNum
    or DestPromise = new$ANumber and DestBudgetPromise = new$InnerPromiseNum
    )
    LOOP
      if (REC$1.DocumentRejectCls is null) then
        RaiseException('Ex_BP_CannotReject');    
      END IF;
    END LOOP;
    /* ,         */
    FOR REC$1 IN (      SELECT Count(ps_in.ID)  AS AdjCount FROM PaymentSchedule ps_in
    WHERE (ps_in.InnerPromiseNum = new$InnerPromiseNum)and(ps_in.AdjustmentNumber > new$AdjustmentNumber)
    and (ps_in.Accepted<>0) 
    )
    LOOP
      if (REC$1.AdjCount > 0) then
        RaiseException('EX_BP_AdjustmentedCANNOTREJECT');    
      END IF;
    END LOOP;
  END IF;
  /*   .       */
  if (new$Accepted = 1 and new$AcceptDate is null and :old.Accepted = 1 and :old.AcceptDate is not null) then
    SELECT COUNT(ffc.Reject_Cls ) INTO CNT$1
    from FacialFinDetail ffd
    left join FacialFinCaption ffc on (ffc.ID = ffd.RecordIndex)
    where ((SourcePromise = new$ANumber and SourceBudgetPromise = new$InnerPromiseNum
    or DestPromise = new$ANumber and DestBudgetPromise = new$InnerPromiseNum)
    and ffc.acceptdate is not null and ffc.Reject_cls is null) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_BP_NOTACCEPTED');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (tr_PaymentSchedule_BU_400)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$AgreementRef <> :old.AgreementRef or new$ExecutionRef <> :old.ExecutionRef) then
    RaiseException('EX_CANTCHANGECAPTIONREF');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_PAYMENTSCHEDULE_BU_700)
-- Create 14.10.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$RVersion is null) then
    new$RVersion := 1;
  elsif ((new$RVersion = -1) and (:Old.RVersion <> -1)) then
    new$RVersion := :Old.RVersion;
  else
    new$RVersion := :Old.RVersion + 1;
  end if;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_PAYMENTSCHEDULE SET
    ID = new$ID,
    ANUMBER = new$ANUMBER,
    PARENTNUMBER = new$PARENTNUMBER,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVSR = new$KVSR,
    KCSR = new$KCSR,
    KVR = new$KVR,
    MONTH01 = new$MONTH01,
    MONTH02 = new$MONTH02,
    MONTH03 = new$MONTH03,
    MONTH04 = new$MONTH04,
    MONTH05 = new$MONTH05,
    MONTH06 = new$MONTH06,
    MONTH07 = new$MONTH07,
    MONTH08 = new$MONTH08,
    MONTH09 = new$MONTH09,
    MONTH10 = new$MONTH10,
    MONTH11 = new$MONTH11,
    MONTH12 = new$MONTH12,
    SUMMA = new$SUMMA,
    REGION = new$REGION,
    SUBKESR = new$SUBKESR,
    MEANSTYPE = new$MEANSTYPE,
    FINSOURCE = new$FINSOURCE,
    FINTYPE = new$FINTYPE,
    FACT = new$FACT,
    FACIALACC_CLS = new$FACIALACC_CLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    ACCEPTDATE = new$ACCEPTDATE,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    ACCEPTED = new$ACCEPTED,
    LASTACCEPTED = new$LASTACCEPTED,
    PROMISETYPE = new$PROMISETYPE,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    OLDNUMBER = new$OLDNUMBER,
    SUMMAPREVIOUSYEAR = new$SUMMAPREVIOUSYEAR,
    SUMMAFINPREVIOUSYEAR = new$SUMMAFINPREVIOUSYEAR,
    QUARTER1 = new$QUARTER1,
    QUARTER2 = new$QUARTER2,
    QUARTER3 = new$QUARTER3,
    QUARTER4 = new$QUARTER4,
    RECORDINDEX = new$RECORDINDEX,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DIRECTIONCLS = new$DIRECTIONCLS,
    RVERSION = new$RVERSION,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    MONTH01DELTA = new$MONTH01DELTA,
    MONTH02DELTA = new$MONTH02DELTA,
    MONTH03DELTA = new$MONTH03DELTA,
    MONTH04DELTA = new$MONTH04DELTA,
    MONTH05DELTA = new$MONTH05DELTA,
    MONTH06DELTA = new$MONTH06DELTA,
    MONTH07DELTA = new$MONTH07DELTA,
    MONTH08DELTA = new$MONTH08DELTA,
    MONTH09DELTA = new$MONTH09DELTA,
    MONTH10DELTA = new$MONTH10DELTA,
    MONTH11DELTA = new$MONTH11DELTA,
    MONTH12DELTA = new$MONTH12DELTA,
    QUARTER1DELTA = new$QUARTER1DELTA,
    QUARTER2DELTA = new$QUARTER2DELTA,
    QUARTER3DELTA = new$QUARTER3DELTA,
    QUARTER4DELTA = new$QUARTER4DELTA,
    SUMMADELTA = new$SUMMADELTA,
    NOTE = new$NOTE,
    FINYEAR = new$FINYEAR,
    SUMMAYEAR1 = new$SUMMAYEAR1,
    SUMMAYEAR2 = new$SUMMAYEAR2,
    SUMMAYEAR3 = new$SUMMAYEAR3,
    SUMMAYEAR1DELTA = new$SUMMAYEAR1DELTA,
    SUMMAYEAR2DELTA = new$SUMMAYEAR2DELTA,
    SUMMAYEAR3DELTA = new$SUMMAYEAR3DELTA,
    ASSIGNMENTKIND = new$ASSIGNMENTKIND,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    EXECUTIONREF = new$EXECUTIONREF,
    INNERPROMISENUM = new$INNERPROMISENUM,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    PROMISENUMBER = new$PROMISENUMBER,
    SUBSIDYCLS = new$SUBSIDYCLS,
    AGREEMENTREF = new$AGREEMENTREF,
    BUDALLOCATIONCLS = new$BUDALLOCATIONCLS,
    PAYPROMISECLS = new$PAYPROMISECLS,
    PROGINDEX = new$PROGINDEX,
    INVESTOBJECT = new$INVESTOBJECT,
    SUMMAYEAR4 = new$SUMMAYEAR4,
    SUMMAOTHERYEARS = new$SUMMAOTHERYEARS,
    SUMMAYEAR4DELTA = new$SUMMAYEAR4DELTA,
    SUMMAOTHERYEARSDELTA = new$SUMMAOTHERYEARSDELTA,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_10 (TR_PAYMENTSCHEDULE_AU_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/

  /*      */
  /*     ,       */
  if ((new$AdjustmentNumber > 0) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update PaymentSchedule set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment    */
  if ((new$AdjustmentNumber > 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and 
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update PaymentSchedule set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_PAYMENTSCHEDULE_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (113, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=113) and (RecordId=new$ID);
  end if;

END;
/
commit work
/

-- #########################################################
-- #########################################################
-- AlterProtocolNames.sql
-- #########################################################
-- #########################################################

/*           */
CREATE OR REPLACE procedure AddProtocolDocType(ID$ NUMBER,Name$ VARCHAR2,AType$ NUMBER)
AS
  CNT$1 NUMBER(10);
BEGIN
  SELECT COUNT(id ) INTO CNT$1
  from ProtocolDoctype where (id = ID$) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    update ProtocolDocType set Name = Name$, AType = AType$  where id = ID$;
  END IF;
END;
/
-- ALTER TRIGGER TR_ProtocolDocType_BU
CREATE OR REPLACE TRIGGER TR_PROTOCOLDOCTYPE_BU
  BEFORE UPDATE
  ON PROTOCOLDOCTYPE
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_ProtocolDocType_BU)
-- Version 8.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (not ((:new.id in (7,12)) and (:old.id in (7,12)) and (:new.AType = :old.AType))) then
--     RaiseException('EX_PDT_BanUpdate');
--   END IF;

END;
/
CALL AddProtocolDocType(6, '         ', 124)
/
CALL AddProtocolDocType(10, '   ', 124)
/
CALL AddProtocolDocType(11, '    ', 124)
/
CALL AddProtocolDocType(19, '        ', 124)
/
-- ALTER TRIGGER TR_ProtocolDocType_BU
CREATE OR REPLACE TRIGGER TR_PROTOCOLDOCTYPE_BU
  BEFORE UPDATE
  ON PROTOCOLDOCTYPE
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_ProtocolDocType_BU)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (not ((:new.id in (7,12)) and (:old.id in (7,12)) and (:new.AType = :old.AType))) then
    RaiseException('EX_PDT_BanUpdate');
  END IF;

END;
/
drop procedure AddProtocolDocType
/
commit work
/

-- #########################################################
-- #########################################################
-- Add_Agreements_DocumentNumber.sql
-- #########################################################
-- #########################################################

/*    Agreements  DocumentNumber -   */
ALTER TABLE TB_Agreements ADD (
  DocumentNumber VARCHAR2(150)/*   */
)
/

CREATE OR REPLACE VIEW Agreements (
  ID,
  SUMMA,
  AGREEMENTDATE,
  AGREEMENTENDDATE,
  EXECUTER_REF,
  CLIENT_REF,
  FACIALACC_CLS,
  AGREEMENTTYPE,
  ACCEPTED,
  ACCEPTDATE,
  CARDADVANCEPERCENT,
  CARDADVANCE,
  CLOSEDOC,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  BUDGETREF,
  LASTADJUSTMENT,
  LASTACCEPTED,
  FACT,
  REGION,
  CLOSEDATE,
  DELIVERYRULES,
  AGREEMENTSUMMA,
  AGREEMENTFINSUMMA,
  ADJUSTMENTREF,
  REESTRNUMBER,
  PAYMENTDATE,
  AGREEMENTCARDADVANCE,
  FINCARDADVANCE,
  STATEORDERREF,
  REJECTCLS,
  REJECTCAUSE,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  AGREEMENTBEGINDATE,
  PROTOCOLNUMBER,
  PROTOCOLDATE,
  REVIEWNOTE,
  DOCSTATEREF,
  RVERSION,
  EXPORTDATE,
  FSORGAN,
  FSBUDGETNAME,
  FSOFFBUDGET,
  RNYEAR,
  RNNUMBER,
  RNDATE,
  PROTOCOLNOTICE,
  PROTOCOLRESULTDATE,
  PROTOCOLDOCTYPE,
  PROTOCOLSALETYPE,
  NOTIFYDATE,
  EXECUTERACCREF,
  DOCBASEDATE,
  DOCBASENOTIFYDATE,
  DOCBASETEXT,
  DOCBASETYPE,
  DOCBASESUMMA,
  UNKNOWNAMOUNT,
  PROTOCOLREASON,
  DOCNUMBER,
  ADJUSTMENTDOCNUMBER,
  OLDDOCNUMBER,
  LOTMAXSUM,
  CLIENT_INN,
  CLIENT_INN20,
  CLIENT_NAME,
  EXECUTER_INN,
  EXECUTER_INN20,
  EXECUTER_NAME,
  EXECUTER_STATUS,
  EXECUTER_COUNTRY,
  EXECUTER_ADDRESS,
  EXECUTER_PHONE,
  REALID,
  ADJUSTMENTNUMBER,
  INNERNUMBER,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  REESTRVERSION,
  DOCTYPE,
  RNCLIENTID,
  INFONUMBER,
  STATEORDERINNERNUMBER,
  PROGINDEX,
  NOTE,
  PURPORTDOC,
  REESTRRECORDNUMBER,
  EXECUTERSTOREDPROPS,
  AUTOSANCTION,
  PURCHASECODE,
  DOCUMENTNUMBER)
AS
  SELECT
    ID,
    SUMMA,
    AGREEMENTDATE,
    AGREEMENTENDDATE,
    EXECUTER_REF,
    CLIENT_REF,
    FACIALACC_CLS,
    AGREEMENTTYPE,
    ACCEPTED,
    ACCEPTDATE,
    CARDADVANCEPERCENT,
    CARDADVANCE,
    CLOSEDOC,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    LASTADJUSTMENT,
    LASTACCEPTED,
    FACT,
    REGION,
    CLOSEDATE,
    DELIVERYRULES,
    AGREEMENTSUMMA,
    AGREEMENTFINSUMMA,
    ADJUSTMENTREF,
    REESTRNUMBER,
    PAYMENTDATE,
    AGREEMENTCARDADVANCE,
    FINCARDADVANCE,
    STATEORDERREF,
    REJECTCLS,
    REJECTCAUSE,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    AGREEMENTBEGINDATE,
    PROTOCOLNUMBER,
    PROTOCOLDATE,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXPORTDATE,
    FSORGAN,
    FSBUDGETNAME,
    FSOFFBUDGET,
    RNYEAR,
    RNNUMBER,
    RNDATE,
    PROTOCOLNOTICE,
    PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE,
    NOTIFYDATE,
    EXECUTERACCREF,
    DOCBASEDATE,
    DOCBASENOTIFYDATE,
    DOCBASETEXT,
    DOCBASETYPE,
    DOCBASESUMMA,
    UNKNOWNAMOUNT,
    PROTOCOLREASON,
    DOCNUMBER,
    ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER,
    LOTMAXSUM,
    CLIENT_INN,
    CLIENT_INN20,
    CLIENT_NAME,
    EXECUTER_INN,
    EXECUTER_INN20,
    EXECUTER_NAME,
    EXECUTER_STATUS,
    EXECUTER_COUNTRY,
    EXECUTER_ADDRESS,
    EXECUTER_PHONE,
    REALID,
    ADJUSTMENTNUMBER,
    INNERNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REESTRVERSION,
    DOCTYPE,
    RNCLIENTID,
    INFONUMBER,
    STATEORDERINNERNUMBER,
    PROGINDEX,
    NOTE,
    PURPORTDOC,
    REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS,
    AUTOSANCTION,
    PURCHASECODE,
    DOCUMENTNUMBER
  FROM TB_Agreements
/

CREATE OR REPLACE TRIGGER TR_AGREEMENTS_ID
  INSTEAD OF DELETE
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  cnt1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_AGREEMENTS_BD)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*   5.0*/
  select count(id) into cnt1$ from agreements where (adjustmentref = :old.id) ;
  /*  .       .*/
  if (cnt1$ = 0) then
    delete from estimate where (recordindex = :old.id);
    delete from agreementsteps where (recordindex = :old.id);
    delete from paymentschedule where agreementref = :old.id;

  else
    RaiseException('ex_agr_cantdeladjustmented');
  END IF;

-- - - - - - - - - - - - -
-- BD_20 (TR_AGREEMENTS_BD_20)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  /*          */
  if ((:old.ProgIndex = 305)and(:old.AdjustmentNumber = 0)) then
    update tenderresultcaption set
    StateOrder = null
    where
    StateOrder = :old.ID;
  END IF;
  if ((:old.ProgIndex = 314)and(:old.AdjustmentNumber = 0)) then
    update tenderresultcaption set
    StateOrder = null,
    Agreement = null
    where
    StateOrder = :old.ID;
  END IF;
  if ((:old.ProgIndex = 304)and(:old.AdjustmentNumber = 0)) then
    update tenderresultcaption set
    Agreement = null
    where
    Agreement = :old.ID;
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_AGREEMENTS
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_10 (TR_AGREEMENTS_AD_10)
-- Last update 05.02.2010
-- - - - - - - - - - - - -

/*   5.0*/
    /*   LastAdjustment     */
    if ((:old.AdjustmentNumber > 0) and (:old.LastAdjustment = 1)) then
        update Agreements set
            LastAdjustment = 1,
            RVersion = -1
        where (ID = :old.AdjustmentRef);
    end if;
    /*   LastAccepted     */
    if ((:old.AdjustmentNumber > 0) and (:old.LastAccepted = 1)) then
        update Agreements set
            LastAccepted = 1,
            RVersion = -1
        where (ID = :old.AdjustmentRef);
    end if;

-- - - - - - - - - - - - -
-- AD_200 (TR_AGREEMENTS_AD_200)
-- Create 04.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

  /*        */
  delete from StateJumpHistory where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_AGREEMENTS_AD_500)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordId, DeleteDate, Summa, ProgIndex)
  values (110, :old.ID, SYSDATE, :old.AgreementSumma, :old.ProgIndex);

END;
/

CREATE OR REPLACE TRIGGER TR_AGREEMENTS_II
  INSTEAD OF INSERT
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  new$ID AGREEMENTS.ID%TYPE := :NEW.ID;
  new$SUMMA AGREEMENTS.SUMMA%TYPE := :NEW.SUMMA;
  new$AGREEMENTDATE AGREEMENTS.AGREEMENTDATE%TYPE := :NEW.AGREEMENTDATE;
  new$AGREEMENTENDDATE AGREEMENTS.AGREEMENTENDDATE%TYPE := :NEW.AGREEMENTENDDATE;
  new$EXECUTER_REF AGREEMENTS.EXECUTER_REF%TYPE := :NEW.EXECUTER_REF;
  new$CLIENT_REF AGREEMENTS.CLIENT_REF%TYPE := :NEW.CLIENT_REF;
  new$FACIALACC_CLS AGREEMENTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$AGREEMENTTYPE AGREEMENTS.AGREEMENTTYPE%TYPE := :NEW.AGREEMENTTYPE;
  new$ACCEPTED AGREEMENTS.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$ACCEPTDATE AGREEMENTS.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$CARDADVANCEPERCENT AGREEMENTS.CARDADVANCEPERCENT%TYPE := :NEW.CARDADVANCEPERCENT;
  new$CARDADVANCE AGREEMENTS.CARDADVANCE%TYPE := :NEW.CARDADVANCE;
  new$CLOSEDOC AGREEMENTS.CLOSEDOC%TYPE := :NEW.CLOSEDOC;
  new$CREATERUSER AGREEMENTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE AGREEMENTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE AGREEMENTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER AGREEMENTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF AGREEMENTS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$LASTADJUSTMENT AGREEMENTS.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED AGREEMENTS.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$FACT AGREEMENTS.FACT%TYPE := :NEW.FACT;
  new$REGION AGREEMENTS.REGION%TYPE := :NEW.REGION;
  new$CLOSEDATE AGREEMENTS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$DELIVERYRULES AGREEMENTS.DELIVERYRULES%TYPE := :NEW.DELIVERYRULES;
  new$AGREEMENTSUMMA AGREEMENTS.AGREEMENTSUMMA%TYPE := :NEW.AGREEMENTSUMMA;
  new$AGREEMENTFINSUMMA AGREEMENTS.AGREEMENTFINSUMMA%TYPE := :NEW.AGREEMENTFINSUMMA;
  new$ADJUSTMENTREF AGREEMENTS.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$REESTRNUMBER AGREEMENTS.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$PAYMENTDATE AGREEMENTS.PAYMENTDATE%TYPE := :NEW.PAYMENTDATE;
  new$AGREEMENTCARDADVANCE AGREEMENTS.AGREEMENTCARDADVANCE%TYPE := :NEW.AGREEMENTCARDADVANCE;
  new$FINCARDADVANCE AGREEMENTS.FINCARDADVANCE%TYPE := :NEW.FINCARDADVANCE;
  new$STATEORDERREF AGREEMENTS.STATEORDERREF%TYPE := :NEW.STATEORDERREF;
  new$REJECTCLS AGREEMENTS.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTCAUSE AGREEMENTS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CRYPTOSTATUS AGREEMENTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID AGREEMENTS.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID AGREEMENTS.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$AGREEMENTBEGINDATE AGREEMENTS.AGREEMENTBEGINDATE%TYPE := :NEW.AGREEMENTBEGINDATE;
  new$PROTOCOLNUMBER AGREEMENTS.PROTOCOLNUMBER%TYPE := :NEW.PROTOCOLNUMBER;
  new$PROTOCOLDATE AGREEMENTS.PROTOCOLDATE%TYPE := :NEW.PROTOCOLDATE;
  new$REVIEWNOTE AGREEMENTS.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF AGREEMENTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION AGREEMENTS.RVERSION%TYPE := :NEW.RVERSION;
  new$EXPORTDATE AGREEMENTS.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$FSORGAN AGREEMENTS.FSORGAN%TYPE := :NEW.FSORGAN;
  new$FSBUDGETNAME AGREEMENTS.FSBUDGETNAME%TYPE := :NEW.FSBUDGETNAME;
  new$FSOFFBUDGET AGREEMENTS.FSOFFBUDGET%TYPE := :NEW.FSOFFBUDGET;
  new$RNYEAR AGREEMENTS.RNYEAR%TYPE := :NEW.RNYEAR;
  new$RNNUMBER AGREEMENTS.RNNUMBER%TYPE := :NEW.RNNUMBER;
  new$RNDATE AGREEMENTS.RNDATE%TYPE := :NEW.RNDATE;
  new$PROTOCOLNOTICE AGREEMENTS.PROTOCOLNOTICE%TYPE := :NEW.PROTOCOLNOTICE;
  new$PROTOCOLRESULTDATE AGREEMENTS.PROTOCOLRESULTDATE%TYPE := :NEW.PROTOCOLRESULTDATE;
  new$PROTOCOLDOCTYPE AGREEMENTS.PROTOCOLDOCTYPE%TYPE := :NEW.PROTOCOLDOCTYPE;
  new$PROTOCOLSALETYPE AGREEMENTS.PROTOCOLSALETYPE%TYPE := :NEW.PROTOCOLSALETYPE;
  new$NOTIFYDATE AGREEMENTS.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$EXECUTERACCREF AGREEMENTS.EXECUTERACCREF%TYPE := :NEW.EXECUTERACCREF;
  new$DOCBASEDATE AGREEMENTS.DOCBASEDATE%TYPE := :NEW.DOCBASEDATE;
  new$DOCBASENOTIFYDATE AGREEMENTS.DOCBASENOTIFYDATE%TYPE := :NEW.DOCBASENOTIFYDATE;
  new$DOCBASETEXT AGREEMENTS.DOCBASETEXT%TYPE := :NEW.DOCBASETEXT;
  new$DOCBASETYPE AGREEMENTS.DOCBASETYPE%TYPE := :NEW.DOCBASETYPE;
  new$DOCBASESUMMA AGREEMENTS.DOCBASESUMMA%TYPE := :NEW.DOCBASESUMMA;
  new$UNKNOWNAMOUNT AGREEMENTS.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PROTOCOLREASON AGREEMENTS.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$DOCNUMBER AGREEMENTS.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$ADJUSTMENTDOCNUMBER AGREEMENTS.ADJUSTMENTDOCNUMBER%TYPE := :NEW.ADJUSTMENTDOCNUMBER;
  new$OLDDOCNUMBER AGREEMENTS.OLDDOCNUMBER%TYPE := :NEW.OLDDOCNUMBER;
  new$LOTMAXSUM AGREEMENTS.LOTMAXSUM%TYPE := :NEW.LOTMAXSUM;
  new$CLIENT_INN AGREEMENTS.CLIENT_INN%TYPE := :NEW.CLIENT_INN;
  new$CLIENT_INN20 AGREEMENTS.CLIENT_INN20%TYPE := :NEW.CLIENT_INN20;
  new$CLIENT_NAME AGREEMENTS.CLIENT_NAME%TYPE := :NEW.CLIENT_NAME;
  new$EXECUTER_INN AGREEMENTS.EXECUTER_INN%TYPE := :NEW.EXECUTER_INN;
  new$EXECUTER_INN20 AGREEMENTS.EXECUTER_INN20%TYPE := :NEW.EXECUTER_INN20;
  new$EXECUTER_NAME AGREEMENTS.EXECUTER_NAME%TYPE := :NEW.EXECUTER_NAME;
  new$EXECUTER_STATUS AGREEMENTS.EXECUTER_STATUS%TYPE := :NEW.EXECUTER_STATUS;
  new$EXECUTER_COUNTRY AGREEMENTS.EXECUTER_COUNTRY%TYPE := :NEW.EXECUTER_COUNTRY;
  new$EXECUTER_ADDRESS AGREEMENTS.EXECUTER_ADDRESS%TYPE := :NEW.EXECUTER_ADDRESS;
  new$EXECUTER_PHONE AGREEMENTS.EXECUTER_PHONE%TYPE := :NEW.EXECUTER_PHONE;
  new$REALID AGREEMENTS.REALID%TYPE := :NEW.REALID;
  new$ADJUSTMENTNUMBER AGREEMENTS.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$INNERNUMBER AGREEMENTS.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$SENDERIDKEY AGREEMENTS.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY AGREEMENTS.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REESTRVERSION AGREEMENTS.REESTRVERSION%TYPE := :NEW.REESTRVERSION;
  new$DOCTYPE AGREEMENTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$RNCLIENTID AGREEMENTS.RNCLIENTID%TYPE := :NEW.RNCLIENTID;
  new$INFONUMBER AGREEMENTS.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$STATEORDERINNERNUMBER AGREEMENTS.STATEORDERINNERNUMBER%TYPE := :NEW.STATEORDERINNERNUMBER;
  new$PROGINDEX AGREEMENTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE AGREEMENTS.NOTE%TYPE := :NEW.NOTE;
  new$PURPORTDOC AGREEMENTS.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$REESTRRECORDNUMBER AGREEMENTS.REESTRRECORDNUMBER%TYPE := :NEW.REESTRRECORDNUMBER;
  new$EXECUTERSTOREDPROPS AGREEMENTS.EXECUTERSTOREDPROPS%TYPE := :NEW.EXECUTERSTOREDPROPS;
  new$AUTOSANCTION AGREEMENTS.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$PURCHASECODE AGREEMENTS.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$DOCUMENTNUMBER AGREEMENTS.DOCUMENTNUMBER%TYPE := :NEW.DOCUMENTNUMBER;
--
  CurVal$ NUMBER (10);
  CountAcc$ NUMBER(10);
  rnClientID1$ VARCHAR2(15);
  rnYear1$ VARCHAR2(15);
  rnNumber1$ VARCHAR2(15);
  ReestrVersion1$ VARCHAR2(15);
  Tmp$ NUMBER(10);
  AdjID$ NUMBER(10);
  AdjDocNum$ VARCHAR2(150);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_AGREEMENTS_BI)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   3.1.2*/
  /*    -*/
  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$CardAdvancePercent is null) then
    new$CardAdvancePercent := 0;
  END IF;
  if (new$CardAdvance is null) then
    new$CardAdvance := 0;
  END IF;
  if (new$AgreementCardAdvance is null) then
    new$AgreementCardAdvance := 0;
  END IF;
  if (new$FinCardAdvance is null) then
    new$FinCardAdvance := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$AgreementSumma is null) then
    new$AgreementSumma := 0;
  END IF;
  if (new$AgreementFinSumma is null) then
    new$AgreementFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$Region is null) then
    new$Region := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  if (new$client_ref is null) then
    new$client_ref := 0;
  END IF;

  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    BEGIN
      select fa.BudgetRef     into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;

  /*    
         -   InnerNumber*/
  if (((new$ProgIndex = 305) or (new$ProgIndex = 304) or (new$ProgIndex = 314)) and (new$InnerNumber is null)) then
    new$InnerNumber := GEN_ID('G_AgreementNumber',1);
  END IF;
  /*   */
  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  /*    .  */

  new$stateorderinnernumber := null;
  if (new$stateorderref is not null) then
    BEGIN
      select
      innernumber
      into new$stateorderinnernumber     from agreements
      where
      id = new$stateorderref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_AGREEMENTS_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_AGREEMENTS_BI_10)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  /*   5.0*/

  /*    .*/
  if (new$InnerNumber is null) then
    RaiseException('EX_AGR_InnerNumsIsNull');
  END IF;

  /*    */
  select max(AdjustmentNumber)
  into Tmp$         from Agreements
  where (InnerNumber = new$InnerNumber)
  ;
  /*      ,   0*/
  if (Tmp$ is null) then
    new$AdjustmentNumber := 0;

  else
    new$AdjustmentNumber := Tmp$ + 1;
  END IF;
  /*        */
  if (((new$AgreementType = 0) and (new$AdjustmentNumber > 0)) or
  ((new$AgreementType = 1) and (new$AdjustmentNumber = 0))) then
    RaiseException('EX_AGR_AgrTypeViolation');
  END IF;
  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;

  else
    new$LastAdjustment := 1;
  END IF;
  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then
    new$LastAccepted := 1;

  else
    new$LastAccepted := 0;
  END IF;
  /*    */
  if (new$AdjustmentNumber > 0) then
    /*      -    */
    select count(ID), max(ID), max(DocNumber)
    into Tmp$, AdjID$, AdjDocNum$             from Agreements
    where (InnerNumber = new$InnerNumber) and (LastAccepted = 1)
    ;
    /*   ,  */
    if (Tmp$ <> 1) then
      RaiseException('EX_AGR_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID)
    into Tmp$             from Agreements
    where (InnerNumber = new$InnerNumber) and (AcceptDate is null)
    ;
    if (Tmp$ > 0) then
      RaiseException('EX_AGR_AdjustDuplicate');
    END IF;
    /* ,    ,    */
    new$AdjustmentRef := AdjID$;
    new$AdjustmentDocNumber := AdjDocNum$;

  else /*     */
    /*       (    )*/
    new$AdjustmentRef := null;
    new$AdjustmentDocNumber := null;

  END IF;

-- - - - - - - - - - - - -
-- BI_20 (TR_AGREEMENTS_BI_20)
-- Create 21.05.2009
-- - - - - - - - - - - - -

  /*    -,     */
  if ((new$Client_INN   is null) and
      (new$Client_INN20 is null) and
      (new$Client_Name  is null))then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name
      into
        new$Client_INN,
        new$Client_INN20,
        new$Client_Name
      from Organizations o
      where o.Id=new$Client_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Client_INN := NULL;
        new$Client_INN20 := NULL;
        new$Client_Name := NULL;
    END;
  END IF;

  /*    -,     */
  if ((new$Executer_INN     is null) and
      (new$Executer_INN20   is null) and
      (new$Executer_Name    is null) and
      (new$Executer_Status  is null) and
      (new$Executer_Country is null) and
      (new$Executer_Address is null) and
      (new$Executer_Phone   is null))then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name,
        o.SupplierStatus,
        o.Country,
        o.Address,
        o.Phone
      into
        new$Executer_INN,
        new$Executer_INN20,
        new$Executer_Name,
        new$Executer_Status,
        new$Executer_Country,
        new$Executer_Address,
        new$Executer_Phone
      from Organizations o
      where o.Id=new$Executer_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Executer_INN := NULL;
        new$Executer_INN20 := NULL;
        new$Executer_Name := NULL;
        new$Executer_Status := NULL;
        new$Executer_Country := NULL;
        new$Executer_Address := NULL;
        new$Executer_Phone := NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_40 (TR_AGREEMENTS_BI_40)
-- Create 06.08.2010
-- - - - - - - - - - - - -

  /*       */
  if (new$senderId is null) then
    new$senderIdKey := -1;
  else
    new$senderIdKey := new$senderId;
  end if;

  if (new$SenderRecordID is null)then
    new$SenderRecordIDKey := new$ID;
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  end if;

-- - - - - - - - - - - - -
-- BI_50 (TR_AGREEMENTS_BI_50)
-- Create 06.08.2010
-- - - - - - - - - - - - -

    if (new$InnerNumber is not null) then
        CurVal$ := gen_id('G_AgreementNumber', 0);
        if (CurVal$ < new$InnerNumber) then
          CurVal$ := gen_id('G_AgreementNumber', new$InnerNumber - CurVal$);
        end if;
    end if;

-- - - - - - - - - - - - -
-- BI_300 (tr_agreements_bi_300)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$ExecuterAccRef is not null) then
    select count(ID)
    into CountAcc$     from org_accounts oa
    where oa.id = new$ExecuterAccRef and oa.Org_ref = new$Executer_Ref
    ;
    if (CountAcc$ = 0) then
      RaiseException('EX_AGR_ACCORGCHECK');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_400 (TR_AGREEMENTS_BI_400)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if ((new$rnClientID is not null) and (new$rnYear is not null) and (new$rnNumber is not null)) then

    rnClientID1$ := new$rnClientID;
    rnYear1$ := new$rnYear;
    rnNumber1$ := new$rnNumber;
    ReestrVersion1$ := new$ReestrVersion;
    while (LENGTH(rnClientID1$) < 11) LOOP
      rnClientID1$ := '0' || rnClientID1$;
    END LOOP;
    while (LENGTH(rnNumber1$) < 6) LOOP
      rnNumber1$ := '0' || rnNumber1$;
    END LOOP;
    if (LENGTH(ReestrVersion1$) < 2) then
      ReestrVersion1$ := '0' || ReestrVersion1$;
    END IF;
    /*  ReestrRecordNumber*/
    if (new$ReestrVersion is null) then
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$;

    else
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$ || ReestrVersion1$;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_AGREEMENTS_BI_500)
-- Last update 19.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- BI_600 (agreements_realid_bi_600)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_AGREEMENTS (
    ID,
    SUMMA,
    AGREEMENTDATE,
    AGREEMENTENDDATE,
    EXECUTER_REF,
    CLIENT_REF,
    FACIALACC_CLS,
    AGREEMENTTYPE,
    ACCEPTED,
    ACCEPTDATE,
    CARDADVANCEPERCENT,
    CARDADVANCE,
    CLOSEDOC,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    LASTADJUSTMENT,
    LASTACCEPTED,
    FACT,
    REGION,
    CLOSEDATE,
    DELIVERYRULES,
    AGREEMENTSUMMA,
    AGREEMENTFINSUMMA,
    ADJUSTMENTREF,
    REESTRNUMBER,
    PAYMENTDATE,
    AGREEMENTCARDADVANCE,
    FINCARDADVANCE,
    STATEORDERREF,
    REJECTCLS,
    REJECTCAUSE,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    AGREEMENTBEGINDATE,
    PROTOCOLNUMBER,
    PROTOCOLDATE,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXPORTDATE,
    FSORGAN,
    FSBUDGETNAME,
    FSOFFBUDGET,
    RNYEAR,
    RNNUMBER,
    RNDATE,
    PROTOCOLNOTICE,
    PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE,
    NOTIFYDATE,
    EXECUTERACCREF,
    DOCBASEDATE,
    DOCBASENOTIFYDATE,
    DOCBASETEXT,
    DOCBASETYPE,
    DOCBASESUMMA,
    UNKNOWNAMOUNT,
    PROTOCOLREASON,
    DOCNUMBER,
    ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER,
    LOTMAXSUM,
    CLIENT_INN,
    CLIENT_INN20,
    CLIENT_NAME,
    EXECUTER_INN,
    EXECUTER_INN20,
    EXECUTER_NAME,
    EXECUTER_STATUS,
    EXECUTER_COUNTRY,
    EXECUTER_ADDRESS,
    EXECUTER_PHONE,
    REALID,
    ADJUSTMENTNUMBER,
    INNERNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REESTRVERSION,
    DOCTYPE,
    RNCLIENTID,
    INFONUMBER,
    STATEORDERINNERNUMBER,
    PROGINDEX,
    NOTE,
    PURPORTDOC,
    REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS,
    AUTOSANCTION,
    PURCHASECODE,
    DOCUMENTNUMBER
  ) VALUES (
    new$ID,
    new$SUMMA,
    new$AGREEMENTDATE,
    new$AGREEMENTENDDATE,
    new$EXECUTER_REF,
    new$CLIENT_REF,
    new$FACIALACC_CLS,
    new$AGREEMENTTYPE,
    new$ACCEPTED,
    new$ACCEPTDATE,
    new$CARDADVANCEPERCENT,
    new$CARDADVANCE,
    new$CLOSEDOC,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$LASTADJUSTMENT,
    new$LASTACCEPTED,
    new$FACT,
    new$REGION,
    new$CLOSEDATE,
    new$DELIVERYRULES,
    new$AGREEMENTSUMMA,
    new$AGREEMENTFINSUMMA,
    new$ADJUSTMENTREF,
    new$REESTRNUMBER,
    new$PAYMENTDATE,
    new$AGREEMENTCARDADVANCE,
    new$FINCARDADVANCE,
    new$STATEORDERREF,
    new$REJECTCLS,
    new$REJECTCAUSE,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$AGREEMENTBEGINDATE,
    new$PROTOCOLNUMBER,
    new$PROTOCOLDATE,
    new$REVIEWNOTE,
    new$DOCSTATEREF,
    new$RVERSION,
    new$EXPORTDATE,
    new$FSORGAN,
    new$FSBUDGETNAME,
    new$FSOFFBUDGET,
    new$RNYEAR,
    new$RNNUMBER,
    new$RNDATE,
    new$PROTOCOLNOTICE,
    new$PROTOCOLRESULTDATE,
    new$PROTOCOLDOCTYPE,
    new$PROTOCOLSALETYPE,
    new$NOTIFYDATE,
    new$EXECUTERACCREF,
    new$DOCBASEDATE,
    new$DOCBASENOTIFYDATE,
    new$DOCBASETEXT,
    new$DOCBASETYPE,
    new$DOCBASESUMMA,
    new$UNKNOWNAMOUNT,
    new$PROTOCOLREASON,
    new$DOCNUMBER,
    new$ADJUSTMENTDOCNUMBER,
    new$OLDDOCNUMBER,
    new$LOTMAXSUM,
    new$CLIENT_INN,
    new$CLIENT_INN20,
    new$CLIENT_NAME,
    new$EXECUTER_INN,
    new$EXECUTER_INN20,
    new$EXECUTER_NAME,
    new$EXECUTER_STATUS,
    new$EXECUTER_COUNTRY,
    new$EXECUTER_ADDRESS,
    new$EXECUTER_PHONE,
    new$REALID,
    new$ADJUSTMENTNUMBER,
    new$INNERNUMBER,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$REESTRVERSION,
    new$DOCTYPE,
    new$RNCLIENTID,
    new$INFONUMBER,
    new$STATEORDERINNERNUMBER,
    new$PROGINDEX,
    new$NOTE,
    new$PURPORTDOC,
    new$REESTRRECORDNUMBER,
    new$EXECUTERSTOREDPROPS,
    new$AUTOSANCTION,
    new$PURCHASECODE,
    new$DOCUMENTNUMBER);

-- - - - - - - - - - - - -
-- AI_10 (TR_AGREEMENTS_AI_10)
-- Last update 05.02.2010
-- - - - - - - - - - - - -

/*   5.0*/
    if ((new$AdjustmentNumber > 0) and (new$LastAdjustment = 1)) then
        update Agreements set
            LastAdjustment = 0,
            RVersion = -1
        where (ID = new$AdjustmentRef);
        if (new$LastAccepted = 1) then
            update Agreements set
                LastAccepted = 0,
                RVersion = -1
            where (ID = new$AdjustmentRef);
        end if;
    end if;

-- - - - - - - - - - - - -
-- AI_500 (TR_AGREEMENTS_AI_500)
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 110) AND (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_AGREEMENTS_IU
  INSTEAD OF UPDATE
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  new$ID AGREEMENTS.ID%TYPE := :NEW.ID;
  new$SUMMA AGREEMENTS.SUMMA%TYPE := :NEW.SUMMA;
  new$AGREEMENTDATE AGREEMENTS.AGREEMENTDATE%TYPE := :NEW.AGREEMENTDATE;
  new$AGREEMENTENDDATE AGREEMENTS.AGREEMENTENDDATE%TYPE := :NEW.AGREEMENTENDDATE;
  new$EXECUTER_REF AGREEMENTS.EXECUTER_REF%TYPE := :NEW.EXECUTER_REF;
  new$CLIENT_REF AGREEMENTS.CLIENT_REF%TYPE := :NEW.CLIENT_REF;
  new$FACIALACC_CLS AGREEMENTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$AGREEMENTTYPE AGREEMENTS.AGREEMENTTYPE%TYPE := :NEW.AGREEMENTTYPE;
  new$ACCEPTED AGREEMENTS.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$ACCEPTDATE AGREEMENTS.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$CARDADVANCEPERCENT AGREEMENTS.CARDADVANCEPERCENT%TYPE := :NEW.CARDADVANCEPERCENT;
  new$CARDADVANCE AGREEMENTS.CARDADVANCE%TYPE := :NEW.CARDADVANCE;
  new$CLOSEDOC AGREEMENTS.CLOSEDOC%TYPE := :NEW.CLOSEDOC;
  new$CREATERUSER AGREEMENTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE AGREEMENTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE AGREEMENTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER AGREEMENTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF AGREEMENTS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$LASTADJUSTMENT AGREEMENTS.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED AGREEMENTS.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$FACT AGREEMENTS.FACT%TYPE := :NEW.FACT;
  new$REGION AGREEMENTS.REGION%TYPE := :NEW.REGION;
  new$CLOSEDATE AGREEMENTS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$DELIVERYRULES AGREEMENTS.DELIVERYRULES%TYPE := :NEW.DELIVERYRULES;
  new$AGREEMENTSUMMA AGREEMENTS.AGREEMENTSUMMA%TYPE := :NEW.AGREEMENTSUMMA;
  new$AGREEMENTFINSUMMA AGREEMENTS.AGREEMENTFINSUMMA%TYPE := :NEW.AGREEMENTFINSUMMA;
  new$ADJUSTMENTREF AGREEMENTS.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$REESTRNUMBER AGREEMENTS.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$PAYMENTDATE AGREEMENTS.PAYMENTDATE%TYPE := :NEW.PAYMENTDATE;
  new$AGREEMENTCARDADVANCE AGREEMENTS.AGREEMENTCARDADVANCE%TYPE := :NEW.AGREEMENTCARDADVANCE;
  new$FINCARDADVANCE AGREEMENTS.FINCARDADVANCE%TYPE := :NEW.FINCARDADVANCE;
  new$STATEORDERREF AGREEMENTS.STATEORDERREF%TYPE := :NEW.STATEORDERREF;
  new$REJECTCLS AGREEMENTS.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTCAUSE AGREEMENTS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CRYPTOSTATUS AGREEMENTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID AGREEMENTS.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID AGREEMENTS.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$AGREEMENTBEGINDATE AGREEMENTS.AGREEMENTBEGINDATE%TYPE := :NEW.AGREEMENTBEGINDATE;
  new$PROTOCOLNUMBER AGREEMENTS.PROTOCOLNUMBER%TYPE := :NEW.PROTOCOLNUMBER;
  new$PROTOCOLDATE AGREEMENTS.PROTOCOLDATE%TYPE := :NEW.PROTOCOLDATE;
  new$REVIEWNOTE AGREEMENTS.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF AGREEMENTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION AGREEMENTS.RVERSION%TYPE := :NEW.RVERSION;
  new$EXPORTDATE AGREEMENTS.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$FSORGAN AGREEMENTS.FSORGAN%TYPE := :NEW.FSORGAN;
  new$FSBUDGETNAME AGREEMENTS.FSBUDGETNAME%TYPE := :NEW.FSBUDGETNAME;
  new$FSOFFBUDGET AGREEMENTS.FSOFFBUDGET%TYPE := :NEW.FSOFFBUDGET;
  new$RNYEAR AGREEMENTS.RNYEAR%TYPE := :NEW.RNYEAR;
  new$RNNUMBER AGREEMENTS.RNNUMBER%TYPE := :NEW.RNNUMBER;
  new$RNDATE AGREEMENTS.RNDATE%TYPE := :NEW.RNDATE;
  new$PROTOCOLNOTICE AGREEMENTS.PROTOCOLNOTICE%TYPE := :NEW.PROTOCOLNOTICE;
  new$PROTOCOLRESULTDATE AGREEMENTS.PROTOCOLRESULTDATE%TYPE := :NEW.PROTOCOLRESULTDATE;
  new$PROTOCOLDOCTYPE AGREEMENTS.PROTOCOLDOCTYPE%TYPE := :NEW.PROTOCOLDOCTYPE;
  new$PROTOCOLSALETYPE AGREEMENTS.PROTOCOLSALETYPE%TYPE := :NEW.PROTOCOLSALETYPE;
  new$NOTIFYDATE AGREEMENTS.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$EXECUTERACCREF AGREEMENTS.EXECUTERACCREF%TYPE := :NEW.EXECUTERACCREF;
  new$DOCBASEDATE AGREEMENTS.DOCBASEDATE%TYPE := :NEW.DOCBASEDATE;
  new$DOCBASENOTIFYDATE AGREEMENTS.DOCBASENOTIFYDATE%TYPE := :NEW.DOCBASENOTIFYDATE;
  new$DOCBASETEXT AGREEMENTS.DOCBASETEXT%TYPE := :NEW.DOCBASETEXT;
  new$DOCBASETYPE AGREEMENTS.DOCBASETYPE%TYPE := :NEW.DOCBASETYPE;
  new$DOCBASESUMMA AGREEMENTS.DOCBASESUMMA%TYPE := :NEW.DOCBASESUMMA;
  new$UNKNOWNAMOUNT AGREEMENTS.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PROTOCOLREASON AGREEMENTS.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$DOCNUMBER AGREEMENTS.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$ADJUSTMENTDOCNUMBER AGREEMENTS.ADJUSTMENTDOCNUMBER%TYPE := :NEW.ADJUSTMENTDOCNUMBER;
  new$OLDDOCNUMBER AGREEMENTS.OLDDOCNUMBER%TYPE := :NEW.OLDDOCNUMBER;
  new$LOTMAXSUM AGREEMENTS.LOTMAXSUM%TYPE := :NEW.LOTMAXSUM;
  new$CLIENT_INN AGREEMENTS.CLIENT_INN%TYPE := :NEW.CLIENT_INN;
  new$CLIENT_INN20 AGREEMENTS.CLIENT_INN20%TYPE := :NEW.CLIENT_INN20;
  new$CLIENT_NAME AGREEMENTS.CLIENT_NAME%TYPE := :NEW.CLIENT_NAME;
  new$EXECUTER_INN AGREEMENTS.EXECUTER_INN%TYPE := :NEW.EXECUTER_INN;
  new$EXECUTER_INN20 AGREEMENTS.EXECUTER_INN20%TYPE := :NEW.EXECUTER_INN20;
  new$EXECUTER_NAME AGREEMENTS.EXECUTER_NAME%TYPE := :NEW.EXECUTER_NAME;
  new$EXECUTER_STATUS AGREEMENTS.EXECUTER_STATUS%TYPE := :NEW.EXECUTER_STATUS;
  new$EXECUTER_COUNTRY AGREEMENTS.EXECUTER_COUNTRY%TYPE := :NEW.EXECUTER_COUNTRY;
  new$EXECUTER_ADDRESS AGREEMENTS.EXECUTER_ADDRESS%TYPE := :NEW.EXECUTER_ADDRESS;
  new$EXECUTER_PHONE AGREEMENTS.EXECUTER_PHONE%TYPE := :NEW.EXECUTER_PHONE;
  new$REALID AGREEMENTS.REALID%TYPE := :NEW.REALID;
  new$ADJUSTMENTNUMBER AGREEMENTS.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$INNERNUMBER AGREEMENTS.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$SENDERIDKEY AGREEMENTS.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY AGREEMENTS.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REESTRVERSION AGREEMENTS.REESTRVERSION%TYPE := :NEW.REESTRVERSION;
  new$DOCTYPE AGREEMENTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$RNCLIENTID AGREEMENTS.RNCLIENTID%TYPE := :NEW.RNCLIENTID;
  new$INFONUMBER AGREEMENTS.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$STATEORDERINNERNUMBER AGREEMENTS.STATEORDERINNERNUMBER%TYPE := :NEW.STATEORDERINNERNUMBER;
  new$PROGINDEX AGREEMENTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE AGREEMENTS.NOTE%TYPE := :NEW.NOTE;
  new$PURPORTDOC AGREEMENTS.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$REESTRRECORDNUMBER AGREEMENTS.REESTRRECORDNUMBER%TYPE := :NEW.REESTRRECORDNUMBER;
  new$EXECUTERSTOREDPROPS AGREEMENTS.EXECUTERSTOREDPROPS%TYPE := :NEW.EXECUTERSTOREDPROPS;
  new$AUTOSANCTION AGREEMENTS.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$PURCHASECODE AGREEMENTS.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$DOCUMENTNUMBER AGREEMENTS.DOCUMENTNUMBER%TYPE := :NEW.DOCUMENTNUMBER;
--
  MaxNumber$ NUMBER (10);
  CurVal$ NUMBER (10);
  CNT$1 NUMBER(10);
  DetCount$ NUMBER(10);
  CountAcc$ NUMBER(10);
  rnClientID1$ VARCHAR2(15);
  rnYear1$ VARCHAR2(15);
  rnNumber1$ VARCHAR2(15);
  ReestrVersion1$ VARCHAR2(15);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_AGREEMENTS_BU)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   3.1*/
  /*    -*/
  if (new$CardAdvancePercent is null) then
    new$CardAdvancePercent := 0;
  END IF;
  if (new$CardAdvance is null) then
    new$CardAdvance := 0;
  END IF;
  if (new$AgreementCardAdvance is null) then
    new$AgreementCardAdvance := 0;
  END IF;
  if (new$FinCardAdvance is null) then
    new$FinCardAdvance := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$AgreementSumma is null) then
    new$AgreementSumma := 0;
  END IF;
  if (new$AgreementFinSumma is null) then
    new$AgreementFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$Region is null) then
    new$Region := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$client_ref is null) then
    new$client_ref := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount$ from AgreementSteps where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      select count(ID)       into DetCount$ from Estimate where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*         -   InnerNumber*/
  if (((new$ProgIndex = 305) or (new$ProgIndex = 304) or (new$ProgIndex = 314)) and (new$InnerNumber is null)) then
    new$InnerNumber := GEN_ID('G_AgreementNumber',1);
  END IF;
  /*   */
  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  /*    .  */

  new$stateorderinnernumber := null;
  if (new$stateorderref is not null) then
    BEGIN
      select
      innernumber
      into new$stateorderinnernumber     from agreements
      where
      id = new$stateorderref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_3 (TR_AGREEMENTS_BU_3)
-- Create 03.12.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*            */
   new$AdjustmentRef := :OLD.AdjustmentRef;

-- - - - - - - - - - - - -
-- BU_5 (TR_AGREEMENTS_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_AGREEMENTS_BU_10)
-- Last update 08.02.2010
-- - - - - - - - - - - - -

/*   5.0*/
    /* ,      ,   */
    if ((new$InnerNumber <> :old.InnerNumber) or
        (new$AdjustmentNumber <> :old.AdjustmentNumber) or
        (new$AgreementType <> :old.AgreementType)) then
        RaiseException('EX_AGR_ChangeInnerNums');
    end if;

    /*    !!!*/
    if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and
        ((new$Accepted = 1) or (new$AcceptDate is null))) then
        RaiseException('EX_RollbackCancel');
    end if;

    /*   ,     LastAccepted*/
    if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) or
        ((:old.Accepted = 0) and (new$Accepted = 1) and (new$AcceptDate is not null))) then
        /*  LastAccepted         */
        if (new$LastAdjustment = 1) then
            new$LastAccepted := 1;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;
    end if;

    /*    ,     LastAccepted*/
    if (((:old.AcceptDate is not null) and (:old.Accepted = 1)) and
        ((new$Accepted = 0) or (new$AcceptDate is null))) then
        /*  LastAccepted         */
        if (new$LastAdjustment = 1) then
            new$LastAccepted := 0;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;
    end if;

    /*   ,     LastAdjustment*/
    if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 0)) or
        ((:old.Accepted = 1) and (new$Accepted = 0) and (new$AcceptDate is not null))) then

        if (new$LastAdjustment = 1) then
            new$LastAdjustment := 0;
            new$LastAccepted := 0;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;

        SELECT Max(AdjustmentNumber) INTO MaxNumber$ FROm AgreementS
        WHERE (InnerNumber = new$InnerNumber);
        /*    ,     */
        if ((new$adjustmentNumber=0) and (MaxNumber$<>0)) then
          RaiseException('EX_Agr_PrimaryAgrHasNotify');
        end if;
    end if;

-- - - - - - - - - - - - -
-- BU_20 (TR_AGREEMENTS_BU_20)
-- Create 21.05.2009
-- - - - - - - - - - - - -

  /*    -,      */
  if ((new$Client_Ref <> :old.Client_Ref) and
      (((new$Client_INN is null) and
        (:old.Client_INN is null)) or
       (new$Client_INN = :old.Client_INN)) and
      (((new$Client_INN20 is null) and
        (:old.Client_INN20 is null)) or
       (new$Client_INN20 = :old.Client_INN20)) and
      (new$Client_Name = :old.Client_Name)) then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name
      into
        new$Client_INN,
        new$Client_INN20,
        new$Client_Name
      from Organizations o
      where o.Id=new$Client_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Client_INN := NULL;
        new$Client_INN20 := NULL;
        new$Client_Name := NULL;
    END;
  END IF;

  /*    -,      */
  if ((new$Executer_Ref <> :old.Executer_Ref) and
      (((new$Executer_INN is null) and
        (:old.Executer_INN is null)) or
       (new$Executer_INN = :old.Executer_INN)) and
      (((new$Executer_INN20 is null) and
        (:old.Executer_INN20 is null)) or
       (new$Executer_INN20 = :old.Executer_INN20)) and
      (new$Executer_Name = :old.Executer_Name) and
      (((new$Executer_Status is null) and
        (:old.Executer_Status is null)) or
       (new$Executer_Status = :old.Executer_Status)) and
      (((new$Executer_Country is null) and
        (:old.Executer_Country is null)) or
       (new$Executer_Country = :old.Executer_Country)) and
      (((new$Executer_Address is null) and
        (:old.Executer_Address is null)) or
       (new$Executer_Address = :old.Executer_Address)) and
      (((new$Executer_Phone is null) and
        (:old.Executer_Phone is null)) or
       (new$Executer_Phone = :old.Executer_Phone))) then
     BEGIN
      select
        o.INN,
        o.INN20,
        o.Name,
        o.SupplierStatus,
        o.Country,
        o.Address,
        o.Phone
      into
        new$Executer_INN,
        new$Executer_INN20,
        new$Executer_Name,
        new$Executer_Status,
        new$Executer_Country,
        new$Executer_Address,
        new$Executer_Phone
      from Organizations o
      where o.Id=new$Executer_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Executer_INN := NULL;
        new$Executer_INN20 := NULL;
        new$Executer_Name := NULL;
        new$Executer_Status := NULL;
        new$Executer_Country := NULL;
        new$Executer_Address := NULL;
        new$Executer_Phone := NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_50 (TR_AGREEMENTS_BU_50)
-- Create 06.08.2010
-- - - - - - - - - - - - -

    if (new$InnerNumber is not null) then
        CurVal$ := gen_id('G_AgreementNumber', 0);
        if (CurVal$ < new$InnerNumber) then
          CurVal$ := gen_id('G_AgreementNumber', new$InnerNumber - CurVal$);
        end if;
    end if;

-- - - - - - - - - - - - -
-- BU_60 (tr_agreements_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*        ,     */
  if (:old.accepted = 1 and new$accepted = 0 and new$acceptdate is not null and new$adjustmentnumber = 0) then
    SELECT COUNT(*) INTO CNT$1
    from executiondocumentscaption
    where
    (            agreementinnernumber = new$innernumber
    and (accepted <> 0 or acceptdate is null)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_Agr_CannotReject');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_AGREEMENTS_BU_200)
-- Create 04.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$id, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (tr_agreements_bu_300)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$ExecuterAccRef is not null) then
    select count(ID)
    into CountAcc$     from org_accounts oa
    where oa.id = new$ExecuterAccRef and oa.Org_ref = new$Executer_Ref
    ;
    if (CountAcc$ = 0) then
      RaiseException('EX_AGR_ACCORGCHECK');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (TR_AGREEMENTS_BU_400)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (((new$rnClientID <> :old.rnClientID) or (new$rnYear <> :old.rnYear) or
  (new$rnNumber <> :old.rnNumber) or (new$ReestrVersion <> :old.ReestrVersion)) and
  (new$rnClientID is not null) and (new$rnYear is not null) and (new$rnNumber is not null)) then

    rnClientID1$ := new$rnClientID;
    rnYear1$ := new$rnYear;
    rnNumber1$ := new$rnNumber;
    ReestrVersion1$ := new$ReestrVersion;
    while (LENGTH(rnClientID1$) < 11) LOOP
      rnClientID1$ := '0' || rnClientID1$;
    END LOOP;
    while (LENGTH(rnNumber1$) < 6) LOOP
      rnNumber1$ := '0' || rnNumber1$;
    END LOOP;
    if (LENGTH(ReestrVersion1$) < 2) then
      ReestrVersion1$ := '0' || ReestrVersion1$;
    END IF;
    /*  ReestrRecordNumber*/
    if (new$ReestrVersion is null) then
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$;

    else
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$ || ReestrVersion1$;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_600 (agreements_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_AGREEMENTS_BU_700)
-- Create 14.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_AGREEMENTS SET
    ID = new$ID,
    SUMMA = new$SUMMA,
    AGREEMENTDATE = new$AGREEMENTDATE,
    AGREEMENTENDDATE = new$AGREEMENTENDDATE,
    EXECUTER_REF = new$EXECUTER_REF,
    CLIENT_REF = new$CLIENT_REF,
    FACIALACC_CLS = new$FACIALACC_CLS,
    AGREEMENTTYPE = new$AGREEMENTTYPE,
    ACCEPTED = new$ACCEPTED,
    ACCEPTDATE = new$ACCEPTDATE,
    CARDADVANCEPERCENT = new$CARDADVANCEPERCENT,
    CARDADVANCE = new$CARDADVANCE,
    CLOSEDOC = new$CLOSEDOC,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    FACT = new$FACT,
    REGION = new$REGION,
    CLOSEDATE = new$CLOSEDATE,
    DELIVERYRULES = new$DELIVERYRULES,
    AGREEMENTSUMMA = new$AGREEMENTSUMMA,
    AGREEMENTFINSUMMA = new$AGREEMENTFINSUMMA,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    REESTRNUMBER = new$REESTRNUMBER,
    PAYMENTDATE = new$PAYMENTDATE,
    AGREEMENTCARDADVANCE = new$AGREEMENTCARDADVANCE,
    FINCARDADVANCE = new$FINCARDADVANCE,
    STATEORDERREF = new$STATEORDERREF,
    REJECTCLS = new$REJECTCLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    AGREEMENTBEGINDATE = new$AGREEMENTBEGINDATE,
    PROTOCOLNUMBER = new$PROTOCOLNUMBER,
    PROTOCOLDATE = new$PROTOCOLDATE,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXPORTDATE = new$EXPORTDATE,
    FSORGAN = new$FSORGAN,
    FSBUDGETNAME = new$FSBUDGETNAME,
    FSOFFBUDGET = new$FSOFFBUDGET,
    RNYEAR = new$RNYEAR,
    RNNUMBER = new$RNNUMBER,
    RNDATE = new$RNDATE,
    PROTOCOLNOTICE = new$PROTOCOLNOTICE,
    PROTOCOLRESULTDATE = new$PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE = new$PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE = new$PROTOCOLSALETYPE,
    NOTIFYDATE = new$NOTIFYDATE,
    EXECUTERACCREF = new$EXECUTERACCREF,
    DOCBASEDATE = new$DOCBASEDATE,
    DOCBASENOTIFYDATE = new$DOCBASENOTIFYDATE,
    DOCBASETEXT = new$DOCBASETEXT,
    DOCBASETYPE = new$DOCBASETYPE,
    DOCBASESUMMA = new$DOCBASESUMMA,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PROTOCOLREASON = new$PROTOCOLREASON,
    DOCNUMBER = new$DOCNUMBER,
    ADJUSTMENTDOCNUMBER = new$ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER = new$OLDDOCNUMBER,
    LOTMAXSUM = new$LOTMAXSUM,
    CLIENT_INN = new$CLIENT_INN,
    CLIENT_INN20 = new$CLIENT_INN20,
    CLIENT_NAME = new$CLIENT_NAME,
    EXECUTER_INN = new$EXECUTER_INN,
    EXECUTER_INN20 = new$EXECUTER_INN20,
    EXECUTER_NAME = new$EXECUTER_NAME,
    EXECUTER_STATUS = new$EXECUTER_STATUS,
    EXECUTER_COUNTRY = new$EXECUTER_COUNTRY,
    EXECUTER_ADDRESS = new$EXECUTER_ADDRESS,
    EXECUTER_PHONE = new$EXECUTER_PHONE,
    REALID = new$REALID,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    INNERNUMBER = new$INNERNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REESTRVERSION = new$REESTRVERSION,
    DOCTYPE = new$DOCTYPE,
    RNCLIENTID = new$RNCLIENTID,
    INFONUMBER = new$INFONUMBER,
    STATEORDERINNERNUMBER = new$STATEORDERINNERNUMBER,
    PROGINDEX = new$PROGINDEX,
    NOTE = new$NOTE,
    PURPORTDOC = new$PURPORTDOC,
    REESTRRECORDNUMBER = new$REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS = new$EXECUTERSTOREDPROPS,
    AUTOSANCTION = new$AUTOSANCTION,
    PURCHASECODE = new$PURCHASECODE,
    DOCUMENTNUMBER = new$DOCUMENTNUMBER
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_AGREEMENTS_AU_10)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   6.0*/
  /*      */
  /*     ,       */
  if ((new$AdjustmentNumber > 0) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update Agreements set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentNumber > 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update Agreements set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*          */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 304)or(new$ProgIndex = 314)))then
    update Estimate
    set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    (RecordIndex = new$Id);
  END IF;
  /*         */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 305) or (new$ProgIndex = 314))) then
    update paymentschedule set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    AgreementRef = new$ID and
    ProgIndex in (317, 318);

  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_AGREEMENTS_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*      */
  if ((new$ProgIndex = 305) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null
    where
    StateOrder = :old.ID;
  END IF;
  /*      */
  if ((new$ProgIndex = 314) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null,
    Agreement = null
    where
    StateOrder = :old.ID;
  END IF;
  /*     */
  if ((:old.ProgIndex = 304) and (new$AdjustmentNumber = 0) and (new$Accepted = 0) and
  (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    Agreement = null
    where
    Agreement = :old.ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_AGREEMENTS_AU_30)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$ProgIndex = 304) or (new$ProgIndex = 314)) and
  ((new$Accepted <> :old.Accepted) or
  (new$AcceptDate is not null and :old.AcceptDate is null) or
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where AgreementRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_AGREEMENTS_AU_500)
-- Create 28.04.2005
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes
                  (TableID, RecordId, DeleteDate
                  )
           VALUES (110, :OLD.ID, SYSDATE
                  );

      DELETE FROM DelRecIndexes
            WHERE (TableID = 110) AND (RecordId = new$ID);
   END IF;

END;
/
commit work 
/

-- #########################################################
-- #########################################################
-- Extend_RejectCause.sql
-- #########################################################
-- #########################################################

/* 
     "  ()"  1000   : ReplacementClsCaption,
  WRITEXECUTIONCAPTION, TenderResultCaption, TENDERPURCHASE, TENDEROBJECTS, GENERALDOCUMENTS, FACIALFINCAPTION, 
  LIMITNOTIFYCAPTION, QUOTESTITLE, PROMISE_CAPTION, BUDNOTIFY, AGREEMENTS, EXECUTIONDOCUMENTSCAPTION, PAYDOC32, INCOMES32, 
  TENDERCAPTION, UTYPEDFORMSCAPTION, UNIONNOTIFYCAPTION, ALLOWANCECAPTION, CORRECTIONCAPTION, LAYERTASKS, ORGANIZATIONS
*/
ALTER TRIGGER TR_REPCLSCAPTION_BU_500 DISABLE
/
ALTER TABLE ReplacementClsCaption ADD (
  TempRejectCause VARCHAR2(255)
)
/
update ReplacementClsCaption set
  TempRejectCause = REJECT_CAUSE
/
commit work 
/
ALTER TABLE ReplacementClsCaption DROP (REJECT_CAUSE)
/
ALTER TABLE ReplacementClsCaption ADD (
  REJECT_CAUSE VARCHAR2(1000)
)
/
update ReplacementClsCaption set
  REJECT_CAUSE = TempRejectCause
/
commit work 
/
ALTER TABLE ReplacementClsCaption DROP (TempRejectCause)
/
ALTER TRIGGER TR_REPCLSCAPTION_BU_500 ENABLE
/
commit work 
/
-- ALTER TRIGGER TR_WRITEXECUTIONCAPTION_BU_500
CREATE OR REPLACE TRIGGER TR_WRITEXECUTIONCAPTION_BU_500
  BEFORE UPDATE
  ON WRITEXECUTIONCAPTION
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_500 (TR_WRITEXECUTIONCAPTION_BU_500)
-- - - - - - - - - - - - -
  NULL;
--   :new.Updatedate := SYSDATE;
--   :new.UpdaterUser := user;

END;
/
ALTER TABLE WRITEXECUTIONCAPTION ADD (
  TempRejectCause VARCHAR2(255)
)
/
update WRITEXECUTIONCAPTION set
  TempRejectCause = REJECTCAUSE
/
commit work 
/
ALTER TABLE WRITEXECUTIONCAPTION DROP (REJECTCAUSE)
/
ALTER TABLE WRITEXECUTIONCAPTION ADD (
  REJECTCAUSE VARCHAR2(1000)
)
/
update WRITEXECUTIONCAPTION set
  REJECTCAUSE = TempRejectCause
/
commit work 
/
ALTER TABLE WRITEXECUTIONCAPTION DROP (TempRejectCause)
/
-- ALTER TRIGGER TR_WRITEXECUTIONCAPTION_BU_500
CREATE OR REPLACE TRIGGER TR_WRITEXECUTIONCAPTION_BU_500
  BEFORE UPDATE
  ON WRITEXECUTIONCAPTION
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_500 (TR_WRITEXECUTIONCAPTION_BU_500)
-- - - - - - - - - - - - -

  :new.Updatedate := SYSDATE;
  :new.UpdaterUser := user;

END;
/
commit work 
/
ALTER TRIGGER TR_TENDERRESULTCAPTION_BU_500 DISABLE
/
ALTER TABLE TenderResultCaption ADD (
  TempRejectCause VARCHAR2(255)
)
/
update TenderResultCaption set
  TempRejectCause = REJECTCAUSE
/
commit work 
/
ALTER TABLE TenderResultCaption DROP (REJECTCAUSE)
/
ALTER TABLE TenderResultCaption ADD (
  REJECTCAUSE VARCHAR2(1000)
)
/
update TenderResultCaption set
  REJECTCAUSE = TempRejectCause
/
commit work 
/
ALTER TABLE TenderResultCaption DROP (TempRejectCause)
/
ALTER TRIGGER TR_TENDERRESULTCAPTION_BU_500 ENABLE
/
commit work 
/
ALTER TRIGGER TR_TENDERPURCHASE_BU_500 DISABLE
/
ALTER TABLE TENDERPURCHASE ADD (
  TempRejectCause VARCHAR2(255)
)
/
update TENDERPURCHASE set
  TempRejectCause = REJECTCAUSE
/
commit work 
/
ALTER TABLE TENDERPURCHASE DROP (REJECTCAUSE)
/
ALTER TABLE TENDERPURCHASE ADD (
  REJECTCAUSE VARCHAR2(1000)
)
/
update TENDERPURCHASE set
  REJECTCAUSE = TempRejectCause
/
commit work 
/
ALTER TABLE TENDERPURCHASE DROP (TempRejectCause)
/
ALTER TRIGGER TR_TENDERPURCHASE_BU_500 ENABLE
/
commit work 
/
ALTER TRIGGER TR_TENDEROBJECTS_BU_500 DISABLE
/
ALTER TABLE TENDEROBJECTS ADD (
  TempRejectCause VARCHAR2(255)
)
/
update TENDEROBJECTS set
  TempRejectCause = REJECTCAUSE
/
commit work 
/
ALTER TABLE TENDEROBJECTS DROP (REJECTCAUSE)
/
ALTER TABLE TENDEROBJECTS ADD (
  REJECTCAUSE VARCHAR2(1000)
)
/
update TENDEROBJECTS set
  REJECTCAUSE = TempRejectCause
/
commit work 
/
ALTER TABLE TENDEROBJECTS DROP (TempRejectCause)
/
ALTER TRIGGER TR_TENDEROBJECTS_BU_500 ENABLE
/
commit work 
/
ALTER TRIGGER TR_GENERALDOCUMENTS_BU_500 DISABLE
/
ALTER TABLE GENERALDOCUMENTS ADD (
  TempRejectCause VARCHAR2(255)
)
/
update GENERALDOCUMENTS set
  TempRejectCause = REJECTCAUSE
/
commit work 
/
ALTER TABLE GENERALDOCUMENTS DROP (REJECTCAUSE)
/
ALTER TABLE GENERALDOCUMENTS ADD (
  REJECTCAUSE VARCHAR2(1000)
)
/
update GENERALDOCUMENTS set
  REJECTCAUSE = TempRejectCause
/
commit work 
/
ALTER TABLE GENERALDOCUMENTS DROP (TempRejectCause)
/
ALTER TRIGGER TR_GENERALDOCUMENTS_BU_500 ENABLE
/
commit work 
/
ALTER TRIGGER TR_FACIALFINCAPTION_BU_500 DISABLE
/
/*     REJECTCAUSE */
-- drop trigger TR_FACIALFINCAPTION_AU_10
CREATE OR REPLACE TRIGGER TR_FACIALFINCAPTION_IU
  INSTEAD OF UPDATE
  ON FACIALFINCAPTION
  FOR EACH ROW
DECLARE
  new$ID FACIALFINCAPTION.ID%TYPE := :NEW.ID;
  new$DOCNUMBER FACIALFINCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SOURCEDOCNUM FACIALFINCAPTION.SOURCEDOCNUM%TYPE := :NEW.SOURCEDOCNUM;
  new$PAYDATE FACIALFINCAPTION.PAYDATE%TYPE := :NEW.PAYDATE;
  new$ACCEPTDATE FACIALFINCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCUMENTDATE FACIALFINCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$REESTRDATE FACIALFINCAPTION.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$CREDIT FACIALFINCAPTION.CREDIT%TYPE := :NEW.CREDIT;
  new$SOURCEACCOUNT FACIALFINCAPTION.SOURCEACCOUNT%TYPE := :NEW.SOURCEACCOUNT;
  new$SOURCEFACIALACC_CLS FACIALFINCAPTION.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$DESTACCOUNT FACIALFINCAPTION.DESTACCOUNT%TYPE := :NEW.DESTACCOUNT;
  new$DESTFACIALACC_CLS FACIALFINCAPTION.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$PROGINDEX FACIALFINCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$ARHIVEDOC FACIALFINCAPTION.ARHIVEDOC%TYPE := :NEW.ARHIVEDOC;
  new$PAYSYMBOLCLS FACIALFINCAPTION.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$PAYTYPECLS FACIALFINCAPTION.PAYTYPECLS%TYPE := :NEW.PAYTYPECLS;
  new$NOTE FACIALFINCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$PERIOD FACIALFINCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$PAYPRIORITY FACIALFINCAPTION.PAYPRIORITY%TYPE := :NEW.PAYPRIORITY;
  new$TYPEOPERATIONCLS FACIALFINCAPTION.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$BUHPAYMENTCLS FACIALFINCAPTION.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$CREATERUSER FACIALFINCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF FACIALFINCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECORDINDEX FACIALFINCAPTION.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$SENDERID FACIALFINCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REESTR_REF FACIALFINCAPTION.REESTR_REF%TYPE := :NEW.REESTR_REF;
  new$REJECT_CLS FACIALFINCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CLIENTBANKNUMBER FACIALFINCAPTION.CLIENTBANKNUMBER%TYPE := :NEW.CLIENTBANKNUMBER;
  new$CRYPTOSTATUS FACIALFINCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$TRUSTNUMBER FACIALFINCAPTION.TRUSTNUMBER%TYPE := :NEW.TRUSTNUMBER;
  new$LINKEDDOCUMENT FACIALFINCAPTION.LINKEDDOCUMENT%TYPE := :NEW.LINKEDDOCUMENT;
  new$BNKRECORDID FACIALFINCAPTION.BNKRECORDID%TYPE := :NEW.BNKRECORDID;
  new$SUBPROGINDEX FACIALFINCAPTION.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$DOCUMENTSTATE FACIALFINCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA FACIALFINCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$TREASUARYDOCSTATECLS FACIALFINCAPTION.TREASUARYDOCSTATECLS%TYPE := :NEW.TREASUARYDOCSTATECLS;
  new$DEPARTMENTCLS FACIALFINCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$NDS FACIALFINCAPTION.NDS%TYPE := :NEW.NDS;
  new$TAXNOTE FACIALFINCAPTION.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$MANAGERBID FACIALFINCAPTION.MANAGERBID%TYPE := :NEW.MANAGERBID;
  new$BIDNUMBER FACIALFINCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$GROUPID FACIALFINCAPTION.GROUPID%TYPE := :NEW.GROUPID;
  new$GROUPSUMMA FACIALFINCAPTION.GROUPSUMMA%TYPE := :NEW.GROUPSUMMA;
  new$DOCSTATEREF FACIALFINCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$LASTEXTRCHANGE FACIALFINCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$FAXDOCCOUNT FACIALFINCAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$STIMATEID FACIALFINCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$INTEGRATEDDOCREF FACIALFINCAPTION.INTEGRATEDDOCREF%TYPE := :NEW.INTEGRATEDDOCREF;
  new$REQUESTNUMBER FACIALFINCAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$REQUESTDATE FACIALFINCAPTION.REQUESTDATE%TYPE := :NEW.REQUESTDATE;
  new$RVERSION FACIALFINCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$FEDERALFUNDSREF FACIALFINCAPTION.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$ELDOCREF FACIALFINCAPTION.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$BUHOPERATIONCLS FACIALFINCAPTION.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CLSTYPE FACIALFINCAPTION.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$OPERATIONDIRECTION FACIALFINCAPTION.OPERATIONDIRECTION%TYPE := :NEW.OPERATIONDIRECTION;
  new$SOURCETYPE FACIALFINCAPTION.SOURCETYPE%TYPE := :NEW.SOURCETYPE;
  new$DESTTYPE FACIALFINCAPTION.DESTTYPE%TYPE := :NEW.DESTTYPE;
  new$CARDNUMBER FACIALFINCAPTION.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$ISBLOCKED FACIALFINCAPTION.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINCAPTION.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINCAPTION.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINCAPTION.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$CASHIERPERSONALINFO FACIALFINCAPTION.CASHIERPERSONALINFO%TYPE := :NEW.CASHIERPERSONALINFO;
  new$BIDDATE FACIALFINCAPTION.BIDDATE%TYPE := :NEW.BIDDATE;
  new$CARDREF FACIALFINCAPTION.CARDREF%TYPE := :NEW.CARDREF;
  new$SOURCESTOREDPAYMENTPROPS FACIALFINCAPTION.SOURCESTOREDPAYMENTPROPS%TYPE := :NEW.SOURCESTOREDPAYMENTPROPS;
  new$DESTSTOREDPAYMENTPROPS FACIALFINCAPTION.DESTSTOREDPAYMENTPROPS%TYPE := :NEW.DESTSTOREDPAYMENTPROPS;
  new$STOREDPAYMENTNOTE FACIALFINCAPTION.STOREDPAYMENTNOTE%TYPE := :NEW.STOREDPAYMENTNOTE;
  new$DOCCHANGEDATE FACIALFINCAPTION.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$UINCODE FACIALFINCAPTION.UINCODE%TYPE := :NEW.UINCODE;
  new$DOCOSN FACIALFINCAPTION.DOCOSN%TYPE := :NEW.DOCOSN;
  new$SIGNERS FACIALFINCAPTION.SIGNERS%TYPE := :NEW.SIGNERS;
  new$DESTCLSTYPE FACIALFINCAPTION.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SENDERIDKEY FACIALFINCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$AUTOSANCTION FACIALFINCAPTION.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$STOREDPAYMENTCONTENT FACIALFINCAPTION.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
--
  SourceFacialAcc_CLS$ NUMBER(10);
  DestFacialAcc_CLS$ NUMBER(10);
  CNT$1 NUMBER(10);
  reestrAccepted1$ NUMBER(10);
  IsReject1$ NUMBER(10);
  UseFax$ NUMBER(10);
  DocNumber$ NUMBER(10);
  DetCount$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINCAPTION_BU)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is not null) then
    /*      */
    GetIntConst(30, 19,UseFax$);
    if ((new$BidNumber is null) and (UseFax$ = 1)) then
      new$BidNumber:= new$DocNumber;

    END IF;
  END IF;
  if (new$credit is null)then
    new$credit:= 0;
  END IF;
  if (new$ArhiveDoc is null) then
    new$ArhiveDoc:= 0;
  END IF;
  if (new$PayTypeCls is null) then
    new$PayTypeCls:= 0;
  END IF;
  if (new$BuhPaymentCls is null) then
    new$BuhPaymentCls:= 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$ClsType is null) then
    new$ClsType := 0;
  END IF;
  if (new$DestClsType is null) then
    new$DestClsType := new$ClsType;
  END IF;
  if (new$SourceFacialAcc_CLS is null) then
    new$SourceFacialAcc_CLS:= 0;
  END IF;
  if (new$DestFacialAcc_CLS is null) then
    new$DestFacialAcc_CLS:= 0;
  END IF;
  if (new$FaxDocCount is null) then
    new$FaxDocCount := 0;
  END IF;
  if (new$OperationDirection is null) then
    new$OperationDirection := 0;
  END IF;
  if (new$OperationDirection <> :old.OperationDirection) then
    if (new$OperationDirection = 0) then
      new$SourceType := 1;
      new$DestType := 1;

    else
      if (new$OperationDirection = 1) then
        new$SourceType := 1;
        new$DestType := -1;

      else
        if (new$OperationDirection = 2) then
          new$SourceType := -1;
          new$DestType := 1;

        else
          new$SourceType := -1;
          new$DestType := -1;

        END IF;
      END IF;
    END IF;
  END IF;
  if (new$DepartmentCls is null) then
    GetIntConst(30, 20,DocNumber$);
    if (DocNumber$ is null) then
      new$DepartmentCls:= 0;

    else
      new$DepartmentCls:= DocNumber$;

    END IF;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount$ from FacialFinDetail where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_Cls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_1 (TR_FACIALFINCAPTION_BU_1)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --   -     
   IF (new$GroupID IS NULL) THEN new$GroupID := new$ID; END IF;
   IF (new$GroupSumma IS NULL) THEN new$GroupSumma := 0; END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_FACIALFINCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (not (    ((new$progindex = 63) or (new$progindex = 64) or (new$progindex = 68) or (new$progindex = 70))
  and (   (((new$credit - :old.credit)>0.001)or((new$credit - :old.credit)<-0.001))
  or (new$sourcefacialacc_cls <> :old.sourcefacialacc_cls)
  or (
  ((new$sourceaccount is null) and (:old.sourceaccount is not null)) or
  ((new$sourceaccount is not null) and (:old.sourceaccount is null)) or
  ((new$sourceaccount <> :old.sourceaccount ) and (:old.sourceaccount is not null) and (new$sourceaccount is not null))
  )
  or (
  ((new$destaccount is null) and (:old.destaccount is not null)) or
  ((new$destaccount is not null) and (:old.destaccount is null)) or
  ((new$destaccount <> :old.destaccount ) and (:old.destaccount is not null) and (new$destaccount is not null))
  )
  or (    (:old.reestr_ref is null)
  and (new$reestr_ref is not null)
  )
  or (    (:old.reestr_ref is not null)
  and (new$reestr_ref is null)
  )
  or (:old.reestr_ref <> new$reestr_ref)
  )
  )
  )
  then /*      NULL */
    reestrAccepted1$ := 0;  /*   IB 4.2 */

  else
    BEGIN
      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id=new$REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrUpdate');
    END IF;
    BEGIN

      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id=:old.REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrUpdate');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_6 (TR_FACIALFINCAPTION_BU_6)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (:old.ProgIndex in(63,68,70)) then /*    */
    SELECT COUNT(id ) INTO CNT$1
    from paydocexchange where ((paydocref=:old.id)and(status<>0)and(TypeInf BETWEEN 0 and 10)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      if(/* (new.DOCNUMBER<>old.DOCNUMBER) or ((new.DOCNUMBER is NULL)and(not old.DOCNUMBER is NULL)) or ((old.DOCNUMBER is NULL)and(not new.DOCNUMBER is NULL)) or*/
      (new$SOURCEDOCNUM<>:old.SOURCEDOCNUM) or ((new$SOURCEDOCNUM is NULL)and(not :old.SOURCEDOCNUM is NULL)) or ((:old.SOURCEDOCNUM is NULL)and(not new$SOURCEDOCNUM is NULL)) or
      (new$PAYDATE<>:old.PAYDATE) or ((new$PAYDATE is NULL)and(not :old.PAYDATE is NULL)) or ((:old.PAYDATE is NULL)and(not new$PAYDATE is NULL))or
      /* (new.DOCUMENTDATE<>old.DOCUMENTDATE) or ((new.DOCUMENTDATE is NULL)and(not old.DOCUMENTDATE is NULL)) or ((old.DOCUMENTDATE is NULL)and(not new.DOCUMENTDATE is NULL))or*/
      (new$REESTRDATE<>:old.REESTRDATE) or ((new$REESTRDATE is NULL)and(not :old.REESTRDATE is NULL)) or ((:old.REESTRDATE is NULL)and(not new$REESTRDATE is NULL))or
      (((new$credit - :old.credit)>0.001)or((new$credit - :old.credit)<-0.001)) or
      (new$SOURCEACCOUNT<>:old.SOURCEACCOUNT) or
      (new$DESTACCOUNT<>:old.DESTACCOUNT) or
      (new$PAYTYPECLS<>:old.PAYTYPECLS) or
      (new$NOTE<>:old.NOTE) or  ((new$NOTE is NULL)and(not :old.NOTE is NULL)) or ((:old.NOTE is NULL)and(not new$NOTE is NULL))or
      (new$PAYPRIORITY<>:old.PAYPRIORITY) or ((new$PAYPRIORITY is NULL)and(not :old.PAYPRIORITY is NULL)) or ((:old.PAYPRIORITY is NULL)and(not new$PAYPRIORITY is NULL))or
      (new$REESTR_REF<>:old.REESTR_REF) or ((new$REESTR_REF is NULL)and(not :old.REESTR_REF is NULL)) or ((:old.REESTR_REF is NULL)and(not new$REESTR_REF is NULL))or
      (new$NDS<>:old.NDS) or ((new$NDS is NULL)and(not :old.NDS is NULL)) or ((:old.NDS is NULL)and(not new$NDS is NULL))or
      (new$TAXNOTE<>:old.TAXNOTE) or ((new$TAXNOTE is NULL)and(not :old.TAXNOTE is NULL)) or ((:old.TAXNOTE is NULL)and(not new$TAXNOTE is NULL)) )then
        RaiseException('ex_CannotChangeSended');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_FACIALFINCAPTION_BU_10)
-- Create 16.03.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$IntegratedDocRef IS NOT NULL) THEN
        /*           ,       
      /*    */
      IF (    (   (new$AcceptDate = :OLD.AcceptDate)
               OR ((new$AcceptDate IS NULL) AND (:OLD.AcceptDate IS NULL))
              )
          AND (   (new$Reject_CLS = :OLD.Reject_CLS)
               OR ((new$Reject_CLS IS NULL) AND (:OLD.Reject_CLS IS NULL))
              )
          AND (   (new$RejectCause = :OLD.RejectCause)
               OR ((new$RejectCause IS NULL) AND (:OLD.RejectCause IS NULL))
              )
          AND (   (new$TREASUARYDOCSTATECLS = :OLD.TREASUARYDOCSTATECLS)
               OR (    (new$TREASUARYDOCSTATECLS IS NULL)
                   AND (:OLD.TREASUARYDOCSTATECLS IS NULL)
                  )
              )
          AND (   (new$DOCSTATEREF = :OLD.DOCSTATEREF)
               OR ((new$DOCSTATEREF IS NULL) AND (:OLD.DOCSTATEREF IS NULL))
              )
          AND (   (new$REESTR_REF = :OLD.REESTR_REF)
               OR ((new$REESTR_REF IS NULL) AND (:OLD.REESTR_REF IS NULL))
              )
          AND (new$SOURCEACCOUNT = :OLD.SOURCEACCOUNT)
          AND (new$DESTACCOUNT = :OLD.DESTACCOUNT)
         ) THEN
         new$AcceptDate := :OLD.AcceptDate;
      ELSE
         FOR R$ IN (SELECT fc.AcceptDate, fc.Reject_CLS, fc.RejectCause,
                           fc.TREASUARYDOCSTATECLS, fc.DOCSTATEREF,
                           fc.REESTR_REF, fc.SOURCEACCOUNT, fc.DESTACCOUNT
                      FROM FacialFinCaption fc
                     WHERE (fc.ID = :NEW.IntegratedDocRef)) LOOP
            IF (    (   (new$AcceptDate = R$.AcceptDate)
                     OR ((new$AcceptDate IS NULL) AND (R$.AcceptDate IS NULL)
                        )
                    )
                AND (   (new$Reject_CLS = R$.Reject_CLS)
                     OR ((new$Reject_CLS IS NULL) AND (R$.Reject_CLS IS NULL)
                        )
                    )
                AND (   (new$RejectCause = R$.RejectCause)
                     OR (    (new$RejectCause IS NULL)
                         AND (R$.RejectCause IS NULL)
                        )
                    )
                AND (   (new$TREASUARYDOCSTATECLS = R$.TREASUARYDOCSTATECLS)
                     OR (    (new$TREASUARYDOCSTATECLS IS NULL)
                         AND (R$.TREASUARYDOCSTATECLS IS NULL)
                        )
                    )
                AND (   (new$DOCSTATEREF = R$.DOCSTATEREF)
                     OR (    (new$DOCSTATEREF IS NULL)
                         AND (R$.DOCSTATEREF IS NULL)
                        )
                    )
                AND (   (new$REESTR_REF = R$.REESTR_REF)
                     OR ((new$REESTR_REF IS NULL) AND (R$.REESTR_REF IS NULL)
                        )
                    )
                AND (new$SOURCEACCOUNT = R$.SOURCEACCOUNT)
                AND (new$DESTACCOUNT = R$.DESTACCOUNT)
               ) THEN
               new$AcceptDate := R$.AcceptDate;
            ELSE
               RaiseException ('EX_CANNOTUPDATECHILDDOC');
            END IF;
         END LOOP;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_32 (TR_FACIALFINCAPTION_BU_32)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$Reestr_ref IS NULL)    /*    select ,  */
                              THEN
      new$SourceDocNum := '';
      new$ReestrDate := NULL;
   ELSIF (    (new$Reestr_ref = :OLD.Reestr_ref)
          AND (new$SourceDocNum = :OLD.SourceDocNum)
          AND (new$ReestrDate = :OLD.ReestrDate)
         ) THEN
/*          */
      NULL;
   ELSE
      BEGIN
         SELECT ffr.ReestrNumber, ffr.ReestrDate
           INTO new$SourceDocNum, new$ReestrDate
           FROM FacialFinReestr ffr
          WHERE ffr.ID = new$Reestr_ref;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            new$SourceDocNum := NULL;
            new$ReestrDate := NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BU_60 (T_FACIALFINCAPTION_BU_60)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF ((new$progindex = 60) AND (new$Credit <> :OLD.Credit)) THEN
      UPDATE FacialFinDetail
         SET Credit = new$Credit
       WHERE (RecordIndex = new$ID);
   END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_FACIALFINCAPTION_BU_70)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --         
   IF (new$SubProgIndex = 416) THEN
      UPDATE Guarantee
         SET AcceptDate = new$AcceptDate
       WHERE SubRecordIndex = new$ID;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (T_FACIALFINCAPTION_BU_100)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*   ,    */
   IF (    (   (:OLD.SourceFacialAcc_CLS <> new$SourceFacialAcc_CLS)
            OR (:OLD.DestFacialAcc_CLS <> new$DestFacialAcc_CLS)
           )
       AND ((new$SubProgIndex <> 1) OR (new$SubProgIndex IS NULL))
      ) THEN
      FOR R$ IN (SELECT ID, SourceFacialAcc_CLS, DestFacialAcc_CLS
                   FROM FacialFinDetail
                  WHERE RecordIndex = new$ID) LOOP
         IF (NOT (new$SourceFacialAcc_CLS = 0)) THEN
            SourceFacialAcc_CLS$ := new$SourceFacialAcc_CLS;
         ELSE
            SourceFacialAcc_CLS$ := R$.SourceFacialAcc_CLS;
         END IF;

         IF (NOT (new$DestFacialAcc_CLS = 0)) THEN
            DestFacialAcc_CLS$ := new$DestFacialAcc_CLS;
         ELSE
            DestFacialAcc_CLS$ := R$.DestFacialAcc_CLS;
         END IF;

         IF (:OLD.SourceFacialAcc_CLS <> new$SourceFacialAcc_CLS) THEN
            UPDATE FacialFinDetail
               SET SourceFacialAcc_CLS = SourceFacialAcc_CLS$,
                   RVersion = -1
             WHERE (ID = R$.ID);
         END IF;

         IF (:OLD.DestFacialAcc_CLS <> new$DestFacialAcc_CLS) THEN
            UPDATE FacialFinDetail
               SET DestFacialAcc_CLS = DestFacialAcc_CLS$,
                   RVersion = -1
             WHERE (ID = R$.ID);
         END IF;
      END LOOP;
   END IF;

   /*    / , 
           .*/
  IF (((NEW$IsBlocked <> :OLD.IsBlocked) OR
      ((NEW$IsBlocked IS NULL) AND (:OLD.IsBlocked IS NOT NULL)) OR
      ((NEW$IsBlocked IS NOT NULL) AND (:OLD.IsBlocked IS NULL))
     ) OR
     ((NEW$BlockedCause <> :OLD.BlockedCause) OR
      ((NEW$BlockedCause IS NULL) AND (:OLD.BlockedCause IS NOT NULL)) OR
      ((NEW$BlockedCause IS NOT NULL) AND (:OLD.BlockedCause IS NULL))
     ) OR
     ((NEW$UnBlockedDate <> :OLD.UnBlockedDate) OR
      ((NEW$UnBlockedDate IS NULL) AND (:OLD.UnBlockedDate IS NOT NULL)) OR
      ((NEW$UnBlockedDate IS NOT NULL) AND (:OLD.UnBlockedDate IS NULL))
     ) OR
     ((NEW$UnBlockedCause <> :OLD.UnBlockedCause) OR
      ((NEW$UnBlockedDate IS NULL) AND (:OLD.UnBlockedCause IS NOT NULL)) OR
      ((NEW$UnBlockedCause IS NOT NULL) AND (:OLD.UnBlockedCause IS NULL))
     )) THEN
     UPDATE FacialFinDetail ffd
     SET ffd.IsBlocked = NEW$IsBlocked, ffd.BlockedCause = NEW$BlockedCause,
         ffd.UnBlockedDate = NEW$UnBlockedDate, ffd.UnBlockedCause = NEW$UnBlockedCause
     WHERE ffd.recordindex = NEW$ID;
  end if;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINCAPTION_BU_210)
-- Create 27.08.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*      */
   IF (new$DOCSTATEREF <> :OLD.DOCSTATEREF) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DOCSTATEREF, new$DOCSTATEREF
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (T_FACIALFINCAPTION_BU_300)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  IsReject1$ := -1;
  if ((:old.Reject_CLS is null)and(new$Reject_CLS is not null)) then
    IsReject1$ := 1;

  else
    if ((:old.Reject_CLS is not null)and(new$Reject_CLS is null)) then
      IsReject1$ := 0;
    END IF;
  END IF;
  if (IsReject1$  <> -1) then
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID = new$ID;
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID in (select d.id from FacialFinDetail d where d.RecordIndex = new$id);

  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINCAPTION_BU_700)
-- Create 17.09.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINCAPTION SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    SOURCEDOCNUM = new$SOURCEDOCNUM,
    PAYDATE = new$PAYDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    REESTRDATE = new$REESTRDATE,
    CREDIT = new$CREDIT,
    SOURCEACCOUNT = new$SOURCEACCOUNT,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    DESTACCOUNT = new$DESTACCOUNT,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    PROGINDEX = new$PROGINDEX,
    ARHIVEDOC = new$ARHIVEDOC,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    PAYTYPECLS = new$PAYTYPECLS,
    NOTE = new$NOTE,
    PERIOD = new$PERIOD,
    PAYPRIORITY = new$PAYPRIORITY,
    TYPEOPERATIONCLS = new$TYPEOPERATIONCLS,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    RECORDINDEX = new$RECORDINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REESTR_REF = new$REESTR_REF,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CLIENTBANKNUMBER = new$CLIENTBANKNUMBER,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    TRUSTNUMBER = new$TRUSTNUMBER,
    LINKEDDOCUMENT = new$LINKEDDOCUMENT,
    BNKRECORDID = new$BNKRECORDID,
    SUBPROGINDEX = new$SUBPROGINDEX,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    TREASUARYDOCSTATECLS = new$TREASUARYDOCSTATECLS,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    NDS = new$NDS,
    TAXNOTE = new$TAXNOTE,
    MANAGERBID = new$MANAGERBID,
    BIDNUMBER = new$BIDNUMBER,
    GROUPID = new$GROUPID,
    GROUPSUMMA = new$GROUPSUMMA,
    DOCSTATEREF = new$DOCSTATEREF,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    FAXDOCCOUNT = new$FAXDOCCOUNT,
    STIMATEID = new$STIMATEID,
    INTEGRATEDDOCREF = new$INTEGRATEDDOCREF,
    REQUESTNUMBER = new$REQUESTNUMBER,
    REQUESTDATE = new$REQUESTDATE,
    RVERSION = new$RVERSION,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    ELDOCREF = new$ELDOCREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    CLSTYPE = new$CLSTYPE,
    OPERATIONDIRECTION = new$OPERATIONDIRECTION,
    SOURCETYPE = new$SOURCETYPE,
    DESTTYPE = new$DESTTYPE,
    CARDNUMBER = new$CARDNUMBER,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    CASHIERPERSONALINFO = new$CASHIERPERSONALINFO,
    BIDDATE = new$BIDDATE,
    CARDREF = new$CARDREF,
    SOURCESTOREDPAYMENTPROPS = new$SOURCESTOREDPAYMENTPROPS,
    DESTSTOREDPAYMENTPROPS = new$DESTSTOREDPAYMENTPROPS,
    STOREDPAYMENTNOTE = new$STOREDPAYMENTNOTE,
    DOCCHANGEDATE = new$DOCCHANGEDATE,
    UINCODE = new$UINCODE,
    DOCOSN = new$DOCOSN,
    SIGNERS = new$SIGNERS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    AUTOSANCTION = new$AUTOSANCTION,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_300 (TR_FACIALFINCAPTION_AU_300)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*          ,      */
  if ((new$AcceptDate <> :old.AcceptDate)or((new$AcceptDate is not null)and(:old.AcceptDate is null))
  or((new$AcceptDate is null)and(:old.AcceptDate is not null))) then
    update facialfindetail set
    AcceptDate = new$AcceptDate,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;
  if (new$BuhOperationCLS <> :old.BuhOperationCLS)  then
    update facialfindetail set
    BuhOperationCLS = new$BuhOperationCLS,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;
  if ((new$ClsType <> :old.ClsType)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$ClsType = 0) then
      update facialfindetail set
      SourceKD = 0,
      DestKD = 0,
      SourceIFS = 0,
      DestIFS = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 1) then
      update facialfindetail set
      SourceKD = 0,
      DestKD = 0,
      SourceKVSR = 0,
      SourceKFSR = 0,
      SourceKCSR = 0,
      SourceKVR = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 2) then
      update facialfindetail set
      SourceIFS = 0,
      DestIFS = 0,
      SourceKVSR = 0,
      SourceKFSR = 0,
      SourceKCSR = 0,
      SourceKVR = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);

    END IF;
  END IF;
  if ((new$DestClsType <> :old.DestClsType)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$DestClsType = 0) then
      update facialfindetail set
      DestKD = 0,
      DestIFS = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
    END IF;
    if (new$DestClsType = 1) then
      update facialfindetail set
      DestKD = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
    END IF;
    if (new$DestClsType = 2) then
      update facialfindetail set
      DestIFS = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINCAPTION_AU_500)
-- Create 28.04.2005
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (:NEW.ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (23, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
        WHERE (TableID = 23) AND (RecordId = :NEW.ID);
   END IF;

END;
/
-- drop trigger TR_FACIALFINCAPTION_BU_10
CREATE OR REPLACE TRIGGER TR_FACIALFINCAPTION_IU
  INSTEAD OF UPDATE
  ON FACIALFINCAPTION
  FOR EACH ROW
DECLARE
  new$ID FACIALFINCAPTION.ID%TYPE := :NEW.ID;
  new$DOCNUMBER FACIALFINCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SOURCEDOCNUM FACIALFINCAPTION.SOURCEDOCNUM%TYPE := :NEW.SOURCEDOCNUM;
  new$PAYDATE FACIALFINCAPTION.PAYDATE%TYPE := :NEW.PAYDATE;
  new$ACCEPTDATE FACIALFINCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCUMENTDATE FACIALFINCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$REESTRDATE FACIALFINCAPTION.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$CREDIT FACIALFINCAPTION.CREDIT%TYPE := :NEW.CREDIT;
  new$SOURCEACCOUNT FACIALFINCAPTION.SOURCEACCOUNT%TYPE := :NEW.SOURCEACCOUNT;
  new$SOURCEFACIALACC_CLS FACIALFINCAPTION.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$DESTACCOUNT FACIALFINCAPTION.DESTACCOUNT%TYPE := :NEW.DESTACCOUNT;
  new$DESTFACIALACC_CLS FACIALFINCAPTION.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$PROGINDEX FACIALFINCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$ARHIVEDOC FACIALFINCAPTION.ARHIVEDOC%TYPE := :NEW.ARHIVEDOC;
  new$PAYSYMBOLCLS FACIALFINCAPTION.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$PAYTYPECLS FACIALFINCAPTION.PAYTYPECLS%TYPE := :NEW.PAYTYPECLS;
  new$NOTE FACIALFINCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$PERIOD FACIALFINCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$PAYPRIORITY FACIALFINCAPTION.PAYPRIORITY%TYPE := :NEW.PAYPRIORITY;
  new$TYPEOPERATIONCLS FACIALFINCAPTION.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$BUHPAYMENTCLS FACIALFINCAPTION.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$CREATERUSER FACIALFINCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF FACIALFINCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECORDINDEX FACIALFINCAPTION.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$SENDERID FACIALFINCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REESTR_REF FACIALFINCAPTION.REESTR_REF%TYPE := :NEW.REESTR_REF;
  new$REJECT_CLS FACIALFINCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CLIENTBANKNUMBER FACIALFINCAPTION.CLIENTBANKNUMBER%TYPE := :NEW.CLIENTBANKNUMBER;
  new$CRYPTOSTATUS FACIALFINCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$TRUSTNUMBER FACIALFINCAPTION.TRUSTNUMBER%TYPE := :NEW.TRUSTNUMBER;
  new$LINKEDDOCUMENT FACIALFINCAPTION.LINKEDDOCUMENT%TYPE := :NEW.LINKEDDOCUMENT;
  new$BNKRECORDID FACIALFINCAPTION.BNKRECORDID%TYPE := :NEW.BNKRECORDID;
  new$SUBPROGINDEX FACIALFINCAPTION.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$DOCUMENTSTATE FACIALFINCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA FACIALFINCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$TREASUARYDOCSTATECLS FACIALFINCAPTION.TREASUARYDOCSTATECLS%TYPE := :NEW.TREASUARYDOCSTATECLS;
  new$DEPARTMENTCLS FACIALFINCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$NDS FACIALFINCAPTION.NDS%TYPE := :NEW.NDS;
  new$TAXNOTE FACIALFINCAPTION.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$MANAGERBID FACIALFINCAPTION.MANAGERBID%TYPE := :NEW.MANAGERBID;
  new$BIDNUMBER FACIALFINCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$GROUPID FACIALFINCAPTION.GROUPID%TYPE := :NEW.GROUPID;
  new$GROUPSUMMA FACIALFINCAPTION.GROUPSUMMA%TYPE := :NEW.GROUPSUMMA;
  new$DOCSTATEREF FACIALFINCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$LASTEXTRCHANGE FACIALFINCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$FAXDOCCOUNT FACIALFINCAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$STIMATEID FACIALFINCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$INTEGRATEDDOCREF FACIALFINCAPTION.INTEGRATEDDOCREF%TYPE := :NEW.INTEGRATEDDOCREF;
  new$REQUESTNUMBER FACIALFINCAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$REQUESTDATE FACIALFINCAPTION.REQUESTDATE%TYPE := :NEW.REQUESTDATE;
  new$RVERSION FACIALFINCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$FEDERALFUNDSREF FACIALFINCAPTION.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$ELDOCREF FACIALFINCAPTION.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$BUHOPERATIONCLS FACIALFINCAPTION.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CLSTYPE FACIALFINCAPTION.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$OPERATIONDIRECTION FACIALFINCAPTION.OPERATIONDIRECTION%TYPE := :NEW.OPERATIONDIRECTION;
  new$SOURCETYPE FACIALFINCAPTION.SOURCETYPE%TYPE := :NEW.SOURCETYPE;
  new$DESTTYPE FACIALFINCAPTION.DESTTYPE%TYPE := :NEW.DESTTYPE;
  new$CARDNUMBER FACIALFINCAPTION.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$ISBLOCKED FACIALFINCAPTION.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINCAPTION.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINCAPTION.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINCAPTION.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$CASHIERPERSONALINFO FACIALFINCAPTION.CASHIERPERSONALINFO%TYPE := :NEW.CASHIERPERSONALINFO;
  new$BIDDATE FACIALFINCAPTION.BIDDATE%TYPE := :NEW.BIDDATE;
  new$CARDREF FACIALFINCAPTION.CARDREF%TYPE := :NEW.CARDREF;
  new$SOURCESTOREDPAYMENTPROPS FACIALFINCAPTION.SOURCESTOREDPAYMENTPROPS%TYPE := :NEW.SOURCESTOREDPAYMENTPROPS;
  new$DESTSTOREDPAYMENTPROPS FACIALFINCAPTION.DESTSTOREDPAYMENTPROPS%TYPE := :NEW.DESTSTOREDPAYMENTPROPS;
  new$STOREDPAYMENTNOTE FACIALFINCAPTION.STOREDPAYMENTNOTE%TYPE := :NEW.STOREDPAYMENTNOTE;
  new$DOCCHANGEDATE FACIALFINCAPTION.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$UINCODE FACIALFINCAPTION.UINCODE%TYPE := :NEW.UINCODE;
  new$DOCOSN FACIALFINCAPTION.DOCOSN%TYPE := :NEW.DOCOSN;
  new$SIGNERS FACIALFINCAPTION.SIGNERS%TYPE := :NEW.SIGNERS;
  new$DESTCLSTYPE FACIALFINCAPTION.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SENDERIDKEY FACIALFINCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$AUTOSANCTION FACIALFINCAPTION.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$STOREDPAYMENTCONTENT FACIALFINCAPTION.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
--
  SourceFacialAcc_CLS$ NUMBER(10);
  DestFacialAcc_CLS$ NUMBER(10);
  CNT$1 NUMBER(10);
  reestrAccepted1$ NUMBER(10);
  IsReject1$ NUMBER(10);
  UseFax$ NUMBER(10);
  DocNumber$ NUMBER(10);
  DetCount$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINCAPTION_BU)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is not null) then
    /*      */
    GetIntConst(30, 19,UseFax$);
    if ((new$BidNumber is null) and (UseFax$ = 1)) then
      new$BidNumber:= new$DocNumber;

    END IF;
  END IF;
  if (new$credit is null)then
    new$credit:= 0;
  END IF;
  if (new$ArhiveDoc is null) then
    new$ArhiveDoc:= 0;
  END IF;
  if (new$PayTypeCls is null) then
    new$PayTypeCls:= 0;
  END IF;
  if (new$BuhPaymentCls is null) then
    new$BuhPaymentCls:= 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$ClsType is null) then
    new$ClsType := 0;
  END IF;
  if (new$DestClsType is null) then
    new$DestClsType := new$ClsType;
  END IF;
  if (new$SourceFacialAcc_CLS is null) then
    new$SourceFacialAcc_CLS:= 0;
  END IF;
  if (new$DestFacialAcc_CLS is null) then
    new$DestFacialAcc_CLS:= 0;
  END IF;
  if (new$FaxDocCount is null) then
    new$FaxDocCount := 0;
  END IF;
  if (new$OperationDirection is null) then
    new$OperationDirection := 0;
  END IF;
  if (new$OperationDirection <> :old.OperationDirection) then
    if (new$OperationDirection = 0) then
      new$SourceType := 1;
      new$DestType := 1;

    else
      if (new$OperationDirection = 1) then
        new$SourceType := 1;
        new$DestType := -1;

      else
        if (new$OperationDirection = 2) then
          new$SourceType := -1;
          new$DestType := 1;

        else
          new$SourceType := -1;
          new$DestType := -1;

        END IF;
      END IF;
    END IF;
  END IF;
  if (new$DepartmentCls is null) then
    GetIntConst(30, 20,DocNumber$);
    if (DocNumber$ is null) then
      new$DepartmentCls:= 0;

    else
      new$DepartmentCls:= DocNumber$;

    END IF;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount$ from FacialFinDetail where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_Cls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_1 (TR_FACIALFINCAPTION_BU_1)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --   -     
   IF (new$GroupID IS NULL) THEN new$GroupID := new$ID; END IF;
   IF (new$GroupSumma IS NULL) THEN new$GroupSumma := 0; END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_FACIALFINCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (not (    ((new$progindex = 63) or (new$progindex = 64) or (new$progindex = 68) or (new$progindex = 70))
  and (   (((new$credit - :old.credit)>0.001)or((new$credit - :old.credit)<-0.001))
  or (new$sourcefacialacc_cls <> :old.sourcefacialacc_cls)
  or (
  ((new$sourceaccount is null) and (:old.sourceaccount is not null)) or
  ((new$sourceaccount is not null) and (:old.sourceaccount is null)) or
  ((new$sourceaccount <> :old.sourceaccount ) and (:old.sourceaccount is not null) and (new$sourceaccount is not null))
  )
  or (
  ((new$destaccount is null) and (:old.destaccount is not null)) or
  ((new$destaccount is not null) and (:old.destaccount is null)) or
  ((new$destaccount <> :old.destaccount ) and (:old.destaccount is not null) and (new$destaccount is not null))
  )
  or (    (:old.reestr_ref is null)
  and (new$reestr_ref is not null)
  )
  or (    (:old.reestr_ref is not null)
  and (new$reestr_ref is null)
  )
  or (:old.reestr_ref <> new$reestr_ref)
  )
  )
  )
  then /*      NULL */
    reestrAccepted1$ := 0;  /*   IB 4.2 */

  else
    BEGIN
      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id=new$REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrUpdate');
    END IF;
    BEGIN

      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id=:old.REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrUpdate');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_6 (TR_FACIALFINCAPTION_BU_6)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (:old.ProgIndex in(63,68,70)) then /*    */
    SELECT COUNT(id ) INTO CNT$1
    from paydocexchange where ((paydocref=:old.id)and(status<>0)and(TypeInf BETWEEN 0 and 10)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      if(/* (new.DOCNUMBER<>old.DOCNUMBER) or ((new.DOCNUMBER is NULL)and(not old.DOCNUMBER is NULL)) or ((old.DOCNUMBER is NULL)and(not new.DOCNUMBER is NULL)) or*/
      (new$SOURCEDOCNUM<>:old.SOURCEDOCNUM) or ((new$SOURCEDOCNUM is NULL)and(not :old.SOURCEDOCNUM is NULL)) or ((:old.SOURCEDOCNUM is NULL)and(not new$SOURCEDOCNUM is NULL)) or
      (new$PAYDATE<>:old.PAYDATE) or ((new$PAYDATE is NULL)and(not :old.PAYDATE is NULL)) or ((:old.PAYDATE is NULL)and(not new$PAYDATE is NULL))or
      /* (new.DOCUMENTDATE<>old.DOCUMENTDATE) or ((new.DOCUMENTDATE is NULL)and(not old.DOCUMENTDATE is NULL)) or ((old.DOCUMENTDATE is NULL)and(not new.DOCUMENTDATE is NULL))or*/
      (new$REESTRDATE<>:old.REESTRDATE) or ((new$REESTRDATE is NULL)and(not :old.REESTRDATE is NULL)) or ((:old.REESTRDATE is NULL)and(not new$REESTRDATE is NULL))or
      (((new$credit - :old.credit)>0.001)or((new$credit - :old.credit)<-0.001)) or
      (new$SOURCEACCOUNT<>:old.SOURCEACCOUNT) or
      (new$DESTACCOUNT<>:old.DESTACCOUNT) or
      (new$PAYTYPECLS<>:old.PAYTYPECLS) or
      (new$NOTE<>:old.NOTE) or  ((new$NOTE is NULL)and(not :old.NOTE is NULL)) or ((:old.NOTE is NULL)and(not new$NOTE is NULL))or
      (new$PAYPRIORITY<>:old.PAYPRIORITY) or ((new$PAYPRIORITY is NULL)and(not :old.PAYPRIORITY is NULL)) or ((:old.PAYPRIORITY is NULL)and(not new$PAYPRIORITY is NULL))or
      (new$REESTR_REF<>:old.REESTR_REF) or ((new$REESTR_REF is NULL)and(not :old.REESTR_REF is NULL)) or ((:old.REESTR_REF is NULL)and(not new$REESTR_REF is NULL))or
      (new$NDS<>:old.NDS) or ((new$NDS is NULL)and(not :old.NDS is NULL)) or ((:old.NDS is NULL)and(not new$NDS is NULL))or
      (new$TAXNOTE<>:old.TAXNOTE) or ((new$TAXNOTE is NULL)and(not :old.TAXNOTE is NULL)) or ((:old.TAXNOTE is NULL)and(not new$TAXNOTE is NULL)) )then
        RaiseException('ex_CannotChangeSended');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_32 (TR_FACIALFINCAPTION_BU_32)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$Reestr_ref IS NULL)    /*    select ,  */
                              THEN
      new$SourceDocNum := '';
      new$ReestrDate := NULL;
   ELSIF (    (new$Reestr_ref = :OLD.Reestr_ref)
          AND (new$SourceDocNum = :OLD.SourceDocNum)
          AND (new$ReestrDate = :OLD.ReestrDate)
         ) THEN
/*          */
      NULL;
   ELSE
      BEGIN
         SELECT ffr.ReestrNumber, ffr.ReestrDate
           INTO new$SourceDocNum, new$ReestrDate
           FROM FacialFinReestr ffr
          WHERE ffr.ID = new$Reestr_ref;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            new$SourceDocNum := NULL;
            new$ReestrDate := NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BU_60 (T_FACIALFINCAPTION_BU_60)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF ((new$progindex = 60) AND (new$Credit <> :OLD.Credit)) THEN
      UPDATE FacialFinDetail
         SET Credit = new$Credit
       WHERE (RecordIndex = new$ID);
   END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_FACIALFINCAPTION_BU_70)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --         
   IF (new$SubProgIndex = 416) THEN
      UPDATE Guarantee
         SET AcceptDate = new$AcceptDate
       WHERE SubRecordIndex = new$ID;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (T_FACIALFINCAPTION_BU_100)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*   ,    */
   IF (    (   (:OLD.SourceFacialAcc_CLS <> new$SourceFacialAcc_CLS)
            OR (:OLD.DestFacialAcc_CLS <> new$DestFacialAcc_CLS)
           )
       AND ((new$SubProgIndex <> 1) OR (new$SubProgIndex IS NULL))
      ) THEN
      FOR R$ IN (SELECT ID, SourceFacialAcc_CLS, DestFacialAcc_CLS
                   FROM FacialFinDetail
                  WHERE RecordIndex = new$ID) LOOP
         IF (NOT (new$SourceFacialAcc_CLS = 0)) THEN
            SourceFacialAcc_CLS$ := new$SourceFacialAcc_CLS;
         ELSE
            SourceFacialAcc_CLS$ := R$.SourceFacialAcc_CLS;
         END IF;

         IF (NOT (new$DestFacialAcc_CLS = 0)) THEN
            DestFacialAcc_CLS$ := new$DestFacialAcc_CLS;
         ELSE
            DestFacialAcc_CLS$ := R$.DestFacialAcc_CLS;
         END IF;

         IF (:OLD.SourceFacialAcc_CLS <> new$SourceFacialAcc_CLS) THEN
            UPDATE FacialFinDetail
               SET SourceFacialAcc_CLS = SourceFacialAcc_CLS$,
                   RVersion = -1
             WHERE (ID = R$.ID);
         END IF;

         IF (:OLD.DestFacialAcc_CLS <> new$DestFacialAcc_CLS) THEN
            UPDATE FacialFinDetail
               SET DestFacialAcc_CLS = DestFacialAcc_CLS$,
                   RVersion = -1
             WHERE (ID = R$.ID);
         END IF;
      END LOOP;
   END IF;

   /*    / , 
           .*/
  IF (((NEW$IsBlocked <> :OLD.IsBlocked) OR
      ((NEW$IsBlocked IS NULL) AND (:OLD.IsBlocked IS NOT NULL)) OR
      ((NEW$IsBlocked IS NOT NULL) AND (:OLD.IsBlocked IS NULL))
     ) OR
     ((NEW$BlockedCause <> :OLD.BlockedCause) OR
      ((NEW$BlockedCause IS NULL) AND (:OLD.BlockedCause IS NOT NULL)) OR
      ((NEW$BlockedCause IS NOT NULL) AND (:OLD.BlockedCause IS NULL))
     ) OR
     ((NEW$UnBlockedDate <> :OLD.UnBlockedDate) OR
      ((NEW$UnBlockedDate IS NULL) AND (:OLD.UnBlockedDate IS NOT NULL)) OR
      ((NEW$UnBlockedDate IS NOT NULL) AND (:OLD.UnBlockedDate IS NULL))
     ) OR
     ((NEW$UnBlockedCause <> :OLD.UnBlockedCause) OR
      ((NEW$UnBlockedDate IS NULL) AND (:OLD.UnBlockedCause IS NOT NULL)) OR
      ((NEW$UnBlockedCause IS NOT NULL) AND (:OLD.UnBlockedCause IS NULL))
     )) THEN
     UPDATE FacialFinDetail ffd
     SET ffd.IsBlocked = NEW$IsBlocked, ffd.BlockedCause = NEW$BlockedCause,
         ffd.UnBlockedDate = NEW$UnBlockedDate, ffd.UnBlockedCause = NEW$UnBlockedCause
     WHERE ffd.recordindex = NEW$ID;
  end if;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINCAPTION_BU_210)
-- Create 27.08.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*      */
   IF (new$DOCSTATEREF <> :OLD.DOCSTATEREF) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DOCSTATEREF, new$DOCSTATEREF
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (T_FACIALFINCAPTION_BU_300)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  IsReject1$ := -1;
  if ((:old.Reject_CLS is null)and(new$Reject_CLS is not null)) then
    IsReject1$ := 1;

  else
    if ((:old.Reject_CLS is not null)and(new$Reject_CLS is null)) then
      IsReject1$ := 0;
    END IF;
  END IF;
  if (IsReject1$  <> -1) then
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID = new$ID;
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID in (select d.id from FacialFinDetail d where d.RecordIndex = new$id);

  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINCAPTION_BU_700)
-- Create 17.09.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINCAPTION SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    SOURCEDOCNUM = new$SOURCEDOCNUM,
    PAYDATE = new$PAYDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    REESTRDATE = new$REESTRDATE,
    CREDIT = new$CREDIT,
    SOURCEACCOUNT = new$SOURCEACCOUNT,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    DESTACCOUNT = new$DESTACCOUNT,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    PROGINDEX = new$PROGINDEX,
    ARHIVEDOC = new$ARHIVEDOC,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    PAYTYPECLS = new$PAYTYPECLS,
    NOTE = new$NOTE,
    PERIOD = new$PERIOD,
    PAYPRIORITY = new$PAYPRIORITY,
    TYPEOPERATIONCLS = new$TYPEOPERATIONCLS,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    RECORDINDEX = new$RECORDINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REESTR_REF = new$REESTR_REF,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CLIENTBANKNUMBER = new$CLIENTBANKNUMBER,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    TRUSTNUMBER = new$TRUSTNUMBER,
    LINKEDDOCUMENT = new$LINKEDDOCUMENT,
    BNKRECORDID = new$BNKRECORDID,
    SUBPROGINDEX = new$SUBPROGINDEX,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    TREASUARYDOCSTATECLS = new$TREASUARYDOCSTATECLS,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    NDS = new$NDS,
    TAXNOTE = new$TAXNOTE,
    MANAGERBID = new$MANAGERBID,
    BIDNUMBER = new$BIDNUMBER,
    GROUPID = new$GROUPID,
    GROUPSUMMA = new$GROUPSUMMA,
    DOCSTATEREF = new$DOCSTATEREF,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    FAXDOCCOUNT = new$FAXDOCCOUNT,
    STIMATEID = new$STIMATEID,
    INTEGRATEDDOCREF = new$INTEGRATEDDOCREF,
    REQUESTNUMBER = new$REQUESTNUMBER,
    REQUESTDATE = new$REQUESTDATE,
    RVERSION = new$RVERSION,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    ELDOCREF = new$ELDOCREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    CLSTYPE = new$CLSTYPE,
    OPERATIONDIRECTION = new$OPERATIONDIRECTION,
    SOURCETYPE = new$SOURCETYPE,
    DESTTYPE = new$DESTTYPE,
    CARDNUMBER = new$CARDNUMBER,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    CASHIERPERSONALINFO = new$CASHIERPERSONALINFO,
    BIDDATE = new$BIDDATE,
    CARDREF = new$CARDREF,
    SOURCESTOREDPAYMENTPROPS = new$SOURCESTOREDPAYMENTPROPS,
    DESTSTOREDPAYMENTPROPS = new$DESTSTOREDPAYMENTPROPS,
    STOREDPAYMENTNOTE = new$STOREDPAYMENTNOTE,
    DOCCHANGEDATE = new$DOCCHANGEDATE,
    UINCODE = new$UINCODE,
    DOCOSN = new$DOCOSN,
    SIGNERS = new$SIGNERS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    AUTOSANCTION = new$AUTOSANCTION,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_300 (TR_FACIALFINCAPTION_AU_300)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*          ,      */
  if ((new$AcceptDate <> :old.AcceptDate)or((new$AcceptDate is not null)and(:old.AcceptDate is null))
  or((new$AcceptDate is null)and(:old.AcceptDate is not null))) then
    update facialfindetail set
    AcceptDate = new$AcceptDate,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;
  if (new$BuhOperationCLS <> :old.BuhOperationCLS)  then
    update facialfindetail set
    BuhOperationCLS = new$BuhOperationCLS,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;
  if ((new$ClsType <> :old.ClsType)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$ClsType = 0) then
      update facialfindetail set
      SourceKD = 0,
      DestKD = 0,
      SourceIFS = 0,
      DestIFS = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 1) then
      update facialfindetail set
      SourceKD = 0,
      DestKD = 0,
      SourceKVSR = 0,
      SourceKFSR = 0,
      SourceKCSR = 0,
      SourceKVR = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 2) then
      update facialfindetail set
      SourceIFS = 0,
      DestIFS = 0,
      SourceKVSR = 0,
      SourceKFSR = 0,
      SourceKCSR = 0,
      SourceKVR = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);

    END IF;
  END IF;
  if ((new$DestClsType <> :old.DestClsType)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$DestClsType = 0) then
      update facialfindetail set
      DestKD = 0,
      DestIFS = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
    END IF;
    if (new$DestClsType = 1) then
      update facialfindetail set
      DestKD = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
    END IF;
    if (new$DestClsType = 2) then
      update facialfindetail set
      DestIFS = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINCAPTION_AU_500)
-- Create 28.04.2005
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (:NEW.ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (23, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
        WHERE (TableID = 23) AND (RecordId = :NEW.ID);
   END IF;

END;
/
ALTER TABLE TB_FACIALFINCAPTION ADD (
  TempRejectCause VARCHAR2(255)
)
/

CREATE OR REPLACE VIEW FACIALFINCAPTION (
  ID,
  DOCNUMBER,
  SOURCEDOCNUM,
  PAYDATE,
  ACCEPTDATE,
  DOCUMENTDATE,
  REESTRDATE,
  CREDIT,
  SOURCEACCOUNT,
  SOURCEFACIALACC_CLS,
  DESTACCOUNT,
  DESTFACIALACC_CLS,
  PROGINDEX,
  ARHIVEDOC,
  PAYSYMBOLCLS,
  PAYTYPECLS,
  NOTE,
  PERIOD,
  PAYPRIORITY,
  TYPEOPERATIONCLS,
  BUHPAYMENTCLS,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  BUDGETREF,
  RECORDINDEX,
  SENDERID,
  SENDERRECORDID,
  REESTR_REF,
  REJECT_CLS,
  REJECTCAUSE,
  CLIENTBANKNUMBER,
  CRYPTOSTATUS,
  TRUSTNUMBER,
  LINKEDDOCUMENT,
  BNKRECORDID,
  SUBPROGINDEX,
  DOCUMENTSTATE,
  USERSVISA,
  TREASUARYDOCSTATECLS,
  DEPARTMENTCLS,
  NDS,
  TAXNOTE,
  MANAGERBID,
  BIDNUMBER,
  GROUPID,
  GROUPSUMMA,
  DOCSTATEREF,
  LASTEXTRCHANGE,
  FAXDOCCOUNT,
  STIMATEID,
  INTEGRATEDDOCREF,
  REQUESTNUMBER,
  REQUESTDATE,
  RVERSION,
  FEDERALFUNDSREF,
  ELDOCREF,
  BUHOPERATIONCLS,
  CLSTYPE,
  OPERATIONDIRECTION,
  SOURCETYPE,
  DESTTYPE,
  CARDNUMBER,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  CASHIERPERSONALINFO,
  BIDDATE,
  CARDREF,
  SOURCESTOREDPAYMENTPROPS,
  DESTSTOREDPAYMENTPROPS,
  STOREDPAYMENTNOTE,
  DOCCHANGEDATE,
  UINCODE,
  DOCOSN,
  SIGNERS,
  DESTCLSTYPE,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  AUTOSANCTION,
  STOREDPAYMENTCONTENT,
  TEMPREJECTCAUSE)
AS
  SELECT
    ID,
    DOCNUMBER,
    SOURCEDOCNUM,
    PAYDATE,
    ACCEPTDATE,
    DOCUMENTDATE,
    REESTRDATE,
    CREDIT,
    SOURCEACCOUNT,
    SOURCEFACIALACC_CLS,
    DESTACCOUNT,
    DESTFACIALACC_CLS,
    PROGINDEX,
    ARHIVEDOC,
    PAYSYMBOLCLS,
    PAYTYPECLS,
    NOTE,
    PERIOD,
    PAYPRIORITY,
    TYPEOPERATIONCLS,
    BUHPAYMENTCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    RECORDINDEX,
    SENDERID,
    SENDERRECORDID,
    REESTR_REF,
    REJECT_CLS,
    REJECTCAUSE,
    CLIENTBANKNUMBER,
    CRYPTOSTATUS,
    TRUSTNUMBER,
    LINKEDDOCUMENT,
    BNKRECORDID,
    SUBPROGINDEX,
    DOCUMENTSTATE,
    USERSVISA,
    TREASUARYDOCSTATECLS,
    DEPARTMENTCLS,
    NDS,
    TAXNOTE,
    MANAGERBID,
    BIDNUMBER,
    GROUPID,
    GROUPSUMMA,
    DOCSTATEREF,
    LASTEXTRCHANGE,
    FAXDOCCOUNT,
    STIMATEID,
    INTEGRATEDDOCREF,
    REQUESTNUMBER,
    REQUESTDATE,
    RVERSION,
    FEDERALFUNDSREF,
    ELDOCREF,
    BUHOPERATIONCLS,
    CLSTYPE,
    OPERATIONDIRECTION,
    SOURCETYPE,
    DESTTYPE,
    CARDNUMBER,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    CASHIERPERSONALINFO,
    BIDDATE,
    CARDREF,
    SOURCESTOREDPAYMENTPROPS,
    DESTSTOREDPAYMENTPROPS,
    STOREDPAYMENTNOTE,
    DOCCHANGEDATE,
    UINCODE,
    DOCOSN,
    SIGNERS,
    DESTCLSTYPE,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    AUTOSANCTION,
    STOREDPAYMENTCONTENT,
    TEMPREJECTCAUSE
  FROM TB_FACIALFINCAPTION
/

CREATE OR REPLACE TRIGGER TR_FACIALFINCAPTION_ID
  INSTEAD OF DELETE
  ON FACIALFINCAPTION
  FOR EACH ROW
DECLARE
  reestrAccepted1$ NUMBER(10);
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_FACIALFINCAPTION_BD)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

 /*       */
  DELETE FROM FacialFinDetail
        WHERE (RecordIndex = :OLD.ID);

-- - - - - - - - - - - - -
-- BD_5 (TR_FACIALFINCAPTION_BD_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (((:old.progIndex = 63) or (:old.progIndex = 64) or
  (:old.progIndex = 68) or (:old.progIndex = 70))
  and (:old.REESTR_REF is not null)) then
    BEGIN
      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id = :old.REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrDelete');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BD_6 (TR_FACIALFINCAPTION_BD_6)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(id ) INTO CNT$1
  from paydocexchange where ((paydocref=:old.id)and(status<>0)and(TypeInf BETWEEN 0 and 10)) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    RaiseException('ex_CannotChangeSended');
  else
    delete from PayDocExchange where paydocref = :old.id;
  END IF;

-- - - - - - - - - - - - -
-- BD_430 (TR_FACIALFINCAPTION_BD_430)
-- Create 04.12.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

  /*         */
  UPDATE FaxDocs
     SET OwnerID = NULL
  WHERE OwnerID = :OLD.ID;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_FACIALFINCAPTION
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_70 (TR_FACIALFINCAPTION_AD_70)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

--   /     
  IF (:OLD.SubProgIndex = 416) THEN
    UPDATE Guarantee
       SET SubRecordIndex = NULL,
           SubProgIndex = 0
     WHERE SubRecordIndex = :OLD.ID;
  END IF;

-- - - - - - - - - - - - -
-- AD_200 (TR_FACIALFINCAPTION_AD_200)
-- Create 27.08.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

  /*       */
  delete from StateJumpHistory
    where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_300 (TR_FACIALFINCAPTION_AD_300)
-- Create 24.02.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

  IF (:OLD.FaxDocCount > 0) THEN
--    :old.FaxDocCount := :old.FaxDocCount;
    NULL;
  ELSE
    UPDATE FaxDocs
       SET OwnerID = NULL
     WHERE OwnerID = :OLD.ID;
  END IF;

-- - - - - - - - - - - - -
-- AD_500 (TR_FACIALFINCAPTION_AD_500)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

  INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate, ProgIndex, Summa)
    VALUES (23, :OLD.ID, SYSDATE, :OLD.ProgIndex, :OLD.Credit);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINCAPTION_II
  INSTEAD OF INSERT
  ON FACIALFINCAPTION
  FOR EACH ROW
DECLARE
  new$ID FACIALFINCAPTION.ID%TYPE := :NEW.ID;
  new$DOCNUMBER FACIALFINCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SOURCEDOCNUM FACIALFINCAPTION.SOURCEDOCNUM%TYPE := :NEW.SOURCEDOCNUM;
  new$PAYDATE FACIALFINCAPTION.PAYDATE%TYPE := :NEW.PAYDATE;
  new$ACCEPTDATE FACIALFINCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCUMENTDATE FACIALFINCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$REESTRDATE FACIALFINCAPTION.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$CREDIT FACIALFINCAPTION.CREDIT%TYPE := :NEW.CREDIT;
  new$SOURCEACCOUNT FACIALFINCAPTION.SOURCEACCOUNT%TYPE := :NEW.SOURCEACCOUNT;
  new$SOURCEFACIALACC_CLS FACIALFINCAPTION.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$DESTACCOUNT FACIALFINCAPTION.DESTACCOUNT%TYPE := :NEW.DESTACCOUNT;
  new$DESTFACIALACC_CLS FACIALFINCAPTION.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$PROGINDEX FACIALFINCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$ARHIVEDOC FACIALFINCAPTION.ARHIVEDOC%TYPE := :NEW.ARHIVEDOC;
  new$PAYSYMBOLCLS FACIALFINCAPTION.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$PAYTYPECLS FACIALFINCAPTION.PAYTYPECLS%TYPE := :NEW.PAYTYPECLS;
  new$NOTE FACIALFINCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$PERIOD FACIALFINCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$PAYPRIORITY FACIALFINCAPTION.PAYPRIORITY%TYPE := :NEW.PAYPRIORITY;
  new$TYPEOPERATIONCLS FACIALFINCAPTION.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$BUHPAYMENTCLS FACIALFINCAPTION.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$CREATERUSER FACIALFINCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF FACIALFINCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECORDINDEX FACIALFINCAPTION.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$SENDERID FACIALFINCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REESTR_REF FACIALFINCAPTION.REESTR_REF%TYPE := :NEW.REESTR_REF;
  new$REJECT_CLS FACIALFINCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CLIENTBANKNUMBER FACIALFINCAPTION.CLIENTBANKNUMBER%TYPE := :NEW.CLIENTBANKNUMBER;
  new$CRYPTOSTATUS FACIALFINCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$TRUSTNUMBER FACIALFINCAPTION.TRUSTNUMBER%TYPE := :NEW.TRUSTNUMBER;
  new$LINKEDDOCUMENT FACIALFINCAPTION.LINKEDDOCUMENT%TYPE := :NEW.LINKEDDOCUMENT;
  new$BNKRECORDID FACIALFINCAPTION.BNKRECORDID%TYPE := :NEW.BNKRECORDID;
  new$SUBPROGINDEX FACIALFINCAPTION.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$DOCUMENTSTATE FACIALFINCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA FACIALFINCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$TREASUARYDOCSTATECLS FACIALFINCAPTION.TREASUARYDOCSTATECLS%TYPE := :NEW.TREASUARYDOCSTATECLS;
  new$DEPARTMENTCLS FACIALFINCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$NDS FACIALFINCAPTION.NDS%TYPE := :NEW.NDS;
  new$TAXNOTE FACIALFINCAPTION.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$MANAGERBID FACIALFINCAPTION.MANAGERBID%TYPE := :NEW.MANAGERBID;
  new$BIDNUMBER FACIALFINCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$GROUPID FACIALFINCAPTION.GROUPID%TYPE := :NEW.GROUPID;
  new$GROUPSUMMA FACIALFINCAPTION.GROUPSUMMA%TYPE := :NEW.GROUPSUMMA;
  new$DOCSTATEREF FACIALFINCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$LASTEXTRCHANGE FACIALFINCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$FAXDOCCOUNT FACIALFINCAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$STIMATEID FACIALFINCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$INTEGRATEDDOCREF FACIALFINCAPTION.INTEGRATEDDOCREF%TYPE := :NEW.INTEGRATEDDOCREF;
  new$REQUESTNUMBER FACIALFINCAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$REQUESTDATE FACIALFINCAPTION.REQUESTDATE%TYPE := :NEW.REQUESTDATE;
  new$RVERSION FACIALFINCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$FEDERALFUNDSREF FACIALFINCAPTION.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$ELDOCREF FACIALFINCAPTION.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$BUHOPERATIONCLS FACIALFINCAPTION.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CLSTYPE FACIALFINCAPTION.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$OPERATIONDIRECTION FACIALFINCAPTION.OPERATIONDIRECTION%TYPE := :NEW.OPERATIONDIRECTION;
  new$SOURCETYPE FACIALFINCAPTION.SOURCETYPE%TYPE := :NEW.SOURCETYPE;
  new$DESTTYPE FACIALFINCAPTION.DESTTYPE%TYPE := :NEW.DESTTYPE;
  new$CARDNUMBER FACIALFINCAPTION.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$ISBLOCKED FACIALFINCAPTION.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINCAPTION.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINCAPTION.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINCAPTION.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$CASHIERPERSONALINFO FACIALFINCAPTION.CASHIERPERSONALINFO%TYPE := :NEW.CASHIERPERSONALINFO;
  new$BIDDATE FACIALFINCAPTION.BIDDATE%TYPE := :NEW.BIDDATE;
  new$CARDREF FACIALFINCAPTION.CARDREF%TYPE := :NEW.CARDREF;
  new$SOURCESTOREDPAYMENTPROPS FACIALFINCAPTION.SOURCESTOREDPAYMENTPROPS%TYPE := :NEW.SOURCESTOREDPAYMENTPROPS;
  new$DESTSTOREDPAYMENTPROPS FACIALFINCAPTION.DESTSTOREDPAYMENTPROPS%TYPE := :NEW.DESTSTOREDPAYMENTPROPS;
  new$STOREDPAYMENTNOTE FACIALFINCAPTION.STOREDPAYMENTNOTE%TYPE := :NEW.STOREDPAYMENTNOTE;
  new$DOCCHANGEDATE FACIALFINCAPTION.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$UINCODE FACIALFINCAPTION.UINCODE%TYPE := :NEW.UINCODE;
  new$DOCOSN FACIALFINCAPTION.DOCOSN%TYPE := :NEW.DOCOSN;
  new$SIGNERS FACIALFINCAPTION.SIGNERS%TYPE := :NEW.SIGNERS;
  new$DESTCLSTYPE FACIALFINCAPTION.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SENDERIDKEY FACIALFINCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$AUTOSANCTION FACIALFINCAPTION.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$STOREDPAYMENTCONTENT FACIALFINCAPTION.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$TEMPREJECTCAUSE FACIALFINCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  UseFax$ NUMBER(10);
  pdt$ NUMBER(10);
  reestrAccepted1$ NUMBER(10);
  DocNumber$ NUMBER(10);
  CmpFacialAcc_Cls$ NUMBER(10);
  PIndex1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALFINCAPTION_BI)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$credit is null)then 
    new$credit:= 0;
  END IF;
  if (new$ArhiveDoc is null) then 
    new$ArhiveDoc:= 0;
  END IF;
  if (new$PayTypeCls is null) then 
    new$PayTypeCls:= 0;
  END IF;
  if (new$BuhPaymentCls is null) then 
    new$BuhPaymentCls:= 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$ClsType is null) then 
    new$ClsType := 0;
  END IF;
  if (new$DestClsType is null) then 
    new$DestClsType := new$ClsType;
  END IF;
  if (new$SourceFacialAcc_CLS is null) then 
    new$SourceFacialAcc_CLS:= 0;
  END IF;
  if (new$DestFacialAcc_CLS is null) then 
    new$DestFacialAcc_CLS:= 0;
  END IF;
  if (new$FaxDocCount is null) then 
    new$FaxDocCount := 0;
  END IF;
  if (new$OperationDirection is null) then 
    new$OperationDirection := 0;
  END IF;
  if (new$OperationDirection = 0) then
    new$SourceType := 1;
    new$DestType := 1;
     
  else
    if (new$OperationDirection = 1) then
      new$SourceType := 1;
      new$DestType := -1;
         
    else
      if (new$OperationDirection = 2) then
        new$SourceType := -1;
        new$DestType := 1;
             
      else
        new$SourceType := -1;
        new$DestType := -1;
             
      END IF;
    END IF;
  END IF;
  if (new$DepartmentCls is null) then
    GetIntConst(30, 20,DocNumber$); 
    if (DocNumber$ is null) then 
      new$DepartmentCls:= 0;
           
    else 
      new$DepartmentCls:= DocNumber$;
       
    END IF;
  END IF;
   
  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    PIndex1$ := new$ProgIndex;
    if (PIndex1$=60) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*    .*/
    END IF;
    if (PIndex1$=61) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*       */
    END IF;
    if (PIndex1$=62) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*    */
    END IF;
    if (PIndex1$=63) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*     */
    END IF;
    if (PIndex1$=64) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*    */
    END IF;
    if (PIndex1$=65) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*  , */
    END IF;
    if (PIndex1$=66) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*   ,  - */
    END IF;
    if (PIndex1$=67) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*    */
    END IF;
    if (PIndex1$=68) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*   \ */
    END IF;
    if (PIndex1$=69) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*    \ */
    END IF;
    if (PIndex1$=70) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*   \ */
    END IF;
    if (PIndex1$=71) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*    \ */
    END IF;
    if (PIndex1$=73) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*   */
    END IF;
    if (PIndex1$=75) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*  */
    END IF;
    if (PIndex1$=76) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*  */
    END IF;
    BEGIN

      select fa.BudgetRef      into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = CmpFacialAcc_Cls$

      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null )) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_1 (TR_FACIALFINCAPTION_BI_1)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --   -     
   IF (new$GroupID IS NULL) THEN new$GroupID := new$ID; END IF;
   IF (new$GroupSumma IS NULL) THEN new$GroupSumma := 0; END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_FACIALFINCAPTION_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (((new$progIndex = 63) or (new$progIndex = 64) or
  (new$progIndex = 68) or (new$progIndex = 70))
  and (new$REESTR_REF is not null)) then
    BEGIN
      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where 
      id = new$REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
        
    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrInsert');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_FacialFinCaption_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;
        
  else
    new$SenderIDKey := new$SenderID;
  END IF;
      
  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;
        
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_16 (TR_FACIALFINCAPTION_BI_16)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*      .    FacialFinCaption
             */
   IF (new$Reestr_ref IS NULL) THEN
      new$SourceDocNum := '';
      new$ReestrDate := NULL;
   ELSE
      BEGIN
         SELECT ffr.ReestrNumber, ffr.ReestrDate
           INTO new$SourceDocNum, new$ReestrDate
           FROM FacialFinReestr ffr
          WHERE ffr.ID = new$Reestr_ref;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            new$SourceDocNum := NULL;
            new$ReestrDate := NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BI_430 (TR_FACIALFINCAPTION_BI_430)
-- Create 04.12.2004
-- Last update 11.10.2006
-- - - - - - - - - - - - -

  IF (NEW$SenderID IS NOT NULL) THEN
    pdt$ := NULL;
    IF (NEW$progindex = 63) THEN pdt$ := 302; END IF;
    IF (NEW$progindex = 66) THEN pdt$ := 301; END IF;
    IF (NEW$progindex = 64) THEN pdt$ := 304; END IF;

    /*       */
    GetIntConst(30, 19, UseFax$);
    IF ((new$BidNumber IS NULL) AND (UseFax$ = 1)) THEN
      new$BidNumber := new$DocNumber;
    END IF;
    SELECT COUNT(*) INTO new$FaxDocCount
    FROM FaxDocs
      WHERE (OwnerDocNumber=new$BidNumber)
        AND (ClientID=new$SenderID)
        AND (FacialAcc_Cls=new$SourceFacialAcc_CLS)
        AND (OwnerDate = new$DocumentDate)
        AND (PrimaryDocType = PDT$);
  ELSE
    new$FaxDocCount := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALFINCAPTION_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$DocChangeDate := new$UpdateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALFINCAPTION (
    ID,
    DOCNUMBER,
    SOURCEDOCNUM,
    PAYDATE,
    ACCEPTDATE,
    DOCUMENTDATE,
    REESTRDATE,
    CREDIT,
    SOURCEACCOUNT,
    SOURCEFACIALACC_CLS,
    DESTACCOUNT,
    DESTFACIALACC_CLS,
    PROGINDEX,
    ARHIVEDOC,
    PAYSYMBOLCLS,
    PAYTYPECLS,
    NOTE,
    PERIOD,
    PAYPRIORITY,
    TYPEOPERATIONCLS,
    BUHPAYMENTCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    RECORDINDEX,
    SENDERID,
    SENDERRECORDID,
    REESTR_REF,
    REJECT_CLS,
    REJECTCAUSE,
    CLIENTBANKNUMBER,
    CRYPTOSTATUS,
    TRUSTNUMBER,
    LINKEDDOCUMENT,
    BNKRECORDID,
    SUBPROGINDEX,
    DOCUMENTSTATE,
    USERSVISA,
    TREASUARYDOCSTATECLS,
    DEPARTMENTCLS,
    NDS,
    TAXNOTE,
    MANAGERBID,
    BIDNUMBER,
    GROUPID,
    GROUPSUMMA,
    DOCSTATEREF,
    LASTEXTRCHANGE,
    FAXDOCCOUNT,
    STIMATEID,
    INTEGRATEDDOCREF,
    REQUESTNUMBER,
    REQUESTDATE,
    RVERSION,
    FEDERALFUNDSREF,
    ELDOCREF,
    BUHOPERATIONCLS,
    CLSTYPE,
    OPERATIONDIRECTION,
    SOURCETYPE,
    DESTTYPE,
    CARDNUMBER,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    CASHIERPERSONALINFO,
    BIDDATE,
    CARDREF,
    SOURCESTOREDPAYMENTPROPS,
    DESTSTOREDPAYMENTPROPS,
    STOREDPAYMENTNOTE,
    DOCCHANGEDATE,
    UINCODE,
    DOCOSN,
    SIGNERS,
    DESTCLSTYPE,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    AUTOSANCTION,
    STOREDPAYMENTCONTENT,
    TEMPREJECTCAUSE
  ) VALUES (
    new$ID,
    new$DOCNUMBER,
    new$SOURCEDOCNUM,
    new$PAYDATE,
    new$ACCEPTDATE,
    new$DOCUMENTDATE,
    new$REESTRDATE,
    new$CREDIT,
    new$SOURCEACCOUNT,
    new$SOURCEFACIALACC_CLS,
    new$DESTACCOUNT,
    new$DESTFACIALACC_CLS,
    new$PROGINDEX,
    new$ARHIVEDOC,
    new$PAYSYMBOLCLS,
    new$PAYTYPECLS,
    new$NOTE,
    new$PERIOD,
    new$PAYPRIORITY,
    new$TYPEOPERATIONCLS,
    new$BUHPAYMENTCLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$RECORDINDEX,
    new$SENDERID,
    new$SENDERRECORDID,
    new$REESTR_REF,
    new$REJECT_CLS,
    new$REJECTCAUSE,
    new$CLIENTBANKNUMBER,
    new$CRYPTOSTATUS,
    new$TRUSTNUMBER,
    new$LINKEDDOCUMENT,
    new$BNKRECORDID,
    new$SUBPROGINDEX,
    new$DOCUMENTSTATE,
    new$USERSVISA,
    new$TREASUARYDOCSTATECLS,
    new$DEPARTMENTCLS,
    new$NDS,
    new$TAXNOTE,
    new$MANAGERBID,
    new$BIDNUMBER,
    new$GROUPID,
    new$GROUPSUMMA,
    new$DOCSTATEREF,
    new$LASTEXTRCHANGE,
    new$FAXDOCCOUNT,
    new$STIMATEID,
    new$INTEGRATEDDOCREF,
    new$REQUESTNUMBER,
    new$REQUESTDATE,
    new$RVERSION,
    new$FEDERALFUNDSREF,
    new$ELDOCREF,
    new$BUHOPERATIONCLS,
    new$CLSTYPE,
    new$OPERATIONDIRECTION,
    new$SOURCETYPE,
    new$DESTTYPE,
    new$CARDNUMBER,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$CASHIERPERSONALINFO,
    new$BIDDATE,
    new$CARDREF,
    new$SOURCESTOREDPAYMENTPROPS,
    new$DESTSTOREDPAYMENTPROPS,
    new$STOREDPAYMENTNOTE,
    new$DOCCHANGEDATE,
    new$UINCODE,
    new$DOCOSN,
    new$SIGNERS,
    new$DESTCLSTYPE,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$AUTOSANCTION,
    new$STOREDPAYMENTCONTENT,
    new$TEMPREJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_430 (TR_FACIALFINCAPTION_AI_430)
-- Create 04.12.2004
-- Last update 11.10.2006
-- - - - - - - - - - - - -

  IF (new$SenderID IS NOT NULL) THEN
      /*       */
      pdt$ := NULL;
      IF (new$progindex = 63) THEN pdt$ := 302; END IF;
      IF (new$progindex = 66) THEN pdt$ := 301; END IF;
      IF (new$progindex = 64) THEN pdt$ := 304; END IF;

        UPDATE FaxDocs
            SET OwnerId=new$id
        WHERE
            (OwnerDocNumber=new$BidNumber)
            AND (ClientID=new$SenderID)
            AND (FacialAcc_Cls=new$SourceFacialAcc_CLS)
            AND (OwnerDate = new$DocumentDate)
            AND (primarydoctype = pdt$);
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALFINCAPTION_AI_500)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
     WHERE (TableID = 23) AND (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINCAPTION_IU
  INSTEAD OF UPDATE
  ON FACIALFINCAPTION
  FOR EACH ROW
DECLARE
  new$ID FACIALFINCAPTION.ID%TYPE := :NEW.ID;
  new$DOCNUMBER FACIALFINCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SOURCEDOCNUM FACIALFINCAPTION.SOURCEDOCNUM%TYPE := :NEW.SOURCEDOCNUM;
  new$PAYDATE FACIALFINCAPTION.PAYDATE%TYPE := :NEW.PAYDATE;
  new$ACCEPTDATE FACIALFINCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCUMENTDATE FACIALFINCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$REESTRDATE FACIALFINCAPTION.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$CREDIT FACIALFINCAPTION.CREDIT%TYPE := :NEW.CREDIT;
  new$SOURCEACCOUNT FACIALFINCAPTION.SOURCEACCOUNT%TYPE := :NEW.SOURCEACCOUNT;
  new$SOURCEFACIALACC_CLS FACIALFINCAPTION.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$DESTACCOUNT FACIALFINCAPTION.DESTACCOUNT%TYPE := :NEW.DESTACCOUNT;
  new$DESTFACIALACC_CLS FACIALFINCAPTION.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$PROGINDEX FACIALFINCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$ARHIVEDOC FACIALFINCAPTION.ARHIVEDOC%TYPE := :NEW.ARHIVEDOC;
  new$PAYSYMBOLCLS FACIALFINCAPTION.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$PAYTYPECLS FACIALFINCAPTION.PAYTYPECLS%TYPE := :NEW.PAYTYPECLS;
  new$NOTE FACIALFINCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$PERIOD FACIALFINCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$PAYPRIORITY FACIALFINCAPTION.PAYPRIORITY%TYPE := :NEW.PAYPRIORITY;
  new$TYPEOPERATIONCLS FACIALFINCAPTION.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$BUHPAYMENTCLS FACIALFINCAPTION.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$CREATERUSER FACIALFINCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF FACIALFINCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECORDINDEX FACIALFINCAPTION.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$SENDERID FACIALFINCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REESTR_REF FACIALFINCAPTION.REESTR_REF%TYPE := :NEW.REESTR_REF;
  new$REJECT_CLS FACIALFINCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CLIENTBANKNUMBER FACIALFINCAPTION.CLIENTBANKNUMBER%TYPE := :NEW.CLIENTBANKNUMBER;
  new$CRYPTOSTATUS FACIALFINCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$TRUSTNUMBER FACIALFINCAPTION.TRUSTNUMBER%TYPE := :NEW.TRUSTNUMBER;
  new$LINKEDDOCUMENT FACIALFINCAPTION.LINKEDDOCUMENT%TYPE := :NEW.LINKEDDOCUMENT;
  new$BNKRECORDID FACIALFINCAPTION.BNKRECORDID%TYPE := :NEW.BNKRECORDID;
  new$SUBPROGINDEX FACIALFINCAPTION.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$DOCUMENTSTATE FACIALFINCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA FACIALFINCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$TREASUARYDOCSTATECLS FACIALFINCAPTION.TREASUARYDOCSTATECLS%TYPE := :NEW.TREASUARYDOCSTATECLS;
  new$DEPARTMENTCLS FACIALFINCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$NDS FACIALFINCAPTION.NDS%TYPE := :NEW.NDS;
  new$TAXNOTE FACIALFINCAPTION.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$MANAGERBID FACIALFINCAPTION.MANAGERBID%TYPE := :NEW.MANAGERBID;
  new$BIDNUMBER FACIALFINCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$GROUPID FACIALFINCAPTION.GROUPID%TYPE := :NEW.GROUPID;
  new$GROUPSUMMA FACIALFINCAPTION.GROUPSUMMA%TYPE := :NEW.GROUPSUMMA;
  new$DOCSTATEREF FACIALFINCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$LASTEXTRCHANGE FACIALFINCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$FAXDOCCOUNT FACIALFINCAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$STIMATEID FACIALFINCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$INTEGRATEDDOCREF FACIALFINCAPTION.INTEGRATEDDOCREF%TYPE := :NEW.INTEGRATEDDOCREF;
  new$REQUESTNUMBER FACIALFINCAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$REQUESTDATE FACIALFINCAPTION.REQUESTDATE%TYPE := :NEW.REQUESTDATE;
  new$RVERSION FACIALFINCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$FEDERALFUNDSREF FACIALFINCAPTION.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$ELDOCREF FACIALFINCAPTION.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$BUHOPERATIONCLS FACIALFINCAPTION.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CLSTYPE FACIALFINCAPTION.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$OPERATIONDIRECTION FACIALFINCAPTION.OPERATIONDIRECTION%TYPE := :NEW.OPERATIONDIRECTION;
  new$SOURCETYPE FACIALFINCAPTION.SOURCETYPE%TYPE := :NEW.SOURCETYPE;
  new$DESTTYPE FACIALFINCAPTION.DESTTYPE%TYPE := :NEW.DESTTYPE;
  new$CARDNUMBER FACIALFINCAPTION.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$ISBLOCKED FACIALFINCAPTION.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINCAPTION.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINCAPTION.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINCAPTION.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$CASHIERPERSONALINFO FACIALFINCAPTION.CASHIERPERSONALINFO%TYPE := :NEW.CASHIERPERSONALINFO;
  new$BIDDATE FACIALFINCAPTION.BIDDATE%TYPE := :NEW.BIDDATE;
  new$CARDREF FACIALFINCAPTION.CARDREF%TYPE := :NEW.CARDREF;
  new$SOURCESTOREDPAYMENTPROPS FACIALFINCAPTION.SOURCESTOREDPAYMENTPROPS%TYPE := :NEW.SOURCESTOREDPAYMENTPROPS;
  new$DESTSTOREDPAYMENTPROPS FACIALFINCAPTION.DESTSTOREDPAYMENTPROPS%TYPE := :NEW.DESTSTOREDPAYMENTPROPS;
  new$STOREDPAYMENTNOTE FACIALFINCAPTION.STOREDPAYMENTNOTE%TYPE := :NEW.STOREDPAYMENTNOTE;
  new$DOCCHANGEDATE FACIALFINCAPTION.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$UINCODE FACIALFINCAPTION.UINCODE%TYPE := :NEW.UINCODE;
  new$DOCOSN FACIALFINCAPTION.DOCOSN%TYPE := :NEW.DOCOSN;
  new$SIGNERS FACIALFINCAPTION.SIGNERS%TYPE := :NEW.SIGNERS;
  new$DESTCLSTYPE FACIALFINCAPTION.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SENDERIDKEY FACIALFINCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$AUTOSANCTION FACIALFINCAPTION.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$STOREDPAYMENTCONTENT FACIALFINCAPTION.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$TEMPREJECTCAUSE FACIALFINCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  SourceFacialAcc_CLS$ NUMBER(10);
  DestFacialAcc_CLS$ NUMBER(10);
  CNT$1 NUMBER(10);
  reestrAccepted1$ NUMBER(10);
  IsReject1$ NUMBER(10);
  UseFax$ NUMBER(10);
  DocNumber$ NUMBER(10);
  DetCount$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINCAPTION_BU)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is not null) then
    /*      */
    GetIntConst(30, 19,UseFax$);
    if ((new$BidNumber is null) and (UseFax$ = 1)) then
      new$BidNumber:= new$DocNumber;

    END IF;
  END IF;
  if (new$credit is null)then
    new$credit:= 0;
  END IF;
  if (new$ArhiveDoc is null) then
    new$ArhiveDoc:= 0;
  END IF;
  if (new$PayTypeCls is null) then
    new$PayTypeCls:= 0;
  END IF;
  if (new$BuhPaymentCls is null) then
    new$BuhPaymentCls:= 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$ClsType is null) then
    new$ClsType := 0;
  END IF;
  if (new$DestClsType is null) then
    new$DestClsType := new$ClsType;
  END IF;
  if (new$SourceFacialAcc_CLS is null) then
    new$SourceFacialAcc_CLS:= 0;
  END IF;
  if (new$DestFacialAcc_CLS is null) then
    new$DestFacialAcc_CLS:= 0;
  END IF;
  if (new$FaxDocCount is null) then
    new$FaxDocCount := 0;
  END IF;
  if (new$OperationDirection is null) then
    new$OperationDirection := 0;
  END IF;
  if (new$OperationDirection <> :old.OperationDirection) then
    if (new$OperationDirection = 0) then
      new$SourceType := 1;
      new$DestType := 1;

    else
      if (new$OperationDirection = 1) then
        new$SourceType := 1;
        new$DestType := -1;

      else
        if (new$OperationDirection = 2) then
          new$SourceType := -1;
          new$DestType := 1;

        else
          new$SourceType := -1;
          new$DestType := -1;

        END IF;
      END IF;
    END IF;
  END IF;
  if (new$DepartmentCls is null) then
    GetIntConst(30, 20,DocNumber$);
    if (DocNumber$ is null) then
      new$DepartmentCls:= 0;

    else
      new$DepartmentCls:= DocNumber$;

    END IF;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount$ from FacialFinDetail where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_Cls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_1 (TR_FACIALFINCAPTION_BU_1)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --   -     
   IF (new$GroupID IS NULL) THEN new$GroupID := new$ID; END IF;
   IF (new$GroupSumma IS NULL) THEN new$GroupSumma := 0; END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_FACIALFINCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (not (    ((new$progindex = 63) or (new$progindex = 64) or (new$progindex = 68) or (new$progindex = 70))
  and (   (((new$credit - :old.credit)>0.001)or((new$credit - :old.credit)<-0.001))
  or (new$sourcefacialacc_cls <> :old.sourcefacialacc_cls)
  or (
  ((new$sourceaccount is null) and (:old.sourceaccount is not null)) or
  ((new$sourceaccount is not null) and (:old.sourceaccount is null)) or
  ((new$sourceaccount <> :old.sourceaccount ) and (:old.sourceaccount is not null) and (new$sourceaccount is not null))
  )
  or (
  ((new$destaccount is null) and (:old.destaccount is not null)) or
  ((new$destaccount is not null) and (:old.destaccount is null)) or
  ((new$destaccount <> :old.destaccount ) and (:old.destaccount is not null) and (new$destaccount is not null))
  )
  or (    (:old.reestr_ref is null)
  and (new$reestr_ref is not null)
  )
  or (    (:old.reestr_ref is not null)
  and (new$reestr_ref is null)
  )
  or (:old.reestr_ref <> new$reestr_ref)
  )
  )
  )
  then /*      NULL */
    reestrAccepted1$ := 0;  /*   IB 4.2 */

  else
    BEGIN
      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id=new$REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrUpdate');
    END IF;
    BEGIN

      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id=:old.REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrUpdate');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_6 (TR_FACIALFINCAPTION_BU_6)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (:old.ProgIndex in(63,68,70)) then /*    */
    SELECT COUNT(id ) INTO CNT$1
    from paydocexchange where ((paydocref=:old.id)and(status<>0)and(TypeInf BETWEEN 0 and 10)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      if(/* (new.DOCNUMBER<>old.DOCNUMBER) or ((new.DOCNUMBER is NULL)and(not old.DOCNUMBER is NULL)) or ((old.DOCNUMBER is NULL)and(not new.DOCNUMBER is NULL)) or*/
      (new$SOURCEDOCNUM<>:old.SOURCEDOCNUM) or ((new$SOURCEDOCNUM is NULL)and(not :old.SOURCEDOCNUM is NULL)) or ((:old.SOURCEDOCNUM is NULL)and(not new$SOURCEDOCNUM is NULL)) or
      (new$PAYDATE<>:old.PAYDATE) or ((new$PAYDATE is NULL)and(not :old.PAYDATE is NULL)) or ((:old.PAYDATE is NULL)and(not new$PAYDATE is NULL))or
      /* (new.DOCUMENTDATE<>old.DOCUMENTDATE) or ((new.DOCUMENTDATE is NULL)and(not old.DOCUMENTDATE is NULL)) or ((old.DOCUMENTDATE is NULL)and(not new.DOCUMENTDATE is NULL))or*/
      (new$REESTRDATE<>:old.REESTRDATE) or ((new$REESTRDATE is NULL)and(not :old.REESTRDATE is NULL)) or ((:old.REESTRDATE is NULL)and(not new$REESTRDATE is NULL))or
      (((new$credit - :old.credit)>0.001)or((new$credit - :old.credit)<-0.001)) or
      (new$SOURCEACCOUNT<>:old.SOURCEACCOUNT) or
      (new$DESTACCOUNT<>:old.DESTACCOUNT) or
      (new$PAYTYPECLS<>:old.PAYTYPECLS) or
      (new$NOTE<>:old.NOTE) or  ((new$NOTE is NULL)and(not :old.NOTE is NULL)) or ((:old.NOTE is NULL)and(not new$NOTE is NULL))or
      (new$PAYPRIORITY<>:old.PAYPRIORITY) or ((new$PAYPRIORITY is NULL)and(not :old.PAYPRIORITY is NULL)) or ((:old.PAYPRIORITY is NULL)and(not new$PAYPRIORITY is NULL))or
      (new$REESTR_REF<>:old.REESTR_REF) or ((new$REESTR_REF is NULL)and(not :old.REESTR_REF is NULL)) or ((:old.REESTR_REF is NULL)and(not new$REESTR_REF is NULL))or
      (new$NDS<>:old.NDS) or ((new$NDS is NULL)and(not :old.NDS is NULL)) or ((:old.NDS is NULL)and(not new$NDS is NULL))or
      (new$TAXNOTE<>:old.TAXNOTE) or ((new$TAXNOTE is NULL)and(not :old.TAXNOTE is NULL)) or ((:old.TAXNOTE is NULL)and(not new$TAXNOTE is NULL)) )then
        RaiseException('ex_CannotChangeSended');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_32 (TR_FACIALFINCAPTION_BU_32)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$Reestr_ref IS NULL)    /*    select ,  */
                              THEN
      new$SourceDocNum := '';
      new$ReestrDate := NULL;
   ELSIF (    (new$Reestr_ref = :OLD.Reestr_ref)
          AND (new$SourceDocNum = :OLD.SourceDocNum)
          AND (new$ReestrDate = :OLD.ReestrDate)
         ) THEN
/*          */
      NULL;
   ELSE
      BEGIN
         SELECT ffr.ReestrNumber, ffr.ReestrDate
           INTO new$SourceDocNum, new$ReestrDate
           FROM FacialFinReestr ffr
          WHERE ffr.ID = new$Reestr_ref;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            new$SourceDocNum := NULL;
            new$ReestrDate := NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BU_60 (T_FACIALFINCAPTION_BU_60)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF ((new$progindex = 60) AND (new$Credit <> :OLD.Credit)) THEN
      UPDATE FacialFinDetail
         SET Credit = new$Credit
       WHERE (RecordIndex = new$ID);
   END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_FACIALFINCAPTION_BU_70)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --         
   IF (new$SubProgIndex = 416) THEN
      UPDATE Guarantee
         SET AcceptDate = new$AcceptDate
       WHERE SubRecordIndex = new$ID;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (T_FACIALFINCAPTION_BU_100)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*   ,    */
   IF (    (   (:OLD.SourceFacialAcc_CLS <> new$SourceFacialAcc_CLS)
            OR (:OLD.DestFacialAcc_CLS <> new$DestFacialAcc_CLS)
           )
       AND ((new$SubProgIndex <> 1) OR (new$SubProgIndex IS NULL))
      ) THEN
      FOR R$ IN (SELECT ID, SourceFacialAcc_CLS, DestFacialAcc_CLS
                   FROM FacialFinDetail
                  WHERE RecordIndex = new$ID) LOOP
         IF (NOT (new$SourceFacialAcc_CLS = 0)) THEN
            SourceFacialAcc_CLS$ := new$SourceFacialAcc_CLS;
         ELSE
            SourceFacialAcc_CLS$ := R$.SourceFacialAcc_CLS;
         END IF;

         IF (NOT (new$DestFacialAcc_CLS = 0)) THEN
            DestFacialAcc_CLS$ := new$DestFacialAcc_CLS;
         ELSE
            DestFacialAcc_CLS$ := R$.DestFacialAcc_CLS;
         END IF;

         IF (:OLD.SourceFacialAcc_CLS <> new$SourceFacialAcc_CLS) THEN
            UPDATE FacialFinDetail
               SET SourceFacialAcc_CLS = SourceFacialAcc_CLS$,
                   RVersion = -1
             WHERE (ID = R$.ID);
         END IF;

         IF (:OLD.DestFacialAcc_CLS <> new$DestFacialAcc_CLS) THEN
            UPDATE FacialFinDetail
               SET DestFacialAcc_CLS = DestFacialAcc_CLS$,
                   RVersion = -1
             WHERE (ID = R$.ID);
         END IF;
      END LOOP;
   END IF;

   /*    / , 
           .*/
  IF (((NEW$IsBlocked <> :OLD.IsBlocked) OR
      ((NEW$IsBlocked IS NULL) AND (:OLD.IsBlocked IS NOT NULL)) OR
      ((NEW$IsBlocked IS NOT NULL) AND (:OLD.IsBlocked IS NULL))
     ) OR
     ((NEW$BlockedCause <> :OLD.BlockedCause) OR
      ((NEW$BlockedCause IS NULL) AND (:OLD.BlockedCause IS NOT NULL)) OR
      ((NEW$BlockedCause IS NOT NULL) AND (:OLD.BlockedCause IS NULL))
     ) OR
     ((NEW$UnBlockedDate <> :OLD.UnBlockedDate) OR
      ((NEW$UnBlockedDate IS NULL) AND (:OLD.UnBlockedDate IS NOT NULL)) OR
      ((NEW$UnBlockedDate IS NOT NULL) AND (:OLD.UnBlockedDate IS NULL))
     ) OR
     ((NEW$UnBlockedCause <> :OLD.UnBlockedCause) OR
      ((NEW$UnBlockedDate IS NULL) AND (:OLD.UnBlockedCause IS NOT NULL)) OR
      ((NEW$UnBlockedCause IS NOT NULL) AND (:OLD.UnBlockedCause IS NULL))
     )) THEN
     UPDATE FacialFinDetail ffd
     SET ffd.IsBlocked = NEW$IsBlocked, ffd.BlockedCause = NEW$BlockedCause,
         ffd.UnBlockedDate = NEW$UnBlockedDate, ffd.UnBlockedCause = NEW$UnBlockedCause
     WHERE ffd.recordindex = NEW$ID;
  end if;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINCAPTION_BU_210)
-- Create 27.08.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*      */
   IF (new$DOCSTATEREF <> :OLD.DOCSTATEREF) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DOCSTATEREF, new$DOCSTATEREF
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (T_FACIALFINCAPTION_BU_300)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  IsReject1$ := -1;
  if ((:old.Reject_CLS is null)and(new$Reject_CLS is not null)) then
    IsReject1$ := 1;

  else
    if ((:old.Reject_CLS is not null)and(new$Reject_CLS is null)) then
      IsReject1$ := 0;
    END IF;
  END IF;
  if (IsReject1$  <> -1) then
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID = new$ID;
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID in (select d.id from FacialFinDetail d where d.RecordIndex = new$id);

  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINCAPTION_BU_700)
-- Create 17.09.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINCAPTION SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    SOURCEDOCNUM = new$SOURCEDOCNUM,
    PAYDATE = new$PAYDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    REESTRDATE = new$REESTRDATE,
    CREDIT = new$CREDIT,
    SOURCEACCOUNT = new$SOURCEACCOUNT,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    DESTACCOUNT = new$DESTACCOUNT,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    PROGINDEX = new$PROGINDEX,
    ARHIVEDOC = new$ARHIVEDOC,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    PAYTYPECLS = new$PAYTYPECLS,
    NOTE = new$NOTE,
    PERIOD = new$PERIOD,
    PAYPRIORITY = new$PAYPRIORITY,
    TYPEOPERATIONCLS = new$TYPEOPERATIONCLS,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    RECORDINDEX = new$RECORDINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REESTR_REF = new$REESTR_REF,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CLIENTBANKNUMBER = new$CLIENTBANKNUMBER,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    TRUSTNUMBER = new$TRUSTNUMBER,
    LINKEDDOCUMENT = new$LINKEDDOCUMENT,
    BNKRECORDID = new$BNKRECORDID,
    SUBPROGINDEX = new$SUBPROGINDEX,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    TREASUARYDOCSTATECLS = new$TREASUARYDOCSTATECLS,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    NDS = new$NDS,
    TAXNOTE = new$TAXNOTE,
    MANAGERBID = new$MANAGERBID,
    BIDNUMBER = new$BIDNUMBER,
    GROUPID = new$GROUPID,
    GROUPSUMMA = new$GROUPSUMMA,
    DOCSTATEREF = new$DOCSTATEREF,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    FAXDOCCOUNT = new$FAXDOCCOUNT,
    STIMATEID = new$STIMATEID,
    INTEGRATEDDOCREF = new$INTEGRATEDDOCREF,
    REQUESTNUMBER = new$REQUESTNUMBER,
    REQUESTDATE = new$REQUESTDATE,
    RVERSION = new$RVERSION,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    ELDOCREF = new$ELDOCREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    CLSTYPE = new$CLSTYPE,
    OPERATIONDIRECTION = new$OPERATIONDIRECTION,
    SOURCETYPE = new$SOURCETYPE,
    DESTTYPE = new$DESTTYPE,
    CARDNUMBER = new$CARDNUMBER,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    CASHIERPERSONALINFO = new$CASHIERPERSONALINFO,
    BIDDATE = new$BIDDATE,
    CARDREF = new$CARDREF,
    SOURCESTOREDPAYMENTPROPS = new$SOURCESTOREDPAYMENTPROPS,
    DESTSTOREDPAYMENTPROPS = new$DESTSTOREDPAYMENTPROPS,
    STOREDPAYMENTNOTE = new$STOREDPAYMENTNOTE,
    DOCCHANGEDATE = new$DOCCHANGEDATE,
    UINCODE = new$UINCODE,
    DOCOSN = new$DOCOSN,
    SIGNERS = new$SIGNERS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    AUTOSANCTION = new$AUTOSANCTION,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_300 (TR_FACIALFINCAPTION_AU_300)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*          ,      */
  if ((new$AcceptDate <> :old.AcceptDate)or((new$AcceptDate is not null)and(:old.AcceptDate is null))
  or((new$AcceptDate is null)and(:old.AcceptDate is not null))) then
    update facialfindetail set
    AcceptDate = new$AcceptDate,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;
  if (new$BuhOperationCLS <> :old.BuhOperationCLS)  then
    update facialfindetail set
    BuhOperationCLS = new$BuhOperationCLS,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;
  if ((new$ClsType <> :old.ClsType)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$ClsType = 0) then
      update facialfindetail set
      SourceKD = 0,
      DestKD = 0,
      SourceIFS = 0,
      DestIFS = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 1) then
      update facialfindetail set
      SourceKD = 0,
      DestKD = 0,
      SourceKVSR = 0,
      SourceKFSR = 0,
      SourceKCSR = 0,
      SourceKVR = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 2) then
      update facialfindetail set
      SourceIFS = 0,
      DestIFS = 0,
      SourceKVSR = 0,
      SourceKFSR = 0,
      SourceKCSR = 0,
      SourceKVR = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);

    END IF;
  END IF;
  if ((new$DestClsType <> :old.DestClsType)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$DestClsType = 0) then
      update facialfindetail set
      DestKD = 0,
      DestIFS = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
    END IF;
    if (new$DestClsType = 1) then
      update facialfindetail set
      DestKD = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
    END IF;
    if (new$DestClsType = 2) then
      update facialfindetail set
      DestIFS = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINCAPTION_AU_500)
-- Create 28.04.2005
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (:NEW.ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (23, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
        WHERE (TableID = 23) AND (RecordId = :NEW.ID);
   END IF;

END;
/
update FACIALFINCAPTION set
  TempRejectCause = REJECTCAUSE
/
commit work 
/
ALTER TABLE TB_FACIALFINCAPTION DROP (REJECTCAUSE)
/

CREATE OR REPLACE VIEW FACIALFINCAPTION (
  ID,
  DOCNUMBER,
  SOURCEDOCNUM,
  PAYDATE,
  ACCEPTDATE,
  DOCUMENTDATE,
  REESTRDATE,
  CREDIT,
  SOURCEACCOUNT,
  SOURCEFACIALACC_CLS,
  DESTACCOUNT,
  DESTFACIALACC_CLS,
  PROGINDEX,
  ARHIVEDOC,
  PAYSYMBOLCLS,
  PAYTYPECLS,
  NOTE,
  PERIOD,
  PAYPRIORITY,
  TYPEOPERATIONCLS,
  BUHPAYMENTCLS,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  BUDGETREF,
  RECORDINDEX,
  SENDERID,
  SENDERRECORDID,
  REESTR_REF,
  REJECT_CLS,
  CLIENTBANKNUMBER,
  CRYPTOSTATUS,
  TRUSTNUMBER,
  LINKEDDOCUMENT,
  BNKRECORDID,
  SUBPROGINDEX,
  DOCUMENTSTATE,
  USERSVISA,
  TREASUARYDOCSTATECLS,
  DEPARTMENTCLS,
  NDS,
  TAXNOTE,
  MANAGERBID,
  BIDNUMBER,
  GROUPID,
  GROUPSUMMA,
  DOCSTATEREF,
  LASTEXTRCHANGE,
  FAXDOCCOUNT,
  STIMATEID,
  INTEGRATEDDOCREF,
  REQUESTNUMBER,
  REQUESTDATE,
  RVERSION,
  FEDERALFUNDSREF,
  ELDOCREF,
  BUHOPERATIONCLS,
  CLSTYPE,
  OPERATIONDIRECTION,
  SOURCETYPE,
  DESTTYPE,
  CARDNUMBER,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  CASHIERPERSONALINFO,
  BIDDATE,
  CARDREF,
  SOURCESTOREDPAYMENTPROPS,
  DESTSTOREDPAYMENTPROPS,
  STOREDPAYMENTNOTE,
  DOCCHANGEDATE,
  UINCODE,
  DOCOSN,
  SIGNERS,
  DESTCLSTYPE,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  AUTOSANCTION,
  STOREDPAYMENTCONTENT,
  TEMPREJECTCAUSE)
AS
  SELECT
    ID,
    DOCNUMBER,
    SOURCEDOCNUM,
    PAYDATE,
    ACCEPTDATE,
    DOCUMENTDATE,
    REESTRDATE,
    CREDIT,
    SOURCEACCOUNT,
    SOURCEFACIALACC_CLS,
    DESTACCOUNT,
    DESTFACIALACC_CLS,
    PROGINDEX,
    ARHIVEDOC,
    PAYSYMBOLCLS,
    PAYTYPECLS,
    NOTE,
    PERIOD,
    PAYPRIORITY,
    TYPEOPERATIONCLS,
    BUHPAYMENTCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    RECORDINDEX,
    SENDERID,
    SENDERRECORDID,
    REESTR_REF,
    REJECT_CLS,
    CLIENTBANKNUMBER,
    CRYPTOSTATUS,
    TRUSTNUMBER,
    LINKEDDOCUMENT,
    BNKRECORDID,
    SUBPROGINDEX,
    DOCUMENTSTATE,
    USERSVISA,
    TREASUARYDOCSTATECLS,
    DEPARTMENTCLS,
    NDS,
    TAXNOTE,
    MANAGERBID,
    BIDNUMBER,
    GROUPID,
    GROUPSUMMA,
    DOCSTATEREF,
    LASTEXTRCHANGE,
    FAXDOCCOUNT,
    STIMATEID,
    INTEGRATEDDOCREF,
    REQUESTNUMBER,
    REQUESTDATE,
    RVERSION,
    FEDERALFUNDSREF,
    ELDOCREF,
    BUHOPERATIONCLS,
    CLSTYPE,
    OPERATIONDIRECTION,
    SOURCETYPE,
    DESTTYPE,
    CARDNUMBER,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    CASHIERPERSONALINFO,
    BIDDATE,
    CARDREF,
    SOURCESTOREDPAYMENTPROPS,
    DESTSTOREDPAYMENTPROPS,
    STOREDPAYMENTNOTE,
    DOCCHANGEDATE,
    UINCODE,
    DOCOSN,
    SIGNERS,
    DESTCLSTYPE,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    AUTOSANCTION,
    STOREDPAYMENTCONTENT,
    TEMPREJECTCAUSE
  FROM TB_FACIALFINCAPTION
/

CREATE OR REPLACE TRIGGER TR_FACIALFINCAPTION_ID
  INSTEAD OF DELETE
  ON FACIALFINCAPTION
  FOR EACH ROW
DECLARE
  reestrAccepted1$ NUMBER(10);
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_FACIALFINCAPTION_BD)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

 /*       */
  DELETE FROM FacialFinDetail
        WHERE (RecordIndex = :OLD.ID);

-- - - - - - - - - - - - -
-- BD_5 (TR_FACIALFINCAPTION_BD_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (((:old.progIndex = 63) or (:old.progIndex = 64) or
  (:old.progIndex = 68) or (:old.progIndex = 70))
  and (:old.REESTR_REF is not null)) then
    BEGIN
      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id = :old.REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrDelete');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BD_6 (TR_FACIALFINCAPTION_BD_6)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(id ) INTO CNT$1
  from paydocexchange where ((paydocref=:old.id)and(status<>0)and(TypeInf BETWEEN 0 and 10)) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    RaiseException('ex_CannotChangeSended');
  else
    delete from PayDocExchange where paydocref = :old.id;
  END IF;

-- - - - - - - - - - - - -
-- BD_430 (TR_FACIALFINCAPTION_BD_430)
-- Create 04.12.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

  /*         */
  UPDATE FaxDocs
     SET OwnerID = NULL
  WHERE OwnerID = :OLD.ID;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_FACIALFINCAPTION
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_70 (TR_FACIALFINCAPTION_AD_70)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

--   /     
  IF (:OLD.SubProgIndex = 416) THEN
    UPDATE Guarantee
       SET SubRecordIndex = NULL,
           SubProgIndex = 0
     WHERE SubRecordIndex = :OLD.ID;
  END IF;

-- - - - - - - - - - - - -
-- AD_200 (TR_FACIALFINCAPTION_AD_200)
-- Create 27.08.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

  /*       */
  delete from StateJumpHistory
    where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_300 (TR_FACIALFINCAPTION_AD_300)
-- Create 24.02.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

  IF (:OLD.FaxDocCount > 0) THEN
--    :old.FaxDocCount := :old.FaxDocCount;
    NULL;
  ELSE
    UPDATE FaxDocs
       SET OwnerID = NULL
     WHERE OwnerID = :OLD.ID;
  END IF;

-- - - - - - - - - - - - -
-- AD_500 (TR_FACIALFINCAPTION_AD_500)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

  INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate, ProgIndex, Summa)
    VALUES (23, :OLD.ID, SYSDATE, :OLD.ProgIndex, :OLD.Credit);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINCAPTION_II
  INSTEAD OF INSERT
  ON FACIALFINCAPTION
  FOR EACH ROW
DECLARE
  new$ID FACIALFINCAPTION.ID%TYPE := :NEW.ID;
  new$DOCNUMBER FACIALFINCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SOURCEDOCNUM FACIALFINCAPTION.SOURCEDOCNUM%TYPE := :NEW.SOURCEDOCNUM;
  new$PAYDATE FACIALFINCAPTION.PAYDATE%TYPE := :NEW.PAYDATE;
  new$ACCEPTDATE FACIALFINCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCUMENTDATE FACIALFINCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$REESTRDATE FACIALFINCAPTION.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$CREDIT FACIALFINCAPTION.CREDIT%TYPE := :NEW.CREDIT;
  new$SOURCEACCOUNT FACIALFINCAPTION.SOURCEACCOUNT%TYPE := :NEW.SOURCEACCOUNT;
  new$SOURCEFACIALACC_CLS FACIALFINCAPTION.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$DESTACCOUNT FACIALFINCAPTION.DESTACCOUNT%TYPE := :NEW.DESTACCOUNT;
  new$DESTFACIALACC_CLS FACIALFINCAPTION.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$PROGINDEX FACIALFINCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$ARHIVEDOC FACIALFINCAPTION.ARHIVEDOC%TYPE := :NEW.ARHIVEDOC;
  new$PAYSYMBOLCLS FACIALFINCAPTION.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$PAYTYPECLS FACIALFINCAPTION.PAYTYPECLS%TYPE := :NEW.PAYTYPECLS;
  new$NOTE FACIALFINCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$PERIOD FACIALFINCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$PAYPRIORITY FACIALFINCAPTION.PAYPRIORITY%TYPE := :NEW.PAYPRIORITY;
  new$TYPEOPERATIONCLS FACIALFINCAPTION.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$BUHPAYMENTCLS FACIALFINCAPTION.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$CREATERUSER FACIALFINCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF FACIALFINCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECORDINDEX FACIALFINCAPTION.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$SENDERID FACIALFINCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REESTR_REF FACIALFINCAPTION.REESTR_REF%TYPE := :NEW.REESTR_REF;
  new$REJECT_CLS FACIALFINCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$CLIENTBANKNUMBER FACIALFINCAPTION.CLIENTBANKNUMBER%TYPE := :NEW.CLIENTBANKNUMBER;
  new$CRYPTOSTATUS FACIALFINCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$TRUSTNUMBER FACIALFINCAPTION.TRUSTNUMBER%TYPE := :NEW.TRUSTNUMBER;
  new$LINKEDDOCUMENT FACIALFINCAPTION.LINKEDDOCUMENT%TYPE := :NEW.LINKEDDOCUMENT;
  new$BNKRECORDID FACIALFINCAPTION.BNKRECORDID%TYPE := :NEW.BNKRECORDID;
  new$SUBPROGINDEX FACIALFINCAPTION.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$DOCUMENTSTATE FACIALFINCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA FACIALFINCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$TREASUARYDOCSTATECLS FACIALFINCAPTION.TREASUARYDOCSTATECLS%TYPE := :NEW.TREASUARYDOCSTATECLS;
  new$DEPARTMENTCLS FACIALFINCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$NDS FACIALFINCAPTION.NDS%TYPE := :NEW.NDS;
  new$TAXNOTE FACIALFINCAPTION.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$MANAGERBID FACIALFINCAPTION.MANAGERBID%TYPE := :NEW.MANAGERBID;
  new$BIDNUMBER FACIALFINCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$GROUPID FACIALFINCAPTION.GROUPID%TYPE := :NEW.GROUPID;
  new$GROUPSUMMA FACIALFINCAPTION.GROUPSUMMA%TYPE := :NEW.GROUPSUMMA;
  new$DOCSTATEREF FACIALFINCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$LASTEXTRCHANGE FACIALFINCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$FAXDOCCOUNT FACIALFINCAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$STIMATEID FACIALFINCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$INTEGRATEDDOCREF FACIALFINCAPTION.INTEGRATEDDOCREF%TYPE := :NEW.INTEGRATEDDOCREF;
  new$REQUESTNUMBER FACIALFINCAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$REQUESTDATE FACIALFINCAPTION.REQUESTDATE%TYPE := :NEW.REQUESTDATE;
  new$RVERSION FACIALFINCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$FEDERALFUNDSREF FACIALFINCAPTION.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$ELDOCREF FACIALFINCAPTION.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$BUHOPERATIONCLS FACIALFINCAPTION.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CLSTYPE FACIALFINCAPTION.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$OPERATIONDIRECTION FACIALFINCAPTION.OPERATIONDIRECTION%TYPE := :NEW.OPERATIONDIRECTION;
  new$SOURCETYPE FACIALFINCAPTION.SOURCETYPE%TYPE := :NEW.SOURCETYPE;
  new$DESTTYPE FACIALFINCAPTION.DESTTYPE%TYPE := :NEW.DESTTYPE;
  new$CARDNUMBER FACIALFINCAPTION.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$ISBLOCKED FACIALFINCAPTION.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINCAPTION.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINCAPTION.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINCAPTION.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$CASHIERPERSONALINFO FACIALFINCAPTION.CASHIERPERSONALINFO%TYPE := :NEW.CASHIERPERSONALINFO;
  new$BIDDATE FACIALFINCAPTION.BIDDATE%TYPE := :NEW.BIDDATE;
  new$CARDREF FACIALFINCAPTION.CARDREF%TYPE := :NEW.CARDREF;
  new$SOURCESTOREDPAYMENTPROPS FACIALFINCAPTION.SOURCESTOREDPAYMENTPROPS%TYPE := :NEW.SOURCESTOREDPAYMENTPROPS;
  new$DESTSTOREDPAYMENTPROPS FACIALFINCAPTION.DESTSTOREDPAYMENTPROPS%TYPE := :NEW.DESTSTOREDPAYMENTPROPS;
  new$STOREDPAYMENTNOTE FACIALFINCAPTION.STOREDPAYMENTNOTE%TYPE := :NEW.STOREDPAYMENTNOTE;
  new$DOCCHANGEDATE FACIALFINCAPTION.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$UINCODE FACIALFINCAPTION.UINCODE%TYPE := :NEW.UINCODE;
  new$DOCOSN FACIALFINCAPTION.DOCOSN%TYPE := :NEW.DOCOSN;
  new$SIGNERS FACIALFINCAPTION.SIGNERS%TYPE := :NEW.SIGNERS;
  new$DESTCLSTYPE FACIALFINCAPTION.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SENDERIDKEY FACIALFINCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$AUTOSANCTION FACIALFINCAPTION.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$STOREDPAYMENTCONTENT FACIALFINCAPTION.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$TEMPREJECTCAUSE FACIALFINCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  UseFax$ NUMBER(10);
  pdt$ NUMBER(10);
  reestrAccepted1$ NUMBER(10);
  DocNumber$ NUMBER(10);
  CmpFacialAcc_Cls$ NUMBER(10);
  PIndex1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALFINCAPTION_BI)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$credit is null)then 
    new$credit:= 0;
  END IF;
  if (new$ArhiveDoc is null) then 
    new$ArhiveDoc:= 0;
  END IF;
  if (new$PayTypeCls is null) then 
    new$PayTypeCls:= 0;
  END IF;
  if (new$BuhPaymentCls is null) then 
    new$BuhPaymentCls:= 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$ClsType is null) then 
    new$ClsType := 0;
  END IF;
  if (new$DestClsType is null) then 
    new$DestClsType := new$ClsType;
  END IF;
  if (new$SourceFacialAcc_CLS is null) then 
    new$SourceFacialAcc_CLS:= 0;
  END IF;
  if (new$DestFacialAcc_CLS is null) then 
    new$DestFacialAcc_CLS:= 0;
  END IF;
  if (new$FaxDocCount is null) then 
    new$FaxDocCount := 0;
  END IF;
  if (new$OperationDirection is null) then 
    new$OperationDirection := 0;
  END IF;
  if (new$OperationDirection = 0) then
    new$SourceType := 1;
    new$DestType := 1;
     
  else
    if (new$OperationDirection = 1) then
      new$SourceType := 1;
      new$DestType := -1;
         
    else
      if (new$OperationDirection = 2) then
        new$SourceType := -1;
        new$DestType := 1;
             
      else
        new$SourceType := -1;
        new$DestType := -1;
             
      END IF;
    END IF;
  END IF;
  if (new$DepartmentCls is null) then
    GetIntConst(30, 20,DocNumber$); 
    if (DocNumber$ is null) then 
      new$DepartmentCls:= 0;
           
    else 
      new$DepartmentCls:= DocNumber$;
       
    END IF;
  END IF;
   
  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    PIndex1$ := new$ProgIndex;
    if (PIndex1$=60) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*    .*/
    END IF;
    if (PIndex1$=61) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*       */
    END IF;
    if (PIndex1$=62) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*    */
    END IF;
    if (PIndex1$=63) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*     */
    END IF;
    if (PIndex1$=64) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*    */
    END IF;
    if (PIndex1$=65) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*  , */
    END IF;
    if (PIndex1$=66) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*   ,  - */
    END IF;
    if (PIndex1$=67) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*    */
    END IF;
    if (PIndex1$=68) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*   \ */
    END IF;
    if (PIndex1$=69) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*    \ */
    END IF;
    if (PIndex1$=70) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*   \ */
    END IF;
    if (PIndex1$=71) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*    \ */
    END IF;
    if (PIndex1$=73) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*   */
    END IF;
    if (PIndex1$=75) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*  */
    END IF;
    if (PIndex1$=76) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*  */
    END IF;
    BEGIN

      select fa.BudgetRef      into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = CmpFacialAcc_Cls$

      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null )) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_1 (TR_FACIALFINCAPTION_BI_1)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --   -     
   IF (new$GroupID IS NULL) THEN new$GroupID := new$ID; END IF;
   IF (new$GroupSumma IS NULL) THEN new$GroupSumma := 0; END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_FACIALFINCAPTION_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (((new$progIndex = 63) or (new$progIndex = 64) or
  (new$progIndex = 68) or (new$progIndex = 70))
  and (new$REESTR_REF is not null)) then
    BEGIN
      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where 
      id = new$REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
        
    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrInsert');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_FacialFinCaption_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;
        
  else
    new$SenderIDKey := new$SenderID;
  END IF;
      
  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;
        
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_16 (TR_FACIALFINCAPTION_BI_16)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*      .    FacialFinCaption
             */
   IF (new$Reestr_ref IS NULL) THEN
      new$SourceDocNum := '';
      new$ReestrDate := NULL;
   ELSE
      BEGIN
         SELECT ffr.ReestrNumber, ffr.ReestrDate
           INTO new$SourceDocNum, new$ReestrDate
           FROM FacialFinReestr ffr
          WHERE ffr.ID = new$Reestr_ref;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            new$SourceDocNum := NULL;
            new$ReestrDate := NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BI_430 (TR_FACIALFINCAPTION_BI_430)
-- Create 04.12.2004
-- Last update 11.10.2006
-- - - - - - - - - - - - -

  IF (NEW$SenderID IS NOT NULL) THEN
    pdt$ := NULL;
    IF (NEW$progindex = 63) THEN pdt$ := 302; END IF;
    IF (NEW$progindex = 66) THEN pdt$ := 301; END IF;
    IF (NEW$progindex = 64) THEN pdt$ := 304; END IF;

    /*       */
    GetIntConst(30, 19, UseFax$);
    IF ((new$BidNumber IS NULL) AND (UseFax$ = 1)) THEN
      new$BidNumber := new$DocNumber;
    END IF;
    SELECT COUNT(*) INTO new$FaxDocCount
    FROM FaxDocs
      WHERE (OwnerDocNumber=new$BidNumber)
        AND (ClientID=new$SenderID)
        AND (FacialAcc_Cls=new$SourceFacialAcc_CLS)
        AND (OwnerDate = new$DocumentDate)
        AND (PrimaryDocType = PDT$);
  ELSE
    new$FaxDocCount := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALFINCAPTION_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$DocChangeDate := new$UpdateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALFINCAPTION (
    ID,
    DOCNUMBER,
    SOURCEDOCNUM,
    PAYDATE,
    ACCEPTDATE,
    DOCUMENTDATE,
    REESTRDATE,
    CREDIT,
    SOURCEACCOUNT,
    SOURCEFACIALACC_CLS,
    DESTACCOUNT,
    DESTFACIALACC_CLS,
    PROGINDEX,
    ARHIVEDOC,
    PAYSYMBOLCLS,
    PAYTYPECLS,
    NOTE,
    PERIOD,
    PAYPRIORITY,
    TYPEOPERATIONCLS,
    BUHPAYMENTCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    RECORDINDEX,
    SENDERID,
    SENDERRECORDID,
    REESTR_REF,
    REJECT_CLS,
    CLIENTBANKNUMBER,
    CRYPTOSTATUS,
    TRUSTNUMBER,
    LINKEDDOCUMENT,
    BNKRECORDID,
    SUBPROGINDEX,
    DOCUMENTSTATE,
    USERSVISA,
    TREASUARYDOCSTATECLS,
    DEPARTMENTCLS,
    NDS,
    TAXNOTE,
    MANAGERBID,
    BIDNUMBER,
    GROUPID,
    GROUPSUMMA,
    DOCSTATEREF,
    LASTEXTRCHANGE,
    FAXDOCCOUNT,
    STIMATEID,
    INTEGRATEDDOCREF,
    REQUESTNUMBER,
    REQUESTDATE,
    RVERSION,
    FEDERALFUNDSREF,
    ELDOCREF,
    BUHOPERATIONCLS,
    CLSTYPE,
    OPERATIONDIRECTION,
    SOURCETYPE,
    DESTTYPE,
    CARDNUMBER,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    CASHIERPERSONALINFO,
    BIDDATE,
    CARDREF,
    SOURCESTOREDPAYMENTPROPS,
    DESTSTOREDPAYMENTPROPS,
    STOREDPAYMENTNOTE,
    DOCCHANGEDATE,
    UINCODE,
    DOCOSN,
    SIGNERS,
    DESTCLSTYPE,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    AUTOSANCTION,
    STOREDPAYMENTCONTENT,
    TEMPREJECTCAUSE
  ) VALUES (
    new$ID,
    new$DOCNUMBER,
    new$SOURCEDOCNUM,
    new$PAYDATE,
    new$ACCEPTDATE,
    new$DOCUMENTDATE,
    new$REESTRDATE,
    new$CREDIT,
    new$SOURCEACCOUNT,
    new$SOURCEFACIALACC_CLS,
    new$DESTACCOUNT,
    new$DESTFACIALACC_CLS,
    new$PROGINDEX,
    new$ARHIVEDOC,
    new$PAYSYMBOLCLS,
    new$PAYTYPECLS,
    new$NOTE,
    new$PERIOD,
    new$PAYPRIORITY,
    new$TYPEOPERATIONCLS,
    new$BUHPAYMENTCLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$RECORDINDEX,
    new$SENDERID,
    new$SENDERRECORDID,
    new$REESTR_REF,
    new$REJECT_CLS,
    new$CLIENTBANKNUMBER,
    new$CRYPTOSTATUS,
    new$TRUSTNUMBER,
    new$LINKEDDOCUMENT,
    new$BNKRECORDID,
    new$SUBPROGINDEX,
    new$DOCUMENTSTATE,
    new$USERSVISA,
    new$TREASUARYDOCSTATECLS,
    new$DEPARTMENTCLS,
    new$NDS,
    new$TAXNOTE,
    new$MANAGERBID,
    new$BIDNUMBER,
    new$GROUPID,
    new$GROUPSUMMA,
    new$DOCSTATEREF,
    new$LASTEXTRCHANGE,
    new$FAXDOCCOUNT,
    new$STIMATEID,
    new$INTEGRATEDDOCREF,
    new$REQUESTNUMBER,
    new$REQUESTDATE,
    new$RVERSION,
    new$FEDERALFUNDSREF,
    new$ELDOCREF,
    new$BUHOPERATIONCLS,
    new$CLSTYPE,
    new$OPERATIONDIRECTION,
    new$SOURCETYPE,
    new$DESTTYPE,
    new$CARDNUMBER,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$CASHIERPERSONALINFO,
    new$BIDDATE,
    new$CARDREF,
    new$SOURCESTOREDPAYMENTPROPS,
    new$DESTSTOREDPAYMENTPROPS,
    new$STOREDPAYMENTNOTE,
    new$DOCCHANGEDATE,
    new$UINCODE,
    new$DOCOSN,
    new$SIGNERS,
    new$DESTCLSTYPE,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$AUTOSANCTION,
    new$STOREDPAYMENTCONTENT,
    new$TEMPREJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_430 (TR_FACIALFINCAPTION_AI_430)
-- Create 04.12.2004
-- Last update 11.10.2006
-- - - - - - - - - - - - -

  IF (new$SenderID IS NOT NULL) THEN
      /*       */
      pdt$ := NULL;
      IF (new$progindex = 63) THEN pdt$ := 302; END IF;
      IF (new$progindex = 66) THEN pdt$ := 301; END IF;
      IF (new$progindex = 64) THEN pdt$ := 304; END IF;

        UPDATE FaxDocs
            SET OwnerId=new$id
        WHERE
            (OwnerDocNumber=new$BidNumber)
            AND (ClientID=new$SenderID)
            AND (FacialAcc_Cls=new$SourceFacialAcc_CLS)
            AND (OwnerDate = new$DocumentDate)
            AND (primarydoctype = pdt$);
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALFINCAPTION_AI_500)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
     WHERE (TableID = 23) AND (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINCAPTION_IU
  INSTEAD OF UPDATE
  ON FACIALFINCAPTION
  FOR EACH ROW
DECLARE
  new$ID FACIALFINCAPTION.ID%TYPE := :NEW.ID;
  new$DOCNUMBER FACIALFINCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SOURCEDOCNUM FACIALFINCAPTION.SOURCEDOCNUM%TYPE := :NEW.SOURCEDOCNUM;
  new$PAYDATE FACIALFINCAPTION.PAYDATE%TYPE := :NEW.PAYDATE;
  new$ACCEPTDATE FACIALFINCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCUMENTDATE FACIALFINCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$REESTRDATE FACIALFINCAPTION.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$CREDIT FACIALFINCAPTION.CREDIT%TYPE := :NEW.CREDIT;
  new$SOURCEACCOUNT FACIALFINCAPTION.SOURCEACCOUNT%TYPE := :NEW.SOURCEACCOUNT;
  new$SOURCEFACIALACC_CLS FACIALFINCAPTION.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$DESTACCOUNT FACIALFINCAPTION.DESTACCOUNT%TYPE := :NEW.DESTACCOUNT;
  new$DESTFACIALACC_CLS FACIALFINCAPTION.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$PROGINDEX FACIALFINCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$ARHIVEDOC FACIALFINCAPTION.ARHIVEDOC%TYPE := :NEW.ARHIVEDOC;
  new$PAYSYMBOLCLS FACIALFINCAPTION.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$PAYTYPECLS FACIALFINCAPTION.PAYTYPECLS%TYPE := :NEW.PAYTYPECLS;
  new$NOTE FACIALFINCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$PERIOD FACIALFINCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$PAYPRIORITY FACIALFINCAPTION.PAYPRIORITY%TYPE := :NEW.PAYPRIORITY;
  new$TYPEOPERATIONCLS FACIALFINCAPTION.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$BUHPAYMENTCLS FACIALFINCAPTION.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$CREATERUSER FACIALFINCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF FACIALFINCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECORDINDEX FACIALFINCAPTION.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$SENDERID FACIALFINCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REESTR_REF FACIALFINCAPTION.REESTR_REF%TYPE := :NEW.REESTR_REF;
  new$REJECT_CLS FACIALFINCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$CLIENTBANKNUMBER FACIALFINCAPTION.CLIENTBANKNUMBER%TYPE := :NEW.CLIENTBANKNUMBER;
  new$CRYPTOSTATUS FACIALFINCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$TRUSTNUMBER FACIALFINCAPTION.TRUSTNUMBER%TYPE := :NEW.TRUSTNUMBER;
  new$LINKEDDOCUMENT FACIALFINCAPTION.LINKEDDOCUMENT%TYPE := :NEW.LINKEDDOCUMENT;
  new$BNKRECORDID FACIALFINCAPTION.BNKRECORDID%TYPE := :NEW.BNKRECORDID;
  new$SUBPROGINDEX FACIALFINCAPTION.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$DOCUMENTSTATE FACIALFINCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA FACIALFINCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$TREASUARYDOCSTATECLS FACIALFINCAPTION.TREASUARYDOCSTATECLS%TYPE := :NEW.TREASUARYDOCSTATECLS;
  new$DEPARTMENTCLS FACIALFINCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$NDS FACIALFINCAPTION.NDS%TYPE := :NEW.NDS;
  new$TAXNOTE FACIALFINCAPTION.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$MANAGERBID FACIALFINCAPTION.MANAGERBID%TYPE := :NEW.MANAGERBID;
  new$BIDNUMBER FACIALFINCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$GROUPID FACIALFINCAPTION.GROUPID%TYPE := :NEW.GROUPID;
  new$GROUPSUMMA FACIALFINCAPTION.GROUPSUMMA%TYPE := :NEW.GROUPSUMMA;
  new$DOCSTATEREF FACIALFINCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$LASTEXTRCHANGE FACIALFINCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$FAXDOCCOUNT FACIALFINCAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$STIMATEID FACIALFINCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$INTEGRATEDDOCREF FACIALFINCAPTION.INTEGRATEDDOCREF%TYPE := :NEW.INTEGRATEDDOCREF;
  new$REQUESTNUMBER FACIALFINCAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$REQUESTDATE FACIALFINCAPTION.REQUESTDATE%TYPE := :NEW.REQUESTDATE;
  new$RVERSION FACIALFINCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$FEDERALFUNDSREF FACIALFINCAPTION.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$ELDOCREF FACIALFINCAPTION.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$BUHOPERATIONCLS FACIALFINCAPTION.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CLSTYPE FACIALFINCAPTION.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$OPERATIONDIRECTION FACIALFINCAPTION.OPERATIONDIRECTION%TYPE := :NEW.OPERATIONDIRECTION;
  new$SOURCETYPE FACIALFINCAPTION.SOURCETYPE%TYPE := :NEW.SOURCETYPE;
  new$DESTTYPE FACIALFINCAPTION.DESTTYPE%TYPE := :NEW.DESTTYPE;
  new$CARDNUMBER FACIALFINCAPTION.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$ISBLOCKED FACIALFINCAPTION.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINCAPTION.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINCAPTION.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINCAPTION.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$CASHIERPERSONALINFO FACIALFINCAPTION.CASHIERPERSONALINFO%TYPE := :NEW.CASHIERPERSONALINFO;
  new$BIDDATE FACIALFINCAPTION.BIDDATE%TYPE := :NEW.BIDDATE;
  new$CARDREF FACIALFINCAPTION.CARDREF%TYPE := :NEW.CARDREF;
  new$SOURCESTOREDPAYMENTPROPS FACIALFINCAPTION.SOURCESTOREDPAYMENTPROPS%TYPE := :NEW.SOURCESTOREDPAYMENTPROPS;
  new$DESTSTOREDPAYMENTPROPS FACIALFINCAPTION.DESTSTOREDPAYMENTPROPS%TYPE := :NEW.DESTSTOREDPAYMENTPROPS;
  new$STOREDPAYMENTNOTE FACIALFINCAPTION.STOREDPAYMENTNOTE%TYPE := :NEW.STOREDPAYMENTNOTE;
  new$DOCCHANGEDATE FACIALFINCAPTION.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$UINCODE FACIALFINCAPTION.UINCODE%TYPE := :NEW.UINCODE;
  new$DOCOSN FACIALFINCAPTION.DOCOSN%TYPE := :NEW.DOCOSN;
  new$SIGNERS FACIALFINCAPTION.SIGNERS%TYPE := :NEW.SIGNERS;
  new$DESTCLSTYPE FACIALFINCAPTION.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SENDERIDKEY FACIALFINCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$AUTOSANCTION FACIALFINCAPTION.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$STOREDPAYMENTCONTENT FACIALFINCAPTION.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$TEMPREJECTCAUSE FACIALFINCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  SourceFacialAcc_CLS$ NUMBER(10);
  DestFacialAcc_CLS$ NUMBER(10);
  CNT$1 NUMBER(10);
  reestrAccepted1$ NUMBER(10);
  IsReject1$ NUMBER(10);
  UseFax$ NUMBER(10);
  DocNumber$ NUMBER(10);
  DetCount$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINCAPTION_BU)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is not null) then
    /*      */
    GetIntConst(30, 19,UseFax$);
    if ((new$BidNumber is null) and (UseFax$ = 1)) then
      new$BidNumber:= new$DocNumber;

    END IF;
  END IF;
  if (new$credit is null)then
    new$credit:= 0;
  END IF;
  if (new$ArhiveDoc is null) then
    new$ArhiveDoc:= 0;
  END IF;
  if (new$PayTypeCls is null) then
    new$PayTypeCls:= 0;
  END IF;
  if (new$BuhPaymentCls is null) then
    new$BuhPaymentCls:= 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$ClsType is null) then
    new$ClsType := 0;
  END IF;
  if (new$DestClsType is null) then
    new$DestClsType := new$ClsType;
  END IF;
  if (new$SourceFacialAcc_CLS is null) then
    new$SourceFacialAcc_CLS:= 0;
  END IF;
  if (new$DestFacialAcc_CLS is null) then
    new$DestFacialAcc_CLS:= 0;
  END IF;
  if (new$FaxDocCount is null) then
    new$FaxDocCount := 0;
  END IF;
  if (new$OperationDirection is null) then
    new$OperationDirection := 0;
  END IF;
  if (new$OperationDirection <> :old.OperationDirection) then
    if (new$OperationDirection = 0) then
      new$SourceType := 1;
      new$DestType := 1;

    else
      if (new$OperationDirection = 1) then
        new$SourceType := 1;
        new$DestType := -1;

      else
        if (new$OperationDirection = 2) then
          new$SourceType := -1;
          new$DestType := 1;

        else
          new$SourceType := -1;
          new$DestType := -1;

        END IF;
      END IF;
    END IF;
  END IF;
  if (new$DepartmentCls is null) then
    GetIntConst(30, 20,DocNumber$);
    if (DocNumber$ is null) then
      new$DepartmentCls:= 0;

    else
      new$DepartmentCls:= DocNumber$;

    END IF;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount$ from FacialFinDetail where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_Cls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_1 (TR_FACIALFINCAPTION_BU_1)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --   -     
   IF (new$GroupID IS NULL) THEN new$GroupID := new$ID; END IF;
   IF (new$GroupSumma IS NULL) THEN new$GroupSumma := 0; END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_FACIALFINCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (not (    ((new$progindex = 63) or (new$progindex = 64) or (new$progindex = 68) or (new$progindex = 70))
  and (   (((new$credit - :old.credit)>0.001)or((new$credit - :old.credit)<-0.001))
  or (new$sourcefacialacc_cls <> :old.sourcefacialacc_cls)
  or (
  ((new$sourceaccount is null) and (:old.sourceaccount is not null)) or
  ((new$sourceaccount is not null) and (:old.sourceaccount is null)) or
  ((new$sourceaccount <> :old.sourceaccount ) and (:old.sourceaccount is not null) and (new$sourceaccount is not null))
  )
  or (
  ((new$destaccount is null) and (:old.destaccount is not null)) or
  ((new$destaccount is not null) and (:old.destaccount is null)) or
  ((new$destaccount <> :old.destaccount ) and (:old.destaccount is not null) and (new$destaccount is not null))
  )
  or (    (:old.reestr_ref is null)
  and (new$reestr_ref is not null)
  )
  or (    (:old.reestr_ref is not null)
  and (new$reestr_ref is null)
  )
  or (:old.reestr_ref <> new$reestr_ref)
  )
  )
  )
  then /*      NULL */
    reestrAccepted1$ := 0;  /*   IB 4.2 */

  else
    BEGIN
      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id=new$REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrUpdate');
    END IF;
    BEGIN

      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id=:old.REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrUpdate');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_6 (TR_FACIALFINCAPTION_BU_6)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (:old.ProgIndex in(63,68,70)) then /*    */
    SELECT COUNT(id ) INTO CNT$1
    from paydocexchange where ((paydocref=:old.id)and(status<>0)and(TypeInf BETWEEN 0 and 10)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      if(/* (new.DOCNUMBER<>old.DOCNUMBER) or ((new.DOCNUMBER is NULL)and(not old.DOCNUMBER is NULL)) or ((old.DOCNUMBER is NULL)and(not new.DOCNUMBER is NULL)) or*/
      (new$SOURCEDOCNUM<>:old.SOURCEDOCNUM) or ((new$SOURCEDOCNUM is NULL)and(not :old.SOURCEDOCNUM is NULL)) or ((:old.SOURCEDOCNUM is NULL)and(not new$SOURCEDOCNUM is NULL)) or
      (new$PAYDATE<>:old.PAYDATE) or ((new$PAYDATE is NULL)and(not :old.PAYDATE is NULL)) or ((:old.PAYDATE is NULL)and(not new$PAYDATE is NULL))or
      /* (new.DOCUMENTDATE<>old.DOCUMENTDATE) or ((new.DOCUMENTDATE is NULL)and(not old.DOCUMENTDATE is NULL)) or ((old.DOCUMENTDATE is NULL)and(not new.DOCUMENTDATE is NULL))or*/
      (new$REESTRDATE<>:old.REESTRDATE) or ((new$REESTRDATE is NULL)and(not :old.REESTRDATE is NULL)) or ((:old.REESTRDATE is NULL)and(not new$REESTRDATE is NULL))or
      (((new$credit - :old.credit)>0.001)or((new$credit - :old.credit)<-0.001)) or
      (new$SOURCEACCOUNT<>:old.SOURCEACCOUNT) or
      (new$DESTACCOUNT<>:old.DESTACCOUNT) or
      (new$PAYTYPECLS<>:old.PAYTYPECLS) or
      (new$NOTE<>:old.NOTE) or  ((new$NOTE is NULL)and(not :old.NOTE is NULL)) or ((:old.NOTE is NULL)and(not new$NOTE is NULL))or
      (new$PAYPRIORITY<>:old.PAYPRIORITY) or ((new$PAYPRIORITY is NULL)and(not :old.PAYPRIORITY is NULL)) or ((:old.PAYPRIORITY is NULL)and(not new$PAYPRIORITY is NULL))or
      (new$REESTR_REF<>:old.REESTR_REF) or ((new$REESTR_REF is NULL)and(not :old.REESTR_REF is NULL)) or ((:old.REESTR_REF is NULL)and(not new$REESTR_REF is NULL))or
      (new$NDS<>:old.NDS) or ((new$NDS is NULL)and(not :old.NDS is NULL)) or ((:old.NDS is NULL)and(not new$NDS is NULL))or
      (new$TAXNOTE<>:old.TAXNOTE) or ((new$TAXNOTE is NULL)and(not :old.TAXNOTE is NULL)) or ((:old.TAXNOTE is NULL)and(not new$TAXNOTE is NULL)) )then
        RaiseException('ex_CannotChangeSended');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_32 (TR_FACIALFINCAPTION_BU_32)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$Reestr_ref IS NULL)    /*    select ,  */
                              THEN
      new$SourceDocNum := '';
      new$ReestrDate := NULL;
   ELSIF (    (new$Reestr_ref = :OLD.Reestr_ref)
          AND (new$SourceDocNum = :OLD.SourceDocNum)
          AND (new$ReestrDate = :OLD.ReestrDate)
         ) THEN
/*          */
      NULL;
   ELSE
      BEGIN
         SELECT ffr.ReestrNumber, ffr.ReestrDate
           INTO new$SourceDocNum, new$ReestrDate
           FROM FacialFinReestr ffr
          WHERE ffr.ID = new$Reestr_ref;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            new$SourceDocNum := NULL;
            new$ReestrDate := NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BU_60 (T_FACIALFINCAPTION_BU_60)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF ((new$progindex = 60) AND (new$Credit <> :OLD.Credit)) THEN
      UPDATE FacialFinDetail
         SET Credit = new$Credit
       WHERE (RecordIndex = new$ID);
   END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_FACIALFINCAPTION_BU_70)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --         
   IF (new$SubProgIndex = 416) THEN
      UPDATE Guarantee
         SET AcceptDate = new$AcceptDate
       WHERE SubRecordIndex = new$ID;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (T_FACIALFINCAPTION_BU_100)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*   ,    */
   IF (    (   (:OLD.SourceFacialAcc_CLS <> new$SourceFacialAcc_CLS)
            OR (:OLD.DestFacialAcc_CLS <> new$DestFacialAcc_CLS)
           )
       AND ((new$SubProgIndex <> 1) OR (new$SubProgIndex IS NULL))
      ) THEN
      FOR R$ IN (SELECT ID, SourceFacialAcc_CLS, DestFacialAcc_CLS
                   FROM FacialFinDetail
                  WHERE RecordIndex = new$ID) LOOP
         IF (NOT (new$SourceFacialAcc_CLS = 0)) THEN
            SourceFacialAcc_CLS$ := new$SourceFacialAcc_CLS;
         ELSE
            SourceFacialAcc_CLS$ := R$.SourceFacialAcc_CLS;
         END IF;

         IF (NOT (new$DestFacialAcc_CLS = 0)) THEN
            DestFacialAcc_CLS$ := new$DestFacialAcc_CLS;
         ELSE
            DestFacialAcc_CLS$ := R$.DestFacialAcc_CLS;
         END IF;

         IF (:OLD.SourceFacialAcc_CLS <> new$SourceFacialAcc_CLS) THEN
            UPDATE FacialFinDetail
               SET SourceFacialAcc_CLS = SourceFacialAcc_CLS$,
                   RVersion = -1
             WHERE (ID = R$.ID);
         END IF;

         IF (:OLD.DestFacialAcc_CLS <> new$DestFacialAcc_CLS) THEN
            UPDATE FacialFinDetail
               SET DestFacialAcc_CLS = DestFacialAcc_CLS$,
                   RVersion = -1
             WHERE (ID = R$.ID);
         END IF;
      END LOOP;
   END IF;

   /*    / , 
           .*/
  IF (((NEW$IsBlocked <> :OLD.IsBlocked) OR
      ((NEW$IsBlocked IS NULL) AND (:OLD.IsBlocked IS NOT NULL)) OR
      ((NEW$IsBlocked IS NOT NULL) AND (:OLD.IsBlocked IS NULL))
     ) OR
     ((NEW$BlockedCause <> :OLD.BlockedCause) OR
      ((NEW$BlockedCause IS NULL) AND (:OLD.BlockedCause IS NOT NULL)) OR
      ((NEW$BlockedCause IS NOT NULL) AND (:OLD.BlockedCause IS NULL))
     ) OR
     ((NEW$UnBlockedDate <> :OLD.UnBlockedDate) OR
      ((NEW$UnBlockedDate IS NULL) AND (:OLD.UnBlockedDate IS NOT NULL)) OR
      ((NEW$UnBlockedDate IS NOT NULL) AND (:OLD.UnBlockedDate IS NULL))
     ) OR
     ((NEW$UnBlockedCause <> :OLD.UnBlockedCause) OR
      ((NEW$UnBlockedDate IS NULL) AND (:OLD.UnBlockedCause IS NOT NULL)) OR
      ((NEW$UnBlockedCause IS NOT NULL) AND (:OLD.UnBlockedCause IS NULL))
     )) THEN
     UPDATE FacialFinDetail ffd
     SET ffd.IsBlocked = NEW$IsBlocked, ffd.BlockedCause = NEW$BlockedCause,
         ffd.UnBlockedDate = NEW$UnBlockedDate, ffd.UnBlockedCause = NEW$UnBlockedCause
     WHERE ffd.recordindex = NEW$ID;
  end if;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINCAPTION_BU_210)
-- Create 27.08.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*      */
   IF (new$DOCSTATEREF <> :OLD.DOCSTATEREF) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DOCSTATEREF, new$DOCSTATEREF
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (T_FACIALFINCAPTION_BU_300)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  IsReject1$ := -1;
  if ((:old.Reject_CLS is null)and(new$Reject_CLS is not null)) then
    IsReject1$ := 1;

  else
    if ((:old.Reject_CLS is not null)and(new$Reject_CLS is null)) then
      IsReject1$ := 0;
    END IF;
  END IF;
  if (IsReject1$  <> -1) then
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID = new$ID;
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID in (select d.id from FacialFinDetail d where d.RecordIndex = new$id);

  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINCAPTION_BU_700)
-- Create 17.09.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINCAPTION SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    SOURCEDOCNUM = new$SOURCEDOCNUM,
    PAYDATE = new$PAYDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    REESTRDATE = new$REESTRDATE,
    CREDIT = new$CREDIT,
    SOURCEACCOUNT = new$SOURCEACCOUNT,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    DESTACCOUNT = new$DESTACCOUNT,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    PROGINDEX = new$PROGINDEX,
    ARHIVEDOC = new$ARHIVEDOC,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    PAYTYPECLS = new$PAYTYPECLS,
    NOTE = new$NOTE,
    PERIOD = new$PERIOD,
    PAYPRIORITY = new$PAYPRIORITY,
    TYPEOPERATIONCLS = new$TYPEOPERATIONCLS,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    RECORDINDEX = new$RECORDINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REESTR_REF = new$REESTR_REF,
    REJECT_CLS = new$REJECT_CLS,
    CLIENTBANKNUMBER = new$CLIENTBANKNUMBER,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    TRUSTNUMBER = new$TRUSTNUMBER,
    LINKEDDOCUMENT = new$LINKEDDOCUMENT,
    BNKRECORDID = new$BNKRECORDID,
    SUBPROGINDEX = new$SUBPROGINDEX,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    TREASUARYDOCSTATECLS = new$TREASUARYDOCSTATECLS,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    NDS = new$NDS,
    TAXNOTE = new$TAXNOTE,
    MANAGERBID = new$MANAGERBID,
    BIDNUMBER = new$BIDNUMBER,
    GROUPID = new$GROUPID,
    GROUPSUMMA = new$GROUPSUMMA,
    DOCSTATEREF = new$DOCSTATEREF,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    FAXDOCCOUNT = new$FAXDOCCOUNT,
    STIMATEID = new$STIMATEID,
    INTEGRATEDDOCREF = new$INTEGRATEDDOCREF,
    REQUESTNUMBER = new$REQUESTNUMBER,
    REQUESTDATE = new$REQUESTDATE,
    RVERSION = new$RVERSION,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    ELDOCREF = new$ELDOCREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    CLSTYPE = new$CLSTYPE,
    OPERATIONDIRECTION = new$OPERATIONDIRECTION,
    SOURCETYPE = new$SOURCETYPE,
    DESTTYPE = new$DESTTYPE,
    CARDNUMBER = new$CARDNUMBER,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    CASHIERPERSONALINFO = new$CASHIERPERSONALINFO,
    BIDDATE = new$BIDDATE,
    CARDREF = new$CARDREF,
    SOURCESTOREDPAYMENTPROPS = new$SOURCESTOREDPAYMENTPROPS,
    DESTSTOREDPAYMENTPROPS = new$DESTSTOREDPAYMENTPROPS,
    STOREDPAYMENTNOTE = new$STOREDPAYMENTNOTE,
    DOCCHANGEDATE = new$DOCCHANGEDATE,
    UINCODE = new$UINCODE,
    DOCOSN = new$DOCOSN,
    SIGNERS = new$SIGNERS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    AUTOSANCTION = new$AUTOSANCTION,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_300 (TR_FACIALFINCAPTION_AU_300)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*          ,      */
  if ((new$AcceptDate <> :old.AcceptDate)or((new$AcceptDate is not null)and(:old.AcceptDate is null))
  or((new$AcceptDate is null)and(:old.AcceptDate is not null))) then
    update facialfindetail set
    AcceptDate = new$AcceptDate,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;
  if (new$BuhOperationCLS <> :old.BuhOperationCLS)  then
    update facialfindetail set
    BuhOperationCLS = new$BuhOperationCLS,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;
  if ((new$ClsType <> :old.ClsType)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$ClsType = 0) then
      update facialfindetail set
      SourceKD = 0,
      DestKD = 0,
      SourceIFS = 0,
      DestIFS = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 1) then
      update facialfindetail set
      SourceKD = 0,
      DestKD = 0,
      SourceKVSR = 0,
      SourceKFSR = 0,
      SourceKCSR = 0,
      SourceKVR = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 2) then
      update facialfindetail set
      SourceIFS = 0,
      DestIFS = 0,
      SourceKVSR = 0,
      SourceKFSR = 0,
      SourceKCSR = 0,
      SourceKVR = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);

    END IF;
  END IF;
  if ((new$DestClsType <> :old.DestClsType)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$DestClsType = 0) then
      update facialfindetail set
      DestKD = 0,
      DestIFS = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
    END IF;
    if (new$DestClsType = 1) then
      update facialfindetail set
      DestKD = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
    END IF;
    if (new$DestClsType = 2) then
      update facialfindetail set
      DestIFS = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINCAPTION_AU_500)
-- Create 28.04.2005
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (:NEW.ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (23, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
        WHERE (TableID = 23) AND (RecordId = :NEW.ID);
   END IF;

END;
/
ALTER TABLE TB_FACIALFINCAPTION ADD (
  REJECTCAUSE VARCHAR2(1000)
)
/

CREATE OR REPLACE VIEW FACIALFINCAPTION (
  ID,
  DOCNUMBER,
  SOURCEDOCNUM,
  PAYDATE,
  ACCEPTDATE,
  DOCUMENTDATE,
  REESTRDATE,
  CREDIT,
  SOURCEACCOUNT,
  SOURCEFACIALACC_CLS,
  DESTACCOUNT,
  DESTFACIALACC_CLS,
  PROGINDEX,
  ARHIVEDOC,
  PAYSYMBOLCLS,
  PAYTYPECLS,
  NOTE,
  PERIOD,
  PAYPRIORITY,
  TYPEOPERATIONCLS,
  BUHPAYMENTCLS,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  BUDGETREF,
  RECORDINDEX,
  SENDERID,
  SENDERRECORDID,
  REESTR_REF,
  REJECT_CLS,
  CLIENTBANKNUMBER,
  CRYPTOSTATUS,
  TRUSTNUMBER,
  LINKEDDOCUMENT,
  BNKRECORDID,
  SUBPROGINDEX,
  DOCUMENTSTATE,
  USERSVISA,
  TREASUARYDOCSTATECLS,
  DEPARTMENTCLS,
  NDS,
  TAXNOTE,
  MANAGERBID,
  BIDNUMBER,
  GROUPID,
  GROUPSUMMA,
  DOCSTATEREF,
  LASTEXTRCHANGE,
  FAXDOCCOUNT,
  STIMATEID,
  INTEGRATEDDOCREF,
  REQUESTNUMBER,
  REQUESTDATE,
  RVERSION,
  FEDERALFUNDSREF,
  ELDOCREF,
  BUHOPERATIONCLS,
  CLSTYPE,
  OPERATIONDIRECTION,
  SOURCETYPE,
  DESTTYPE,
  CARDNUMBER,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  CASHIERPERSONALINFO,
  BIDDATE,
  CARDREF,
  SOURCESTOREDPAYMENTPROPS,
  DESTSTOREDPAYMENTPROPS,
  STOREDPAYMENTNOTE,
  DOCCHANGEDATE,
  UINCODE,
  DOCOSN,
  SIGNERS,
  DESTCLSTYPE,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  AUTOSANCTION,
  STOREDPAYMENTCONTENT,
  TEMPREJECTCAUSE,
  REJECTCAUSE)
AS
  SELECT
    ID,
    DOCNUMBER,
    SOURCEDOCNUM,
    PAYDATE,
    ACCEPTDATE,
    DOCUMENTDATE,
    REESTRDATE,
    CREDIT,
    SOURCEACCOUNT,
    SOURCEFACIALACC_CLS,
    DESTACCOUNT,
    DESTFACIALACC_CLS,
    PROGINDEX,
    ARHIVEDOC,
    PAYSYMBOLCLS,
    PAYTYPECLS,
    NOTE,
    PERIOD,
    PAYPRIORITY,
    TYPEOPERATIONCLS,
    BUHPAYMENTCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    RECORDINDEX,
    SENDERID,
    SENDERRECORDID,
    REESTR_REF,
    REJECT_CLS,
    CLIENTBANKNUMBER,
    CRYPTOSTATUS,
    TRUSTNUMBER,
    LINKEDDOCUMENT,
    BNKRECORDID,
    SUBPROGINDEX,
    DOCUMENTSTATE,
    USERSVISA,
    TREASUARYDOCSTATECLS,
    DEPARTMENTCLS,
    NDS,
    TAXNOTE,
    MANAGERBID,
    BIDNUMBER,
    GROUPID,
    GROUPSUMMA,
    DOCSTATEREF,
    LASTEXTRCHANGE,
    FAXDOCCOUNT,
    STIMATEID,
    INTEGRATEDDOCREF,
    REQUESTNUMBER,
    REQUESTDATE,
    RVERSION,
    FEDERALFUNDSREF,
    ELDOCREF,
    BUHOPERATIONCLS,
    CLSTYPE,
    OPERATIONDIRECTION,
    SOURCETYPE,
    DESTTYPE,
    CARDNUMBER,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    CASHIERPERSONALINFO,
    BIDDATE,
    CARDREF,
    SOURCESTOREDPAYMENTPROPS,
    DESTSTOREDPAYMENTPROPS,
    STOREDPAYMENTNOTE,
    DOCCHANGEDATE,
    UINCODE,
    DOCOSN,
    SIGNERS,
    DESTCLSTYPE,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    AUTOSANCTION,
    STOREDPAYMENTCONTENT,
    TEMPREJECTCAUSE,
    REJECTCAUSE
  FROM TB_FACIALFINCAPTION
/

CREATE OR REPLACE TRIGGER TR_FACIALFINCAPTION_ID
  INSTEAD OF DELETE
  ON FACIALFINCAPTION
  FOR EACH ROW
DECLARE
  reestrAccepted1$ NUMBER(10);
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_FACIALFINCAPTION_BD)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

 /*       */
  DELETE FROM FacialFinDetail
        WHERE (RecordIndex = :OLD.ID);

-- - - - - - - - - - - - -
-- BD_5 (TR_FACIALFINCAPTION_BD_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (((:old.progIndex = 63) or (:old.progIndex = 64) or
  (:old.progIndex = 68) or (:old.progIndex = 70))
  and (:old.REESTR_REF is not null)) then
    BEGIN
      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id = :old.REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrDelete');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BD_6 (TR_FACIALFINCAPTION_BD_6)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(id ) INTO CNT$1
  from paydocexchange where ((paydocref=:old.id)and(status<>0)and(TypeInf BETWEEN 0 and 10)) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    RaiseException('ex_CannotChangeSended');
  else
    delete from PayDocExchange where paydocref = :old.id;
  END IF;

-- - - - - - - - - - - - -
-- BD_430 (TR_FACIALFINCAPTION_BD_430)
-- Create 04.12.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

  /*         */
  UPDATE FaxDocs
     SET OwnerID = NULL
  WHERE OwnerID = :OLD.ID;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_FACIALFINCAPTION
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_70 (TR_FACIALFINCAPTION_AD_70)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

--   /     
  IF (:OLD.SubProgIndex = 416) THEN
    UPDATE Guarantee
       SET SubRecordIndex = NULL,
           SubProgIndex = 0
     WHERE SubRecordIndex = :OLD.ID;
  END IF;

-- - - - - - - - - - - - -
-- AD_200 (TR_FACIALFINCAPTION_AD_200)
-- Create 27.08.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

  /*       */
  delete from StateJumpHistory
    where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_300 (TR_FACIALFINCAPTION_AD_300)
-- Create 24.02.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

  IF (:OLD.FaxDocCount > 0) THEN
--    :old.FaxDocCount := :old.FaxDocCount;
    NULL;
  ELSE
    UPDATE FaxDocs
       SET OwnerID = NULL
     WHERE OwnerID = :OLD.ID;
  END IF;

-- - - - - - - - - - - - -
-- AD_500 (TR_FACIALFINCAPTION_AD_500)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

  INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate, ProgIndex, Summa)
    VALUES (23, :OLD.ID, SYSDATE, :OLD.ProgIndex, :OLD.Credit);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINCAPTION_II
  INSTEAD OF INSERT
  ON FACIALFINCAPTION
  FOR EACH ROW
DECLARE
  new$ID FACIALFINCAPTION.ID%TYPE := :NEW.ID;
  new$DOCNUMBER FACIALFINCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SOURCEDOCNUM FACIALFINCAPTION.SOURCEDOCNUM%TYPE := :NEW.SOURCEDOCNUM;
  new$PAYDATE FACIALFINCAPTION.PAYDATE%TYPE := :NEW.PAYDATE;
  new$ACCEPTDATE FACIALFINCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCUMENTDATE FACIALFINCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$REESTRDATE FACIALFINCAPTION.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$CREDIT FACIALFINCAPTION.CREDIT%TYPE := :NEW.CREDIT;
  new$SOURCEACCOUNT FACIALFINCAPTION.SOURCEACCOUNT%TYPE := :NEW.SOURCEACCOUNT;
  new$SOURCEFACIALACC_CLS FACIALFINCAPTION.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$DESTACCOUNT FACIALFINCAPTION.DESTACCOUNT%TYPE := :NEW.DESTACCOUNT;
  new$DESTFACIALACC_CLS FACIALFINCAPTION.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$PROGINDEX FACIALFINCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$ARHIVEDOC FACIALFINCAPTION.ARHIVEDOC%TYPE := :NEW.ARHIVEDOC;
  new$PAYSYMBOLCLS FACIALFINCAPTION.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$PAYTYPECLS FACIALFINCAPTION.PAYTYPECLS%TYPE := :NEW.PAYTYPECLS;
  new$NOTE FACIALFINCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$PERIOD FACIALFINCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$PAYPRIORITY FACIALFINCAPTION.PAYPRIORITY%TYPE := :NEW.PAYPRIORITY;
  new$TYPEOPERATIONCLS FACIALFINCAPTION.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$BUHPAYMENTCLS FACIALFINCAPTION.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$CREATERUSER FACIALFINCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF FACIALFINCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECORDINDEX FACIALFINCAPTION.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$SENDERID FACIALFINCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REESTR_REF FACIALFINCAPTION.REESTR_REF%TYPE := :NEW.REESTR_REF;
  new$REJECT_CLS FACIALFINCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$CLIENTBANKNUMBER FACIALFINCAPTION.CLIENTBANKNUMBER%TYPE := :NEW.CLIENTBANKNUMBER;
  new$CRYPTOSTATUS FACIALFINCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$TRUSTNUMBER FACIALFINCAPTION.TRUSTNUMBER%TYPE := :NEW.TRUSTNUMBER;
  new$LINKEDDOCUMENT FACIALFINCAPTION.LINKEDDOCUMENT%TYPE := :NEW.LINKEDDOCUMENT;
  new$BNKRECORDID FACIALFINCAPTION.BNKRECORDID%TYPE := :NEW.BNKRECORDID;
  new$SUBPROGINDEX FACIALFINCAPTION.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$DOCUMENTSTATE FACIALFINCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA FACIALFINCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$TREASUARYDOCSTATECLS FACIALFINCAPTION.TREASUARYDOCSTATECLS%TYPE := :NEW.TREASUARYDOCSTATECLS;
  new$DEPARTMENTCLS FACIALFINCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$NDS FACIALFINCAPTION.NDS%TYPE := :NEW.NDS;
  new$TAXNOTE FACIALFINCAPTION.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$MANAGERBID FACIALFINCAPTION.MANAGERBID%TYPE := :NEW.MANAGERBID;
  new$BIDNUMBER FACIALFINCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$GROUPID FACIALFINCAPTION.GROUPID%TYPE := :NEW.GROUPID;
  new$GROUPSUMMA FACIALFINCAPTION.GROUPSUMMA%TYPE := :NEW.GROUPSUMMA;
  new$DOCSTATEREF FACIALFINCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$LASTEXTRCHANGE FACIALFINCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$FAXDOCCOUNT FACIALFINCAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$STIMATEID FACIALFINCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$INTEGRATEDDOCREF FACIALFINCAPTION.INTEGRATEDDOCREF%TYPE := :NEW.INTEGRATEDDOCREF;
  new$REQUESTNUMBER FACIALFINCAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$REQUESTDATE FACIALFINCAPTION.REQUESTDATE%TYPE := :NEW.REQUESTDATE;
  new$RVERSION FACIALFINCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$FEDERALFUNDSREF FACIALFINCAPTION.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$ELDOCREF FACIALFINCAPTION.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$BUHOPERATIONCLS FACIALFINCAPTION.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CLSTYPE FACIALFINCAPTION.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$OPERATIONDIRECTION FACIALFINCAPTION.OPERATIONDIRECTION%TYPE := :NEW.OPERATIONDIRECTION;
  new$SOURCETYPE FACIALFINCAPTION.SOURCETYPE%TYPE := :NEW.SOURCETYPE;
  new$DESTTYPE FACIALFINCAPTION.DESTTYPE%TYPE := :NEW.DESTTYPE;
  new$CARDNUMBER FACIALFINCAPTION.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$ISBLOCKED FACIALFINCAPTION.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINCAPTION.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINCAPTION.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINCAPTION.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$CASHIERPERSONALINFO FACIALFINCAPTION.CASHIERPERSONALINFO%TYPE := :NEW.CASHIERPERSONALINFO;
  new$BIDDATE FACIALFINCAPTION.BIDDATE%TYPE := :NEW.BIDDATE;
  new$CARDREF FACIALFINCAPTION.CARDREF%TYPE := :NEW.CARDREF;
  new$SOURCESTOREDPAYMENTPROPS FACIALFINCAPTION.SOURCESTOREDPAYMENTPROPS%TYPE := :NEW.SOURCESTOREDPAYMENTPROPS;
  new$DESTSTOREDPAYMENTPROPS FACIALFINCAPTION.DESTSTOREDPAYMENTPROPS%TYPE := :NEW.DESTSTOREDPAYMENTPROPS;
  new$STOREDPAYMENTNOTE FACIALFINCAPTION.STOREDPAYMENTNOTE%TYPE := :NEW.STOREDPAYMENTNOTE;
  new$DOCCHANGEDATE FACIALFINCAPTION.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$UINCODE FACIALFINCAPTION.UINCODE%TYPE := :NEW.UINCODE;
  new$DOCOSN FACIALFINCAPTION.DOCOSN%TYPE := :NEW.DOCOSN;
  new$SIGNERS FACIALFINCAPTION.SIGNERS%TYPE := :NEW.SIGNERS;
  new$DESTCLSTYPE FACIALFINCAPTION.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SENDERIDKEY FACIALFINCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$AUTOSANCTION FACIALFINCAPTION.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$STOREDPAYMENTCONTENT FACIALFINCAPTION.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$TEMPREJECTCAUSE FACIALFINCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
  new$REJECTCAUSE FACIALFINCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  UseFax$ NUMBER(10);
  pdt$ NUMBER(10);
  reestrAccepted1$ NUMBER(10);
  DocNumber$ NUMBER(10);
  CmpFacialAcc_Cls$ NUMBER(10);
  PIndex1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALFINCAPTION_BI)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$credit is null)then 
    new$credit:= 0;
  END IF;
  if (new$ArhiveDoc is null) then 
    new$ArhiveDoc:= 0;
  END IF;
  if (new$PayTypeCls is null) then 
    new$PayTypeCls:= 0;
  END IF;
  if (new$BuhPaymentCls is null) then 
    new$BuhPaymentCls:= 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$ClsType is null) then 
    new$ClsType := 0;
  END IF;
  if (new$DestClsType is null) then 
    new$DestClsType := new$ClsType;
  END IF;
  if (new$SourceFacialAcc_CLS is null) then 
    new$SourceFacialAcc_CLS:= 0;
  END IF;
  if (new$DestFacialAcc_CLS is null) then 
    new$DestFacialAcc_CLS:= 0;
  END IF;
  if (new$FaxDocCount is null) then 
    new$FaxDocCount := 0;
  END IF;
  if (new$OperationDirection is null) then 
    new$OperationDirection := 0;
  END IF;
  if (new$OperationDirection = 0) then
    new$SourceType := 1;
    new$DestType := 1;
     
  else
    if (new$OperationDirection = 1) then
      new$SourceType := 1;
      new$DestType := -1;
         
    else
      if (new$OperationDirection = 2) then
        new$SourceType := -1;
        new$DestType := 1;
             
      else
        new$SourceType := -1;
        new$DestType := -1;
             
      END IF;
    END IF;
  END IF;
  if (new$DepartmentCls is null) then
    GetIntConst(30, 20,DocNumber$); 
    if (DocNumber$ is null) then 
      new$DepartmentCls:= 0;
           
    else 
      new$DepartmentCls:= DocNumber$;
       
    END IF;
  END IF;
   
  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    PIndex1$ := new$ProgIndex;
    if (PIndex1$=60) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*    .*/
    END IF;
    if (PIndex1$=61) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*       */
    END IF;
    if (PIndex1$=62) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*    */
    END IF;
    if (PIndex1$=63) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*     */
    END IF;
    if (PIndex1$=64) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*    */
    END IF;
    if (PIndex1$=65) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*  , */
    END IF;
    if (PIndex1$=66) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*   ,  - */
    END IF;
    if (PIndex1$=67) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*    */
    END IF;
    if (PIndex1$=68) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*   \ */
    END IF;
    if (PIndex1$=69) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*    \ */
    END IF;
    if (PIndex1$=70) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*   \ */
    END IF;
    if (PIndex1$=71) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*    \ */
    END IF;
    if (PIndex1$=73) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*   */
    END IF;
    if (PIndex1$=75) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*  */
    END IF;
    if (PIndex1$=76) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*  */
    END IF;
    BEGIN

      select fa.BudgetRef      into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = CmpFacialAcc_Cls$

      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null )) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_1 (TR_FACIALFINCAPTION_BI_1)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --   -     
   IF (new$GroupID IS NULL) THEN new$GroupID := new$ID; END IF;
   IF (new$GroupSumma IS NULL) THEN new$GroupSumma := 0; END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_FACIALFINCAPTION_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (((new$progIndex = 63) or (new$progIndex = 64) or
  (new$progIndex = 68) or (new$progIndex = 70))
  and (new$REESTR_REF is not null)) then
    BEGIN
      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where 
      id = new$REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
        
    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrInsert');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_FacialFinCaption_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;
        
  else
    new$SenderIDKey := new$SenderID;
  END IF;
      
  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;
        
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_16 (TR_FACIALFINCAPTION_BI_16)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*      .    FacialFinCaption
             */
   IF (new$Reestr_ref IS NULL) THEN
      new$SourceDocNum := '';
      new$ReestrDate := NULL;
   ELSE
      BEGIN
         SELECT ffr.ReestrNumber, ffr.ReestrDate
           INTO new$SourceDocNum, new$ReestrDate
           FROM FacialFinReestr ffr
          WHERE ffr.ID = new$Reestr_ref;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            new$SourceDocNum := NULL;
            new$ReestrDate := NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BI_430 (TR_FACIALFINCAPTION_BI_430)
-- Create 04.12.2004
-- Last update 11.10.2006
-- - - - - - - - - - - - -

  IF (NEW$SenderID IS NOT NULL) THEN
    pdt$ := NULL;
    IF (NEW$progindex = 63) THEN pdt$ := 302; END IF;
    IF (NEW$progindex = 66) THEN pdt$ := 301; END IF;
    IF (NEW$progindex = 64) THEN pdt$ := 304; END IF;

    /*       */
    GetIntConst(30, 19, UseFax$);
    IF ((new$BidNumber IS NULL) AND (UseFax$ = 1)) THEN
      new$BidNumber := new$DocNumber;
    END IF;
    SELECT COUNT(*) INTO new$FaxDocCount
    FROM FaxDocs
      WHERE (OwnerDocNumber=new$BidNumber)
        AND (ClientID=new$SenderID)
        AND (FacialAcc_Cls=new$SourceFacialAcc_CLS)
        AND (OwnerDate = new$DocumentDate)
        AND (PrimaryDocType = PDT$);
  ELSE
    new$FaxDocCount := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALFINCAPTION_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$DocChangeDate := new$UpdateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALFINCAPTION (
    ID,
    DOCNUMBER,
    SOURCEDOCNUM,
    PAYDATE,
    ACCEPTDATE,
    DOCUMENTDATE,
    REESTRDATE,
    CREDIT,
    SOURCEACCOUNT,
    SOURCEFACIALACC_CLS,
    DESTACCOUNT,
    DESTFACIALACC_CLS,
    PROGINDEX,
    ARHIVEDOC,
    PAYSYMBOLCLS,
    PAYTYPECLS,
    NOTE,
    PERIOD,
    PAYPRIORITY,
    TYPEOPERATIONCLS,
    BUHPAYMENTCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    RECORDINDEX,
    SENDERID,
    SENDERRECORDID,
    REESTR_REF,
    REJECT_CLS,
    CLIENTBANKNUMBER,
    CRYPTOSTATUS,
    TRUSTNUMBER,
    LINKEDDOCUMENT,
    BNKRECORDID,
    SUBPROGINDEX,
    DOCUMENTSTATE,
    USERSVISA,
    TREASUARYDOCSTATECLS,
    DEPARTMENTCLS,
    NDS,
    TAXNOTE,
    MANAGERBID,
    BIDNUMBER,
    GROUPID,
    GROUPSUMMA,
    DOCSTATEREF,
    LASTEXTRCHANGE,
    FAXDOCCOUNT,
    STIMATEID,
    INTEGRATEDDOCREF,
    REQUESTNUMBER,
    REQUESTDATE,
    RVERSION,
    FEDERALFUNDSREF,
    ELDOCREF,
    BUHOPERATIONCLS,
    CLSTYPE,
    OPERATIONDIRECTION,
    SOURCETYPE,
    DESTTYPE,
    CARDNUMBER,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    CASHIERPERSONALINFO,
    BIDDATE,
    CARDREF,
    SOURCESTOREDPAYMENTPROPS,
    DESTSTOREDPAYMENTPROPS,
    STOREDPAYMENTNOTE,
    DOCCHANGEDATE,
    UINCODE,
    DOCOSN,
    SIGNERS,
    DESTCLSTYPE,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    AUTOSANCTION,
    STOREDPAYMENTCONTENT,
    TEMPREJECTCAUSE,
    REJECTCAUSE
  ) VALUES (
    new$ID,
    new$DOCNUMBER,
    new$SOURCEDOCNUM,
    new$PAYDATE,
    new$ACCEPTDATE,
    new$DOCUMENTDATE,
    new$REESTRDATE,
    new$CREDIT,
    new$SOURCEACCOUNT,
    new$SOURCEFACIALACC_CLS,
    new$DESTACCOUNT,
    new$DESTFACIALACC_CLS,
    new$PROGINDEX,
    new$ARHIVEDOC,
    new$PAYSYMBOLCLS,
    new$PAYTYPECLS,
    new$NOTE,
    new$PERIOD,
    new$PAYPRIORITY,
    new$TYPEOPERATIONCLS,
    new$BUHPAYMENTCLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$RECORDINDEX,
    new$SENDERID,
    new$SENDERRECORDID,
    new$REESTR_REF,
    new$REJECT_CLS,
    new$CLIENTBANKNUMBER,
    new$CRYPTOSTATUS,
    new$TRUSTNUMBER,
    new$LINKEDDOCUMENT,
    new$BNKRECORDID,
    new$SUBPROGINDEX,
    new$DOCUMENTSTATE,
    new$USERSVISA,
    new$TREASUARYDOCSTATECLS,
    new$DEPARTMENTCLS,
    new$NDS,
    new$TAXNOTE,
    new$MANAGERBID,
    new$BIDNUMBER,
    new$GROUPID,
    new$GROUPSUMMA,
    new$DOCSTATEREF,
    new$LASTEXTRCHANGE,
    new$FAXDOCCOUNT,
    new$STIMATEID,
    new$INTEGRATEDDOCREF,
    new$REQUESTNUMBER,
    new$REQUESTDATE,
    new$RVERSION,
    new$FEDERALFUNDSREF,
    new$ELDOCREF,
    new$BUHOPERATIONCLS,
    new$CLSTYPE,
    new$OPERATIONDIRECTION,
    new$SOURCETYPE,
    new$DESTTYPE,
    new$CARDNUMBER,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$CASHIERPERSONALINFO,
    new$BIDDATE,
    new$CARDREF,
    new$SOURCESTOREDPAYMENTPROPS,
    new$DESTSTOREDPAYMENTPROPS,
    new$STOREDPAYMENTNOTE,
    new$DOCCHANGEDATE,
    new$UINCODE,
    new$DOCOSN,
    new$SIGNERS,
    new$DESTCLSTYPE,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$AUTOSANCTION,
    new$STOREDPAYMENTCONTENT,
    new$TEMPREJECTCAUSE,
    new$REJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_430 (TR_FACIALFINCAPTION_AI_430)
-- Create 04.12.2004
-- Last update 11.10.2006
-- - - - - - - - - - - - -

  IF (new$SenderID IS NOT NULL) THEN
      /*       */
      pdt$ := NULL;
      IF (new$progindex = 63) THEN pdt$ := 302; END IF;
      IF (new$progindex = 66) THEN pdt$ := 301; END IF;
      IF (new$progindex = 64) THEN pdt$ := 304; END IF;

        UPDATE FaxDocs
            SET OwnerId=new$id
        WHERE
            (OwnerDocNumber=new$BidNumber)
            AND (ClientID=new$SenderID)
            AND (FacialAcc_Cls=new$SourceFacialAcc_CLS)
            AND (OwnerDate = new$DocumentDate)
            AND (primarydoctype = pdt$);
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALFINCAPTION_AI_500)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
     WHERE (TableID = 23) AND (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINCAPTION_IU
  INSTEAD OF UPDATE
  ON FACIALFINCAPTION
  FOR EACH ROW
DECLARE
  new$ID FACIALFINCAPTION.ID%TYPE := :NEW.ID;
  new$DOCNUMBER FACIALFINCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SOURCEDOCNUM FACIALFINCAPTION.SOURCEDOCNUM%TYPE := :NEW.SOURCEDOCNUM;
  new$PAYDATE FACIALFINCAPTION.PAYDATE%TYPE := :NEW.PAYDATE;
  new$ACCEPTDATE FACIALFINCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCUMENTDATE FACIALFINCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$REESTRDATE FACIALFINCAPTION.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$CREDIT FACIALFINCAPTION.CREDIT%TYPE := :NEW.CREDIT;
  new$SOURCEACCOUNT FACIALFINCAPTION.SOURCEACCOUNT%TYPE := :NEW.SOURCEACCOUNT;
  new$SOURCEFACIALACC_CLS FACIALFINCAPTION.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$DESTACCOUNT FACIALFINCAPTION.DESTACCOUNT%TYPE := :NEW.DESTACCOUNT;
  new$DESTFACIALACC_CLS FACIALFINCAPTION.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$PROGINDEX FACIALFINCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$ARHIVEDOC FACIALFINCAPTION.ARHIVEDOC%TYPE := :NEW.ARHIVEDOC;
  new$PAYSYMBOLCLS FACIALFINCAPTION.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$PAYTYPECLS FACIALFINCAPTION.PAYTYPECLS%TYPE := :NEW.PAYTYPECLS;
  new$NOTE FACIALFINCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$PERIOD FACIALFINCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$PAYPRIORITY FACIALFINCAPTION.PAYPRIORITY%TYPE := :NEW.PAYPRIORITY;
  new$TYPEOPERATIONCLS FACIALFINCAPTION.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$BUHPAYMENTCLS FACIALFINCAPTION.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$CREATERUSER FACIALFINCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF FACIALFINCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECORDINDEX FACIALFINCAPTION.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$SENDERID FACIALFINCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REESTR_REF FACIALFINCAPTION.REESTR_REF%TYPE := :NEW.REESTR_REF;
  new$REJECT_CLS FACIALFINCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$CLIENTBANKNUMBER FACIALFINCAPTION.CLIENTBANKNUMBER%TYPE := :NEW.CLIENTBANKNUMBER;
  new$CRYPTOSTATUS FACIALFINCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$TRUSTNUMBER FACIALFINCAPTION.TRUSTNUMBER%TYPE := :NEW.TRUSTNUMBER;
  new$LINKEDDOCUMENT FACIALFINCAPTION.LINKEDDOCUMENT%TYPE := :NEW.LINKEDDOCUMENT;
  new$BNKRECORDID FACIALFINCAPTION.BNKRECORDID%TYPE := :NEW.BNKRECORDID;
  new$SUBPROGINDEX FACIALFINCAPTION.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$DOCUMENTSTATE FACIALFINCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA FACIALFINCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$TREASUARYDOCSTATECLS FACIALFINCAPTION.TREASUARYDOCSTATECLS%TYPE := :NEW.TREASUARYDOCSTATECLS;
  new$DEPARTMENTCLS FACIALFINCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$NDS FACIALFINCAPTION.NDS%TYPE := :NEW.NDS;
  new$TAXNOTE FACIALFINCAPTION.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$MANAGERBID FACIALFINCAPTION.MANAGERBID%TYPE := :NEW.MANAGERBID;
  new$BIDNUMBER FACIALFINCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$GROUPID FACIALFINCAPTION.GROUPID%TYPE := :NEW.GROUPID;
  new$GROUPSUMMA FACIALFINCAPTION.GROUPSUMMA%TYPE := :NEW.GROUPSUMMA;
  new$DOCSTATEREF FACIALFINCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$LASTEXTRCHANGE FACIALFINCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$FAXDOCCOUNT FACIALFINCAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$STIMATEID FACIALFINCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$INTEGRATEDDOCREF FACIALFINCAPTION.INTEGRATEDDOCREF%TYPE := :NEW.INTEGRATEDDOCREF;
  new$REQUESTNUMBER FACIALFINCAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$REQUESTDATE FACIALFINCAPTION.REQUESTDATE%TYPE := :NEW.REQUESTDATE;
  new$RVERSION FACIALFINCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$FEDERALFUNDSREF FACIALFINCAPTION.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$ELDOCREF FACIALFINCAPTION.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$BUHOPERATIONCLS FACIALFINCAPTION.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CLSTYPE FACIALFINCAPTION.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$OPERATIONDIRECTION FACIALFINCAPTION.OPERATIONDIRECTION%TYPE := :NEW.OPERATIONDIRECTION;
  new$SOURCETYPE FACIALFINCAPTION.SOURCETYPE%TYPE := :NEW.SOURCETYPE;
  new$DESTTYPE FACIALFINCAPTION.DESTTYPE%TYPE := :NEW.DESTTYPE;
  new$CARDNUMBER FACIALFINCAPTION.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$ISBLOCKED FACIALFINCAPTION.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINCAPTION.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINCAPTION.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINCAPTION.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$CASHIERPERSONALINFO FACIALFINCAPTION.CASHIERPERSONALINFO%TYPE := :NEW.CASHIERPERSONALINFO;
  new$BIDDATE FACIALFINCAPTION.BIDDATE%TYPE := :NEW.BIDDATE;
  new$CARDREF FACIALFINCAPTION.CARDREF%TYPE := :NEW.CARDREF;
  new$SOURCESTOREDPAYMENTPROPS FACIALFINCAPTION.SOURCESTOREDPAYMENTPROPS%TYPE := :NEW.SOURCESTOREDPAYMENTPROPS;
  new$DESTSTOREDPAYMENTPROPS FACIALFINCAPTION.DESTSTOREDPAYMENTPROPS%TYPE := :NEW.DESTSTOREDPAYMENTPROPS;
  new$STOREDPAYMENTNOTE FACIALFINCAPTION.STOREDPAYMENTNOTE%TYPE := :NEW.STOREDPAYMENTNOTE;
  new$DOCCHANGEDATE FACIALFINCAPTION.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$UINCODE FACIALFINCAPTION.UINCODE%TYPE := :NEW.UINCODE;
  new$DOCOSN FACIALFINCAPTION.DOCOSN%TYPE := :NEW.DOCOSN;
  new$SIGNERS FACIALFINCAPTION.SIGNERS%TYPE := :NEW.SIGNERS;
  new$DESTCLSTYPE FACIALFINCAPTION.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SENDERIDKEY FACIALFINCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$AUTOSANCTION FACIALFINCAPTION.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$STOREDPAYMENTCONTENT FACIALFINCAPTION.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$TEMPREJECTCAUSE FACIALFINCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
  new$REJECTCAUSE FACIALFINCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  SourceFacialAcc_CLS$ NUMBER(10);
  DestFacialAcc_CLS$ NUMBER(10);
  CNT$1 NUMBER(10);
  reestrAccepted1$ NUMBER(10);
  IsReject1$ NUMBER(10);
  UseFax$ NUMBER(10);
  DocNumber$ NUMBER(10);
  DetCount$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINCAPTION_BU)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is not null) then
    /*      */
    GetIntConst(30, 19,UseFax$);
    if ((new$BidNumber is null) and (UseFax$ = 1)) then
      new$BidNumber:= new$DocNumber;

    END IF;
  END IF;
  if (new$credit is null)then
    new$credit:= 0;
  END IF;
  if (new$ArhiveDoc is null) then
    new$ArhiveDoc:= 0;
  END IF;
  if (new$PayTypeCls is null) then
    new$PayTypeCls:= 0;
  END IF;
  if (new$BuhPaymentCls is null) then
    new$BuhPaymentCls:= 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$ClsType is null) then
    new$ClsType := 0;
  END IF;
  if (new$DestClsType is null) then
    new$DestClsType := new$ClsType;
  END IF;
  if (new$SourceFacialAcc_CLS is null) then
    new$SourceFacialAcc_CLS:= 0;
  END IF;
  if (new$DestFacialAcc_CLS is null) then
    new$DestFacialAcc_CLS:= 0;
  END IF;
  if (new$FaxDocCount is null) then
    new$FaxDocCount := 0;
  END IF;
  if (new$OperationDirection is null) then
    new$OperationDirection := 0;
  END IF;
  if (new$OperationDirection <> :old.OperationDirection) then
    if (new$OperationDirection = 0) then
      new$SourceType := 1;
      new$DestType := 1;

    else
      if (new$OperationDirection = 1) then
        new$SourceType := 1;
        new$DestType := -1;

      else
        if (new$OperationDirection = 2) then
          new$SourceType := -1;
          new$DestType := 1;

        else
          new$SourceType := -1;
          new$DestType := -1;

        END IF;
      END IF;
    END IF;
  END IF;
  if (new$DepartmentCls is null) then
    GetIntConst(30, 20,DocNumber$);
    if (DocNumber$ is null) then
      new$DepartmentCls:= 0;

    else
      new$DepartmentCls:= DocNumber$;

    END IF;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount$ from FacialFinDetail where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_Cls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_1 (TR_FACIALFINCAPTION_BU_1)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --   -     
   IF (new$GroupID IS NULL) THEN new$GroupID := new$ID; END IF;
   IF (new$GroupSumma IS NULL) THEN new$GroupSumma := 0; END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_FACIALFINCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (not (    ((new$progindex = 63) or (new$progindex = 64) or (new$progindex = 68) or (new$progindex = 70))
  and (   (((new$credit - :old.credit)>0.001)or((new$credit - :old.credit)<-0.001))
  or (new$sourcefacialacc_cls <> :old.sourcefacialacc_cls)
  or (
  ((new$sourceaccount is null) and (:old.sourceaccount is not null)) or
  ((new$sourceaccount is not null) and (:old.sourceaccount is null)) or
  ((new$sourceaccount <> :old.sourceaccount ) and (:old.sourceaccount is not null) and (new$sourceaccount is not null))
  )
  or (
  ((new$destaccount is null) and (:old.destaccount is not null)) or
  ((new$destaccount is not null) and (:old.destaccount is null)) or
  ((new$destaccount <> :old.destaccount ) and (:old.destaccount is not null) and (new$destaccount is not null))
  )
  or (    (:old.reestr_ref is null)
  and (new$reestr_ref is not null)
  )
  or (    (:old.reestr_ref is not null)
  and (new$reestr_ref is null)
  )
  or (:old.reestr_ref <> new$reestr_ref)
  )
  )
  )
  then /*      NULL */
    reestrAccepted1$ := 0;  /*   IB 4.2 */

  else
    BEGIN
      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id=new$REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrUpdate');
    END IF;
    BEGIN

      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id=:old.REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrUpdate');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_6 (TR_FACIALFINCAPTION_BU_6)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (:old.ProgIndex in(63,68,70)) then /*    */
    SELECT COUNT(id ) INTO CNT$1
    from paydocexchange where ((paydocref=:old.id)and(status<>0)and(TypeInf BETWEEN 0 and 10)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      if(/* (new.DOCNUMBER<>old.DOCNUMBER) or ((new.DOCNUMBER is NULL)and(not old.DOCNUMBER is NULL)) or ((old.DOCNUMBER is NULL)and(not new.DOCNUMBER is NULL)) or*/
      (new$SOURCEDOCNUM<>:old.SOURCEDOCNUM) or ((new$SOURCEDOCNUM is NULL)and(not :old.SOURCEDOCNUM is NULL)) or ((:old.SOURCEDOCNUM is NULL)and(not new$SOURCEDOCNUM is NULL)) or
      (new$PAYDATE<>:old.PAYDATE) or ((new$PAYDATE is NULL)and(not :old.PAYDATE is NULL)) or ((:old.PAYDATE is NULL)and(not new$PAYDATE is NULL))or
      /* (new.DOCUMENTDATE<>old.DOCUMENTDATE) or ((new.DOCUMENTDATE is NULL)and(not old.DOCUMENTDATE is NULL)) or ((old.DOCUMENTDATE is NULL)and(not new.DOCUMENTDATE is NULL))or*/
      (new$REESTRDATE<>:old.REESTRDATE) or ((new$REESTRDATE is NULL)and(not :old.REESTRDATE is NULL)) or ((:old.REESTRDATE is NULL)and(not new$REESTRDATE is NULL))or
      (((new$credit - :old.credit)>0.001)or((new$credit - :old.credit)<-0.001)) or
      (new$SOURCEACCOUNT<>:old.SOURCEACCOUNT) or
      (new$DESTACCOUNT<>:old.DESTACCOUNT) or
      (new$PAYTYPECLS<>:old.PAYTYPECLS) or
      (new$NOTE<>:old.NOTE) or  ((new$NOTE is NULL)and(not :old.NOTE is NULL)) or ((:old.NOTE is NULL)and(not new$NOTE is NULL))or
      (new$PAYPRIORITY<>:old.PAYPRIORITY) or ((new$PAYPRIORITY is NULL)and(not :old.PAYPRIORITY is NULL)) or ((:old.PAYPRIORITY is NULL)and(not new$PAYPRIORITY is NULL))or
      (new$REESTR_REF<>:old.REESTR_REF) or ((new$REESTR_REF is NULL)and(not :old.REESTR_REF is NULL)) or ((:old.REESTR_REF is NULL)and(not new$REESTR_REF is NULL))or
      (new$NDS<>:old.NDS) or ((new$NDS is NULL)and(not :old.NDS is NULL)) or ((:old.NDS is NULL)and(not new$NDS is NULL))or
      (new$TAXNOTE<>:old.TAXNOTE) or ((new$TAXNOTE is NULL)and(not :old.TAXNOTE is NULL)) or ((:old.TAXNOTE is NULL)and(not new$TAXNOTE is NULL)) )then
        RaiseException('ex_CannotChangeSended');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_32 (TR_FACIALFINCAPTION_BU_32)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$Reestr_ref IS NULL)    /*    select ,  */
                              THEN
      new$SourceDocNum := '';
      new$ReestrDate := NULL;
   ELSIF (    (new$Reestr_ref = :OLD.Reestr_ref)
          AND (new$SourceDocNum = :OLD.SourceDocNum)
          AND (new$ReestrDate = :OLD.ReestrDate)
         ) THEN
/*          */
      NULL;
   ELSE
      BEGIN
         SELECT ffr.ReestrNumber, ffr.ReestrDate
           INTO new$SourceDocNum, new$ReestrDate
           FROM FacialFinReestr ffr
          WHERE ffr.ID = new$Reestr_ref;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            new$SourceDocNum := NULL;
            new$ReestrDate := NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BU_60 (T_FACIALFINCAPTION_BU_60)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF ((new$progindex = 60) AND (new$Credit <> :OLD.Credit)) THEN
      UPDATE FacialFinDetail
         SET Credit = new$Credit
       WHERE (RecordIndex = new$ID);
   END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_FACIALFINCAPTION_BU_70)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --         
   IF (new$SubProgIndex = 416) THEN
      UPDATE Guarantee
         SET AcceptDate = new$AcceptDate
       WHERE SubRecordIndex = new$ID;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (T_FACIALFINCAPTION_BU_100)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*   ,    */
   IF (    (   (:OLD.SourceFacialAcc_CLS <> new$SourceFacialAcc_CLS)
            OR (:OLD.DestFacialAcc_CLS <> new$DestFacialAcc_CLS)
           )
       AND ((new$SubProgIndex <> 1) OR (new$SubProgIndex IS NULL))
      ) THEN
      FOR R$ IN (SELECT ID, SourceFacialAcc_CLS, DestFacialAcc_CLS
                   FROM FacialFinDetail
                  WHERE RecordIndex = new$ID) LOOP
         IF (NOT (new$SourceFacialAcc_CLS = 0)) THEN
            SourceFacialAcc_CLS$ := new$SourceFacialAcc_CLS;
         ELSE
            SourceFacialAcc_CLS$ := R$.SourceFacialAcc_CLS;
         END IF;

         IF (NOT (new$DestFacialAcc_CLS = 0)) THEN
            DestFacialAcc_CLS$ := new$DestFacialAcc_CLS;
         ELSE
            DestFacialAcc_CLS$ := R$.DestFacialAcc_CLS;
         END IF;

         IF (:OLD.SourceFacialAcc_CLS <> new$SourceFacialAcc_CLS) THEN
            UPDATE FacialFinDetail
               SET SourceFacialAcc_CLS = SourceFacialAcc_CLS$,
                   RVersion = -1
             WHERE (ID = R$.ID);
         END IF;

         IF (:OLD.DestFacialAcc_CLS <> new$DestFacialAcc_CLS) THEN
            UPDATE FacialFinDetail
               SET DestFacialAcc_CLS = DestFacialAcc_CLS$,
                   RVersion = -1
             WHERE (ID = R$.ID);
         END IF;
      END LOOP;
   END IF;

   /*    / , 
           .*/
  IF (((NEW$IsBlocked <> :OLD.IsBlocked) OR
      ((NEW$IsBlocked IS NULL) AND (:OLD.IsBlocked IS NOT NULL)) OR
      ((NEW$IsBlocked IS NOT NULL) AND (:OLD.IsBlocked IS NULL))
     ) OR
     ((NEW$BlockedCause <> :OLD.BlockedCause) OR
      ((NEW$BlockedCause IS NULL) AND (:OLD.BlockedCause IS NOT NULL)) OR
      ((NEW$BlockedCause IS NOT NULL) AND (:OLD.BlockedCause IS NULL))
     ) OR
     ((NEW$UnBlockedDate <> :OLD.UnBlockedDate) OR
      ((NEW$UnBlockedDate IS NULL) AND (:OLD.UnBlockedDate IS NOT NULL)) OR
      ((NEW$UnBlockedDate IS NOT NULL) AND (:OLD.UnBlockedDate IS NULL))
     ) OR
     ((NEW$UnBlockedCause <> :OLD.UnBlockedCause) OR
      ((NEW$UnBlockedDate IS NULL) AND (:OLD.UnBlockedCause IS NOT NULL)) OR
      ((NEW$UnBlockedCause IS NOT NULL) AND (:OLD.UnBlockedCause IS NULL))
     )) THEN
     UPDATE FacialFinDetail ffd
     SET ffd.IsBlocked = NEW$IsBlocked, ffd.BlockedCause = NEW$BlockedCause,
         ffd.UnBlockedDate = NEW$UnBlockedDate, ffd.UnBlockedCause = NEW$UnBlockedCause
     WHERE ffd.recordindex = NEW$ID;
  end if;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINCAPTION_BU_210)
-- Create 27.08.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*      */
   IF (new$DOCSTATEREF <> :OLD.DOCSTATEREF) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DOCSTATEREF, new$DOCSTATEREF
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (T_FACIALFINCAPTION_BU_300)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  IsReject1$ := -1;
  if ((:old.Reject_CLS is null)and(new$Reject_CLS is not null)) then
    IsReject1$ := 1;

  else
    if ((:old.Reject_CLS is not null)and(new$Reject_CLS is null)) then
      IsReject1$ := 0;
    END IF;
  END IF;
  if (IsReject1$  <> -1) then
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID = new$ID;
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID in (select d.id from FacialFinDetail d where d.RecordIndex = new$id);

  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINCAPTION_BU_700)
-- Create 17.09.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINCAPTION SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    SOURCEDOCNUM = new$SOURCEDOCNUM,
    PAYDATE = new$PAYDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    REESTRDATE = new$REESTRDATE,
    CREDIT = new$CREDIT,
    SOURCEACCOUNT = new$SOURCEACCOUNT,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    DESTACCOUNT = new$DESTACCOUNT,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    PROGINDEX = new$PROGINDEX,
    ARHIVEDOC = new$ARHIVEDOC,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    PAYTYPECLS = new$PAYTYPECLS,
    NOTE = new$NOTE,
    PERIOD = new$PERIOD,
    PAYPRIORITY = new$PAYPRIORITY,
    TYPEOPERATIONCLS = new$TYPEOPERATIONCLS,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    RECORDINDEX = new$RECORDINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REESTR_REF = new$REESTR_REF,
    REJECT_CLS = new$REJECT_CLS,
    CLIENTBANKNUMBER = new$CLIENTBANKNUMBER,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    TRUSTNUMBER = new$TRUSTNUMBER,
    LINKEDDOCUMENT = new$LINKEDDOCUMENT,
    BNKRECORDID = new$BNKRECORDID,
    SUBPROGINDEX = new$SUBPROGINDEX,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    TREASUARYDOCSTATECLS = new$TREASUARYDOCSTATECLS,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    NDS = new$NDS,
    TAXNOTE = new$TAXNOTE,
    MANAGERBID = new$MANAGERBID,
    BIDNUMBER = new$BIDNUMBER,
    GROUPID = new$GROUPID,
    GROUPSUMMA = new$GROUPSUMMA,
    DOCSTATEREF = new$DOCSTATEREF,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    FAXDOCCOUNT = new$FAXDOCCOUNT,
    STIMATEID = new$STIMATEID,
    INTEGRATEDDOCREF = new$INTEGRATEDDOCREF,
    REQUESTNUMBER = new$REQUESTNUMBER,
    REQUESTDATE = new$REQUESTDATE,
    RVERSION = new$RVERSION,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    ELDOCREF = new$ELDOCREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    CLSTYPE = new$CLSTYPE,
    OPERATIONDIRECTION = new$OPERATIONDIRECTION,
    SOURCETYPE = new$SOURCETYPE,
    DESTTYPE = new$DESTTYPE,
    CARDNUMBER = new$CARDNUMBER,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    CASHIERPERSONALINFO = new$CASHIERPERSONALINFO,
    BIDDATE = new$BIDDATE,
    CARDREF = new$CARDREF,
    SOURCESTOREDPAYMENTPROPS = new$SOURCESTOREDPAYMENTPROPS,
    DESTSTOREDPAYMENTPROPS = new$DESTSTOREDPAYMENTPROPS,
    STOREDPAYMENTNOTE = new$STOREDPAYMENTNOTE,
    DOCCHANGEDATE = new$DOCCHANGEDATE,
    UINCODE = new$UINCODE,
    DOCOSN = new$DOCOSN,
    SIGNERS = new$SIGNERS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    AUTOSANCTION = new$AUTOSANCTION,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_300 (TR_FACIALFINCAPTION_AU_300)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*          ,      */
  if ((new$AcceptDate <> :old.AcceptDate)or((new$AcceptDate is not null)and(:old.AcceptDate is null))
  or((new$AcceptDate is null)and(:old.AcceptDate is not null))) then
    update facialfindetail set
    AcceptDate = new$AcceptDate,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;
  if (new$BuhOperationCLS <> :old.BuhOperationCLS)  then
    update facialfindetail set
    BuhOperationCLS = new$BuhOperationCLS,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;
  if ((new$ClsType <> :old.ClsType)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$ClsType = 0) then
      update facialfindetail set
      SourceKD = 0,
      DestKD = 0,
      SourceIFS = 0,
      DestIFS = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 1) then
      update facialfindetail set
      SourceKD = 0,
      DestKD = 0,
      SourceKVSR = 0,
      SourceKFSR = 0,
      SourceKCSR = 0,
      SourceKVR = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 2) then
      update facialfindetail set
      SourceIFS = 0,
      DestIFS = 0,
      SourceKVSR = 0,
      SourceKFSR = 0,
      SourceKCSR = 0,
      SourceKVR = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);

    END IF;
  END IF;
  if ((new$DestClsType <> :old.DestClsType)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$DestClsType = 0) then
      update facialfindetail set
      DestKD = 0,
      DestIFS = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
    END IF;
    if (new$DestClsType = 1) then
      update facialfindetail set
      DestKD = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
    END IF;
    if (new$DestClsType = 2) then
      update facialfindetail set
      DestIFS = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINCAPTION_AU_500)
-- Create 28.04.2005
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (:NEW.ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (23, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
        WHERE (TableID = 23) AND (RecordId = :NEW.ID);
   END IF;

END;
/
update FACIALFINCAPTION set
  REJECTCAUSE = TempRejectCause
/
commit work 
/
ALTER TABLE TB_FACIALFINCAPTION DROP (TempRejectCause)
/

CREATE OR REPLACE VIEW FACIALFINCAPTION (
  ID,
  DOCNUMBER,
  SOURCEDOCNUM,
  PAYDATE,
  ACCEPTDATE,
  DOCUMENTDATE,
  REESTRDATE,
  CREDIT,
  SOURCEACCOUNT,
  SOURCEFACIALACC_CLS,
  DESTACCOUNT,
  DESTFACIALACC_CLS,
  PROGINDEX,
  ARHIVEDOC,
  PAYSYMBOLCLS,
  PAYTYPECLS,
  NOTE,
  PERIOD,
  PAYPRIORITY,
  TYPEOPERATIONCLS,
  BUHPAYMENTCLS,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  BUDGETREF,
  RECORDINDEX,
  SENDERID,
  SENDERRECORDID,
  REESTR_REF,
  REJECT_CLS,
  CLIENTBANKNUMBER,
  CRYPTOSTATUS,
  TRUSTNUMBER,
  LINKEDDOCUMENT,
  BNKRECORDID,
  SUBPROGINDEX,
  DOCUMENTSTATE,
  USERSVISA,
  TREASUARYDOCSTATECLS,
  DEPARTMENTCLS,
  NDS,
  TAXNOTE,
  MANAGERBID,
  BIDNUMBER,
  GROUPID,
  GROUPSUMMA,
  DOCSTATEREF,
  LASTEXTRCHANGE,
  FAXDOCCOUNT,
  STIMATEID,
  INTEGRATEDDOCREF,
  REQUESTNUMBER,
  REQUESTDATE,
  RVERSION,
  FEDERALFUNDSREF,
  ELDOCREF,
  BUHOPERATIONCLS,
  CLSTYPE,
  OPERATIONDIRECTION,
  SOURCETYPE,
  DESTTYPE,
  CARDNUMBER,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  CASHIERPERSONALINFO,
  BIDDATE,
  CARDREF,
  SOURCESTOREDPAYMENTPROPS,
  DESTSTOREDPAYMENTPROPS,
  STOREDPAYMENTNOTE,
  DOCCHANGEDATE,
  UINCODE,
  DOCOSN,
  SIGNERS,
  DESTCLSTYPE,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  AUTOSANCTION,
  STOREDPAYMENTCONTENT,
  REJECTCAUSE)
AS
  SELECT
    ID,
    DOCNUMBER,
    SOURCEDOCNUM,
    PAYDATE,
    ACCEPTDATE,
    DOCUMENTDATE,
    REESTRDATE,
    CREDIT,
    SOURCEACCOUNT,
    SOURCEFACIALACC_CLS,
    DESTACCOUNT,
    DESTFACIALACC_CLS,
    PROGINDEX,
    ARHIVEDOC,
    PAYSYMBOLCLS,
    PAYTYPECLS,
    NOTE,
    PERIOD,
    PAYPRIORITY,
    TYPEOPERATIONCLS,
    BUHPAYMENTCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    RECORDINDEX,
    SENDERID,
    SENDERRECORDID,
    REESTR_REF,
    REJECT_CLS,
    CLIENTBANKNUMBER,
    CRYPTOSTATUS,
    TRUSTNUMBER,
    LINKEDDOCUMENT,
    BNKRECORDID,
    SUBPROGINDEX,
    DOCUMENTSTATE,
    USERSVISA,
    TREASUARYDOCSTATECLS,
    DEPARTMENTCLS,
    NDS,
    TAXNOTE,
    MANAGERBID,
    BIDNUMBER,
    GROUPID,
    GROUPSUMMA,
    DOCSTATEREF,
    LASTEXTRCHANGE,
    FAXDOCCOUNT,
    STIMATEID,
    INTEGRATEDDOCREF,
    REQUESTNUMBER,
    REQUESTDATE,
    RVERSION,
    FEDERALFUNDSREF,
    ELDOCREF,
    BUHOPERATIONCLS,
    CLSTYPE,
    OPERATIONDIRECTION,
    SOURCETYPE,
    DESTTYPE,
    CARDNUMBER,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    CASHIERPERSONALINFO,
    BIDDATE,
    CARDREF,
    SOURCESTOREDPAYMENTPROPS,
    DESTSTOREDPAYMENTPROPS,
    STOREDPAYMENTNOTE,
    DOCCHANGEDATE,
    UINCODE,
    DOCOSN,
    SIGNERS,
    DESTCLSTYPE,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    AUTOSANCTION,
    STOREDPAYMENTCONTENT,
    REJECTCAUSE
  FROM TB_FACIALFINCAPTION
/

CREATE OR REPLACE TRIGGER TR_FACIALFINCAPTION_ID
  INSTEAD OF DELETE
  ON FACIALFINCAPTION
  FOR EACH ROW
DECLARE
  reestrAccepted1$ NUMBER(10);
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_FACIALFINCAPTION_BD)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

 /*       */
  DELETE FROM FacialFinDetail
        WHERE (RecordIndex = :OLD.ID);

-- - - - - - - - - - - - -
-- BD_5 (TR_FACIALFINCAPTION_BD_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (((:old.progIndex = 63) or (:old.progIndex = 64) or
  (:old.progIndex = 68) or (:old.progIndex = 70))
  and (:old.REESTR_REF is not null)) then
    BEGIN
      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id = :old.REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrDelete');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BD_6 (TR_FACIALFINCAPTION_BD_6)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(id ) INTO CNT$1
  from paydocexchange where ((paydocref=:old.id)and(status<>0)and(TypeInf BETWEEN 0 and 10)) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    RaiseException('ex_CannotChangeSended');
  else
    delete from PayDocExchange where paydocref = :old.id;
  END IF;

-- - - - - - - - - - - - -
-- BD_430 (TR_FACIALFINCAPTION_BD_430)
-- Create 04.12.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

  /*         */
  UPDATE FaxDocs
     SET OwnerID = NULL
  WHERE OwnerID = :OLD.ID;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_FACIALFINCAPTION
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_70 (TR_FACIALFINCAPTION_AD_70)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

--   /     
  IF (:OLD.SubProgIndex = 416) THEN
    UPDATE Guarantee
       SET SubRecordIndex = NULL,
           SubProgIndex = 0
     WHERE SubRecordIndex = :OLD.ID;
  END IF;

-- - - - - - - - - - - - -
-- AD_200 (TR_FACIALFINCAPTION_AD_200)
-- Create 27.08.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

  /*       */
  delete from StateJumpHistory
    where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_300 (TR_FACIALFINCAPTION_AD_300)
-- Create 24.02.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

  IF (:OLD.FaxDocCount > 0) THEN
--    :old.FaxDocCount := :old.FaxDocCount;
    NULL;
  ELSE
    UPDATE FaxDocs
       SET OwnerID = NULL
     WHERE OwnerID = :OLD.ID;
  END IF;

-- - - - - - - - - - - - -
-- AD_500 (TR_FACIALFINCAPTION_AD_500)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

  INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate, ProgIndex, Summa)
    VALUES (23, :OLD.ID, SYSDATE, :OLD.ProgIndex, :OLD.Credit);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINCAPTION_II
  INSTEAD OF INSERT
  ON FACIALFINCAPTION
  FOR EACH ROW
DECLARE
  new$ID FACIALFINCAPTION.ID%TYPE := :NEW.ID;
  new$DOCNUMBER FACIALFINCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SOURCEDOCNUM FACIALFINCAPTION.SOURCEDOCNUM%TYPE := :NEW.SOURCEDOCNUM;
  new$PAYDATE FACIALFINCAPTION.PAYDATE%TYPE := :NEW.PAYDATE;
  new$ACCEPTDATE FACIALFINCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCUMENTDATE FACIALFINCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$REESTRDATE FACIALFINCAPTION.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$CREDIT FACIALFINCAPTION.CREDIT%TYPE := :NEW.CREDIT;
  new$SOURCEACCOUNT FACIALFINCAPTION.SOURCEACCOUNT%TYPE := :NEW.SOURCEACCOUNT;
  new$SOURCEFACIALACC_CLS FACIALFINCAPTION.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$DESTACCOUNT FACIALFINCAPTION.DESTACCOUNT%TYPE := :NEW.DESTACCOUNT;
  new$DESTFACIALACC_CLS FACIALFINCAPTION.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$PROGINDEX FACIALFINCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$ARHIVEDOC FACIALFINCAPTION.ARHIVEDOC%TYPE := :NEW.ARHIVEDOC;
  new$PAYSYMBOLCLS FACIALFINCAPTION.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$PAYTYPECLS FACIALFINCAPTION.PAYTYPECLS%TYPE := :NEW.PAYTYPECLS;
  new$NOTE FACIALFINCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$PERIOD FACIALFINCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$PAYPRIORITY FACIALFINCAPTION.PAYPRIORITY%TYPE := :NEW.PAYPRIORITY;
  new$TYPEOPERATIONCLS FACIALFINCAPTION.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$BUHPAYMENTCLS FACIALFINCAPTION.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$CREATERUSER FACIALFINCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF FACIALFINCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECORDINDEX FACIALFINCAPTION.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$SENDERID FACIALFINCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REESTR_REF FACIALFINCAPTION.REESTR_REF%TYPE := :NEW.REESTR_REF;
  new$REJECT_CLS FACIALFINCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$CLIENTBANKNUMBER FACIALFINCAPTION.CLIENTBANKNUMBER%TYPE := :NEW.CLIENTBANKNUMBER;
  new$CRYPTOSTATUS FACIALFINCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$TRUSTNUMBER FACIALFINCAPTION.TRUSTNUMBER%TYPE := :NEW.TRUSTNUMBER;
  new$LINKEDDOCUMENT FACIALFINCAPTION.LINKEDDOCUMENT%TYPE := :NEW.LINKEDDOCUMENT;
  new$BNKRECORDID FACIALFINCAPTION.BNKRECORDID%TYPE := :NEW.BNKRECORDID;
  new$SUBPROGINDEX FACIALFINCAPTION.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$DOCUMENTSTATE FACIALFINCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA FACIALFINCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$TREASUARYDOCSTATECLS FACIALFINCAPTION.TREASUARYDOCSTATECLS%TYPE := :NEW.TREASUARYDOCSTATECLS;
  new$DEPARTMENTCLS FACIALFINCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$NDS FACIALFINCAPTION.NDS%TYPE := :NEW.NDS;
  new$TAXNOTE FACIALFINCAPTION.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$MANAGERBID FACIALFINCAPTION.MANAGERBID%TYPE := :NEW.MANAGERBID;
  new$BIDNUMBER FACIALFINCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$GROUPID FACIALFINCAPTION.GROUPID%TYPE := :NEW.GROUPID;
  new$GROUPSUMMA FACIALFINCAPTION.GROUPSUMMA%TYPE := :NEW.GROUPSUMMA;
  new$DOCSTATEREF FACIALFINCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$LASTEXTRCHANGE FACIALFINCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$FAXDOCCOUNT FACIALFINCAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$STIMATEID FACIALFINCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$INTEGRATEDDOCREF FACIALFINCAPTION.INTEGRATEDDOCREF%TYPE := :NEW.INTEGRATEDDOCREF;
  new$REQUESTNUMBER FACIALFINCAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$REQUESTDATE FACIALFINCAPTION.REQUESTDATE%TYPE := :NEW.REQUESTDATE;
  new$RVERSION FACIALFINCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$FEDERALFUNDSREF FACIALFINCAPTION.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$ELDOCREF FACIALFINCAPTION.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$BUHOPERATIONCLS FACIALFINCAPTION.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CLSTYPE FACIALFINCAPTION.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$OPERATIONDIRECTION FACIALFINCAPTION.OPERATIONDIRECTION%TYPE := :NEW.OPERATIONDIRECTION;
  new$SOURCETYPE FACIALFINCAPTION.SOURCETYPE%TYPE := :NEW.SOURCETYPE;
  new$DESTTYPE FACIALFINCAPTION.DESTTYPE%TYPE := :NEW.DESTTYPE;
  new$CARDNUMBER FACIALFINCAPTION.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$ISBLOCKED FACIALFINCAPTION.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINCAPTION.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINCAPTION.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINCAPTION.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$CASHIERPERSONALINFO FACIALFINCAPTION.CASHIERPERSONALINFO%TYPE := :NEW.CASHIERPERSONALINFO;
  new$BIDDATE FACIALFINCAPTION.BIDDATE%TYPE := :NEW.BIDDATE;
  new$CARDREF FACIALFINCAPTION.CARDREF%TYPE := :NEW.CARDREF;
  new$SOURCESTOREDPAYMENTPROPS FACIALFINCAPTION.SOURCESTOREDPAYMENTPROPS%TYPE := :NEW.SOURCESTOREDPAYMENTPROPS;
  new$DESTSTOREDPAYMENTPROPS FACIALFINCAPTION.DESTSTOREDPAYMENTPROPS%TYPE := :NEW.DESTSTOREDPAYMENTPROPS;
  new$STOREDPAYMENTNOTE FACIALFINCAPTION.STOREDPAYMENTNOTE%TYPE := :NEW.STOREDPAYMENTNOTE;
  new$DOCCHANGEDATE FACIALFINCAPTION.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$UINCODE FACIALFINCAPTION.UINCODE%TYPE := :NEW.UINCODE;
  new$DOCOSN FACIALFINCAPTION.DOCOSN%TYPE := :NEW.DOCOSN;
  new$SIGNERS FACIALFINCAPTION.SIGNERS%TYPE := :NEW.SIGNERS;
  new$DESTCLSTYPE FACIALFINCAPTION.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SENDERIDKEY FACIALFINCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$AUTOSANCTION FACIALFINCAPTION.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$STOREDPAYMENTCONTENT FACIALFINCAPTION.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$REJECTCAUSE FACIALFINCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  UseFax$ NUMBER(10);
  pdt$ NUMBER(10);
  reestrAccepted1$ NUMBER(10);
  DocNumber$ NUMBER(10);
  CmpFacialAcc_Cls$ NUMBER(10);
  PIndex1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALFINCAPTION_BI)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$credit is null)then 
    new$credit:= 0;
  END IF;
  if (new$ArhiveDoc is null) then 
    new$ArhiveDoc:= 0;
  END IF;
  if (new$PayTypeCls is null) then 
    new$PayTypeCls:= 0;
  END IF;
  if (new$BuhPaymentCls is null) then 
    new$BuhPaymentCls:= 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$ClsType is null) then 
    new$ClsType := 0;
  END IF;
  if (new$DestClsType is null) then 
    new$DestClsType := new$ClsType;
  END IF;
  if (new$SourceFacialAcc_CLS is null) then 
    new$SourceFacialAcc_CLS:= 0;
  END IF;
  if (new$DestFacialAcc_CLS is null) then 
    new$DestFacialAcc_CLS:= 0;
  END IF;
  if (new$FaxDocCount is null) then 
    new$FaxDocCount := 0;
  END IF;
  if (new$OperationDirection is null) then 
    new$OperationDirection := 0;
  END IF;
  if (new$OperationDirection = 0) then
    new$SourceType := 1;
    new$DestType := 1;
     
  else
    if (new$OperationDirection = 1) then
      new$SourceType := 1;
      new$DestType := -1;
         
    else
      if (new$OperationDirection = 2) then
        new$SourceType := -1;
        new$DestType := 1;
             
      else
        new$SourceType := -1;
        new$DestType := -1;
             
      END IF;
    END IF;
  END IF;
  if (new$DepartmentCls is null) then
    GetIntConst(30, 20,DocNumber$); 
    if (DocNumber$ is null) then 
      new$DepartmentCls:= 0;
           
    else 
      new$DepartmentCls:= DocNumber$;
       
    END IF;
  END IF;
   
  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    PIndex1$ := new$ProgIndex;
    if (PIndex1$=60) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*    .*/
    END IF;
    if (PIndex1$=61) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*       */
    END IF;
    if (PIndex1$=62) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*    */
    END IF;
    if (PIndex1$=63) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*     */
    END IF;
    if (PIndex1$=64) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*    */
    END IF;
    if (PIndex1$=65) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*  , */
    END IF;
    if (PIndex1$=66) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*   ,  - */
    END IF;
    if (PIndex1$=67) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*    */
    END IF;
    if (PIndex1$=68) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*   \ */
    END IF;
    if (PIndex1$=69) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*    \ */
    END IF;
    if (PIndex1$=70) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*   \ */
    END IF;
    if (PIndex1$=71) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*    \ */
    END IF;
    if (PIndex1$=73) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*   */
    END IF;
    if (PIndex1$=75) then 
      CmpFacialAcc_Cls$ := new$DestFacialAcc_CLS;           /*  */
    END IF;
    if (PIndex1$=76) then 
      CmpFacialAcc_Cls$ := new$SourceFacialAcc_CLS;         /*  */
    END IF;
    BEGIN

      select fa.BudgetRef      into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = CmpFacialAcc_Cls$

      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null )) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_1 (TR_FACIALFINCAPTION_BI_1)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --   -     
   IF (new$GroupID IS NULL) THEN new$GroupID := new$ID; END IF;
   IF (new$GroupSumma IS NULL) THEN new$GroupSumma := 0; END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_FACIALFINCAPTION_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (((new$progIndex = 63) or (new$progIndex = 64) or
  (new$progIndex = 68) or (new$progIndex = 70))
  and (new$REESTR_REF is not null)) then
    BEGIN
      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where 
      id = new$REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
        
    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrInsert');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_FacialFinCaption_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;
        
  else
    new$SenderIDKey := new$SenderID;
  END IF;
      
  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;
        
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_16 (TR_FACIALFINCAPTION_BI_16)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*      .    FacialFinCaption
             */
   IF (new$Reestr_ref IS NULL) THEN
      new$SourceDocNum := '';
      new$ReestrDate := NULL;
   ELSE
      BEGIN
         SELECT ffr.ReestrNumber, ffr.ReestrDate
           INTO new$SourceDocNum, new$ReestrDate
           FROM FacialFinReestr ffr
          WHERE ffr.ID = new$Reestr_ref;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            new$SourceDocNum := NULL;
            new$ReestrDate := NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BI_430 (TR_FACIALFINCAPTION_BI_430)
-- Create 04.12.2004
-- Last update 11.10.2006
-- - - - - - - - - - - - -

  IF (NEW$SenderID IS NOT NULL) THEN
    pdt$ := NULL;
    IF (NEW$progindex = 63) THEN pdt$ := 302; END IF;
    IF (NEW$progindex = 66) THEN pdt$ := 301; END IF;
    IF (NEW$progindex = 64) THEN pdt$ := 304; END IF;

    /*       */
    GetIntConst(30, 19, UseFax$);
    IF ((new$BidNumber IS NULL) AND (UseFax$ = 1)) THEN
      new$BidNumber := new$DocNumber;
    END IF;
    SELECT COUNT(*) INTO new$FaxDocCount
    FROM FaxDocs
      WHERE (OwnerDocNumber=new$BidNumber)
        AND (ClientID=new$SenderID)
        AND (FacialAcc_Cls=new$SourceFacialAcc_CLS)
        AND (OwnerDate = new$DocumentDate)
        AND (PrimaryDocType = PDT$);
  ELSE
    new$FaxDocCount := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALFINCAPTION_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$DocChangeDate := new$UpdateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALFINCAPTION (
    ID,
    DOCNUMBER,
    SOURCEDOCNUM,
    PAYDATE,
    ACCEPTDATE,
    DOCUMENTDATE,
    REESTRDATE,
    CREDIT,
    SOURCEACCOUNT,
    SOURCEFACIALACC_CLS,
    DESTACCOUNT,
    DESTFACIALACC_CLS,
    PROGINDEX,
    ARHIVEDOC,
    PAYSYMBOLCLS,
    PAYTYPECLS,
    NOTE,
    PERIOD,
    PAYPRIORITY,
    TYPEOPERATIONCLS,
    BUHPAYMENTCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    RECORDINDEX,
    SENDERID,
    SENDERRECORDID,
    REESTR_REF,
    REJECT_CLS,
    CLIENTBANKNUMBER,
    CRYPTOSTATUS,
    TRUSTNUMBER,
    LINKEDDOCUMENT,
    BNKRECORDID,
    SUBPROGINDEX,
    DOCUMENTSTATE,
    USERSVISA,
    TREASUARYDOCSTATECLS,
    DEPARTMENTCLS,
    NDS,
    TAXNOTE,
    MANAGERBID,
    BIDNUMBER,
    GROUPID,
    GROUPSUMMA,
    DOCSTATEREF,
    LASTEXTRCHANGE,
    FAXDOCCOUNT,
    STIMATEID,
    INTEGRATEDDOCREF,
    REQUESTNUMBER,
    REQUESTDATE,
    RVERSION,
    FEDERALFUNDSREF,
    ELDOCREF,
    BUHOPERATIONCLS,
    CLSTYPE,
    OPERATIONDIRECTION,
    SOURCETYPE,
    DESTTYPE,
    CARDNUMBER,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    CASHIERPERSONALINFO,
    BIDDATE,
    CARDREF,
    SOURCESTOREDPAYMENTPROPS,
    DESTSTOREDPAYMENTPROPS,
    STOREDPAYMENTNOTE,
    DOCCHANGEDATE,
    UINCODE,
    DOCOSN,
    SIGNERS,
    DESTCLSTYPE,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    AUTOSANCTION,
    STOREDPAYMENTCONTENT,
    REJECTCAUSE
  ) VALUES (
    new$ID,
    new$DOCNUMBER,
    new$SOURCEDOCNUM,
    new$PAYDATE,
    new$ACCEPTDATE,
    new$DOCUMENTDATE,
    new$REESTRDATE,
    new$CREDIT,
    new$SOURCEACCOUNT,
    new$SOURCEFACIALACC_CLS,
    new$DESTACCOUNT,
    new$DESTFACIALACC_CLS,
    new$PROGINDEX,
    new$ARHIVEDOC,
    new$PAYSYMBOLCLS,
    new$PAYTYPECLS,
    new$NOTE,
    new$PERIOD,
    new$PAYPRIORITY,
    new$TYPEOPERATIONCLS,
    new$BUHPAYMENTCLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$RECORDINDEX,
    new$SENDERID,
    new$SENDERRECORDID,
    new$REESTR_REF,
    new$REJECT_CLS,
    new$CLIENTBANKNUMBER,
    new$CRYPTOSTATUS,
    new$TRUSTNUMBER,
    new$LINKEDDOCUMENT,
    new$BNKRECORDID,
    new$SUBPROGINDEX,
    new$DOCUMENTSTATE,
    new$USERSVISA,
    new$TREASUARYDOCSTATECLS,
    new$DEPARTMENTCLS,
    new$NDS,
    new$TAXNOTE,
    new$MANAGERBID,
    new$BIDNUMBER,
    new$GROUPID,
    new$GROUPSUMMA,
    new$DOCSTATEREF,
    new$LASTEXTRCHANGE,
    new$FAXDOCCOUNT,
    new$STIMATEID,
    new$INTEGRATEDDOCREF,
    new$REQUESTNUMBER,
    new$REQUESTDATE,
    new$RVERSION,
    new$FEDERALFUNDSREF,
    new$ELDOCREF,
    new$BUHOPERATIONCLS,
    new$CLSTYPE,
    new$OPERATIONDIRECTION,
    new$SOURCETYPE,
    new$DESTTYPE,
    new$CARDNUMBER,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$CASHIERPERSONALINFO,
    new$BIDDATE,
    new$CARDREF,
    new$SOURCESTOREDPAYMENTPROPS,
    new$DESTSTOREDPAYMENTPROPS,
    new$STOREDPAYMENTNOTE,
    new$DOCCHANGEDATE,
    new$UINCODE,
    new$DOCOSN,
    new$SIGNERS,
    new$DESTCLSTYPE,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$AUTOSANCTION,
    new$STOREDPAYMENTCONTENT,
    new$REJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_430 (TR_FACIALFINCAPTION_AI_430)
-- Create 04.12.2004
-- Last update 11.10.2006
-- - - - - - - - - - - - -

  IF (new$SenderID IS NOT NULL) THEN
      /*       */
      pdt$ := NULL;
      IF (new$progindex = 63) THEN pdt$ := 302; END IF;
      IF (new$progindex = 66) THEN pdt$ := 301; END IF;
      IF (new$progindex = 64) THEN pdt$ := 304; END IF;

        UPDATE FaxDocs
            SET OwnerId=new$id
        WHERE
            (OwnerDocNumber=new$BidNumber)
            AND (ClientID=new$SenderID)
            AND (FacialAcc_Cls=new$SourceFacialAcc_CLS)
            AND (OwnerDate = new$DocumentDate)
            AND (primarydoctype = pdt$);
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALFINCAPTION_AI_500)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
     WHERE (TableID = 23) AND (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINCAPTION_IU
  INSTEAD OF UPDATE
  ON FACIALFINCAPTION
  FOR EACH ROW
DECLARE
  new$ID FACIALFINCAPTION.ID%TYPE := :NEW.ID;
  new$DOCNUMBER FACIALFINCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SOURCEDOCNUM FACIALFINCAPTION.SOURCEDOCNUM%TYPE := :NEW.SOURCEDOCNUM;
  new$PAYDATE FACIALFINCAPTION.PAYDATE%TYPE := :NEW.PAYDATE;
  new$ACCEPTDATE FACIALFINCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCUMENTDATE FACIALFINCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$REESTRDATE FACIALFINCAPTION.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$CREDIT FACIALFINCAPTION.CREDIT%TYPE := :NEW.CREDIT;
  new$SOURCEACCOUNT FACIALFINCAPTION.SOURCEACCOUNT%TYPE := :NEW.SOURCEACCOUNT;
  new$SOURCEFACIALACC_CLS FACIALFINCAPTION.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$DESTACCOUNT FACIALFINCAPTION.DESTACCOUNT%TYPE := :NEW.DESTACCOUNT;
  new$DESTFACIALACC_CLS FACIALFINCAPTION.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$PROGINDEX FACIALFINCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$ARHIVEDOC FACIALFINCAPTION.ARHIVEDOC%TYPE := :NEW.ARHIVEDOC;
  new$PAYSYMBOLCLS FACIALFINCAPTION.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$PAYTYPECLS FACIALFINCAPTION.PAYTYPECLS%TYPE := :NEW.PAYTYPECLS;
  new$NOTE FACIALFINCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$PERIOD FACIALFINCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$PAYPRIORITY FACIALFINCAPTION.PAYPRIORITY%TYPE := :NEW.PAYPRIORITY;
  new$TYPEOPERATIONCLS FACIALFINCAPTION.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$BUHPAYMENTCLS FACIALFINCAPTION.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$CREATERUSER FACIALFINCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF FACIALFINCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECORDINDEX FACIALFINCAPTION.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$SENDERID FACIALFINCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REESTR_REF FACIALFINCAPTION.REESTR_REF%TYPE := :NEW.REESTR_REF;
  new$REJECT_CLS FACIALFINCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$CLIENTBANKNUMBER FACIALFINCAPTION.CLIENTBANKNUMBER%TYPE := :NEW.CLIENTBANKNUMBER;
  new$CRYPTOSTATUS FACIALFINCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$TRUSTNUMBER FACIALFINCAPTION.TRUSTNUMBER%TYPE := :NEW.TRUSTNUMBER;
  new$LINKEDDOCUMENT FACIALFINCAPTION.LINKEDDOCUMENT%TYPE := :NEW.LINKEDDOCUMENT;
  new$BNKRECORDID FACIALFINCAPTION.BNKRECORDID%TYPE := :NEW.BNKRECORDID;
  new$SUBPROGINDEX FACIALFINCAPTION.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$DOCUMENTSTATE FACIALFINCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA FACIALFINCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$TREASUARYDOCSTATECLS FACIALFINCAPTION.TREASUARYDOCSTATECLS%TYPE := :NEW.TREASUARYDOCSTATECLS;
  new$DEPARTMENTCLS FACIALFINCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$NDS FACIALFINCAPTION.NDS%TYPE := :NEW.NDS;
  new$TAXNOTE FACIALFINCAPTION.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$MANAGERBID FACIALFINCAPTION.MANAGERBID%TYPE := :NEW.MANAGERBID;
  new$BIDNUMBER FACIALFINCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$GROUPID FACIALFINCAPTION.GROUPID%TYPE := :NEW.GROUPID;
  new$GROUPSUMMA FACIALFINCAPTION.GROUPSUMMA%TYPE := :NEW.GROUPSUMMA;
  new$DOCSTATEREF FACIALFINCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$LASTEXTRCHANGE FACIALFINCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$FAXDOCCOUNT FACIALFINCAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$STIMATEID FACIALFINCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$INTEGRATEDDOCREF FACIALFINCAPTION.INTEGRATEDDOCREF%TYPE := :NEW.INTEGRATEDDOCREF;
  new$REQUESTNUMBER FACIALFINCAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$REQUESTDATE FACIALFINCAPTION.REQUESTDATE%TYPE := :NEW.REQUESTDATE;
  new$RVERSION FACIALFINCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$FEDERALFUNDSREF FACIALFINCAPTION.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$ELDOCREF FACIALFINCAPTION.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$BUHOPERATIONCLS FACIALFINCAPTION.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CLSTYPE FACIALFINCAPTION.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$OPERATIONDIRECTION FACIALFINCAPTION.OPERATIONDIRECTION%TYPE := :NEW.OPERATIONDIRECTION;
  new$SOURCETYPE FACIALFINCAPTION.SOURCETYPE%TYPE := :NEW.SOURCETYPE;
  new$DESTTYPE FACIALFINCAPTION.DESTTYPE%TYPE := :NEW.DESTTYPE;
  new$CARDNUMBER FACIALFINCAPTION.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$ISBLOCKED FACIALFINCAPTION.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINCAPTION.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINCAPTION.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINCAPTION.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$CASHIERPERSONALINFO FACIALFINCAPTION.CASHIERPERSONALINFO%TYPE := :NEW.CASHIERPERSONALINFO;
  new$BIDDATE FACIALFINCAPTION.BIDDATE%TYPE := :NEW.BIDDATE;
  new$CARDREF FACIALFINCAPTION.CARDREF%TYPE := :NEW.CARDREF;
  new$SOURCESTOREDPAYMENTPROPS FACIALFINCAPTION.SOURCESTOREDPAYMENTPROPS%TYPE := :NEW.SOURCESTOREDPAYMENTPROPS;
  new$DESTSTOREDPAYMENTPROPS FACIALFINCAPTION.DESTSTOREDPAYMENTPROPS%TYPE := :NEW.DESTSTOREDPAYMENTPROPS;
  new$STOREDPAYMENTNOTE FACIALFINCAPTION.STOREDPAYMENTNOTE%TYPE := :NEW.STOREDPAYMENTNOTE;
  new$DOCCHANGEDATE FACIALFINCAPTION.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$UINCODE FACIALFINCAPTION.UINCODE%TYPE := :NEW.UINCODE;
  new$DOCOSN FACIALFINCAPTION.DOCOSN%TYPE := :NEW.DOCOSN;
  new$SIGNERS FACIALFINCAPTION.SIGNERS%TYPE := :NEW.SIGNERS;
  new$DESTCLSTYPE FACIALFINCAPTION.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SENDERIDKEY FACIALFINCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$AUTOSANCTION FACIALFINCAPTION.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$STOREDPAYMENTCONTENT FACIALFINCAPTION.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$REJECTCAUSE FACIALFINCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  SourceFacialAcc_CLS$ NUMBER(10);
  DestFacialAcc_CLS$ NUMBER(10);
  CNT$1 NUMBER(10);
  reestrAccepted1$ NUMBER(10);
  IsReject1$ NUMBER(10);
  UseFax$ NUMBER(10);
  DocNumber$ NUMBER(10);
  DetCount$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINCAPTION_BU)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is not null) then
    /*      */
    GetIntConst(30, 19,UseFax$);
    if ((new$BidNumber is null) and (UseFax$ = 1)) then
      new$BidNumber:= new$DocNumber;

    END IF;
  END IF;
  if (new$credit is null)then
    new$credit:= 0;
  END IF;
  if (new$ArhiveDoc is null) then
    new$ArhiveDoc:= 0;
  END IF;
  if (new$PayTypeCls is null) then
    new$PayTypeCls:= 0;
  END IF;
  if (new$BuhPaymentCls is null) then
    new$BuhPaymentCls:= 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$ClsType is null) then
    new$ClsType := 0;
  END IF;
  if (new$DestClsType is null) then
    new$DestClsType := new$ClsType;
  END IF;
  if (new$SourceFacialAcc_CLS is null) then
    new$SourceFacialAcc_CLS:= 0;
  END IF;
  if (new$DestFacialAcc_CLS is null) then
    new$DestFacialAcc_CLS:= 0;
  END IF;
  if (new$FaxDocCount is null) then
    new$FaxDocCount := 0;
  END IF;
  if (new$OperationDirection is null) then
    new$OperationDirection := 0;
  END IF;
  if (new$OperationDirection <> :old.OperationDirection) then
    if (new$OperationDirection = 0) then
      new$SourceType := 1;
      new$DestType := 1;

    else
      if (new$OperationDirection = 1) then
        new$SourceType := 1;
        new$DestType := -1;

      else
        if (new$OperationDirection = 2) then
          new$SourceType := -1;
          new$DestType := 1;

        else
          new$SourceType := -1;
          new$DestType := -1;

        END IF;
      END IF;
    END IF;
  END IF;
  if (new$DepartmentCls is null) then
    GetIntConst(30, 20,DocNumber$);
    if (DocNumber$ is null) then
      new$DepartmentCls:= 0;

    else
      new$DepartmentCls:= DocNumber$;

    END IF;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount$ from FacialFinDetail where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_Cls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_1 (TR_FACIALFINCAPTION_BU_1)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --   -     
   IF (new$GroupID IS NULL) THEN new$GroupID := new$ID; END IF;
   IF (new$GroupSumma IS NULL) THEN new$GroupSumma := 0; END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_FACIALFINCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (not (    ((new$progindex = 63) or (new$progindex = 64) or (new$progindex = 68) or (new$progindex = 70))
  and (   (((new$credit - :old.credit)>0.001)or((new$credit - :old.credit)<-0.001))
  or (new$sourcefacialacc_cls <> :old.sourcefacialacc_cls)
  or (
  ((new$sourceaccount is null) and (:old.sourceaccount is not null)) or
  ((new$sourceaccount is not null) and (:old.sourceaccount is null)) or
  ((new$sourceaccount <> :old.sourceaccount ) and (:old.sourceaccount is not null) and (new$sourceaccount is not null))
  )
  or (
  ((new$destaccount is null) and (:old.destaccount is not null)) or
  ((new$destaccount is not null) and (:old.destaccount is null)) or
  ((new$destaccount <> :old.destaccount ) and (:old.destaccount is not null) and (new$destaccount is not null))
  )
  or (    (:old.reestr_ref is null)
  and (new$reestr_ref is not null)
  )
  or (    (:old.reestr_ref is not null)
  and (new$reestr_ref is null)
  )
  or (:old.reestr_ref <> new$reestr_ref)
  )
  )
  )
  then /*      NULL */
    reestrAccepted1$ := 0;  /*   IB 4.2 */

  else
    BEGIN
      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id=new$REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrUpdate');
    END IF;
    BEGIN

      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id=:old.REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrUpdate');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_6 (TR_FACIALFINCAPTION_BU_6)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (:old.ProgIndex in(63,68,70)) then /*    */
    SELECT COUNT(id ) INTO CNT$1
    from paydocexchange where ((paydocref=:old.id)and(status<>0)and(TypeInf BETWEEN 0 and 10)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      if(/* (new.DOCNUMBER<>old.DOCNUMBER) or ((new.DOCNUMBER is NULL)and(not old.DOCNUMBER is NULL)) or ((old.DOCNUMBER is NULL)and(not new.DOCNUMBER is NULL)) or*/
      (new$SOURCEDOCNUM<>:old.SOURCEDOCNUM) or ((new$SOURCEDOCNUM is NULL)and(not :old.SOURCEDOCNUM is NULL)) or ((:old.SOURCEDOCNUM is NULL)and(not new$SOURCEDOCNUM is NULL)) or
      (new$PAYDATE<>:old.PAYDATE) or ((new$PAYDATE is NULL)and(not :old.PAYDATE is NULL)) or ((:old.PAYDATE is NULL)and(not new$PAYDATE is NULL))or
      /* (new.DOCUMENTDATE<>old.DOCUMENTDATE) or ((new.DOCUMENTDATE is NULL)and(not old.DOCUMENTDATE is NULL)) or ((old.DOCUMENTDATE is NULL)and(not new.DOCUMENTDATE is NULL))or*/
      (new$REESTRDATE<>:old.REESTRDATE) or ((new$REESTRDATE is NULL)and(not :old.REESTRDATE is NULL)) or ((:old.REESTRDATE is NULL)and(not new$REESTRDATE is NULL))or
      (((new$credit - :old.credit)>0.001)or((new$credit - :old.credit)<-0.001)) or
      (new$SOURCEACCOUNT<>:old.SOURCEACCOUNT) or
      (new$DESTACCOUNT<>:old.DESTACCOUNT) or
      (new$PAYTYPECLS<>:old.PAYTYPECLS) or
      (new$NOTE<>:old.NOTE) or  ((new$NOTE is NULL)and(not :old.NOTE is NULL)) or ((:old.NOTE is NULL)and(not new$NOTE is NULL))or
      (new$PAYPRIORITY<>:old.PAYPRIORITY) or ((new$PAYPRIORITY is NULL)and(not :old.PAYPRIORITY is NULL)) or ((:old.PAYPRIORITY is NULL)and(not new$PAYPRIORITY is NULL))or
      (new$REESTR_REF<>:old.REESTR_REF) or ((new$REESTR_REF is NULL)and(not :old.REESTR_REF is NULL)) or ((:old.REESTR_REF is NULL)and(not new$REESTR_REF is NULL))or
      (new$NDS<>:old.NDS) or ((new$NDS is NULL)and(not :old.NDS is NULL)) or ((:old.NDS is NULL)and(not new$NDS is NULL))or
      (new$TAXNOTE<>:old.TAXNOTE) or ((new$TAXNOTE is NULL)and(not :old.TAXNOTE is NULL)) or ((:old.TAXNOTE is NULL)and(not new$TAXNOTE is NULL)) )then
        RaiseException('ex_CannotChangeSended');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_32 (TR_FACIALFINCAPTION_BU_32)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$Reestr_ref IS NULL)    /*    select ,  */
                              THEN
      new$SourceDocNum := '';
      new$ReestrDate := NULL;
   ELSIF (    (new$Reestr_ref = :OLD.Reestr_ref)
          AND (new$SourceDocNum = :OLD.SourceDocNum)
          AND (new$ReestrDate = :OLD.ReestrDate)
         ) THEN
/*          */
      NULL;
   ELSE
      BEGIN
         SELECT ffr.ReestrNumber, ffr.ReestrDate
           INTO new$SourceDocNum, new$ReestrDate
           FROM FacialFinReestr ffr
          WHERE ffr.ID = new$Reestr_ref;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            new$SourceDocNum := NULL;
            new$ReestrDate := NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BU_60 (T_FACIALFINCAPTION_BU_60)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF ((new$progindex = 60) AND (new$Credit <> :OLD.Credit)) THEN
      UPDATE FacialFinDetail
         SET Credit = new$Credit
       WHERE (RecordIndex = new$ID);
   END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_FACIALFINCAPTION_BU_70)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --         
   IF (new$SubProgIndex = 416) THEN
      UPDATE Guarantee
         SET AcceptDate = new$AcceptDate
       WHERE SubRecordIndex = new$ID;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (T_FACIALFINCAPTION_BU_100)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*   ,    */
   IF (    (   (:OLD.SourceFacialAcc_CLS <> new$SourceFacialAcc_CLS)
            OR (:OLD.DestFacialAcc_CLS <> new$DestFacialAcc_CLS)
           )
       AND ((new$SubProgIndex <> 1) OR (new$SubProgIndex IS NULL))
      ) THEN
      FOR R$ IN (SELECT ID, SourceFacialAcc_CLS, DestFacialAcc_CLS
                   FROM FacialFinDetail
                  WHERE RecordIndex = new$ID) LOOP
         IF (NOT (new$SourceFacialAcc_CLS = 0)) THEN
            SourceFacialAcc_CLS$ := new$SourceFacialAcc_CLS;
         ELSE
            SourceFacialAcc_CLS$ := R$.SourceFacialAcc_CLS;
         END IF;

         IF (NOT (new$DestFacialAcc_CLS = 0)) THEN
            DestFacialAcc_CLS$ := new$DestFacialAcc_CLS;
         ELSE
            DestFacialAcc_CLS$ := R$.DestFacialAcc_CLS;
         END IF;

         IF (:OLD.SourceFacialAcc_CLS <> new$SourceFacialAcc_CLS) THEN
            UPDATE FacialFinDetail
               SET SourceFacialAcc_CLS = SourceFacialAcc_CLS$,
                   RVersion = -1
             WHERE (ID = R$.ID);
         END IF;

         IF (:OLD.DestFacialAcc_CLS <> new$DestFacialAcc_CLS) THEN
            UPDATE FacialFinDetail
               SET DestFacialAcc_CLS = DestFacialAcc_CLS$,
                   RVersion = -1
             WHERE (ID = R$.ID);
         END IF;
      END LOOP;
   END IF;

   /*    / , 
           .*/
  IF (((NEW$IsBlocked <> :OLD.IsBlocked) OR
      ((NEW$IsBlocked IS NULL) AND (:OLD.IsBlocked IS NOT NULL)) OR
      ((NEW$IsBlocked IS NOT NULL) AND (:OLD.IsBlocked IS NULL))
     ) OR
     ((NEW$BlockedCause <> :OLD.BlockedCause) OR
      ((NEW$BlockedCause IS NULL) AND (:OLD.BlockedCause IS NOT NULL)) OR
      ((NEW$BlockedCause IS NOT NULL) AND (:OLD.BlockedCause IS NULL))
     ) OR
     ((NEW$UnBlockedDate <> :OLD.UnBlockedDate) OR
      ((NEW$UnBlockedDate IS NULL) AND (:OLD.UnBlockedDate IS NOT NULL)) OR
      ((NEW$UnBlockedDate IS NOT NULL) AND (:OLD.UnBlockedDate IS NULL))
     ) OR
     ((NEW$UnBlockedCause <> :OLD.UnBlockedCause) OR
      ((NEW$UnBlockedDate IS NULL) AND (:OLD.UnBlockedCause IS NOT NULL)) OR
      ((NEW$UnBlockedCause IS NOT NULL) AND (:OLD.UnBlockedCause IS NULL))
     )) THEN
     UPDATE FacialFinDetail ffd
     SET ffd.IsBlocked = NEW$IsBlocked, ffd.BlockedCause = NEW$BlockedCause,
         ffd.UnBlockedDate = NEW$UnBlockedDate, ffd.UnBlockedCause = NEW$UnBlockedCause
     WHERE ffd.recordindex = NEW$ID;
  end if;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINCAPTION_BU_210)
-- Create 27.08.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*      */
   IF (new$DOCSTATEREF <> :OLD.DOCSTATEREF) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DOCSTATEREF, new$DOCSTATEREF
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (T_FACIALFINCAPTION_BU_300)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  IsReject1$ := -1;
  if ((:old.Reject_CLS is null)and(new$Reject_CLS is not null)) then
    IsReject1$ := 1;

  else
    if ((:old.Reject_CLS is not null)and(new$Reject_CLS is null)) then
      IsReject1$ := 0;
    END IF;
  END IF;
  if (IsReject1$  <> -1) then
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID = new$ID;
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID in (select d.id from FacialFinDetail d where d.RecordIndex = new$id);

  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINCAPTION_BU_700)
-- Create 17.09.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINCAPTION SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    SOURCEDOCNUM = new$SOURCEDOCNUM,
    PAYDATE = new$PAYDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    REESTRDATE = new$REESTRDATE,
    CREDIT = new$CREDIT,
    SOURCEACCOUNT = new$SOURCEACCOUNT,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    DESTACCOUNT = new$DESTACCOUNT,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    PROGINDEX = new$PROGINDEX,
    ARHIVEDOC = new$ARHIVEDOC,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    PAYTYPECLS = new$PAYTYPECLS,
    NOTE = new$NOTE,
    PERIOD = new$PERIOD,
    PAYPRIORITY = new$PAYPRIORITY,
    TYPEOPERATIONCLS = new$TYPEOPERATIONCLS,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    RECORDINDEX = new$RECORDINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REESTR_REF = new$REESTR_REF,
    REJECT_CLS = new$REJECT_CLS,
    CLIENTBANKNUMBER = new$CLIENTBANKNUMBER,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    TRUSTNUMBER = new$TRUSTNUMBER,
    LINKEDDOCUMENT = new$LINKEDDOCUMENT,
    BNKRECORDID = new$BNKRECORDID,
    SUBPROGINDEX = new$SUBPROGINDEX,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    TREASUARYDOCSTATECLS = new$TREASUARYDOCSTATECLS,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    NDS = new$NDS,
    TAXNOTE = new$TAXNOTE,
    MANAGERBID = new$MANAGERBID,
    BIDNUMBER = new$BIDNUMBER,
    GROUPID = new$GROUPID,
    GROUPSUMMA = new$GROUPSUMMA,
    DOCSTATEREF = new$DOCSTATEREF,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    FAXDOCCOUNT = new$FAXDOCCOUNT,
    STIMATEID = new$STIMATEID,
    INTEGRATEDDOCREF = new$INTEGRATEDDOCREF,
    REQUESTNUMBER = new$REQUESTNUMBER,
    REQUESTDATE = new$REQUESTDATE,
    RVERSION = new$RVERSION,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    ELDOCREF = new$ELDOCREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    CLSTYPE = new$CLSTYPE,
    OPERATIONDIRECTION = new$OPERATIONDIRECTION,
    SOURCETYPE = new$SOURCETYPE,
    DESTTYPE = new$DESTTYPE,
    CARDNUMBER = new$CARDNUMBER,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    CASHIERPERSONALINFO = new$CASHIERPERSONALINFO,
    BIDDATE = new$BIDDATE,
    CARDREF = new$CARDREF,
    SOURCESTOREDPAYMENTPROPS = new$SOURCESTOREDPAYMENTPROPS,
    DESTSTOREDPAYMENTPROPS = new$DESTSTOREDPAYMENTPROPS,
    STOREDPAYMENTNOTE = new$STOREDPAYMENTNOTE,
    DOCCHANGEDATE = new$DOCCHANGEDATE,
    UINCODE = new$UINCODE,
    DOCOSN = new$DOCOSN,
    SIGNERS = new$SIGNERS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    AUTOSANCTION = new$AUTOSANCTION,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_300 (TR_FACIALFINCAPTION_AU_300)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*          ,      */
  if ((new$AcceptDate <> :old.AcceptDate)or((new$AcceptDate is not null)and(:old.AcceptDate is null))
  or((new$AcceptDate is null)and(:old.AcceptDate is not null))) then
    update facialfindetail set
    AcceptDate = new$AcceptDate,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;
  if (new$BuhOperationCLS <> :old.BuhOperationCLS)  then
    update facialfindetail set
    BuhOperationCLS = new$BuhOperationCLS,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;
  if ((new$ClsType <> :old.ClsType)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$ClsType = 0) then
      update facialfindetail set
      SourceKD = 0,
      DestKD = 0,
      SourceIFS = 0,
      DestIFS = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 1) then
      update facialfindetail set
      SourceKD = 0,
      DestKD = 0,
      SourceKVSR = 0,
      SourceKFSR = 0,
      SourceKCSR = 0,
      SourceKVR = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 2) then
      update facialfindetail set
      SourceIFS = 0,
      DestIFS = 0,
      SourceKVSR = 0,
      SourceKFSR = 0,
      SourceKCSR = 0,
      SourceKVR = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);

    END IF;
  END IF;
  if ((new$DestClsType <> :old.DestClsType)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$DestClsType = 0) then
      update facialfindetail set
      DestKD = 0,
      DestIFS = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
    END IF;
    if (new$DestClsType = 1) then
      update facialfindetail set
      DestKD = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
    END IF;
    if (new$DestClsType = 2) then
      update facialfindetail set
      DestIFS = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINCAPTION_AU_500)
-- Create 28.04.2005
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (:NEW.ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (23, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
        WHERE (TableID = 23) AND (RecordId = :NEW.ID);
   END IF;

END;
/
-- CREATE TRIGGER TR_FACIALFINCAPTION_AU_10
CREATE OR REPLACE TRIGGER TR_FACIALFINCAPTION_IU
  INSTEAD OF UPDATE
  ON FACIALFINCAPTION
  FOR EACH ROW
DECLARE
  new$ID FACIALFINCAPTION.ID%TYPE := :NEW.ID;
  new$DOCNUMBER FACIALFINCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SOURCEDOCNUM FACIALFINCAPTION.SOURCEDOCNUM%TYPE := :NEW.SOURCEDOCNUM;
  new$PAYDATE FACIALFINCAPTION.PAYDATE%TYPE := :NEW.PAYDATE;
  new$ACCEPTDATE FACIALFINCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCUMENTDATE FACIALFINCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$REESTRDATE FACIALFINCAPTION.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$CREDIT FACIALFINCAPTION.CREDIT%TYPE := :NEW.CREDIT;
  new$SOURCEACCOUNT FACIALFINCAPTION.SOURCEACCOUNT%TYPE := :NEW.SOURCEACCOUNT;
  new$SOURCEFACIALACC_CLS FACIALFINCAPTION.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$DESTACCOUNT FACIALFINCAPTION.DESTACCOUNT%TYPE := :NEW.DESTACCOUNT;
  new$DESTFACIALACC_CLS FACIALFINCAPTION.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$PROGINDEX FACIALFINCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$ARHIVEDOC FACIALFINCAPTION.ARHIVEDOC%TYPE := :NEW.ARHIVEDOC;
  new$PAYSYMBOLCLS FACIALFINCAPTION.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$PAYTYPECLS FACIALFINCAPTION.PAYTYPECLS%TYPE := :NEW.PAYTYPECLS;
  new$NOTE FACIALFINCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$PERIOD FACIALFINCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$PAYPRIORITY FACIALFINCAPTION.PAYPRIORITY%TYPE := :NEW.PAYPRIORITY;
  new$TYPEOPERATIONCLS FACIALFINCAPTION.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$BUHPAYMENTCLS FACIALFINCAPTION.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$CREATERUSER FACIALFINCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF FACIALFINCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECORDINDEX FACIALFINCAPTION.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$SENDERID FACIALFINCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REESTR_REF FACIALFINCAPTION.REESTR_REF%TYPE := :NEW.REESTR_REF;
  new$REJECT_CLS FACIALFINCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$CLIENTBANKNUMBER FACIALFINCAPTION.CLIENTBANKNUMBER%TYPE := :NEW.CLIENTBANKNUMBER;
  new$CRYPTOSTATUS FACIALFINCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$TRUSTNUMBER FACIALFINCAPTION.TRUSTNUMBER%TYPE := :NEW.TRUSTNUMBER;
  new$LINKEDDOCUMENT FACIALFINCAPTION.LINKEDDOCUMENT%TYPE := :NEW.LINKEDDOCUMENT;
  new$BNKRECORDID FACIALFINCAPTION.BNKRECORDID%TYPE := :NEW.BNKRECORDID;
  new$SUBPROGINDEX FACIALFINCAPTION.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$DOCUMENTSTATE FACIALFINCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA FACIALFINCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$TREASUARYDOCSTATECLS FACIALFINCAPTION.TREASUARYDOCSTATECLS%TYPE := :NEW.TREASUARYDOCSTATECLS;
  new$DEPARTMENTCLS FACIALFINCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$NDS FACIALFINCAPTION.NDS%TYPE := :NEW.NDS;
  new$TAXNOTE FACIALFINCAPTION.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$MANAGERBID FACIALFINCAPTION.MANAGERBID%TYPE := :NEW.MANAGERBID;
  new$BIDNUMBER FACIALFINCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$GROUPID FACIALFINCAPTION.GROUPID%TYPE := :NEW.GROUPID;
  new$GROUPSUMMA FACIALFINCAPTION.GROUPSUMMA%TYPE := :NEW.GROUPSUMMA;
  new$DOCSTATEREF FACIALFINCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$LASTEXTRCHANGE FACIALFINCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$FAXDOCCOUNT FACIALFINCAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$STIMATEID FACIALFINCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$INTEGRATEDDOCREF FACIALFINCAPTION.INTEGRATEDDOCREF%TYPE := :NEW.INTEGRATEDDOCREF;
  new$REQUESTNUMBER FACIALFINCAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$REQUESTDATE FACIALFINCAPTION.REQUESTDATE%TYPE := :NEW.REQUESTDATE;
  new$RVERSION FACIALFINCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$FEDERALFUNDSREF FACIALFINCAPTION.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$ELDOCREF FACIALFINCAPTION.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$BUHOPERATIONCLS FACIALFINCAPTION.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CLSTYPE FACIALFINCAPTION.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$OPERATIONDIRECTION FACIALFINCAPTION.OPERATIONDIRECTION%TYPE := :NEW.OPERATIONDIRECTION;
  new$SOURCETYPE FACIALFINCAPTION.SOURCETYPE%TYPE := :NEW.SOURCETYPE;
  new$DESTTYPE FACIALFINCAPTION.DESTTYPE%TYPE := :NEW.DESTTYPE;
  new$CARDNUMBER FACIALFINCAPTION.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$ISBLOCKED FACIALFINCAPTION.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINCAPTION.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINCAPTION.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINCAPTION.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$CASHIERPERSONALINFO FACIALFINCAPTION.CASHIERPERSONALINFO%TYPE := :NEW.CASHIERPERSONALINFO;
  new$BIDDATE FACIALFINCAPTION.BIDDATE%TYPE := :NEW.BIDDATE;
  new$CARDREF FACIALFINCAPTION.CARDREF%TYPE := :NEW.CARDREF;
  new$SOURCESTOREDPAYMENTPROPS FACIALFINCAPTION.SOURCESTOREDPAYMENTPROPS%TYPE := :NEW.SOURCESTOREDPAYMENTPROPS;
  new$DESTSTOREDPAYMENTPROPS FACIALFINCAPTION.DESTSTOREDPAYMENTPROPS%TYPE := :NEW.DESTSTOREDPAYMENTPROPS;
  new$STOREDPAYMENTNOTE FACIALFINCAPTION.STOREDPAYMENTNOTE%TYPE := :NEW.STOREDPAYMENTNOTE;
  new$DOCCHANGEDATE FACIALFINCAPTION.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$UINCODE FACIALFINCAPTION.UINCODE%TYPE := :NEW.UINCODE;
  new$DOCOSN FACIALFINCAPTION.DOCOSN%TYPE := :NEW.DOCOSN;
  new$SIGNERS FACIALFINCAPTION.SIGNERS%TYPE := :NEW.SIGNERS;
  new$DESTCLSTYPE FACIALFINCAPTION.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SENDERIDKEY FACIALFINCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$AUTOSANCTION FACIALFINCAPTION.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$STOREDPAYMENTCONTENT FACIALFINCAPTION.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$REJECTCAUSE FACIALFINCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  SourceFacialAcc_CLS$ NUMBER(10);
  DestFacialAcc_CLS$ NUMBER(10);
  CNT$1 NUMBER(10);
  reestrAccepted1$ NUMBER(10);
  IsReject1$ NUMBER(10);
  UseFax$ NUMBER(10);
  DocNumber$ NUMBER(10);
  DetCount$ NUMBER(10);
  Dummy$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINCAPTION_BU)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is not null) then
    /*      */
    GetIntConst(30, 19,UseFax$);
    if ((new$BidNumber is null) and (UseFax$ = 1)) then
      new$BidNumber:= new$DocNumber;

    END IF;
  END IF;
  if (new$credit is null)then
    new$credit:= 0;
  END IF;
  if (new$ArhiveDoc is null) then
    new$ArhiveDoc:= 0;
  END IF;
  if (new$PayTypeCls is null) then
    new$PayTypeCls:= 0;
  END IF;
  if (new$BuhPaymentCls is null) then
    new$BuhPaymentCls:= 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$ClsType is null) then
    new$ClsType := 0;
  END IF;
  if (new$DestClsType is null) then
    new$DestClsType := new$ClsType;
  END IF;
  if (new$SourceFacialAcc_CLS is null) then
    new$SourceFacialAcc_CLS:= 0;
  END IF;
  if (new$DestFacialAcc_CLS is null) then
    new$DestFacialAcc_CLS:= 0;
  END IF;
  if (new$FaxDocCount is null) then
    new$FaxDocCount := 0;
  END IF;
  if (new$OperationDirection is null) then
    new$OperationDirection := 0;
  END IF;
  if (new$OperationDirection <> :old.OperationDirection) then
    if (new$OperationDirection = 0) then
      new$SourceType := 1;
      new$DestType := 1;

    else
      if (new$OperationDirection = 1) then
        new$SourceType := 1;
        new$DestType := -1;

      else
        if (new$OperationDirection = 2) then
          new$SourceType := -1;
          new$DestType := 1;

        else
          new$SourceType := -1;
          new$DestType := -1;

        END IF;
      END IF;
    END IF;
  END IF;
  if (new$DepartmentCls is null) then
    GetIntConst(30, 20,DocNumber$);
    if (DocNumber$ is null) then
      new$DepartmentCls:= 0;

    else
      new$DepartmentCls:= DocNumber$;

    END IF;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount$ from FacialFinDetail where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_Cls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_1 (TR_FACIALFINCAPTION_BU_1)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --   -     
   IF (new$GroupID IS NULL) THEN new$GroupID := new$ID; END IF;
   IF (new$GroupSumma IS NULL) THEN new$GroupSumma := 0; END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_FACIALFINCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (not (    ((new$progindex = 63) or (new$progindex = 64) or (new$progindex = 68) or (new$progindex = 70))
  and (   (((new$credit - :old.credit)>0.001)or((new$credit - :old.credit)<-0.001))
  or (new$sourcefacialacc_cls <> :old.sourcefacialacc_cls)
  or (
  ((new$sourceaccount is null) and (:old.sourceaccount is not null)) or
  ((new$sourceaccount is not null) and (:old.sourceaccount is null)) or
  ((new$sourceaccount <> :old.sourceaccount ) and (:old.sourceaccount is not null) and (new$sourceaccount is not null))
  )
  or (
  ((new$destaccount is null) and (:old.destaccount is not null)) or
  ((new$destaccount is not null) and (:old.destaccount is null)) or
  ((new$destaccount <> :old.destaccount ) and (:old.destaccount is not null) and (new$destaccount is not null))
  )
  or (    (:old.reestr_ref is null)
  and (new$reestr_ref is not null)
  )
  or (    (:old.reestr_ref is not null)
  and (new$reestr_ref is null)
  )
  or (:old.reestr_ref <> new$reestr_ref)
  )
  )
  )
  then /*      NULL */
    reestrAccepted1$ := 0;  /*   IB 4.2 */

  else
    BEGIN
      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id=new$REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrUpdate');
    END IF;
    BEGIN

      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id=:old.REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrUpdate');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_6 (TR_FACIALFINCAPTION_BU_6)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (:old.ProgIndex in(63,68,70)) then /*    */
    SELECT COUNT(id ) INTO CNT$1
    from paydocexchange where ((paydocref=:old.id)and(status<>0)and(TypeInf BETWEEN 0 and 10)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      if(/* (new.DOCNUMBER<>old.DOCNUMBER) or ((new.DOCNUMBER is NULL)and(not old.DOCNUMBER is NULL)) or ((old.DOCNUMBER is NULL)and(not new.DOCNUMBER is NULL)) or*/
      (new$SOURCEDOCNUM<>:old.SOURCEDOCNUM) or ((new$SOURCEDOCNUM is NULL)and(not :old.SOURCEDOCNUM is NULL)) or ((:old.SOURCEDOCNUM is NULL)and(not new$SOURCEDOCNUM is NULL)) or
      (new$PAYDATE<>:old.PAYDATE) or ((new$PAYDATE is NULL)and(not :old.PAYDATE is NULL)) or ((:old.PAYDATE is NULL)and(not new$PAYDATE is NULL))or
      /* (new.DOCUMENTDATE<>old.DOCUMENTDATE) or ((new.DOCUMENTDATE is NULL)and(not old.DOCUMENTDATE is NULL)) or ((old.DOCUMENTDATE is NULL)and(not new.DOCUMENTDATE is NULL))or*/
      (new$REESTRDATE<>:old.REESTRDATE) or ((new$REESTRDATE is NULL)and(not :old.REESTRDATE is NULL)) or ((:old.REESTRDATE is NULL)and(not new$REESTRDATE is NULL))or
      (((new$credit - :old.credit)>0.001)or((new$credit - :old.credit)<-0.001)) or
      (new$SOURCEACCOUNT<>:old.SOURCEACCOUNT) or
      (new$DESTACCOUNT<>:old.DESTACCOUNT) or
      (new$PAYTYPECLS<>:old.PAYTYPECLS) or
      (new$NOTE<>:old.NOTE) or  ((new$NOTE is NULL)and(not :old.NOTE is NULL)) or ((:old.NOTE is NULL)and(not new$NOTE is NULL))or
      (new$PAYPRIORITY<>:old.PAYPRIORITY) or ((new$PAYPRIORITY is NULL)and(not :old.PAYPRIORITY is NULL)) or ((:old.PAYPRIORITY is NULL)and(not new$PAYPRIORITY is NULL))or
      (new$REESTR_REF<>:old.REESTR_REF) or ((new$REESTR_REF is NULL)and(not :old.REESTR_REF is NULL)) or ((:old.REESTR_REF is NULL)and(not new$REESTR_REF is NULL))or
      (new$NDS<>:old.NDS) or ((new$NDS is NULL)and(not :old.NDS is NULL)) or ((:old.NDS is NULL)and(not new$NDS is NULL))or
      (new$TAXNOTE<>:old.TAXNOTE) or ((new$TAXNOTE is NULL)and(not :old.TAXNOTE is NULL)) or ((:old.TAXNOTE is NULL)and(not new$TAXNOTE is NULL)) )then
        RaiseException('ex_CannotChangeSended');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_32 (TR_FACIALFINCAPTION_BU_32)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$Reestr_ref IS NULL)    /*    select ,  */
                              THEN
      new$SourceDocNum := '';
      new$ReestrDate := NULL;
   ELSIF (    (new$Reestr_ref = :OLD.Reestr_ref)
          AND (new$SourceDocNum = :OLD.SourceDocNum)
          AND (new$ReestrDate = :OLD.ReestrDate)
         ) THEN
/*          */
      NULL;
   ELSE
      BEGIN
         SELECT ffr.ReestrNumber, ffr.ReestrDate
           INTO new$SourceDocNum, new$ReestrDate
           FROM FacialFinReestr ffr
          WHERE ffr.ID = new$Reestr_ref;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            new$SourceDocNum := NULL;
            new$ReestrDate := NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BU_60 (T_FACIALFINCAPTION_BU_60)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF ((new$progindex = 60) AND (new$Credit <> :OLD.Credit)) THEN
      UPDATE FacialFinDetail
         SET Credit = new$Credit
       WHERE (RecordIndex = new$ID);
   END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_FACIALFINCAPTION_BU_70)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --         
   IF (new$SubProgIndex = 416) THEN
      UPDATE Guarantee
         SET AcceptDate = new$AcceptDate
       WHERE SubRecordIndex = new$ID;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (T_FACIALFINCAPTION_BU_100)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*   ,    */
   IF (    (   (:OLD.SourceFacialAcc_CLS <> new$SourceFacialAcc_CLS)
            OR (:OLD.DestFacialAcc_CLS <> new$DestFacialAcc_CLS)
           )
       AND ((new$SubProgIndex <> 1) OR (new$SubProgIndex IS NULL))
      ) THEN
      FOR R$ IN (SELECT ID, SourceFacialAcc_CLS, DestFacialAcc_CLS
                   FROM FacialFinDetail
                  WHERE RecordIndex = new$ID) LOOP
         IF (NOT (new$SourceFacialAcc_CLS = 0)) THEN
            SourceFacialAcc_CLS$ := new$SourceFacialAcc_CLS;
         ELSE
            SourceFacialAcc_CLS$ := R$.SourceFacialAcc_CLS;
         END IF;

         IF (NOT (new$DestFacialAcc_CLS = 0)) THEN
            DestFacialAcc_CLS$ := new$DestFacialAcc_CLS;
         ELSE
            DestFacialAcc_CLS$ := R$.DestFacialAcc_CLS;
         END IF;

         IF (:OLD.SourceFacialAcc_CLS <> new$SourceFacialAcc_CLS) THEN
            UPDATE FacialFinDetail
               SET SourceFacialAcc_CLS = SourceFacialAcc_CLS$,
                   RVersion = -1
             WHERE (ID = R$.ID);
         END IF;

         IF (:OLD.DestFacialAcc_CLS <> new$DestFacialAcc_CLS) THEN
            UPDATE FacialFinDetail
               SET DestFacialAcc_CLS = DestFacialAcc_CLS$,
                   RVersion = -1
             WHERE (ID = R$.ID);
         END IF;
      END LOOP;
   END IF;

   /*    / , 
           .*/
  IF (((NEW$IsBlocked <> :OLD.IsBlocked) OR
      ((NEW$IsBlocked IS NULL) AND (:OLD.IsBlocked IS NOT NULL)) OR
      ((NEW$IsBlocked IS NOT NULL) AND (:OLD.IsBlocked IS NULL))
     ) OR
     ((NEW$BlockedCause <> :OLD.BlockedCause) OR
      ((NEW$BlockedCause IS NULL) AND (:OLD.BlockedCause IS NOT NULL)) OR
      ((NEW$BlockedCause IS NOT NULL) AND (:OLD.BlockedCause IS NULL))
     ) OR
     ((NEW$UnBlockedDate <> :OLD.UnBlockedDate) OR
      ((NEW$UnBlockedDate IS NULL) AND (:OLD.UnBlockedDate IS NOT NULL)) OR
      ((NEW$UnBlockedDate IS NOT NULL) AND (:OLD.UnBlockedDate IS NULL))
     ) OR
     ((NEW$UnBlockedCause <> :OLD.UnBlockedCause) OR
      ((NEW$UnBlockedDate IS NULL) AND (:OLD.UnBlockedCause IS NOT NULL)) OR
      ((NEW$UnBlockedCause IS NOT NULL) AND (:OLD.UnBlockedCause IS NULL))
     )) THEN
     UPDATE FacialFinDetail ffd
     SET ffd.IsBlocked = NEW$IsBlocked, ffd.BlockedCause = NEW$BlockedCause,
         ffd.UnBlockedDate = NEW$UnBlockedDate, ffd.UnBlockedCause = NEW$UnBlockedCause
     WHERE ffd.recordindex = NEW$ID;
  end if;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINCAPTION_BU_210)
-- Create 27.08.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*      */
   IF (new$DOCSTATEREF <> :OLD.DOCSTATEREF) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DOCSTATEREF, new$DOCSTATEREF
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (T_FACIALFINCAPTION_BU_300)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  IsReject1$ := -1;
  if ((:old.Reject_CLS is null)and(new$Reject_CLS is not null)) then
    IsReject1$ := 1;

  else
    if ((:old.Reject_CLS is not null)and(new$Reject_CLS is null)) then
      IsReject1$ := 0;
    END IF;
  END IF;
  if (IsReject1$  <> -1) then
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID = new$ID;
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID in (select d.id from FacialFinDetail d where d.RecordIndex = new$id);

  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINCAPTION_BU_700)
-- Create 17.09.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINCAPTION SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    SOURCEDOCNUM = new$SOURCEDOCNUM,
    PAYDATE = new$PAYDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    REESTRDATE = new$REESTRDATE,
    CREDIT = new$CREDIT,
    SOURCEACCOUNT = new$SOURCEACCOUNT,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    DESTACCOUNT = new$DESTACCOUNT,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    PROGINDEX = new$PROGINDEX,
    ARHIVEDOC = new$ARHIVEDOC,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    PAYTYPECLS = new$PAYTYPECLS,
    NOTE = new$NOTE,
    PERIOD = new$PERIOD,
    PAYPRIORITY = new$PAYPRIORITY,
    TYPEOPERATIONCLS = new$TYPEOPERATIONCLS,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    RECORDINDEX = new$RECORDINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REESTR_REF = new$REESTR_REF,
    REJECT_CLS = new$REJECT_CLS,
    CLIENTBANKNUMBER = new$CLIENTBANKNUMBER,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    TRUSTNUMBER = new$TRUSTNUMBER,
    LINKEDDOCUMENT = new$LINKEDDOCUMENT,
    BNKRECORDID = new$BNKRECORDID,
    SUBPROGINDEX = new$SUBPROGINDEX,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    TREASUARYDOCSTATECLS = new$TREASUARYDOCSTATECLS,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    NDS = new$NDS,
    TAXNOTE = new$TAXNOTE,
    MANAGERBID = new$MANAGERBID,
    BIDNUMBER = new$BIDNUMBER,
    GROUPID = new$GROUPID,
    GROUPSUMMA = new$GROUPSUMMA,
    DOCSTATEREF = new$DOCSTATEREF,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    FAXDOCCOUNT = new$FAXDOCCOUNT,
    STIMATEID = new$STIMATEID,
    INTEGRATEDDOCREF = new$INTEGRATEDDOCREF,
    REQUESTNUMBER = new$REQUESTNUMBER,
    REQUESTDATE = new$REQUESTDATE,
    RVERSION = new$RVERSION,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    ELDOCREF = new$ELDOCREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    CLSTYPE = new$CLSTYPE,
    OPERATIONDIRECTION = new$OPERATIONDIRECTION,
    SOURCETYPE = new$SOURCETYPE,
    DESTTYPE = new$DESTTYPE,
    CARDNUMBER = new$CARDNUMBER,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    CASHIERPERSONALINFO = new$CASHIERPERSONALINFO,
    BIDDATE = new$BIDDATE,
    CARDREF = new$CARDREF,
    SOURCESTOREDPAYMENTPROPS = new$SOURCESTOREDPAYMENTPROPS,
    DESTSTOREDPAYMENTPROPS = new$DESTSTOREDPAYMENTPROPS,
    STOREDPAYMENTNOTE = new$STOREDPAYMENTNOTE,
    DOCCHANGEDATE = new$DOCCHANGEDATE,
    UINCODE = new$UINCODE,
    DOCOSN = new$DOCOSN,
    SIGNERS = new$SIGNERS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    AUTOSANCTION = new$AUTOSANCTION,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_FACIALFINCAPTION_AU_10)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 72) then /*   */
    if (((new$AcceptDate = :old.AcceptDate)or((new$AcceptDate is null)and(:old.AcceptDate is null)))
    and((new$Reject_CLS = :old.Reject_CLS)or((new$Reject_CLS is null)and(:old.Reject_CLS is null)))
    and((new$RejectCause = :old.RejectCause)or((new$RejectCause is null)and(:old.RejectCause is null)))
    and((new$TREASUARYDOCSTATECLS = :old.TREASUARYDOCSTATECLS)or((new$TREASUARYDOCSTATECLS is null)and(:old.TREASUARYDOCSTATECLS is null)))
    and((new$DOCSTATEREF = :old.DOCSTATEREF)or((new$DOCSTATEREF is null)and(:old.DOCSTATEREF is null)))
    and((new$REESTR_REF = :old.REESTR_REF)or((new$REESTR_REF is NULL)and(:old.REESTR_REF is NULL)))
    and(new$SOURCEACCOUNT = :old.SOURCEACCOUNT)
    and(new$DESTACCOUNT = :old.DESTACCOUNT)
    ) then
      Dummy$ := 0;
          
    Else
      /*    ,      */
      update FacialFinCaption set
      AcceptDate = new$AcceptDate,
      Reject_CLS = new$Reject_CLS,
      RejectCause = new$RejectCause,
      TREASUARYDOCSTATECLS = new$TREASUARYDOCSTATECLS,
      DOCSTATEREF = new$DOCSTATEREF,
      REESTR_REF = new$REESTR_REF,
      SOURCEACCOUNT = new$SOURCEACCOUNT,
      DESTACCOUNT = new$DESTACCOUNT
      where
      IntegratedDocRef = new$id;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_300 (TR_FACIALFINCAPTION_AU_300)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*          ,      */
  if ((new$AcceptDate <> :old.AcceptDate)or((new$AcceptDate is not null)and(:old.AcceptDate is null))
  or((new$AcceptDate is null)and(:old.AcceptDate is not null))) then
    update facialfindetail set
    AcceptDate = new$AcceptDate,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;
  if (new$BuhOperationCLS <> :old.BuhOperationCLS)  then
    update facialfindetail set
    BuhOperationCLS = new$BuhOperationCLS,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;
  if ((new$ClsType <> :old.ClsType)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$ClsType = 0) then
      update facialfindetail set
      SourceKD = 0,
      DestKD = 0,
      SourceIFS = 0,
      DestIFS = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 1) then
      update facialfindetail set
      SourceKD = 0,
      DestKD = 0,
      SourceKVSR = 0,
      SourceKFSR = 0,
      SourceKCSR = 0,
      SourceKVR = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 2) then
      update facialfindetail set
      SourceIFS = 0,
      DestIFS = 0,
      SourceKVSR = 0,
      SourceKFSR = 0,
      SourceKCSR = 0,
      SourceKVR = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);

    END IF;
  END IF;
  if ((new$DestClsType <> :old.DestClsType)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$DestClsType = 0) then
      update facialfindetail set
      DestKD = 0,
      DestIFS = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
    END IF;
    if (new$DestClsType = 1) then
      update facialfindetail set
      DestKD = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
    END IF;
    if (new$DestClsType = 2) then
      update facialfindetail set
      DestIFS = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINCAPTION_AU_500)
-- Create 28.04.2005
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (:NEW.ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (23, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
        WHERE (TableID = 23) AND (RecordId = :NEW.ID);
   END IF;

END;
/
-- CREATE TRIGGER TR_FACIALFINCAPTION_BU_10
CREATE OR REPLACE TRIGGER TR_FACIALFINCAPTION_IU
  INSTEAD OF UPDATE
  ON FACIALFINCAPTION
  FOR EACH ROW
DECLARE
  new$ID FACIALFINCAPTION.ID%TYPE := :NEW.ID;
  new$DOCNUMBER FACIALFINCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SOURCEDOCNUM FACIALFINCAPTION.SOURCEDOCNUM%TYPE := :NEW.SOURCEDOCNUM;
  new$PAYDATE FACIALFINCAPTION.PAYDATE%TYPE := :NEW.PAYDATE;
  new$ACCEPTDATE FACIALFINCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCUMENTDATE FACIALFINCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$REESTRDATE FACIALFINCAPTION.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$CREDIT FACIALFINCAPTION.CREDIT%TYPE := :NEW.CREDIT;
  new$SOURCEACCOUNT FACIALFINCAPTION.SOURCEACCOUNT%TYPE := :NEW.SOURCEACCOUNT;
  new$SOURCEFACIALACC_CLS FACIALFINCAPTION.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$DESTACCOUNT FACIALFINCAPTION.DESTACCOUNT%TYPE := :NEW.DESTACCOUNT;
  new$DESTFACIALACC_CLS FACIALFINCAPTION.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$PROGINDEX FACIALFINCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$ARHIVEDOC FACIALFINCAPTION.ARHIVEDOC%TYPE := :NEW.ARHIVEDOC;
  new$PAYSYMBOLCLS FACIALFINCAPTION.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$PAYTYPECLS FACIALFINCAPTION.PAYTYPECLS%TYPE := :NEW.PAYTYPECLS;
  new$NOTE FACIALFINCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$PERIOD FACIALFINCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$PAYPRIORITY FACIALFINCAPTION.PAYPRIORITY%TYPE := :NEW.PAYPRIORITY;
  new$TYPEOPERATIONCLS FACIALFINCAPTION.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$BUHPAYMENTCLS FACIALFINCAPTION.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$CREATERUSER FACIALFINCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF FACIALFINCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECORDINDEX FACIALFINCAPTION.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$SENDERID FACIALFINCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REESTR_REF FACIALFINCAPTION.REESTR_REF%TYPE := :NEW.REESTR_REF;
  new$REJECT_CLS FACIALFINCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$CLIENTBANKNUMBER FACIALFINCAPTION.CLIENTBANKNUMBER%TYPE := :NEW.CLIENTBANKNUMBER;
  new$CRYPTOSTATUS FACIALFINCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$TRUSTNUMBER FACIALFINCAPTION.TRUSTNUMBER%TYPE := :NEW.TRUSTNUMBER;
  new$LINKEDDOCUMENT FACIALFINCAPTION.LINKEDDOCUMENT%TYPE := :NEW.LINKEDDOCUMENT;
  new$BNKRECORDID FACIALFINCAPTION.BNKRECORDID%TYPE := :NEW.BNKRECORDID;
  new$SUBPROGINDEX FACIALFINCAPTION.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$DOCUMENTSTATE FACIALFINCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA FACIALFINCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$TREASUARYDOCSTATECLS FACIALFINCAPTION.TREASUARYDOCSTATECLS%TYPE := :NEW.TREASUARYDOCSTATECLS;
  new$DEPARTMENTCLS FACIALFINCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$NDS FACIALFINCAPTION.NDS%TYPE := :NEW.NDS;
  new$TAXNOTE FACIALFINCAPTION.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$MANAGERBID FACIALFINCAPTION.MANAGERBID%TYPE := :NEW.MANAGERBID;
  new$BIDNUMBER FACIALFINCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$GROUPID FACIALFINCAPTION.GROUPID%TYPE := :NEW.GROUPID;
  new$GROUPSUMMA FACIALFINCAPTION.GROUPSUMMA%TYPE := :NEW.GROUPSUMMA;
  new$DOCSTATEREF FACIALFINCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$LASTEXTRCHANGE FACIALFINCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$FAXDOCCOUNT FACIALFINCAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$STIMATEID FACIALFINCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$INTEGRATEDDOCREF FACIALFINCAPTION.INTEGRATEDDOCREF%TYPE := :NEW.INTEGRATEDDOCREF;
  new$REQUESTNUMBER FACIALFINCAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$REQUESTDATE FACIALFINCAPTION.REQUESTDATE%TYPE := :NEW.REQUESTDATE;
  new$RVERSION FACIALFINCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$FEDERALFUNDSREF FACIALFINCAPTION.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$ELDOCREF FACIALFINCAPTION.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$BUHOPERATIONCLS FACIALFINCAPTION.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CLSTYPE FACIALFINCAPTION.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$OPERATIONDIRECTION FACIALFINCAPTION.OPERATIONDIRECTION%TYPE := :NEW.OPERATIONDIRECTION;
  new$SOURCETYPE FACIALFINCAPTION.SOURCETYPE%TYPE := :NEW.SOURCETYPE;
  new$DESTTYPE FACIALFINCAPTION.DESTTYPE%TYPE := :NEW.DESTTYPE;
  new$CARDNUMBER FACIALFINCAPTION.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$ISBLOCKED FACIALFINCAPTION.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINCAPTION.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINCAPTION.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINCAPTION.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$CASHIERPERSONALINFO FACIALFINCAPTION.CASHIERPERSONALINFO%TYPE := :NEW.CASHIERPERSONALINFO;
  new$BIDDATE FACIALFINCAPTION.BIDDATE%TYPE := :NEW.BIDDATE;
  new$CARDREF FACIALFINCAPTION.CARDREF%TYPE := :NEW.CARDREF;
  new$SOURCESTOREDPAYMENTPROPS FACIALFINCAPTION.SOURCESTOREDPAYMENTPROPS%TYPE := :NEW.SOURCESTOREDPAYMENTPROPS;
  new$DESTSTOREDPAYMENTPROPS FACIALFINCAPTION.DESTSTOREDPAYMENTPROPS%TYPE := :NEW.DESTSTOREDPAYMENTPROPS;
  new$STOREDPAYMENTNOTE FACIALFINCAPTION.STOREDPAYMENTNOTE%TYPE := :NEW.STOREDPAYMENTNOTE;
  new$DOCCHANGEDATE FACIALFINCAPTION.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$UINCODE FACIALFINCAPTION.UINCODE%TYPE := :NEW.UINCODE;
  new$DOCOSN FACIALFINCAPTION.DOCOSN%TYPE := :NEW.DOCOSN;
  new$SIGNERS FACIALFINCAPTION.SIGNERS%TYPE := :NEW.SIGNERS;
  new$DESTCLSTYPE FACIALFINCAPTION.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SENDERIDKEY FACIALFINCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$AUTOSANCTION FACIALFINCAPTION.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$STOREDPAYMENTCONTENT FACIALFINCAPTION.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$REJECTCAUSE FACIALFINCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  SourceFacialAcc_CLS$ NUMBER(10);
  DestFacialAcc_CLS$ NUMBER(10);
  CNT$1 NUMBER(10);
  reestrAccepted1$ NUMBER(10);
  IsReject1$ NUMBER(10);
  UseFax$ NUMBER(10);
  DocNumber$ NUMBER(10);
  DetCount$ NUMBER(10);
  Dummy$ NUMBER(10);
  ParentAcceptDate$ NUMBER;
  ParentReject_CLS$ NUMBER(10);
  ParentRejectCause$ VARCHAR2(255);
  ParentTREASUARYDOCSTATECLS$ NUMBER(10);
  ParentDOCSTATEREF$ NUMBER(10);
  ParentSOURCEACCOUNT$ NUMBER(10);
  ParentDESTACCOUNT$ NUMBER(10);
  ParentREESTR_REF$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINCAPTION_BU)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is not null) then
    /*      */
    GetIntConst(30, 19,UseFax$);
    if ((new$BidNumber is null) and (UseFax$ = 1)) then
      new$BidNumber:= new$DocNumber;

    END IF;
  END IF;
  if (new$credit is null)then
    new$credit:= 0;
  END IF;
  if (new$ArhiveDoc is null) then
    new$ArhiveDoc:= 0;
  END IF;
  if (new$PayTypeCls is null) then
    new$PayTypeCls:= 0;
  END IF;
  if (new$BuhPaymentCls is null) then
    new$BuhPaymentCls:= 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$ClsType is null) then
    new$ClsType := 0;
  END IF;
  if (new$DestClsType is null) then
    new$DestClsType := new$ClsType;
  END IF;
  if (new$SourceFacialAcc_CLS is null) then
    new$SourceFacialAcc_CLS:= 0;
  END IF;
  if (new$DestFacialAcc_CLS is null) then
    new$DestFacialAcc_CLS:= 0;
  END IF;
  if (new$FaxDocCount is null) then
    new$FaxDocCount := 0;
  END IF;
  if (new$OperationDirection is null) then
    new$OperationDirection := 0;
  END IF;
  if (new$OperationDirection <> :old.OperationDirection) then
    if (new$OperationDirection = 0) then
      new$SourceType := 1;
      new$DestType := 1;

    else
      if (new$OperationDirection = 1) then
        new$SourceType := 1;
        new$DestType := -1;

      else
        if (new$OperationDirection = 2) then
          new$SourceType := -1;
          new$DestType := 1;

        else
          new$SourceType := -1;
          new$DestType := -1;

        END IF;
      END IF;
    END IF;
  END IF;
  if (new$DepartmentCls is null) then
    GetIntConst(30, 20,DocNumber$);
    if (DocNumber$ is null) then
      new$DepartmentCls:= 0;

    else
      new$DepartmentCls:= DocNumber$;

    END IF;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount$ from FacialFinDetail where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_Cls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_1 (TR_FACIALFINCAPTION_BU_1)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --   -     
   IF (new$GroupID IS NULL) THEN new$GroupID := new$ID; END IF;
   IF (new$GroupSumma IS NULL) THEN new$GroupSumma := 0; END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_FACIALFINCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (not (    ((new$progindex = 63) or (new$progindex = 64) or (new$progindex = 68) or (new$progindex = 70))
  and (   (((new$credit - :old.credit)>0.001)or((new$credit - :old.credit)<-0.001))
  or (new$sourcefacialacc_cls <> :old.sourcefacialacc_cls)
  or (
  ((new$sourceaccount is null) and (:old.sourceaccount is not null)) or
  ((new$sourceaccount is not null) and (:old.sourceaccount is null)) or
  ((new$sourceaccount <> :old.sourceaccount ) and (:old.sourceaccount is not null) and (new$sourceaccount is not null))
  )
  or (
  ((new$destaccount is null) and (:old.destaccount is not null)) or
  ((new$destaccount is not null) and (:old.destaccount is null)) or
  ((new$destaccount <> :old.destaccount ) and (:old.destaccount is not null) and (new$destaccount is not null))
  )
  or (    (:old.reestr_ref is null)
  and (new$reestr_ref is not null)
  )
  or (    (:old.reestr_ref is not null)
  and (new$reestr_ref is null)
  )
  or (:old.reestr_ref <> new$reestr_ref)
  )
  )
  )
  then /*      NULL */
    reestrAccepted1$ := 0;  /*   IB 4.2 */

  else
    BEGIN
      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id=new$REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrUpdate');
    END IF;
    BEGIN

      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id=:old.REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrUpdate');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_6 (TR_FACIALFINCAPTION_BU_6)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (:old.ProgIndex in(63,68,70)) then /*    */
    SELECT COUNT(id ) INTO CNT$1
    from paydocexchange where ((paydocref=:old.id)and(status<>0)and(TypeInf BETWEEN 0 and 10)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      if(/* (new.DOCNUMBER<>old.DOCNUMBER) or ((new.DOCNUMBER is NULL)and(not old.DOCNUMBER is NULL)) or ((old.DOCNUMBER is NULL)and(not new.DOCNUMBER is NULL)) or*/
      (new$SOURCEDOCNUM<>:old.SOURCEDOCNUM) or ((new$SOURCEDOCNUM is NULL)and(not :old.SOURCEDOCNUM is NULL)) or ((:old.SOURCEDOCNUM is NULL)and(not new$SOURCEDOCNUM is NULL)) or
      (new$PAYDATE<>:old.PAYDATE) or ((new$PAYDATE is NULL)and(not :old.PAYDATE is NULL)) or ((:old.PAYDATE is NULL)and(not new$PAYDATE is NULL))or
      /* (new.DOCUMENTDATE<>old.DOCUMENTDATE) or ((new.DOCUMENTDATE is NULL)and(not old.DOCUMENTDATE is NULL)) or ((old.DOCUMENTDATE is NULL)and(not new.DOCUMENTDATE is NULL))or*/
      (new$REESTRDATE<>:old.REESTRDATE) or ((new$REESTRDATE is NULL)and(not :old.REESTRDATE is NULL)) or ((:old.REESTRDATE is NULL)and(not new$REESTRDATE is NULL))or
      (((new$credit - :old.credit)>0.001)or((new$credit - :old.credit)<-0.001)) or
      (new$SOURCEACCOUNT<>:old.SOURCEACCOUNT) or
      (new$DESTACCOUNT<>:old.DESTACCOUNT) or
      (new$PAYTYPECLS<>:old.PAYTYPECLS) or
      (new$NOTE<>:old.NOTE) or  ((new$NOTE is NULL)and(not :old.NOTE is NULL)) or ((:old.NOTE is NULL)and(not new$NOTE is NULL))or
      (new$PAYPRIORITY<>:old.PAYPRIORITY) or ((new$PAYPRIORITY is NULL)and(not :old.PAYPRIORITY is NULL)) or ((:old.PAYPRIORITY is NULL)and(not new$PAYPRIORITY is NULL))or
      (new$REESTR_REF<>:old.REESTR_REF) or ((new$REESTR_REF is NULL)and(not :old.REESTR_REF is NULL)) or ((:old.REESTR_REF is NULL)and(not new$REESTR_REF is NULL))or
      (new$NDS<>:old.NDS) or ((new$NDS is NULL)and(not :old.NDS is NULL)) or ((:old.NDS is NULL)and(not new$NDS is NULL))or
      (new$TAXNOTE<>:old.TAXNOTE) or ((new$TAXNOTE is NULL)and(not :old.TAXNOTE is NULL)) or ((:old.TAXNOTE is NULL)and(not new$TAXNOTE is NULL)) )then
        RaiseException('ex_CannotChangeSended');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_FACIALFINCAPTION_BU_10)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if (new$IntegratedDocRef is not null) then
    /*           ,       */
    /*    */
    if (((new$AcceptDate = :old.AcceptDate)or((new$AcceptDate is null)and(:old.AcceptDate is null)))
    and((new$Reject_CLS = :old.Reject_CLS)or((new$Reject_CLS is null)and(:old.Reject_CLS is null)))
    and((new$RejectCause = :old.RejectCause)or((new$RejectCause is null)and(:old.RejectCause is null)))
    and((new$TREASUARYDOCSTATECLS = :old.TREASUARYDOCSTATECLS)or((new$TREASUARYDOCSTATECLS is null)and(:old.TREASUARYDOCSTATECLS is null)))
    and((new$DOCSTATEREF = :old.DOCSTATEREF)or((new$DOCSTATEREF is null)and(:old.DOCSTATEREF is null)))
    and((new$REESTR_REF = :old.REESTR_REF)or((new$REESTR_REF is NULL)and(:old.REESTR_REF is NULL)))
    and(new$SOURCEACCOUNT = :old.SOURCEACCOUNT)
    and(new$DESTACCOUNT = :old.DESTACCOUNT)
    ) then
      new$AcceptDate := :old.AcceptDate;
          
    Else
      BEGIN
        select
        fc.AcceptDate, fc.Reject_CLS, fc.RejectCause, fc.TREASUARYDOCSTATECLS, fc.DOCSTATEREF,
        fc.REESTR_REF,fc.SOURCEACCOUNT, fc.DESTACCOUNT
        into
        ParentAcceptDate$, ParentReject_CLS$, ParentRejectCause$, ParentTREASUARYDOCSTATECLS$,
        ParentDOCSTATEREF$,ParentREESTR_REF$,ParentSOURCEACCOUNT$,ParentDESTACCOUNT$       from
        FacialFinCaption fc
        where
        (fc.id = new$IntegratedDocRef)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (((new$AcceptDate = ParentAcceptDate$)or((new$AcceptDate is null)and(ParentAcceptDate$ is null)))
      and((new$Reject_CLS = ParentReject_CLS$)or((new$Reject_CLS is null)and(ParentReject_CLS$ is null)))
      and((new$RejectCause = ParentRejectCause$)or((new$RejectCause is null)and(ParentRejectCause$ is null)))
      and((new$TREASUARYDOCSTATECLS = ParentTREASUARYDOCSTATECLS$)or((new$TREASUARYDOCSTATECLS is null)and(ParentTREASUARYDOCSTATECLS$ is null)))
      and((new$DOCSTATEREF = ParentDOCSTATEREF$)or((new$DOCSTATEREF is null)and(ParentDOCSTATEREF$ is null)))
      and((new$REESTR_REF = ParentREESTR_REF$)or((new$REESTR_REF is NULL)and(ParentREESTR_REF$ is NULL)))
      and(new$SOURCEACCOUNT = ParentSOURCEACCOUNT$)
      and(new$DESTACCOUNT = ParentDESTACCOUNT$)
      ) then
        new$AcceptDate := ParentAcceptDate$;
              
      Else
        RaiseException('EX_CANNOTUPDATECHILDDOC');    
      END IF;  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_32 (TR_FACIALFINCAPTION_BU_32)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$Reestr_ref IS NULL)    /*    select ,  */
                              THEN
      new$SourceDocNum := '';
      new$ReestrDate := NULL;
   ELSIF (    (new$Reestr_ref = :OLD.Reestr_ref)
          AND (new$SourceDocNum = :OLD.SourceDocNum)
          AND (new$ReestrDate = :OLD.ReestrDate)
         ) THEN
/*          */
      NULL;
   ELSE
      BEGIN
         SELECT ffr.ReestrNumber, ffr.ReestrDate
           INTO new$SourceDocNum, new$ReestrDate
           FROM FacialFinReestr ffr
          WHERE ffr.ID = new$Reestr_ref;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            new$SourceDocNum := NULL;
            new$ReestrDate := NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BU_60 (T_FACIALFINCAPTION_BU_60)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF ((new$progindex = 60) AND (new$Credit <> :OLD.Credit)) THEN
      UPDATE FacialFinDetail
         SET Credit = new$Credit
       WHERE (RecordIndex = new$ID);
   END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_FACIALFINCAPTION_BU_70)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --         
   IF (new$SubProgIndex = 416) THEN
      UPDATE Guarantee
         SET AcceptDate = new$AcceptDate
       WHERE SubRecordIndex = new$ID;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (T_FACIALFINCAPTION_BU_100)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*   ,    */
   IF (    (   (:OLD.SourceFacialAcc_CLS <> new$SourceFacialAcc_CLS)
            OR (:OLD.DestFacialAcc_CLS <> new$DestFacialAcc_CLS)
           )
       AND ((new$SubProgIndex <> 1) OR (new$SubProgIndex IS NULL))
      ) THEN
      FOR R$ IN (SELECT ID, SourceFacialAcc_CLS, DestFacialAcc_CLS
                   FROM FacialFinDetail
                  WHERE RecordIndex = new$ID) LOOP
         IF (NOT (new$SourceFacialAcc_CLS = 0)) THEN
            SourceFacialAcc_CLS$ := new$SourceFacialAcc_CLS;
         ELSE
            SourceFacialAcc_CLS$ := R$.SourceFacialAcc_CLS;
         END IF;

         IF (NOT (new$DestFacialAcc_CLS = 0)) THEN
            DestFacialAcc_CLS$ := new$DestFacialAcc_CLS;
         ELSE
            DestFacialAcc_CLS$ := R$.DestFacialAcc_CLS;
         END IF;

         IF (:OLD.SourceFacialAcc_CLS <> new$SourceFacialAcc_CLS) THEN
            UPDATE FacialFinDetail
               SET SourceFacialAcc_CLS = SourceFacialAcc_CLS$,
                   RVersion = -1
             WHERE (ID = R$.ID);
         END IF;

         IF (:OLD.DestFacialAcc_CLS <> new$DestFacialAcc_CLS) THEN
            UPDATE FacialFinDetail
               SET DestFacialAcc_CLS = DestFacialAcc_CLS$,
                   RVersion = -1
             WHERE (ID = R$.ID);
         END IF;
      END LOOP;
   END IF;

   /*    / , 
           .*/
  IF (((NEW$IsBlocked <> :OLD.IsBlocked) OR
      ((NEW$IsBlocked IS NULL) AND (:OLD.IsBlocked IS NOT NULL)) OR
      ((NEW$IsBlocked IS NOT NULL) AND (:OLD.IsBlocked IS NULL))
     ) OR
     ((NEW$BlockedCause <> :OLD.BlockedCause) OR
      ((NEW$BlockedCause IS NULL) AND (:OLD.BlockedCause IS NOT NULL)) OR
      ((NEW$BlockedCause IS NOT NULL) AND (:OLD.BlockedCause IS NULL))
     ) OR
     ((NEW$UnBlockedDate <> :OLD.UnBlockedDate) OR
      ((NEW$UnBlockedDate IS NULL) AND (:OLD.UnBlockedDate IS NOT NULL)) OR
      ((NEW$UnBlockedDate IS NOT NULL) AND (:OLD.UnBlockedDate IS NULL))
     ) OR
     ((NEW$UnBlockedCause <> :OLD.UnBlockedCause) OR
      ((NEW$UnBlockedDate IS NULL) AND (:OLD.UnBlockedCause IS NOT NULL)) OR
      ((NEW$UnBlockedCause IS NOT NULL) AND (:OLD.UnBlockedCause IS NULL))
     )) THEN
     UPDATE FacialFinDetail ffd
     SET ffd.IsBlocked = NEW$IsBlocked, ffd.BlockedCause = NEW$BlockedCause,
         ffd.UnBlockedDate = NEW$UnBlockedDate, ffd.UnBlockedCause = NEW$UnBlockedCause
     WHERE ffd.recordindex = NEW$ID;
  end if;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINCAPTION_BU_210)
-- Create 27.08.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*      */
   IF (new$DOCSTATEREF <> :OLD.DOCSTATEREF) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DOCSTATEREF, new$DOCSTATEREF
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (T_FACIALFINCAPTION_BU_300)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  IsReject1$ := -1;
  if ((:old.Reject_CLS is null)and(new$Reject_CLS is not null)) then
    IsReject1$ := 1;

  else
    if ((:old.Reject_CLS is not null)and(new$Reject_CLS is null)) then
      IsReject1$ := 0;
    END IF;
  END IF;
  if (IsReject1$  <> -1) then
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID = new$ID;
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID in (select d.id from FacialFinDetail d where d.RecordIndex = new$id);

  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINCAPTION_BU_700)
-- Create 17.09.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINCAPTION SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    SOURCEDOCNUM = new$SOURCEDOCNUM,
    PAYDATE = new$PAYDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    REESTRDATE = new$REESTRDATE,
    CREDIT = new$CREDIT,
    SOURCEACCOUNT = new$SOURCEACCOUNT,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    DESTACCOUNT = new$DESTACCOUNT,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    PROGINDEX = new$PROGINDEX,
    ARHIVEDOC = new$ARHIVEDOC,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    PAYTYPECLS = new$PAYTYPECLS,
    NOTE = new$NOTE,
    PERIOD = new$PERIOD,
    PAYPRIORITY = new$PAYPRIORITY,
    TYPEOPERATIONCLS = new$TYPEOPERATIONCLS,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    RECORDINDEX = new$RECORDINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REESTR_REF = new$REESTR_REF,
    REJECT_CLS = new$REJECT_CLS,
    CLIENTBANKNUMBER = new$CLIENTBANKNUMBER,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    TRUSTNUMBER = new$TRUSTNUMBER,
    LINKEDDOCUMENT = new$LINKEDDOCUMENT,
    BNKRECORDID = new$BNKRECORDID,
    SUBPROGINDEX = new$SUBPROGINDEX,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    TREASUARYDOCSTATECLS = new$TREASUARYDOCSTATECLS,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    NDS = new$NDS,
    TAXNOTE = new$TAXNOTE,
    MANAGERBID = new$MANAGERBID,
    BIDNUMBER = new$BIDNUMBER,
    GROUPID = new$GROUPID,
    GROUPSUMMA = new$GROUPSUMMA,
    DOCSTATEREF = new$DOCSTATEREF,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    FAXDOCCOUNT = new$FAXDOCCOUNT,
    STIMATEID = new$STIMATEID,
    INTEGRATEDDOCREF = new$INTEGRATEDDOCREF,
    REQUESTNUMBER = new$REQUESTNUMBER,
    REQUESTDATE = new$REQUESTDATE,
    RVERSION = new$RVERSION,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    ELDOCREF = new$ELDOCREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    CLSTYPE = new$CLSTYPE,
    OPERATIONDIRECTION = new$OPERATIONDIRECTION,
    SOURCETYPE = new$SOURCETYPE,
    DESTTYPE = new$DESTTYPE,
    CARDNUMBER = new$CARDNUMBER,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    CASHIERPERSONALINFO = new$CASHIERPERSONALINFO,
    BIDDATE = new$BIDDATE,
    CARDREF = new$CARDREF,
    SOURCESTOREDPAYMENTPROPS = new$SOURCESTOREDPAYMENTPROPS,
    DESTSTOREDPAYMENTPROPS = new$DESTSTOREDPAYMENTPROPS,
    STOREDPAYMENTNOTE = new$STOREDPAYMENTNOTE,
    DOCCHANGEDATE = new$DOCCHANGEDATE,
    UINCODE = new$UINCODE,
    DOCOSN = new$DOCOSN,
    SIGNERS = new$SIGNERS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    AUTOSANCTION = new$AUTOSANCTION,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_FACIALFINCAPTION_AU_10)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 72) then /*   */
    if (((new$AcceptDate = :old.AcceptDate)or((new$AcceptDate is null)and(:old.AcceptDate is null)))
    and((new$Reject_CLS = :old.Reject_CLS)or((new$Reject_CLS is null)and(:old.Reject_CLS is null)))
    and((new$RejectCause = :old.RejectCause)or((new$RejectCause is null)and(:old.RejectCause is null)))
    and((new$TREASUARYDOCSTATECLS = :old.TREASUARYDOCSTATECLS)or((new$TREASUARYDOCSTATECLS is null)and(:old.TREASUARYDOCSTATECLS is null)))
    and((new$DOCSTATEREF = :old.DOCSTATEREF)or((new$DOCSTATEREF is null)and(:old.DOCSTATEREF is null)))
    and((new$REESTR_REF = :old.REESTR_REF)or((new$REESTR_REF is NULL)and(:old.REESTR_REF is NULL)))
    and(new$SOURCEACCOUNT = :old.SOURCEACCOUNT)
    and(new$DESTACCOUNT = :old.DESTACCOUNT)
    ) then
      Dummy$ := 0;
          
    Else
      /*    ,      */
      update FacialFinCaption set
      AcceptDate = new$AcceptDate,
      Reject_CLS = new$Reject_CLS,
      RejectCause = new$RejectCause,
      TREASUARYDOCSTATECLS = new$TREASUARYDOCSTATECLS,
      DOCSTATEREF = new$DOCSTATEREF,
      REESTR_REF = new$REESTR_REF,
      SOURCEACCOUNT = new$SOURCEACCOUNT,
      DESTACCOUNT = new$DESTACCOUNT
      where
      IntegratedDocRef = new$id;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_300 (TR_FACIALFINCAPTION_AU_300)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*          ,      */
  if ((new$AcceptDate <> :old.AcceptDate)or((new$AcceptDate is not null)and(:old.AcceptDate is null))
  or((new$AcceptDate is null)and(:old.AcceptDate is not null))) then
    update facialfindetail set
    AcceptDate = new$AcceptDate,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;
  if (new$BuhOperationCLS <> :old.BuhOperationCLS)  then
    update facialfindetail set
    BuhOperationCLS = new$BuhOperationCLS,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;
  if ((new$ClsType <> :old.ClsType)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$ClsType = 0) then
      update facialfindetail set
      SourceKD = 0,
      DestKD = 0,
      SourceIFS = 0,
      DestIFS = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 1) then
      update facialfindetail set
      SourceKD = 0,
      DestKD = 0,
      SourceKVSR = 0,
      SourceKFSR = 0,
      SourceKCSR = 0,
      SourceKVR = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 2) then
      update facialfindetail set
      SourceIFS = 0,
      DestIFS = 0,
      SourceKVSR = 0,
      SourceKFSR = 0,
      SourceKCSR = 0,
      SourceKVR = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);

    END IF;
  END IF;
  if ((new$DestClsType <> :old.DestClsType)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$DestClsType = 0) then
      update facialfindetail set
      DestKD = 0,
      DestIFS = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
    END IF;
    if (new$DestClsType = 1) then
      update facialfindetail set
      DestKD = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
    END IF;
    if (new$DestClsType = 2) then
      update facialfindetail set
      DestIFS = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINCAPTION_AU_500)
-- Create 28.04.2005
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (:NEW.ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (23, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
        WHERE (TableID = 23) AND (RecordId = :NEW.ID);
   END IF;

END;
/
ALTER TRIGGER TR_FACIALFINCAPTION_BU_500 ENABLE
/
commit work 
/
ALTER TRIGGER TR_LIMITNOTIFYCAPTION_BU_500 DISABLE
/
ALTER TABLE TB_LIMITNOTIFYCAPTION ADD (
  TempRejectCause VARCHAR2(255)
)
/

CREATE OR REPLACE VIEW LIMITNOTIFYCAPTION (
  ID,
  INPUTDATE,
  ACCEPTDATE,
  FINSOURCE,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  BUDGETREF,
  IMPORTID,
  SENDERINN,
  ANUMBER,
  DFACCOUNT,
  SOURCEFACIALACC,
  REJECT_CLS,
  REJECTCAUSE,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  DOCUMENTSTATE,
  USERSVISA,
  ACCEPTSUMMA,
  PLANDOCTYPE,
  DOCSTATEREF,
  RVERSION,
  STIMATEID,
  FACIALACCCLS,
  BIDNUMBER,
  FAXDOCCOUNT,
  LASTEXTRCHANGE,
  AMONTH,
  AYEAR,
  TEMPREJECTCAUSE)
AS
  SELECT
    ID,
    INPUTDATE,
    ACCEPTDATE,
    FINSOURCE,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    IMPORTID,
    SENDERINN,
    ANUMBER,
    DFACCOUNT,
    SOURCEFACIALACC,
    REJECT_CLS,
    REJECTCAUSE,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DOCUMENTSTATE,
    USERSVISA,
    ACCEPTSUMMA,
    PLANDOCTYPE,
    DOCSTATEREF,
    RVERSION,
    STIMATEID,
    FACIALACCCLS,
    BIDNUMBER,
    FAXDOCCOUNT,
    LASTEXTRCHANGE,
    AMONTH,
    AYEAR,
    TEMPREJECTCAUSE
  FROM TB_LIMITNOTIFYCAPTION
/

CREATE OR REPLACE TRIGGER TR_LIMITNOTIFYCAPTION_ID
  INSTEAD OF DELETE
  ON LIMITNOTIFYCAPTION
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_LIMITNOTIFYCAPTION_BD)
-- Last update 14.07.2005
-- - - - - - - - - - - - -

   DELETE FROM LimitFinDetail
         WHERE (RecordIndex = :OLD.ID);

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_LIMITNOTIFYCAPTION
  WHERE ID = :OLD.ID
           AND (   RVersion = :OLD.RVersion
                OR RVersion IS NULL AND :OLD.RVersion IS NULL
               );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AD_200 (TR_LIMITNOTIFYCAPTION_AD_200)
-- Create 27.08.2004
-- Last update 14.07.2005
-- - - - - - - - - - - - -

   /*      */
   DELETE FROM StateJumpHistory
         WHERE DocID = :OLD.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_LIMITNOTIFYCAPTION_AD_500)
-- Last update 14.07.2005
-- - - - - - - - - - - - -

   INSERT INTO DelRecIndexes
               (TableID, RecordId, DeleteDate
               )
        VALUES (75, :OLD.ID, SYSDATE
               );

END;
/

CREATE OR REPLACE TRIGGER TR_LIMITNOTIFYCAPTION_II
  INSTEAD OF INSERT
  ON LIMITNOTIFYCAPTION
  FOR EACH ROW
DECLARE
  new$ID LIMITNOTIFYCAPTION.ID%TYPE := :NEW.ID;
  new$INPUTDATE LIMITNOTIFYCAPTION.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$ACCEPTDATE LIMITNOTIFYCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$FINSOURCE LIMITNOTIFYCAPTION.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$CREATERUSER LIMITNOTIFYCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE LIMITNOTIFYCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE LIMITNOTIFYCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER LIMITNOTIFYCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF LIMITNOTIFYCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$IMPORTID LIMITNOTIFYCAPTION.IMPORTID%TYPE := :NEW.IMPORTID;
  new$SENDERINN LIMITNOTIFYCAPTION.SENDERINN%TYPE := :NEW.SENDERINN;
  new$ANUMBER LIMITNOTIFYCAPTION.ANUMBER%TYPE := :NEW.ANUMBER;
  new$DFACCOUNT LIMITNOTIFYCAPTION.DFACCOUNT%TYPE := :NEW.DFACCOUNT;
  new$SOURCEFACIALACC LIMITNOTIFYCAPTION.SOURCEFACIALACC%TYPE := :NEW.SOURCEFACIALACC;
  new$REJECT_CLS LIMITNOTIFYCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE LIMITNOTIFYCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CRYPTOSTATUS LIMITNOTIFYCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID LIMITNOTIFYCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID LIMITNOTIFYCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCUMENTSTATE LIMITNOTIFYCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA LIMITNOTIFYCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$ACCEPTSUMMA LIMITNOTIFYCAPTION.ACCEPTSUMMA%TYPE := :NEW.ACCEPTSUMMA;
  new$PLANDOCTYPE LIMITNOTIFYCAPTION.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$DOCSTATEREF LIMITNOTIFYCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION LIMITNOTIFYCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$STIMATEID LIMITNOTIFYCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$FACIALACCCLS LIMITNOTIFYCAPTION.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$BIDNUMBER LIMITNOTIFYCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT LIMITNOTIFYCAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$LASTEXTRCHANGE LIMITNOTIFYCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$AMONTH LIMITNOTIFYCAPTION.AMONTH%TYPE := :NEW.AMONTH;
  new$AYEAR LIMITNOTIFYCAPTION.AYEAR%TYPE := :NEW.AYEAR;
  new$TEMPREJECTCAUSE LIMITNOTIFYCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  UseFax$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_LIMITNOTIFYCAPTION_BI)
-- Last update 07.12.2005
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   IF (new$AcceptSumma IS NULL) THEN new$AcceptSumma := 0; END IF;
   IF (new$InputDate IS NULL) THEN new$InputDate := 0; END IF;
   IF (new$FinSource IS NULL) THEN new$FinSource := 0; END IF;
   IF (new$SourceFacialAcc IS NULL) THEN new$SourceFacialAcc := 0; END IF;
   IF (new$FacialAccCls IS NULL) THEN new$FacialAccCls := 0; END IF;
   IF (new$PlanDocType IS NULL) THEN new$PlanDocType := 0; END IF;

   /*  .  ,     */
   IF ((NEW$BudgetRef IS NULL) OR (NEW$BudgetRef = 0)) THEN
      BEGIN
         SELECT fa.BudgetRef
           INTO NEW$BudgetRef
           FROM FacialAcc_Cls fa
          WHERE fa.ID = NEW$SourceFacialAcc;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            NEW$BudgetRef := NULL;
      END;
   END IF;

   /*  ,    */
   IF ((NEW$BudgetRef IS NULL) OR (NEW$BudgetRef = 0)) THEN
      GetIntConst (-1, 3, NEW$BudgetRef);
   END IF;

-- - - - - - - - - - - - -
-- BI_430 (TR_LIMITNOTIFYCAPTION_BI_430)
-- Create 18.09.2006
-- - - - - - - - - - - - -

    IF (NEW$SenderID IS NOT NULL) THEN
        /*        */
        GetIntConst(30, 19, UseFax$);
        IF ((NEW$BidNumber IS NULL) AND (UseFax$ = 1)) THEN
          NEW$BidNumber := NEW$ANumber;
        END IF;
        NEW$FaxDocCount := 0;
    END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_LIMITNOTIFYCAPTION_BI_500)
-- Last update 15.07.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_LIMITNOTIFYCAPTION (
    ID,
    INPUTDATE,
    ACCEPTDATE,
    FINSOURCE,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    IMPORTID,
    SENDERINN,
    ANUMBER,
    DFACCOUNT,
    SOURCEFACIALACC,
    REJECT_CLS,
    REJECTCAUSE,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DOCUMENTSTATE,
    USERSVISA,
    ACCEPTSUMMA,
    PLANDOCTYPE,
    DOCSTATEREF,
    RVERSION,
    STIMATEID,
    FACIALACCCLS,
    BIDNUMBER,
    FAXDOCCOUNT,
    LASTEXTRCHANGE,
    AMONTH,
    AYEAR,
    TEMPREJECTCAUSE
  ) VALUES (
    new$ID,
    new$INPUTDATE,
    new$ACCEPTDATE,
    new$FINSOURCE,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$IMPORTID,
    new$SENDERINN,
    new$ANUMBER,
    new$DFACCOUNT,
    new$SOURCEFACIALACC,
    new$REJECT_CLS,
    new$REJECTCAUSE,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$DOCUMENTSTATE,
    new$USERSVISA,
    new$ACCEPTSUMMA,
    new$PLANDOCTYPE,
    new$DOCSTATEREF,
    new$RVERSION,
    new$STIMATEID,
    new$FACIALACCCLS,
    new$BIDNUMBER,
    new$FAXDOCCOUNT,
    new$LASTEXTRCHANGE,
    new$AMONTH,
    new$AYEAR,
    new$TEMPREJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_LIMITNOTIFYCAPTION_AI_500)
-- Last update 15.07.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 75) AND (RecordId = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_LIMITNOTIFYCAPTION_IU
  INSTEAD OF UPDATE
  ON LIMITNOTIFYCAPTION
  FOR EACH ROW
DECLARE
  new$ID LIMITNOTIFYCAPTION.ID%TYPE := :NEW.ID;
  new$INPUTDATE LIMITNOTIFYCAPTION.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$ACCEPTDATE LIMITNOTIFYCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$FINSOURCE LIMITNOTIFYCAPTION.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$CREATERUSER LIMITNOTIFYCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE LIMITNOTIFYCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE LIMITNOTIFYCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER LIMITNOTIFYCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF LIMITNOTIFYCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$IMPORTID LIMITNOTIFYCAPTION.IMPORTID%TYPE := :NEW.IMPORTID;
  new$SENDERINN LIMITNOTIFYCAPTION.SENDERINN%TYPE := :NEW.SENDERINN;
  new$ANUMBER LIMITNOTIFYCAPTION.ANUMBER%TYPE := :NEW.ANUMBER;
  new$DFACCOUNT LIMITNOTIFYCAPTION.DFACCOUNT%TYPE := :NEW.DFACCOUNT;
  new$SOURCEFACIALACC LIMITNOTIFYCAPTION.SOURCEFACIALACC%TYPE := :NEW.SOURCEFACIALACC;
  new$REJECT_CLS LIMITNOTIFYCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE LIMITNOTIFYCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CRYPTOSTATUS LIMITNOTIFYCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID LIMITNOTIFYCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID LIMITNOTIFYCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCUMENTSTATE LIMITNOTIFYCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA LIMITNOTIFYCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$ACCEPTSUMMA LIMITNOTIFYCAPTION.ACCEPTSUMMA%TYPE := :NEW.ACCEPTSUMMA;
  new$PLANDOCTYPE LIMITNOTIFYCAPTION.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$DOCSTATEREF LIMITNOTIFYCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION LIMITNOTIFYCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$STIMATEID LIMITNOTIFYCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$FACIALACCCLS LIMITNOTIFYCAPTION.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$BIDNUMBER LIMITNOTIFYCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT LIMITNOTIFYCAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$LASTEXTRCHANGE LIMITNOTIFYCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$AMONTH LIMITNOTIFYCAPTION.AMONTH%TYPE := :NEW.AMONTH;
  new$AYEAR LIMITNOTIFYCAPTION.AYEAR%TYPE := :NEW.AYEAR;
  new$TEMPREJECTCAUSE LIMITNOTIFYCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  cnt$ Number(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_LIMITNOTIFYCAPTION_BU)
-- Last update 07.12.05
-- - - - - - - - - - - - -

   IF (new$acceptsumma IS NULL) THEN new$acceptsumma := 0; END IF;
   IF (new$InputDate IS NULL) THEN new$InputDate := 0; END IF;
   IF (new$FinSource IS NULL) THEN new$FinSource := 0; END IF;
   IF (new$SourceFacialAcc IS NULL) THEN new$SourceFacialAcc := 0; END IF;
   IF (new$FacialAccCls IS NULL) THEN new$FacialAccCls := 0; END IF;
   IF (new$PlanDocType IS NULL) THEN new$PlanDocType := 0; END IF;

  /*   */
  IF (:NEW.BudgetRef <> :OLD.BudgetRef) THEN
   IF ( NOT((:NEW.BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL)) ) THEN
     select count(id) into cnt$
     from LimitFinDetail lfd where lfd.recordindex = :NEW.ID and ROWNUM=1;
     IF (cnt$ > 0) THEN
       RaiseException('Ex_CantModufyBudget');
     END IF;
   END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_LIMITNOTIFYCAPTION_BU_200)
-- Create 27.08.2004
-- - - - - - - - - - - - -

   /*     */
   IF (:OLD.DocStateRef <> new$DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_LIMITNOTIFYCAPTION_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_LIMITNOTIFYCAPTION SET
    ID = new$ID,
    INPUTDATE = new$INPUTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    FINSOURCE = new$FINSOURCE,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    IMPORTID = new$IMPORTID,
    SENDERINN = new$SENDERINN,
    ANUMBER = new$ANUMBER,
    DFACCOUNT = new$DFACCOUNT,
    SOURCEFACIALACC = new$SOURCEFACIALACC,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    ACCEPTSUMMA = new$ACCEPTSUMMA,
    PLANDOCTYPE = new$PLANDOCTYPE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    STIMATEID = new$STIMATEID,
    FACIALACCCLS = new$FACIALACCCLS,
    BIDNUMBER = new$BIDNUMBER,
    FAXDOCCOUNT = new$FAXDOCCOUNT,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    AMONTH = new$AMONTH,
    AYEAR = new$AYEAR,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_LIMITNOTIFYCAPTION_AU_10)
-- Create 07.09.2005
-- - - - - - - - - - - - -

   UPDATE LimitFinDetail lfd
      SET lfd.AcceptDate = new$AcceptDate,
          lfd.AMONTH = new$AMonth,
          lfd.AYEAR = new$AYear,
          lfd.FinSource = new$FinSource,
          lfd.SourceFacialAcc = new$SourceFacialAcc,
          lfd.DFAccount = new$DFAccount,
          lfd.RVersion = -1
    WHERE (lfd.RecordIndex = new$Id);

   /*    ,    
         */
   IF (NOT (new$reject_cls IS NULL) AND (:OLD.reject_cls IS NULL)) THEN
      UPDATE limitfindetail lfd
         SET lfd.requestflag = 1,
             lfd.RVersion = -1
       WHERE (lfd.RecordIndex = new$Id);
   END IF;

   /* */
   IF ((new$reject_cls IS NULL) AND NOT (:OLD.reject_cls IS NULL)) THEN
      UPDATE limitfindetail lfd
         SET lfd.requestflag = 3,
             lfd.RVersion = -1
       WHERE (lfd.RecordIndex = new$Id);
   END IF;

END;
/
update LIMITNOTIFYCAPTION set
  TempRejectCause = REJECTCAUSE
/
commit work 
/
ALTER TABLE TB_LIMITNOTIFYCAPTION DROP (REJECTCAUSE)
/

CREATE OR REPLACE VIEW LIMITNOTIFYCAPTION (
  ID,
  INPUTDATE,
  ACCEPTDATE,
  FINSOURCE,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  BUDGETREF,
  IMPORTID,
  SENDERINN,
  ANUMBER,
  DFACCOUNT,
  SOURCEFACIALACC,
  REJECT_CLS,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  DOCUMENTSTATE,
  USERSVISA,
  ACCEPTSUMMA,
  PLANDOCTYPE,
  DOCSTATEREF,
  RVERSION,
  STIMATEID,
  FACIALACCCLS,
  BIDNUMBER,
  FAXDOCCOUNT,
  LASTEXTRCHANGE,
  AMONTH,
  AYEAR,
  TEMPREJECTCAUSE)
AS
  SELECT
    ID,
    INPUTDATE,
    ACCEPTDATE,
    FINSOURCE,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    IMPORTID,
    SENDERINN,
    ANUMBER,
    DFACCOUNT,
    SOURCEFACIALACC,
    REJECT_CLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DOCUMENTSTATE,
    USERSVISA,
    ACCEPTSUMMA,
    PLANDOCTYPE,
    DOCSTATEREF,
    RVERSION,
    STIMATEID,
    FACIALACCCLS,
    BIDNUMBER,
    FAXDOCCOUNT,
    LASTEXTRCHANGE,
    AMONTH,
    AYEAR,
    TEMPREJECTCAUSE
  FROM TB_LIMITNOTIFYCAPTION
/

CREATE OR REPLACE TRIGGER TR_LIMITNOTIFYCAPTION_ID
  INSTEAD OF DELETE
  ON LIMITNOTIFYCAPTION
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_LIMITNOTIFYCAPTION_BD)
-- Last update 14.07.2005
-- - - - - - - - - - - - -

   DELETE FROM LimitFinDetail
         WHERE (RecordIndex = :OLD.ID);

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_LIMITNOTIFYCAPTION
  WHERE ID = :OLD.ID
           AND (   RVersion = :OLD.RVersion
                OR RVersion IS NULL AND :OLD.RVersion IS NULL
               );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AD_200 (TR_LIMITNOTIFYCAPTION_AD_200)
-- Create 27.08.2004
-- Last update 14.07.2005
-- - - - - - - - - - - - -

   /*      */
   DELETE FROM StateJumpHistory
         WHERE DocID = :OLD.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_LIMITNOTIFYCAPTION_AD_500)
-- Last update 14.07.2005
-- - - - - - - - - - - - -

   INSERT INTO DelRecIndexes
               (TableID, RecordId, DeleteDate
               )
        VALUES (75, :OLD.ID, SYSDATE
               );

END;
/

CREATE OR REPLACE TRIGGER TR_LIMITNOTIFYCAPTION_II
  INSTEAD OF INSERT
  ON LIMITNOTIFYCAPTION
  FOR EACH ROW
DECLARE
  new$ID LIMITNOTIFYCAPTION.ID%TYPE := :NEW.ID;
  new$INPUTDATE LIMITNOTIFYCAPTION.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$ACCEPTDATE LIMITNOTIFYCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$FINSOURCE LIMITNOTIFYCAPTION.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$CREATERUSER LIMITNOTIFYCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE LIMITNOTIFYCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE LIMITNOTIFYCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER LIMITNOTIFYCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF LIMITNOTIFYCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$IMPORTID LIMITNOTIFYCAPTION.IMPORTID%TYPE := :NEW.IMPORTID;
  new$SENDERINN LIMITNOTIFYCAPTION.SENDERINN%TYPE := :NEW.SENDERINN;
  new$ANUMBER LIMITNOTIFYCAPTION.ANUMBER%TYPE := :NEW.ANUMBER;
  new$DFACCOUNT LIMITNOTIFYCAPTION.DFACCOUNT%TYPE := :NEW.DFACCOUNT;
  new$SOURCEFACIALACC LIMITNOTIFYCAPTION.SOURCEFACIALACC%TYPE := :NEW.SOURCEFACIALACC;
  new$REJECT_CLS LIMITNOTIFYCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$CRYPTOSTATUS LIMITNOTIFYCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID LIMITNOTIFYCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID LIMITNOTIFYCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCUMENTSTATE LIMITNOTIFYCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA LIMITNOTIFYCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$ACCEPTSUMMA LIMITNOTIFYCAPTION.ACCEPTSUMMA%TYPE := :NEW.ACCEPTSUMMA;
  new$PLANDOCTYPE LIMITNOTIFYCAPTION.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$DOCSTATEREF LIMITNOTIFYCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION LIMITNOTIFYCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$STIMATEID LIMITNOTIFYCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$FACIALACCCLS LIMITNOTIFYCAPTION.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$BIDNUMBER LIMITNOTIFYCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT LIMITNOTIFYCAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$LASTEXTRCHANGE LIMITNOTIFYCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$AMONTH LIMITNOTIFYCAPTION.AMONTH%TYPE := :NEW.AMONTH;
  new$AYEAR LIMITNOTIFYCAPTION.AYEAR%TYPE := :NEW.AYEAR;
  new$TEMPREJECTCAUSE LIMITNOTIFYCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  UseFax$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_LIMITNOTIFYCAPTION_BI)
-- Last update 07.12.2005
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   IF (new$AcceptSumma IS NULL) THEN new$AcceptSumma := 0; END IF;
   IF (new$InputDate IS NULL) THEN new$InputDate := 0; END IF;
   IF (new$FinSource IS NULL) THEN new$FinSource := 0; END IF;
   IF (new$SourceFacialAcc IS NULL) THEN new$SourceFacialAcc := 0; END IF;
   IF (new$FacialAccCls IS NULL) THEN new$FacialAccCls := 0; END IF;
   IF (new$PlanDocType IS NULL) THEN new$PlanDocType := 0; END IF;

   /*  .  ,     */
   IF ((NEW$BudgetRef IS NULL) OR (NEW$BudgetRef = 0)) THEN
      BEGIN
         SELECT fa.BudgetRef
           INTO NEW$BudgetRef
           FROM FacialAcc_Cls fa
          WHERE fa.ID = NEW$SourceFacialAcc;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            NEW$BudgetRef := NULL;
      END;
   END IF;

   /*  ,    */
   IF ((NEW$BudgetRef IS NULL) OR (NEW$BudgetRef = 0)) THEN
      GetIntConst (-1, 3, NEW$BudgetRef);
   END IF;

-- - - - - - - - - - - - -
-- BI_430 (TR_LIMITNOTIFYCAPTION_BI_430)
-- Create 18.09.2006
-- - - - - - - - - - - - -

    IF (NEW$SenderID IS NOT NULL) THEN
        /*        */
        GetIntConst(30, 19, UseFax$);
        IF ((NEW$BidNumber IS NULL) AND (UseFax$ = 1)) THEN
          NEW$BidNumber := NEW$ANumber;
        END IF;
        NEW$FaxDocCount := 0;
    END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_LIMITNOTIFYCAPTION_BI_500)
-- Last update 15.07.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_LIMITNOTIFYCAPTION (
    ID,
    INPUTDATE,
    ACCEPTDATE,
    FINSOURCE,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    IMPORTID,
    SENDERINN,
    ANUMBER,
    DFACCOUNT,
    SOURCEFACIALACC,
    REJECT_CLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DOCUMENTSTATE,
    USERSVISA,
    ACCEPTSUMMA,
    PLANDOCTYPE,
    DOCSTATEREF,
    RVERSION,
    STIMATEID,
    FACIALACCCLS,
    BIDNUMBER,
    FAXDOCCOUNT,
    LASTEXTRCHANGE,
    AMONTH,
    AYEAR,
    TEMPREJECTCAUSE
  ) VALUES (
    new$ID,
    new$INPUTDATE,
    new$ACCEPTDATE,
    new$FINSOURCE,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$IMPORTID,
    new$SENDERINN,
    new$ANUMBER,
    new$DFACCOUNT,
    new$SOURCEFACIALACC,
    new$REJECT_CLS,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$DOCUMENTSTATE,
    new$USERSVISA,
    new$ACCEPTSUMMA,
    new$PLANDOCTYPE,
    new$DOCSTATEREF,
    new$RVERSION,
    new$STIMATEID,
    new$FACIALACCCLS,
    new$BIDNUMBER,
    new$FAXDOCCOUNT,
    new$LASTEXTRCHANGE,
    new$AMONTH,
    new$AYEAR,
    new$TEMPREJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_LIMITNOTIFYCAPTION_AI_500)
-- Last update 15.07.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 75) AND (RecordId = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_LIMITNOTIFYCAPTION_IU
  INSTEAD OF UPDATE
  ON LIMITNOTIFYCAPTION
  FOR EACH ROW
DECLARE
  new$ID LIMITNOTIFYCAPTION.ID%TYPE := :NEW.ID;
  new$INPUTDATE LIMITNOTIFYCAPTION.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$ACCEPTDATE LIMITNOTIFYCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$FINSOURCE LIMITNOTIFYCAPTION.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$CREATERUSER LIMITNOTIFYCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE LIMITNOTIFYCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE LIMITNOTIFYCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER LIMITNOTIFYCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF LIMITNOTIFYCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$IMPORTID LIMITNOTIFYCAPTION.IMPORTID%TYPE := :NEW.IMPORTID;
  new$SENDERINN LIMITNOTIFYCAPTION.SENDERINN%TYPE := :NEW.SENDERINN;
  new$ANUMBER LIMITNOTIFYCAPTION.ANUMBER%TYPE := :NEW.ANUMBER;
  new$DFACCOUNT LIMITNOTIFYCAPTION.DFACCOUNT%TYPE := :NEW.DFACCOUNT;
  new$SOURCEFACIALACC LIMITNOTIFYCAPTION.SOURCEFACIALACC%TYPE := :NEW.SOURCEFACIALACC;
  new$REJECT_CLS LIMITNOTIFYCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$CRYPTOSTATUS LIMITNOTIFYCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID LIMITNOTIFYCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID LIMITNOTIFYCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCUMENTSTATE LIMITNOTIFYCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA LIMITNOTIFYCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$ACCEPTSUMMA LIMITNOTIFYCAPTION.ACCEPTSUMMA%TYPE := :NEW.ACCEPTSUMMA;
  new$PLANDOCTYPE LIMITNOTIFYCAPTION.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$DOCSTATEREF LIMITNOTIFYCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION LIMITNOTIFYCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$STIMATEID LIMITNOTIFYCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$FACIALACCCLS LIMITNOTIFYCAPTION.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$BIDNUMBER LIMITNOTIFYCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT LIMITNOTIFYCAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$LASTEXTRCHANGE LIMITNOTIFYCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$AMONTH LIMITNOTIFYCAPTION.AMONTH%TYPE := :NEW.AMONTH;
  new$AYEAR LIMITNOTIFYCAPTION.AYEAR%TYPE := :NEW.AYEAR;
  new$TEMPREJECTCAUSE LIMITNOTIFYCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  cnt$ Number(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_LIMITNOTIFYCAPTION_BU)
-- Last update 07.12.05
-- - - - - - - - - - - - -

   IF (new$acceptsumma IS NULL) THEN new$acceptsumma := 0; END IF;
   IF (new$InputDate IS NULL) THEN new$InputDate := 0; END IF;
   IF (new$FinSource IS NULL) THEN new$FinSource := 0; END IF;
   IF (new$SourceFacialAcc IS NULL) THEN new$SourceFacialAcc := 0; END IF;
   IF (new$FacialAccCls IS NULL) THEN new$FacialAccCls := 0; END IF;
   IF (new$PlanDocType IS NULL) THEN new$PlanDocType := 0; END IF;

  /*   */
  IF (:NEW.BudgetRef <> :OLD.BudgetRef) THEN
   IF ( NOT((:NEW.BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL)) ) THEN
     select count(id) into cnt$
     from LimitFinDetail lfd where lfd.recordindex = :NEW.ID and ROWNUM=1;
     IF (cnt$ > 0) THEN
       RaiseException('Ex_CantModufyBudget');
     END IF;
   END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_LIMITNOTIFYCAPTION_BU_200)
-- Create 27.08.2004
-- - - - - - - - - - - - -

   /*     */
   IF (:OLD.DocStateRef <> new$DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_LIMITNOTIFYCAPTION_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_LIMITNOTIFYCAPTION SET
    ID = new$ID,
    INPUTDATE = new$INPUTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    FINSOURCE = new$FINSOURCE,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    IMPORTID = new$IMPORTID,
    SENDERINN = new$SENDERINN,
    ANUMBER = new$ANUMBER,
    DFACCOUNT = new$DFACCOUNT,
    SOURCEFACIALACC = new$SOURCEFACIALACC,
    REJECT_CLS = new$REJECT_CLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    ACCEPTSUMMA = new$ACCEPTSUMMA,
    PLANDOCTYPE = new$PLANDOCTYPE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    STIMATEID = new$STIMATEID,
    FACIALACCCLS = new$FACIALACCCLS,
    BIDNUMBER = new$BIDNUMBER,
    FAXDOCCOUNT = new$FAXDOCCOUNT,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    AMONTH = new$AMONTH,
    AYEAR = new$AYEAR,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_LIMITNOTIFYCAPTION_AU_10)
-- Create 07.09.2005
-- - - - - - - - - - - - -

   UPDATE LimitFinDetail lfd
      SET lfd.AcceptDate = new$AcceptDate,
          lfd.AMONTH = new$AMonth,
          lfd.AYEAR = new$AYear,
          lfd.FinSource = new$FinSource,
          lfd.SourceFacialAcc = new$SourceFacialAcc,
          lfd.DFAccount = new$DFAccount,
          lfd.RVersion = -1
    WHERE (lfd.RecordIndex = new$Id);

   /*    ,    
         */
   IF (NOT (new$reject_cls IS NULL) AND (:OLD.reject_cls IS NULL)) THEN
      UPDATE limitfindetail lfd
         SET lfd.requestflag = 1,
             lfd.RVersion = -1
       WHERE (lfd.RecordIndex = new$Id);
   END IF;

   /* */
   IF ((new$reject_cls IS NULL) AND NOT (:OLD.reject_cls IS NULL)) THEN
      UPDATE limitfindetail lfd
         SET lfd.requestflag = 3,
             lfd.RVersion = -1
       WHERE (lfd.RecordIndex = new$Id);
   END IF;

END;
/
ALTER TABLE TB_LIMITNOTIFYCAPTION ADD (
  REJECTCAUSE VARCHAR2(1000)
)
/

CREATE OR REPLACE VIEW LIMITNOTIFYCAPTION (
  ID,
  INPUTDATE,
  ACCEPTDATE,
  FINSOURCE,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  BUDGETREF,
  IMPORTID,
  SENDERINN,
  ANUMBER,
  DFACCOUNT,
  SOURCEFACIALACC,
  REJECT_CLS,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  DOCUMENTSTATE,
  USERSVISA,
  ACCEPTSUMMA,
  PLANDOCTYPE,
  DOCSTATEREF,
  RVERSION,
  STIMATEID,
  FACIALACCCLS,
  BIDNUMBER,
  FAXDOCCOUNT,
  LASTEXTRCHANGE,
  AMONTH,
  AYEAR,
  TEMPREJECTCAUSE,
  REJECTCAUSE)
AS
  SELECT
    ID,
    INPUTDATE,
    ACCEPTDATE,
    FINSOURCE,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    IMPORTID,
    SENDERINN,
    ANUMBER,
    DFACCOUNT,
    SOURCEFACIALACC,
    REJECT_CLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DOCUMENTSTATE,
    USERSVISA,
    ACCEPTSUMMA,
    PLANDOCTYPE,
    DOCSTATEREF,
    RVERSION,
    STIMATEID,
    FACIALACCCLS,
    BIDNUMBER,
    FAXDOCCOUNT,
    LASTEXTRCHANGE,
    AMONTH,
    AYEAR,
    TEMPREJECTCAUSE,
    REJECTCAUSE
  FROM TB_LIMITNOTIFYCAPTION
/

CREATE OR REPLACE TRIGGER TR_LIMITNOTIFYCAPTION_ID
  INSTEAD OF DELETE
  ON LIMITNOTIFYCAPTION
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_LIMITNOTIFYCAPTION_BD)
-- Last update 14.07.2005
-- - - - - - - - - - - - -

   DELETE FROM LimitFinDetail
         WHERE (RecordIndex = :OLD.ID);

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_LIMITNOTIFYCAPTION
  WHERE ID = :OLD.ID
           AND (   RVersion = :OLD.RVersion
                OR RVersion IS NULL AND :OLD.RVersion IS NULL
               );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AD_200 (TR_LIMITNOTIFYCAPTION_AD_200)
-- Create 27.08.2004
-- Last update 14.07.2005
-- - - - - - - - - - - - -

   /*      */
   DELETE FROM StateJumpHistory
         WHERE DocID = :OLD.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_LIMITNOTIFYCAPTION_AD_500)
-- Last update 14.07.2005
-- - - - - - - - - - - - -

   INSERT INTO DelRecIndexes
               (TableID, RecordId, DeleteDate
               )
        VALUES (75, :OLD.ID, SYSDATE
               );

END;
/

CREATE OR REPLACE TRIGGER TR_LIMITNOTIFYCAPTION_II
  INSTEAD OF INSERT
  ON LIMITNOTIFYCAPTION
  FOR EACH ROW
DECLARE
  new$ID LIMITNOTIFYCAPTION.ID%TYPE := :NEW.ID;
  new$INPUTDATE LIMITNOTIFYCAPTION.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$ACCEPTDATE LIMITNOTIFYCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$FINSOURCE LIMITNOTIFYCAPTION.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$CREATERUSER LIMITNOTIFYCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE LIMITNOTIFYCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE LIMITNOTIFYCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER LIMITNOTIFYCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF LIMITNOTIFYCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$IMPORTID LIMITNOTIFYCAPTION.IMPORTID%TYPE := :NEW.IMPORTID;
  new$SENDERINN LIMITNOTIFYCAPTION.SENDERINN%TYPE := :NEW.SENDERINN;
  new$ANUMBER LIMITNOTIFYCAPTION.ANUMBER%TYPE := :NEW.ANUMBER;
  new$DFACCOUNT LIMITNOTIFYCAPTION.DFACCOUNT%TYPE := :NEW.DFACCOUNT;
  new$SOURCEFACIALACC LIMITNOTIFYCAPTION.SOURCEFACIALACC%TYPE := :NEW.SOURCEFACIALACC;
  new$REJECT_CLS LIMITNOTIFYCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$CRYPTOSTATUS LIMITNOTIFYCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID LIMITNOTIFYCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID LIMITNOTIFYCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCUMENTSTATE LIMITNOTIFYCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA LIMITNOTIFYCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$ACCEPTSUMMA LIMITNOTIFYCAPTION.ACCEPTSUMMA%TYPE := :NEW.ACCEPTSUMMA;
  new$PLANDOCTYPE LIMITNOTIFYCAPTION.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$DOCSTATEREF LIMITNOTIFYCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION LIMITNOTIFYCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$STIMATEID LIMITNOTIFYCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$FACIALACCCLS LIMITNOTIFYCAPTION.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$BIDNUMBER LIMITNOTIFYCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT LIMITNOTIFYCAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$LASTEXTRCHANGE LIMITNOTIFYCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$AMONTH LIMITNOTIFYCAPTION.AMONTH%TYPE := :NEW.AMONTH;
  new$AYEAR LIMITNOTIFYCAPTION.AYEAR%TYPE := :NEW.AYEAR;
  new$TEMPREJECTCAUSE LIMITNOTIFYCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
  new$REJECTCAUSE LIMITNOTIFYCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  UseFax$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_LIMITNOTIFYCAPTION_BI)
-- Last update 07.12.2005
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   IF (new$AcceptSumma IS NULL) THEN new$AcceptSumma := 0; END IF;
   IF (new$InputDate IS NULL) THEN new$InputDate := 0; END IF;
   IF (new$FinSource IS NULL) THEN new$FinSource := 0; END IF;
   IF (new$SourceFacialAcc IS NULL) THEN new$SourceFacialAcc := 0; END IF;
   IF (new$FacialAccCls IS NULL) THEN new$FacialAccCls := 0; END IF;
   IF (new$PlanDocType IS NULL) THEN new$PlanDocType := 0; END IF;

   /*  .  ,     */
   IF ((NEW$BudgetRef IS NULL) OR (NEW$BudgetRef = 0)) THEN
      BEGIN
         SELECT fa.BudgetRef
           INTO NEW$BudgetRef
           FROM FacialAcc_Cls fa
          WHERE fa.ID = NEW$SourceFacialAcc;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            NEW$BudgetRef := NULL;
      END;
   END IF;

   /*  ,    */
   IF ((NEW$BudgetRef IS NULL) OR (NEW$BudgetRef = 0)) THEN
      GetIntConst (-1, 3, NEW$BudgetRef);
   END IF;

-- - - - - - - - - - - - -
-- BI_430 (TR_LIMITNOTIFYCAPTION_BI_430)
-- Create 18.09.2006
-- - - - - - - - - - - - -

    IF (NEW$SenderID IS NOT NULL) THEN
        /*        */
        GetIntConst(30, 19, UseFax$);
        IF ((NEW$BidNumber IS NULL) AND (UseFax$ = 1)) THEN
          NEW$BidNumber := NEW$ANumber;
        END IF;
        NEW$FaxDocCount := 0;
    END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_LIMITNOTIFYCAPTION_BI_500)
-- Last update 15.07.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_LIMITNOTIFYCAPTION (
    ID,
    INPUTDATE,
    ACCEPTDATE,
    FINSOURCE,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    IMPORTID,
    SENDERINN,
    ANUMBER,
    DFACCOUNT,
    SOURCEFACIALACC,
    REJECT_CLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DOCUMENTSTATE,
    USERSVISA,
    ACCEPTSUMMA,
    PLANDOCTYPE,
    DOCSTATEREF,
    RVERSION,
    STIMATEID,
    FACIALACCCLS,
    BIDNUMBER,
    FAXDOCCOUNT,
    LASTEXTRCHANGE,
    AMONTH,
    AYEAR,
    TEMPREJECTCAUSE,
    REJECTCAUSE
  ) VALUES (
    new$ID,
    new$INPUTDATE,
    new$ACCEPTDATE,
    new$FINSOURCE,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$IMPORTID,
    new$SENDERINN,
    new$ANUMBER,
    new$DFACCOUNT,
    new$SOURCEFACIALACC,
    new$REJECT_CLS,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$DOCUMENTSTATE,
    new$USERSVISA,
    new$ACCEPTSUMMA,
    new$PLANDOCTYPE,
    new$DOCSTATEREF,
    new$RVERSION,
    new$STIMATEID,
    new$FACIALACCCLS,
    new$BIDNUMBER,
    new$FAXDOCCOUNT,
    new$LASTEXTRCHANGE,
    new$AMONTH,
    new$AYEAR,
    new$TEMPREJECTCAUSE,
    new$REJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_LIMITNOTIFYCAPTION_AI_500)
-- Last update 15.07.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 75) AND (RecordId = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_LIMITNOTIFYCAPTION_IU
  INSTEAD OF UPDATE
  ON LIMITNOTIFYCAPTION
  FOR EACH ROW
DECLARE
  new$ID LIMITNOTIFYCAPTION.ID%TYPE := :NEW.ID;
  new$INPUTDATE LIMITNOTIFYCAPTION.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$ACCEPTDATE LIMITNOTIFYCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$FINSOURCE LIMITNOTIFYCAPTION.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$CREATERUSER LIMITNOTIFYCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE LIMITNOTIFYCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE LIMITNOTIFYCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER LIMITNOTIFYCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF LIMITNOTIFYCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$IMPORTID LIMITNOTIFYCAPTION.IMPORTID%TYPE := :NEW.IMPORTID;
  new$SENDERINN LIMITNOTIFYCAPTION.SENDERINN%TYPE := :NEW.SENDERINN;
  new$ANUMBER LIMITNOTIFYCAPTION.ANUMBER%TYPE := :NEW.ANUMBER;
  new$DFACCOUNT LIMITNOTIFYCAPTION.DFACCOUNT%TYPE := :NEW.DFACCOUNT;
  new$SOURCEFACIALACC LIMITNOTIFYCAPTION.SOURCEFACIALACC%TYPE := :NEW.SOURCEFACIALACC;
  new$REJECT_CLS LIMITNOTIFYCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$CRYPTOSTATUS LIMITNOTIFYCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID LIMITNOTIFYCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID LIMITNOTIFYCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCUMENTSTATE LIMITNOTIFYCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA LIMITNOTIFYCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$ACCEPTSUMMA LIMITNOTIFYCAPTION.ACCEPTSUMMA%TYPE := :NEW.ACCEPTSUMMA;
  new$PLANDOCTYPE LIMITNOTIFYCAPTION.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$DOCSTATEREF LIMITNOTIFYCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION LIMITNOTIFYCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$STIMATEID LIMITNOTIFYCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$FACIALACCCLS LIMITNOTIFYCAPTION.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$BIDNUMBER LIMITNOTIFYCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT LIMITNOTIFYCAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$LASTEXTRCHANGE LIMITNOTIFYCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$AMONTH LIMITNOTIFYCAPTION.AMONTH%TYPE := :NEW.AMONTH;
  new$AYEAR LIMITNOTIFYCAPTION.AYEAR%TYPE := :NEW.AYEAR;
  new$TEMPREJECTCAUSE LIMITNOTIFYCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
  new$REJECTCAUSE LIMITNOTIFYCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  cnt$ Number(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_LIMITNOTIFYCAPTION_BU)
-- Last update 07.12.05
-- - - - - - - - - - - - -

   IF (new$acceptsumma IS NULL) THEN new$acceptsumma := 0; END IF;
   IF (new$InputDate IS NULL) THEN new$InputDate := 0; END IF;
   IF (new$FinSource IS NULL) THEN new$FinSource := 0; END IF;
   IF (new$SourceFacialAcc IS NULL) THEN new$SourceFacialAcc := 0; END IF;
   IF (new$FacialAccCls IS NULL) THEN new$FacialAccCls := 0; END IF;
   IF (new$PlanDocType IS NULL) THEN new$PlanDocType := 0; END IF;

  /*   */
  IF (:NEW.BudgetRef <> :OLD.BudgetRef) THEN
   IF ( NOT((:NEW.BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL)) ) THEN
     select count(id) into cnt$
     from LimitFinDetail lfd where lfd.recordindex = :NEW.ID and ROWNUM=1;
     IF (cnt$ > 0) THEN
       RaiseException('Ex_CantModufyBudget');
     END IF;
   END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_LIMITNOTIFYCAPTION_BU_200)
-- Create 27.08.2004
-- - - - - - - - - - - - -

   /*     */
   IF (:OLD.DocStateRef <> new$DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_LIMITNOTIFYCAPTION_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_LIMITNOTIFYCAPTION SET
    ID = new$ID,
    INPUTDATE = new$INPUTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    FINSOURCE = new$FINSOURCE,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    IMPORTID = new$IMPORTID,
    SENDERINN = new$SENDERINN,
    ANUMBER = new$ANUMBER,
    DFACCOUNT = new$DFACCOUNT,
    SOURCEFACIALACC = new$SOURCEFACIALACC,
    REJECT_CLS = new$REJECT_CLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    ACCEPTSUMMA = new$ACCEPTSUMMA,
    PLANDOCTYPE = new$PLANDOCTYPE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    STIMATEID = new$STIMATEID,
    FACIALACCCLS = new$FACIALACCCLS,
    BIDNUMBER = new$BIDNUMBER,
    FAXDOCCOUNT = new$FAXDOCCOUNT,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    AMONTH = new$AMONTH,
    AYEAR = new$AYEAR,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_LIMITNOTIFYCAPTION_AU_10)
-- Create 07.09.2005
-- - - - - - - - - - - - -

   UPDATE LimitFinDetail lfd
      SET lfd.AcceptDate = new$AcceptDate,
          lfd.AMONTH = new$AMonth,
          lfd.AYEAR = new$AYear,
          lfd.FinSource = new$FinSource,
          lfd.SourceFacialAcc = new$SourceFacialAcc,
          lfd.DFAccount = new$DFAccount,
          lfd.RVersion = -1
    WHERE (lfd.RecordIndex = new$Id);

   /*    ,    
         */
   IF (NOT (new$reject_cls IS NULL) AND (:OLD.reject_cls IS NULL)) THEN
      UPDATE limitfindetail lfd
         SET lfd.requestflag = 1,
             lfd.RVersion = -1
       WHERE (lfd.RecordIndex = new$Id);
   END IF;

   /* */
   IF ((new$reject_cls IS NULL) AND NOT (:OLD.reject_cls IS NULL)) THEN
      UPDATE limitfindetail lfd
         SET lfd.requestflag = 3,
             lfd.RVersion = -1
       WHERE (lfd.RecordIndex = new$Id);
   END IF;

END;
/
update LIMITNOTIFYCAPTION set
  REJECTCAUSE = TempRejectCause
/
commit work 
/
ALTER TABLE TB_LIMITNOTIFYCAPTION DROP (TempRejectCause)
/

CREATE OR REPLACE VIEW LIMITNOTIFYCAPTION (
  ID,
  INPUTDATE,
  ACCEPTDATE,
  FINSOURCE,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  BUDGETREF,
  IMPORTID,
  SENDERINN,
  ANUMBER,
  DFACCOUNT,
  SOURCEFACIALACC,
  REJECT_CLS,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  DOCUMENTSTATE,
  USERSVISA,
  ACCEPTSUMMA,
  PLANDOCTYPE,
  DOCSTATEREF,
  RVERSION,
  STIMATEID,
  FACIALACCCLS,
  BIDNUMBER,
  FAXDOCCOUNT,
  LASTEXTRCHANGE,
  AMONTH,
  AYEAR,
  REJECTCAUSE)
AS
  SELECT
    ID,
    INPUTDATE,
    ACCEPTDATE,
    FINSOURCE,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    IMPORTID,
    SENDERINN,
    ANUMBER,
    DFACCOUNT,
    SOURCEFACIALACC,
    REJECT_CLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DOCUMENTSTATE,
    USERSVISA,
    ACCEPTSUMMA,
    PLANDOCTYPE,
    DOCSTATEREF,
    RVERSION,
    STIMATEID,
    FACIALACCCLS,
    BIDNUMBER,
    FAXDOCCOUNT,
    LASTEXTRCHANGE,
    AMONTH,
    AYEAR,
    REJECTCAUSE
  FROM TB_LIMITNOTIFYCAPTION
/

CREATE OR REPLACE TRIGGER TR_LIMITNOTIFYCAPTION_ID
  INSTEAD OF DELETE
  ON LIMITNOTIFYCAPTION
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_LIMITNOTIFYCAPTION_BD)
-- Last update 14.07.2005
-- - - - - - - - - - - - -

   DELETE FROM LimitFinDetail
         WHERE (RecordIndex = :OLD.ID);

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_LIMITNOTIFYCAPTION
  WHERE ID = :OLD.ID
           AND (   RVersion = :OLD.RVersion
                OR RVersion IS NULL AND :OLD.RVersion IS NULL
               );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AD_200 (TR_LIMITNOTIFYCAPTION_AD_200)
-- Create 27.08.2004
-- Last update 14.07.2005
-- - - - - - - - - - - - -

   /*      */
   DELETE FROM StateJumpHistory
         WHERE DocID = :OLD.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_LIMITNOTIFYCAPTION_AD_500)
-- Last update 14.07.2005
-- - - - - - - - - - - - -

   INSERT INTO DelRecIndexes
               (TableID, RecordId, DeleteDate
               )
        VALUES (75, :OLD.ID, SYSDATE
               );

END;
/

CREATE OR REPLACE TRIGGER TR_LIMITNOTIFYCAPTION_II
  INSTEAD OF INSERT
  ON LIMITNOTIFYCAPTION
  FOR EACH ROW
DECLARE
  new$ID LIMITNOTIFYCAPTION.ID%TYPE := :NEW.ID;
  new$INPUTDATE LIMITNOTIFYCAPTION.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$ACCEPTDATE LIMITNOTIFYCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$FINSOURCE LIMITNOTIFYCAPTION.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$CREATERUSER LIMITNOTIFYCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE LIMITNOTIFYCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE LIMITNOTIFYCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER LIMITNOTIFYCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF LIMITNOTIFYCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$IMPORTID LIMITNOTIFYCAPTION.IMPORTID%TYPE := :NEW.IMPORTID;
  new$SENDERINN LIMITNOTIFYCAPTION.SENDERINN%TYPE := :NEW.SENDERINN;
  new$ANUMBER LIMITNOTIFYCAPTION.ANUMBER%TYPE := :NEW.ANUMBER;
  new$DFACCOUNT LIMITNOTIFYCAPTION.DFACCOUNT%TYPE := :NEW.DFACCOUNT;
  new$SOURCEFACIALACC LIMITNOTIFYCAPTION.SOURCEFACIALACC%TYPE := :NEW.SOURCEFACIALACC;
  new$REJECT_CLS LIMITNOTIFYCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$CRYPTOSTATUS LIMITNOTIFYCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID LIMITNOTIFYCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID LIMITNOTIFYCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCUMENTSTATE LIMITNOTIFYCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA LIMITNOTIFYCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$ACCEPTSUMMA LIMITNOTIFYCAPTION.ACCEPTSUMMA%TYPE := :NEW.ACCEPTSUMMA;
  new$PLANDOCTYPE LIMITNOTIFYCAPTION.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$DOCSTATEREF LIMITNOTIFYCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION LIMITNOTIFYCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$STIMATEID LIMITNOTIFYCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$FACIALACCCLS LIMITNOTIFYCAPTION.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$BIDNUMBER LIMITNOTIFYCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT LIMITNOTIFYCAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$LASTEXTRCHANGE LIMITNOTIFYCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$AMONTH LIMITNOTIFYCAPTION.AMONTH%TYPE := :NEW.AMONTH;
  new$AYEAR LIMITNOTIFYCAPTION.AYEAR%TYPE := :NEW.AYEAR;
  new$REJECTCAUSE LIMITNOTIFYCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  UseFax$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_LIMITNOTIFYCAPTION_BI)
-- Last update 07.12.2005
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   IF (new$AcceptSumma IS NULL) THEN new$AcceptSumma := 0; END IF;
   IF (new$InputDate IS NULL) THEN new$InputDate := 0; END IF;
   IF (new$FinSource IS NULL) THEN new$FinSource := 0; END IF;
   IF (new$SourceFacialAcc IS NULL) THEN new$SourceFacialAcc := 0; END IF;
   IF (new$FacialAccCls IS NULL) THEN new$FacialAccCls := 0; END IF;
   IF (new$PlanDocType IS NULL) THEN new$PlanDocType := 0; END IF;

   /*  .  ,     */
   IF ((NEW$BudgetRef IS NULL) OR (NEW$BudgetRef = 0)) THEN
      BEGIN
         SELECT fa.BudgetRef
           INTO NEW$BudgetRef
           FROM FacialAcc_Cls fa
          WHERE fa.ID = NEW$SourceFacialAcc;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            NEW$BudgetRef := NULL;
      END;
   END IF;

   /*  ,    */
   IF ((NEW$BudgetRef IS NULL) OR (NEW$BudgetRef = 0)) THEN
      GetIntConst (-1, 3, NEW$BudgetRef);
   END IF;

-- - - - - - - - - - - - -
-- BI_430 (TR_LIMITNOTIFYCAPTION_BI_430)
-- Create 18.09.2006
-- - - - - - - - - - - - -

    IF (NEW$SenderID IS NOT NULL) THEN
        /*        */
        GetIntConst(30, 19, UseFax$);
        IF ((NEW$BidNumber IS NULL) AND (UseFax$ = 1)) THEN
          NEW$BidNumber := NEW$ANumber;
        END IF;
        NEW$FaxDocCount := 0;
    END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_LIMITNOTIFYCAPTION_BI_500)
-- Last update 15.07.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_LIMITNOTIFYCAPTION (
    ID,
    INPUTDATE,
    ACCEPTDATE,
    FINSOURCE,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    IMPORTID,
    SENDERINN,
    ANUMBER,
    DFACCOUNT,
    SOURCEFACIALACC,
    REJECT_CLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DOCUMENTSTATE,
    USERSVISA,
    ACCEPTSUMMA,
    PLANDOCTYPE,
    DOCSTATEREF,
    RVERSION,
    STIMATEID,
    FACIALACCCLS,
    BIDNUMBER,
    FAXDOCCOUNT,
    LASTEXTRCHANGE,
    AMONTH,
    AYEAR,
    REJECTCAUSE
  ) VALUES (
    new$ID,
    new$INPUTDATE,
    new$ACCEPTDATE,
    new$FINSOURCE,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$IMPORTID,
    new$SENDERINN,
    new$ANUMBER,
    new$DFACCOUNT,
    new$SOURCEFACIALACC,
    new$REJECT_CLS,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$DOCUMENTSTATE,
    new$USERSVISA,
    new$ACCEPTSUMMA,
    new$PLANDOCTYPE,
    new$DOCSTATEREF,
    new$RVERSION,
    new$STIMATEID,
    new$FACIALACCCLS,
    new$BIDNUMBER,
    new$FAXDOCCOUNT,
    new$LASTEXTRCHANGE,
    new$AMONTH,
    new$AYEAR,
    new$REJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_LIMITNOTIFYCAPTION_AI_500)
-- Last update 15.07.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 75) AND (RecordId = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_LIMITNOTIFYCAPTION_IU
  INSTEAD OF UPDATE
  ON LIMITNOTIFYCAPTION
  FOR EACH ROW
DECLARE
  new$ID LIMITNOTIFYCAPTION.ID%TYPE := :NEW.ID;
  new$INPUTDATE LIMITNOTIFYCAPTION.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$ACCEPTDATE LIMITNOTIFYCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$FINSOURCE LIMITNOTIFYCAPTION.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$CREATERUSER LIMITNOTIFYCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE LIMITNOTIFYCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE LIMITNOTIFYCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER LIMITNOTIFYCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF LIMITNOTIFYCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$IMPORTID LIMITNOTIFYCAPTION.IMPORTID%TYPE := :NEW.IMPORTID;
  new$SENDERINN LIMITNOTIFYCAPTION.SENDERINN%TYPE := :NEW.SENDERINN;
  new$ANUMBER LIMITNOTIFYCAPTION.ANUMBER%TYPE := :NEW.ANUMBER;
  new$DFACCOUNT LIMITNOTIFYCAPTION.DFACCOUNT%TYPE := :NEW.DFACCOUNT;
  new$SOURCEFACIALACC LIMITNOTIFYCAPTION.SOURCEFACIALACC%TYPE := :NEW.SOURCEFACIALACC;
  new$REJECT_CLS LIMITNOTIFYCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$CRYPTOSTATUS LIMITNOTIFYCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID LIMITNOTIFYCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID LIMITNOTIFYCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCUMENTSTATE LIMITNOTIFYCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA LIMITNOTIFYCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$ACCEPTSUMMA LIMITNOTIFYCAPTION.ACCEPTSUMMA%TYPE := :NEW.ACCEPTSUMMA;
  new$PLANDOCTYPE LIMITNOTIFYCAPTION.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$DOCSTATEREF LIMITNOTIFYCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION LIMITNOTIFYCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$STIMATEID LIMITNOTIFYCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$FACIALACCCLS LIMITNOTIFYCAPTION.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$BIDNUMBER LIMITNOTIFYCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT LIMITNOTIFYCAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$LASTEXTRCHANGE LIMITNOTIFYCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$AMONTH LIMITNOTIFYCAPTION.AMONTH%TYPE := :NEW.AMONTH;
  new$AYEAR LIMITNOTIFYCAPTION.AYEAR%TYPE := :NEW.AYEAR;
  new$REJECTCAUSE LIMITNOTIFYCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  cnt$ Number(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_LIMITNOTIFYCAPTION_BU)
-- Last update 07.12.05
-- - - - - - - - - - - - -

   IF (new$acceptsumma IS NULL) THEN new$acceptsumma := 0; END IF;
   IF (new$InputDate IS NULL) THEN new$InputDate := 0; END IF;
   IF (new$FinSource IS NULL) THEN new$FinSource := 0; END IF;
   IF (new$SourceFacialAcc IS NULL) THEN new$SourceFacialAcc := 0; END IF;
   IF (new$FacialAccCls IS NULL) THEN new$FacialAccCls := 0; END IF;
   IF (new$PlanDocType IS NULL) THEN new$PlanDocType := 0; END IF;

  /*   */
  IF (:NEW.BudgetRef <> :OLD.BudgetRef) THEN
   IF ( NOT((:NEW.BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL)) ) THEN
     select count(id) into cnt$
     from LimitFinDetail lfd where lfd.recordindex = :NEW.ID and ROWNUM=1;
     IF (cnt$ > 0) THEN
       RaiseException('Ex_CantModufyBudget');
     END IF;
   END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_LIMITNOTIFYCAPTION_BU_200)
-- Create 27.08.2004
-- - - - - - - - - - - - -

   /*     */
   IF (:OLD.DocStateRef <> new$DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_LIMITNOTIFYCAPTION_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_LIMITNOTIFYCAPTION SET
    ID = new$ID,
    INPUTDATE = new$INPUTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    FINSOURCE = new$FINSOURCE,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    IMPORTID = new$IMPORTID,
    SENDERINN = new$SENDERINN,
    ANUMBER = new$ANUMBER,
    DFACCOUNT = new$DFACCOUNT,
    SOURCEFACIALACC = new$SOURCEFACIALACC,
    REJECT_CLS = new$REJECT_CLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    ACCEPTSUMMA = new$ACCEPTSUMMA,
    PLANDOCTYPE = new$PLANDOCTYPE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    STIMATEID = new$STIMATEID,
    FACIALACCCLS = new$FACIALACCCLS,
    BIDNUMBER = new$BIDNUMBER,
    FAXDOCCOUNT = new$FAXDOCCOUNT,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    AMONTH = new$AMONTH,
    AYEAR = new$AYEAR,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_LIMITNOTIFYCAPTION_AU_10)
-- Create 07.09.2005
-- - - - - - - - - - - - -

   UPDATE LimitFinDetail lfd
      SET lfd.AcceptDate = new$AcceptDate,
          lfd.AMONTH = new$AMonth,
          lfd.AYEAR = new$AYear,
          lfd.FinSource = new$FinSource,
          lfd.SourceFacialAcc = new$SourceFacialAcc,
          lfd.DFAccount = new$DFAccount,
          lfd.RVersion = -1
    WHERE (lfd.RecordIndex = new$Id);

   /*    ,    
         */
   IF (NOT (new$reject_cls IS NULL) AND (:OLD.reject_cls IS NULL)) THEN
      UPDATE limitfindetail lfd
         SET lfd.requestflag = 1,
             lfd.RVersion = -1
       WHERE (lfd.RecordIndex = new$Id);
   END IF;

   /* */
   IF ((new$reject_cls IS NULL) AND NOT (:OLD.reject_cls IS NULL)) THEN
      UPDATE limitfindetail lfd
         SET lfd.requestflag = 3,
             lfd.RVersion = -1
       WHERE (lfd.RecordIndex = new$Id);
   END IF;

END;
/
ALTER TRIGGER TR_LIMITNOTIFYCAPTION_BU_500 ENABLE
/
commit work 
/
ALTER TRIGGER TR_QUOTESTITLE_BU_500 DISABLE
/
ALTER TABLE TB_QUOTESTITLE ADD (
  TempRejectCause VARCHAR2(255)
)
/

CREATE OR REPLACE VIEW QUOTESTITLE (
  ID,
  BUILDDATE,
  ACCEPTDATE,
  INCACCOUNT,
  BUDGETREF,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  RECORDINDEX,
  PROGINDEX,
  DOCNUMBER,
  TYPEOPERATIONCLS,
  RVERSION,
  REESTRDATE,
  REESTRNUMBER,
  SENDERID,
  SENDERRECORDID,
  FACIALACCCLS,
  REJECTCLS,
  REJECTCAUSE,
  CRYPTOSTATUS,
  STIMATEID,
  SUMMA,
  DOCSTATEREF,
  DEPARTMENTCLS,
  DOCCHANGEDATE,
  TEMPREJECTCAUSE)
AS
  SELECT
    ID,
    BUILDDATE,
    ACCEPTDATE,
    INCACCOUNT,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    RECORDINDEX,
    PROGINDEX,
    DOCNUMBER,
    TYPEOPERATIONCLS,
    RVERSION,
    REESTRDATE,
    REESTRNUMBER,
    SENDERID,
    SENDERRECORDID,
    FACIALACCCLS,
    REJECTCLS,
    REJECTCAUSE,
    CRYPTOSTATUS,
    STIMATEID,
    SUMMA,
    DOCSTATEREF,
    DEPARTMENTCLS,
    DOCCHANGEDATE,
    TEMPREJECTCAUSE
  FROM TB_QUOTESTITLE
/

CREATE OR REPLACE TRIGGER TR_QUOTESTITLE_ID
  INSTEAD OF DELETE
  ON QUOTESTITLE
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (T_QUOTESTITLE_BD)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  delete from Incomes32 where (ProgIndex = 45 or ProgIndex =140) and (RecordIndex = :old.ID);

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_QUOTESTITLE
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);
   
  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_500 (TR_QUOTESTITLE_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordID, DeleteDate, ProgIndex, SUMMA) values (160, :old.ID, SYSDATE, :old.ProgIndex, :old.SUMMA);

END;
/

CREATE OR REPLACE TRIGGER TR_QUOTESTITLE_II
  INSTEAD OF INSERT
  ON QUOTESTITLE
  FOR EACH ROW
DECLARE
  new$ID QUOTESTITLE.ID%TYPE := :NEW.ID;
  new$BUILDDATE QUOTESTITLE.BUILDDATE%TYPE := :NEW.BUILDDATE;
  new$ACCEPTDATE QUOTESTITLE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$INCACCOUNT QUOTESTITLE.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$BUDGETREF QUOTESTITLE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER QUOTESTITLE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE QUOTESTITLE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE QUOTESTITLE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER QUOTESTITLE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$RECORDINDEX QUOTESTITLE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$PROGINDEX QUOTESTITLE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$DOCNUMBER QUOTESTITLE.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$TYPEOPERATIONCLS QUOTESTITLE.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$RVERSION QUOTESTITLE.RVERSION%TYPE := :NEW.RVERSION;
  new$REESTRDATE QUOTESTITLE.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$REESTRNUMBER QUOTESTITLE.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$SENDERID QUOTESTITLE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID QUOTESTITLE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$FACIALACCCLS QUOTESTITLE.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$REJECTCLS QUOTESTITLE.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTCAUSE QUOTESTITLE.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CRYPTOSTATUS QUOTESTITLE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$STIMATEID QUOTESTITLE.STIMATEID%TYPE := :NEW.STIMATEID;
  new$SUMMA QUOTESTITLE.SUMMA%TYPE := :NEW.SUMMA;
  new$DOCSTATEREF QUOTESTITLE.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$DEPARTMENTCLS QUOTESTITLE.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$DOCCHANGEDATE QUOTESTITLE.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$TEMPREJECTCAUSE QUOTESTITLE.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (T_QUOTESTITLE_BI)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  /*  .    0,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$IncAccount is null) then
    GetDefDFAccRefForBudget(new$BudgetRef,new$IncAccount);
  END IF;
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  if (new$DepartmentCls is null) then
    new$DepartmentCls := 0;
  END IF;
  if (new$Summa is null ) then
    new$Summa := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (T_QUOTESTITLE_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$DocChangeDate := new$UpdateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_QUOTESTITLE (
    ID,
    BUILDDATE,
    ACCEPTDATE,
    INCACCOUNT,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    RECORDINDEX,
    PROGINDEX,
    DOCNUMBER,
    TYPEOPERATIONCLS,
    RVERSION,
    REESTRDATE,
    REESTRNUMBER,
    SENDERID,
    SENDERRECORDID,
    FACIALACCCLS,
    REJECTCLS,
    REJECTCAUSE,
    CRYPTOSTATUS,
    STIMATEID,
    SUMMA,
    DOCSTATEREF,
    DEPARTMENTCLS,
    DOCCHANGEDATE,
    TEMPREJECTCAUSE
  ) VALUES (
    new$ID,
    new$BUILDDATE,
    new$ACCEPTDATE,
    new$INCACCOUNT,
    new$BUDGETREF,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$RECORDINDEX,
    new$PROGINDEX,
    new$DOCNUMBER,
    new$TYPEOPERATIONCLS,
    new$RVERSION,
    new$REESTRDATE,
    new$REESTRNUMBER,
    new$SENDERID,
    new$SENDERRECORDID,
    new$FACIALACCCLS,
    new$REJECTCLS,
    new$REJECTCAUSE,
    new$CRYPTOSTATUS,
    new$STIMATEID,
    new$SUMMA,
    new$DOCSTATEREF,
    new$DEPARTMENTCLS,
    new$DOCCHANGEDATE,
    new$TEMPREJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_QUOTESTITLE_AI_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 160) AND (RecordID = :NEW.ID);

END;
/

CREATE OR REPLACE TRIGGER TR_QUOTESTITLE_IU
  INSTEAD OF UPDATE
  ON QUOTESTITLE
  FOR EACH ROW
DECLARE
  new$ID QUOTESTITLE.ID%TYPE := :NEW.ID;
  new$BUILDDATE QUOTESTITLE.BUILDDATE%TYPE := :NEW.BUILDDATE;
  new$ACCEPTDATE QUOTESTITLE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$INCACCOUNT QUOTESTITLE.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$BUDGETREF QUOTESTITLE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER QUOTESTITLE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE QUOTESTITLE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE QUOTESTITLE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER QUOTESTITLE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$RECORDINDEX QUOTESTITLE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$PROGINDEX QUOTESTITLE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$DOCNUMBER QUOTESTITLE.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$TYPEOPERATIONCLS QUOTESTITLE.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$RVERSION QUOTESTITLE.RVERSION%TYPE := :NEW.RVERSION;
  new$REESTRDATE QUOTESTITLE.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$REESTRNUMBER QUOTESTITLE.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$SENDERID QUOTESTITLE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID QUOTESTITLE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$FACIALACCCLS QUOTESTITLE.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$REJECTCLS QUOTESTITLE.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTCAUSE QUOTESTITLE.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CRYPTOSTATUS QUOTESTITLE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$STIMATEID QUOTESTITLE.STIMATEID%TYPE := :NEW.STIMATEID;
  new$SUMMA QUOTESTITLE.SUMMA%TYPE := :NEW.SUMMA;
  new$DOCSTATEREF QUOTESTITLE.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$DEPARTMENTCLS QUOTESTITLE.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$DOCCHANGEDATE QUOTESTITLE.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$TEMPREJECTCAUSE QUOTESTITLE.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  IsReject$ NUMBER(10);
  DetCount1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (T_QUOTESTITLE_BU)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if (not((new$BudgetRef is null) and (:old.BudgetRef is null))) then
      select count(ID)       into DetCount1$ from Incomes32 where RecordIndex = :old.ID
      ;
      if (DetCount1$ > 0) then 
        RaiseException('Ex_CantModufyBudget');    
      END IF;
    END IF;
  END IF;
  if (new$IncAccount is null) then
    GetDefDFAccRefForBudget(new$BudgetRef,new$IncAccount);
  END IF;
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  if (new$DepartmentCls is null) then
    new$DepartmentCls := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (T_QUOTESTITLE_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(new$RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(new$RejectCLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = new$ID)
      or(ChildID in (select d.id from incomes32 d where d.RecordIndex = new$id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_QUOTESTITLE_BU_700)
-- Create 19.09.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_QUOTESTITLE SET
    ID = new$ID,
    BUILDDATE = new$BUILDDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    INCACCOUNT = new$INCACCOUNT,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    RECORDINDEX = new$RECORDINDEX,
    PROGINDEX = new$PROGINDEX,
    DOCNUMBER = new$DOCNUMBER,
    TYPEOPERATIONCLS = new$TYPEOPERATIONCLS,
    RVERSION = new$RVERSION,
    REESTRDATE = new$REESTRDATE,
    REESTRNUMBER = new$REESTRNUMBER,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    FACIALACCCLS = new$FACIALACCCLS,
    REJECTCLS = new$REJECTCLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    STIMATEID = new$STIMATEID,
    SUMMA = new$SUMMA,
    DOCSTATEREF = new$DOCSTATEREF,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    DOCCHANGEDATE = new$DOCCHANGEDATE,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_20 (T_QUOTESTITLE_AU_20)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   /*    .        */

   /*           / */
   /*       */
   /*     else, ..    null  UNKNOWN,   then  */
   
      /*    ,     */
      /*     else, ..    null  UNKNOWN,   then  */
      IF (    
              /*    /     */
              (new$IncAccount = :OLD.IncAccount)
          AND 
              /*    /     */
              (   (new$AcceptDate = :OLD.AcceptDate)
               OR ((new$AcceptDate IS NULL) AND (:OLD.AcceptDate IS NULL))
              )
          AND 
              /*    /     */
              (   (new$DocNumber = :OLD.DocNumber)
               OR ((new$DocNumber IS NULL) AND (:OLD.DocNumber IS NULL))
              )
          AND 
              /*      */
              (   (new$ReestrNumber = :OLD.ReestrNumber)
               OR ((new$ReestrNumber IS NULL) AND (:OLD.ReestrNumber IS NULL)
                  )
              )
         ) THEN
         /*   */
         NULL;                        /*  new$AcceptDate := :old.AcceptDate; */
      ELSE
         /*      (    )*/
         /*       update Incomes32,   */
         UPDATE Incomes32 i
            SET i.iDate = new$AcceptDate,
                i.IncAccount = new$IncAccount,
                i.RVersion = -1
          WHERE i.RecordIndex = new$ID;
      END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_QUOTESTITLE_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   IF (:NEW.ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes
                  (TableID, RecordId, DeleteDate
                  )
           VALUES (160, :OLD.ID, SYSDATE
                  );

      DELETE FROM DelRecIndexes
            WHERE (TableID = 160) AND (RecordId = :NEW.ID);
   END IF;

END;
/
update QUOTESTITLE set
  TempRejectCause = REJECTCAUSE
/
commit work 
/
ALTER TABLE TB_QUOTESTITLE DROP (REJECTCAUSE)
/

CREATE OR REPLACE VIEW QUOTESTITLE (
  ID,
  BUILDDATE,
  ACCEPTDATE,
  INCACCOUNT,
  BUDGETREF,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  RECORDINDEX,
  PROGINDEX,
  DOCNUMBER,
  TYPEOPERATIONCLS,
  RVERSION,
  REESTRDATE,
  REESTRNUMBER,
  SENDERID,
  SENDERRECORDID,
  FACIALACCCLS,
  REJECTCLS,
  CRYPTOSTATUS,
  STIMATEID,
  SUMMA,
  DOCSTATEREF,
  DEPARTMENTCLS,
  DOCCHANGEDATE,
  TEMPREJECTCAUSE)
AS
  SELECT
    ID,
    BUILDDATE,
    ACCEPTDATE,
    INCACCOUNT,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    RECORDINDEX,
    PROGINDEX,
    DOCNUMBER,
    TYPEOPERATIONCLS,
    RVERSION,
    REESTRDATE,
    REESTRNUMBER,
    SENDERID,
    SENDERRECORDID,
    FACIALACCCLS,
    REJECTCLS,
    CRYPTOSTATUS,
    STIMATEID,
    SUMMA,
    DOCSTATEREF,
    DEPARTMENTCLS,
    DOCCHANGEDATE,
    TEMPREJECTCAUSE
  FROM TB_QUOTESTITLE
/

CREATE OR REPLACE TRIGGER TR_QUOTESTITLE_ID
  INSTEAD OF DELETE
  ON QUOTESTITLE
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (T_QUOTESTITLE_BD)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  delete from Incomes32 where (ProgIndex = 45 or ProgIndex =140) and (RecordIndex = :old.ID);

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_QUOTESTITLE
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);
   
  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_500 (TR_QUOTESTITLE_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordID, DeleteDate, ProgIndex, SUMMA) values (160, :old.ID, SYSDATE, :old.ProgIndex, :old.SUMMA);

END;
/

CREATE OR REPLACE TRIGGER TR_QUOTESTITLE_II
  INSTEAD OF INSERT
  ON QUOTESTITLE
  FOR EACH ROW
DECLARE
  new$ID QUOTESTITLE.ID%TYPE := :NEW.ID;
  new$BUILDDATE QUOTESTITLE.BUILDDATE%TYPE := :NEW.BUILDDATE;
  new$ACCEPTDATE QUOTESTITLE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$INCACCOUNT QUOTESTITLE.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$BUDGETREF QUOTESTITLE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER QUOTESTITLE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE QUOTESTITLE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE QUOTESTITLE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER QUOTESTITLE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$RECORDINDEX QUOTESTITLE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$PROGINDEX QUOTESTITLE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$DOCNUMBER QUOTESTITLE.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$TYPEOPERATIONCLS QUOTESTITLE.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$RVERSION QUOTESTITLE.RVERSION%TYPE := :NEW.RVERSION;
  new$REESTRDATE QUOTESTITLE.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$REESTRNUMBER QUOTESTITLE.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$SENDERID QUOTESTITLE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID QUOTESTITLE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$FACIALACCCLS QUOTESTITLE.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$REJECTCLS QUOTESTITLE.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS QUOTESTITLE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$STIMATEID QUOTESTITLE.STIMATEID%TYPE := :NEW.STIMATEID;
  new$SUMMA QUOTESTITLE.SUMMA%TYPE := :NEW.SUMMA;
  new$DOCSTATEREF QUOTESTITLE.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$DEPARTMENTCLS QUOTESTITLE.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$DOCCHANGEDATE QUOTESTITLE.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$TEMPREJECTCAUSE QUOTESTITLE.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (T_QUOTESTITLE_BI)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  /*  .    0,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$IncAccount is null) then
    GetDefDFAccRefForBudget(new$BudgetRef,new$IncAccount);
  END IF;
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  if (new$DepartmentCls is null) then
    new$DepartmentCls := 0;
  END IF;
  if (new$Summa is null ) then
    new$Summa := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (T_QUOTESTITLE_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$DocChangeDate := new$UpdateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_QUOTESTITLE (
    ID,
    BUILDDATE,
    ACCEPTDATE,
    INCACCOUNT,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    RECORDINDEX,
    PROGINDEX,
    DOCNUMBER,
    TYPEOPERATIONCLS,
    RVERSION,
    REESTRDATE,
    REESTRNUMBER,
    SENDERID,
    SENDERRECORDID,
    FACIALACCCLS,
    REJECTCLS,
    CRYPTOSTATUS,
    STIMATEID,
    SUMMA,
    DOCSTATEREF,
    DEPARTMENTCLS,
    DOCCHANGEDATE,
    TEMPREJECTCAUSE
  ) VALUES (
    new$ID,
    new$BUILDDATE,
    new$ACCEPTDATE,
    new$INCACCOUNT,
    new$BUDGETREF,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$RECORDINDEX,
    new$PROGINDEX,
    new$DOCNUMBER,
    new$TYPEOPERATIONCLS,
    new$RVERSION,
    new$REESTRDATE,
    new$REESTRNUMBER,
    new$SENDERID,
    new$SENDERRECORDID,
    new$FACIALACCCLS,
    new$REJECTCLS,
    new$CRYPTOSTATUS,
    new$STIMATEID,
    new$SUMMA,
    new$DOCSTATEREF,
    new$DEPARTMENTCLS,
    new$DOCCHANGEDATE,
    new$TEMPREJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_QUOTESTITLE_AI_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 160) AND (RecordID = :NEW.ID);

END;
/

CREATE OR REPLACE TRIGGER TR_QUOTESTITLE_IU
  INSTEAD OF UPDATE
  ON QUOTESTITLE
  FOR EACH ROW
DECLARE
  new$ID QUOTESTITLE.ID%TYPE := :NEW.ID;
  new$BUILDDATE QUOTESTITLE.BUILDDATE%TYPE := :NEW.BUILDDATE;
  new$ACCEPTDATE QUOTESTITLE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$INCACCOUNT QUOTESTITLE.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$BUDGETREF QUOTESTITLE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER QUOTESTITLE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE QUOTESTITLE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE QUOTESTITLE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER QUOTESTITLE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$RECORDINDEX QUOTESTITLE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$PROGINDEX QUOTESTITLE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$DOCNUMBER QUOTESTITLE.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$TYPEOPERATIONCLS QUOTESTITLE.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$RVERSION QUOTESTITLE.RVERSION%TYPE := :NEW.RVERSION;
  new$REESTRDATE QUOTESTITLE.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$REESTRNUMBER QUOTESTITLE.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$SENDERID QUOTESTITLE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID QUOTESTITLE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$FACIALACCCLS QUOTESTITLE.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$REJECTCLS QUOTESTITLE.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS QUOTESTITLE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$STIMATEID QUOTESTITLE.STIMATEID%TYPE := :NEW.STIMATEID;
  new$SUMMA QUOTESTITLE.SUMMA%TYPE := :NEW.SUMMA;
  new$DOCSTATEREF QUOTESTITLE.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$DEPARTMENTCLS QUOTESTITLE.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$DOCCHANGEDATE QUOTESTITLE.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$TEMPREJECTCAUSE QUOTESTITLE.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  IsReject$ NUMBER(10);
  DetCount1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (T_QUOTESTITLE_BU)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if (not((new$BudgetRef is null) and (:old.BudgetRef is null))) then
      select count(ID)       into DetCount1$ from Incomes32 where RecordIndex = :old.ID
      ;
      if (DetCount1$ > 0) then 
        RaiseException('Ex_CantModufyBudget');    
      END IF;
    END IF;
  END IF;
  if (new$IncAccount is null) then
    GetDefDFAccRefForBudget(new$BudgetRef,new$IncAccount);
  END IF;
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  if (new$DepartmentCls is null) then
    new$DepartmentCls := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (T_QUOTESTITLE_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(new$RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(new$RejectCLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = new$ID)
      or(ChildID in (select d.id from incomes32 d where d.RecordIndex = new$id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_QUOTESTITLE_BU_700)
-- Create 19.09.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_QUOTESTITLE SET
    ID = new$ID,
    BUILDDATE = new$BUILDDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    INCACCOUNT = new$INCACCOUNT,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    RECORDINDEX = new$RECORDINDEX,
    PROGINDEX = new$PROGINDEX,
    DOCNUMBER = new$DOCNUMBER,
    TYPEOPERATIONCLS = new$TYPEOPERATIONCLS,
    RVERSION = new$RVERSION,
    REESTRDATE = new$REESTRDATE,
    REESTRNUMBER = new$REESTRNUMBER,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    FACIALACCCLS = new$FACIALACCCLS,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    STIMATEID = new$STIMATEID,
    SUMMA = new$SUMMA,
    DOCSTATEREF = new$DOCSTATEREF,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    DOCCHANGEDATE = new$DOCCHANGEDATE,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_20 (T_QUOTESTITLE_AU_20)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   /*    .        */

   /*           / */
   /*       */
   /*     else, ..    null  UNKNOWN,   then  */
   
      /*    ,     */
      /*     else, ..    null  UNKNOWN,   then  */
      IF (    
              /*    /     */
              (new$IncAccount = :OLD.IncAccount)
          AND 
              /*    /     */
              (   (new$AcceptDate = :OLD.AcceptDate)
               OR ((new$AcceptDate IS NULL) AND (:OLD.AcceptDate IS NULL))
              )
          AND 
              /*    /     */
              (   (new$DocNumber = :OLD.DocNumber)
               OR ((new$DocNumber IS NULL) AND (:OLD.DocNumber IS NULL))
              )
          AND 
              /*      */
              (   (new$ReestrNumber = :OLD.ReestrNumber)
               OR ((new$ReestrNumber IS NULL) AND (:OLD.ReestrNumber IS NULL)
                  )
              )
         ) THEN
         /*   */
         NULL;                        /*  new$AcceptDate := :old.AcceptDate; */
      ELSE
         /*      (    )*/
         /*       update Incomes32,   */
         UPDATE Incomes32 i
            SET i.iDate = new$AcceptDate,
                i.IncAccount = new$IncAccount,
                i.RVersion = -1
          WHERE i.RecordIndex = new$ID;
      END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_QUOTESTITLE_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   IF (:NEW.ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes
                  (TableID, RecordId, DeleteDate
                  )
           VALUES (160, :OLD.ID, SYSDATE
                  );

      DELETE FROM DelRecIndexes
            WHERE (TableID = 160) AND (RecordId = :NEW.ID);
   END IF;

END;
/
ALTER TABLE TB_QUOTESTITLE ADD (
  REJECTCAUSE VARCHAR2(1000)
)
/

CREATE OR REPLACE VIEW QUOTESTITLE (
  ID,
  BUILDDATE,
  ACCEPTDATE,
  INCACCOUNT,
  BUDGETREF,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  RECORDINDEX,
  PROGINDEX,
  DOCNUMBER,
  TYPEOPERATIONCLS,
  RVERSION,
  REESTRDATE,
  REESTRNUMBER,
  SENDERID,
  SENDERRECORDID,
  FACIALACCCLS,
  REJECTCLS,
  CRYPTOSTATUS,
  STIMATEID,
  SUMMA,
  DOCSTATEREF,
  DEPARTMENTCLS,
  DOCCHANGEDATE,
  TEMPREJECTCAUSE,
  REJECTCAUSE)
AS
  SELECT
    ID,
    BUILDDATE,
    ACCEPTDATE,
    INCACCOUNT,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    RECORDINDEX,
    PROGINDEX,
    DOCNUMBER,
    TYPEOPERATIONCLS,
    RVERSION,
    REESTRDATE,
    REESTRNUMBER,
    SENDERID,
    SENDERRECORDID,
    FACIALACCCLS,
    REJECTCLS,
    CRYPTOSTATUS,
    STIMATEID,
    SUMMA,
    DOCSTATEREF,
    DEPARTMENTCLS,
    DOCCHANGEDATE,
    TEMPREJECTCAUSE,
    REJECTCAUSE
  FROM TB_QUOTESTITLE
/

CREATE OR REPLACE TRIGGER TR_QUOTESTITLE_ID
  INSTEAD OF DELETE
  ON QUOTESTITLE
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (T_QUOTESTITLE_BD)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  delete from Incomes32 where (ProgIndex = 45 or ProgIndex =140) and (RecordIndex = :old.ID);

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_QUOTESTITLE
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);
   
  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_500 (TR_QUOTESTITLE_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordID, DeleteDate, ProgIndex, SUMMA) values (160, :old.ID, SYSDATE, :old.ProgIndex, :old.SUMMA);

END;
/

CREATE OR REPLACE TRIGGER TR_QUOTESTITLE_II
  INSTEAD OF INSERT
  ON QUOTESTITLE
  FOR EACH ROW
DECLARE
  new$ID QUOTESTITLE.ID%TYPE := :NEW.ID;
  new$BUILDDATE QUOTESTITLE.BUILDDATE%TYPE := :NEW.BUILDDATE;
  new$ACCEPTDATE QUOTESTITLE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$INCACCOUNT QUOTESTITLE.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$BUDGETREF QUOTESTITLE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER QUOTESTITLE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE QUOTESTITLE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE QUOTESTITLE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER QUOTESTITLE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$RECORDINDEX QUOTESTITLE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$PROGINDEX QUOTESTITLE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$DOCNUMBER QUOTESTITLE.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$TYPEOPERATIONCLS QUOTESTITLE.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$RVERSION QUOTESTITLE.RVERSION%TYPE := :NEW.RVERSION;
  new$REESTRDATE QUOTESTITLE.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$REESTRNUMBER QUOTESTITLE.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$SENDERID QUOTESTITLE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID QUOTESTITLE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$FACIALACCCLS QUOTESTITLE.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$REJECTCLS QUOTESTITLE.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS QUOTESTITLE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$STIMATEID QUOTESTITLE.STIMATEID%TYPE := :NEW.STIMATEID;
  new$SUMMA QUOTESTITLE.SUMMA%TYPE := :NEW.SUMMA;
  new$DOCSTATEREF QUOTESTITLE.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$DEPARTMENTCLS QUOTESTITLE.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$DOCCHANGEDATE QUOTESTITLE.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$TEMPREJECTCAUSE QUOTESTITLE.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
  new$REJECTCAUSE QUOTESTITLE.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (T_QUOTESTITLE_BI)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  /*  .    0,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$IncAccount is null) then
    GetDefDFAccRefForBudget(new$BudgetRef,new$IncAccount);
  END IF;
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  if (new$DepartmentCls is null) then
    new$DepartmentCls := 0;
  END IF;
  if (new$Summa is null ) then
    new$Summa := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (T_QUOTESTITLE_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$DocChangeDate := new$UpdateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_QUOTESTITLE (
    ID,
    BUILDDATE,
    ACCEPTDATE,
    INCACCOUNT,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    RECORDINDEX,
    PROGINDEX,
    DOCNUMBER,
    TYPEOPERATIONCLS,
    RVERSION,
    REESTRDATE,
    REESTRNUMBER,
    SENDERID,
    SENDERRECORDID,
    FACIALACCCLS,
    REJECTCLS,
    CRYPTOSTATUS,
    STIMATEID,
    SUMMA,
    DOCSTATEREF,
    DEPARTMENTCLS,
    DOCCHANGEDATE,
    TEMPREJECTCAUSE,
    REJECTCAUSE
  ) VALUES (
    new$ID,
    new$BUILDDATE,
    new$ACCEPTDATE,
    new$INCACCOUNT,
    new$BUDGETREF,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$RECORDINDEX,
    new$PROGINDEX,
    new$DOCNUMBER,
    new$TYPEOPERATIONCLS,
    new$RVERSION,
    new$REESTRDATE,
    new$REESTRNUMBER,
    new$SENDERID,
    new$SENDERRECORDID,
    new$FACIALACCCLS,
    new$REJECTCLS,
    new$CRYPTOSTATUS,
    new$STIMATEID,
    new$SUMMA,
    new$DOCSTATEREF,
    new$DEPARTMENTCLS,
    new$DOCCHANGEDATE,
    new$TEMPREJECTCAUSE,
    new$REJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_QUOTESTITLE_AI_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 160) AND (RecordID = :NEW.ID);

END;
/

CREATE OR REPLACE TRIGGER TR_QUOTESTITLE_IU
  INSTEAD OF UPDATE
  ON QUOTESTITLE
  FOR EACH ROW
DECLARE
  new$ID QUOTESTITLE.ID%TYPE := :NEW.ID;
  new$BUILDDATE QUOTESTITLE.BUILDDATE%TYPE := :NEW.BUILDDATE;
  new$ACCEPTDATE QUOTESTITLE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$INCACCOUNT QUOTESTITLE.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$BUDGETREF QUOTESTITLE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER QUOTESTITLE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE QUOTESTITLE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE QUOTESTITLE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER QUOTESTITLE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$RECORDINDEX QUOTESTITLE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$PROGINDEX QUOTESTITLE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$DOCNUMBER QUOTESTITLE.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$TYPEOPERATIONCLS QUOTESTITLE.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$RVERSION QUOTESTITLE.RVERSION%TYPE := :NEW.RVERSION;
  new$REESTRDATE QUOTESTITLE.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$REESTRNUMBER QUOTESTITLE.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$SENDERID QUOTESTITLE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID QUOTESTITLE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$FACIALACCCLS QUOTESTITLE.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$REJECTCLS QUOTESTITLE.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS QUOTESTITLE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$STIMATEID QUOTESTITLE.STIMATEID%TYPE := :NEW.STIMATEID;
  new$SUMMA QUOTESTITLE.SUMMA%TYPE := :NEW.SUMMA;
  new$DOCSTATEREF QUOTESTITLE.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$DEPARTMENTCLS QUOTESTITLE.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$DOCCHANGEDATE QUOTESTITLE.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$TEMPREJECTCAUSE QUOTESTITLE.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
  new$REJECTCAUSE QUOTESTITLE.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  IsReject$ NUMBER(10);
  DetCount1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (T_QUOTESTITLE_BU)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if (not((new$BudgetRef is null) and (:old.BudgetRef is null))) then
      select count(ID)       into DetCount1$ from Incomes32 where RecordIndex = :old.ID
      ;
      if (DetCount1$ > 0) then 
        RaiseException('Ex_CantModufyBudget');    
      END IF;
    END IF;
  END IF;
  if (new$IncAccount is null) then
    GetDefDFAccRefForBudget(new$BudgetRef,new$IncAccount);
  END IF;
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  if (new$DepartmentCls is null) then
    new$DepartmentCls := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (T_QUOTESTITLE_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(new$RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(new$RejectCLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = new$ID)
      or(ChildID in (select d.id from incomes32 d where d.RecordIndex = new$id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_QUOTESTITLE_BU_700)
-- Create 19.09.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_QUOTESTITLE SET
    ID = new$ID,
    BUILDDATE = new$BUILDDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    INCACCOUNT = new$INCACCOUNT,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    RECORDINDEX = new$RECORDINDEX,
    PROGINDEX = new$PROGINDEX,
    DOCNUMBER = new$DOCNUMBER,
    TYPEOPERATIONCLS = new$TYPEOPERATIONCLS,
    RVERSION = new$RVERSION,
    REESTRDATE = new$REESTRDATE,
    REESTRNUMBER = new$REESTRNUMBER,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    FACIALACCCLS = new$FACIALACCCLS,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    STIMATEID = new$STIMATEID,
    SUMMA = new$SUMMA,
    DOCSTATEREF = new$DOCSTATEREF,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    DOCCHANGEDATE = new$DOCCHANGEDATE,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_20 (T_QUOTESTITLE_AU_20)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   /*    .        */

   /*           / */
   /*       */
   /*     else, ..    null  UNKNOWN,   then  */
   
      /*    ,     */
      /*     else, ..    null  UNKNOWN,   then  */
      IF (    
              /*    /     */
              (new$IncAccount = :OLD.IncAccount)
          AND 
              /*    /     */
              (   (new$AcceptDate = :OLD.AcceptDate)
               OR ((new$AcceptDate IS NULL) AND (:OLD.AcceptDate IS NULL))
              )
          AND 
              /*    /     */
              (   (new$DocNumber = :OLD.DocNumber)
               OR ((new$DocNumber IS NULL) AND (:OLD.DocNumber IS NULL))
              )
          AND 
              /*      */
              (   (new$ReestrNumber = :OLD.ReestrNumber)
               OR ((new$ReestrNumber IS NULL) AND (:OLD.ReestrNumber IS NULL)
                  )
              )
         ) THEN
         /*   */
         NULL;                        /*  new$AcceptDate := :old.AcceptDate; */
      ELSE
         /*      (    )*/
         /*       update Incomes32,   */
         UPDATE Incomes32 i
            SET i.iDate = new$AcceptDate,
                i.IncAccount = new$IncAccount,
                i.RVersion = -1
          WHERE i.RecordIndex = new$ID;
      END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_QUOTESTITLE_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   IF (:NEW.ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes
                  (TableID, RecordId, DeleteDate
                  )
           VALUES (160, :OLD.ID, SYSDATE
                  );

      DELETE FROM DelRecIndexes
            WHERE (TableID = 160) AND (RecordId = :NEW.ID);
   END IF;

END;
/
update QUOTESTITLE set
  REJECTCAUSE = TempRejectCause
/
commit work 
/
ALTER TABLE TB_QUOTESTITLE DROP (TempRejectCause)
/

CREATE OR REPLACE VIEW QUOTESTITLE (
  ID,
  BUILDDATE,
  ACCEPTDATE,
  INCACCOUNT,
  BUDGETREF,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  RECORDINDEX,
  PROGINDEX,
  DOCNUMBER,
  TYPEOPERATIONCLS,
  RVERSION,
  REESTRDATE,
  REESTRNUMBER,
  SENDERID,
  SENDERRECORDID,
  FACIALACCCLS,
  REJECTCLS,
  CRYPTOSTATUS,
  STIMATEID,
  SUMMA,
  DOCSTATEREF,
  DEPARTMENTCLS,
  DOCCHANGEDATE,
  REJECTCAUSE)
AS
  SELECT
    ID,
    BUILDDATE,
    ACCEPTDATE,
    INCACCOUNT,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    RECORDINDEX,
    PROGINDEX,
    DOCNUMBER,
    TYPEOPERATIONCLS,
    RVERSION,
    REESTRDATE,
    REESTRNUMBER,
    SENDERID,
    SENDERRECORDID,
    FACIALACCCLS,
    REJECTCLS,
    CRYPTOSTATUS,
    STIMATEID,
    SUMMA,
    DOCSTATEREF,
    DEPARTMENTCLS,
    DOCCHANGEDATE,
    REJECTCAUSE
  FROM TB_QUOTESTITLE
/

CREATE OR REPLACE TRIGGER TR_QUOTESTITLE_ID
  INSTEAD OF DELETE
  ON QUOTESTITLE
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (T_QUOTESTITLE_BD)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  delete from Incomes32 where (ProgIndex = 45 or ProgIndex =140) and (RecordIndex = :old.ID);

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_QUOTESTITLE
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);
   
  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_500 (TR_QUOTESTITLE_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordID, DeleteDate, ProgIndex, SUMMA) values (160, :old.ID, SYSDATE, :old.ProgIndex, :old.SUMMA);

END;
/

CREATE OR REPLACE TRIGGER TR_QUOTESTITLE_II
  INSTEAD OF INSERT
  ON QUOTESTITLE
  FOR EACH ROW
DECLARE
  new$ID QUOTESTITLE.ID%TYPE := :NEW.ID;
  new$BUILDDATE QUOTESTITLE.BUILDDATE%TYPE := :NEW.BUILDDATE;
  new$ACCEPTDATE QUOTESTITLE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$INCACCOUNT QUOTESTITLE.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$BUDGETREF QUOTESTITLE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER QUOTESTITLE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE QUOTESTITLE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE QUOTESTITLE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER QUOTESTITLE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$RECORDINDEX QUOTESTITLE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$PROGINDEX QUOTESTITLE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$DOCNUMBER QUOTESTITLE.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$TYPEOPERATIONCLS QUOTESTITLE.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$RVERSION QUOTESTITLE.RVERSION%TYPE := :NEW.RVERSION;
  new$REESTRDATE QUOTESTITLE.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$REESTRNUMBER QUOTESTITLE.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$SENDERID QUOTESTITLE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID QUOTESTITLE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$FACIALACCCLS QUOTESTITLE.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$REJECTCLS QUOTESTITLE.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS QUOTESTITLE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$STIMATEID QUOTESTITLE.STIMATEID%TYPE := :NEW.STIMATEID;
  new$SUMMA QUOTESTITLE.SUMMA%TYPE := :NEW.SUMMA;
  new$DOCSTATEREF QUOTESTITLE.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$DEPARTMENTCLS QUOTESTITLE.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$DOCCHANGEDATE QUOTESTITLE.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$REJECTCAUSE QUOTESTITLE.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (T_QUOTESTITLE_BI)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  /*  .    0,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$IncAccount is null) then
    GetDefDFAccRefForBudget(new$BudgetRef,new$IncAccount);
  END IF;
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  if (new$DepartmentCls is null) then
    new$DepartmentCls := 0;
  END IF;
  if (new$Summa is null ) then
    new$Summa := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (T_QUOTESTITLE_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$DocChangeDate := new$UpdateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_QUOTESTITLE (
    ID,
    BUILDDATE,
    ACCEPTDATE,
    INCACCOUNT,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    RECORDINDEX,
    PROGINDEX,
    DOCNUMBER,
    TYPEOPERATIONCLS,
    RVERSION,
    REESTRDATE,
    REESTRNUMBER,
    SENDERID,
    SENDERRECORDID,
    FACIALACCCLS,
    REJECTCLS,
    CRYPTOSTATUS,
    STIMATEID,
    SUMMA,
    DOCSTATEREF,
    DEPARTMENTCLS,
    DOCCHANGEDATE,
    REJECTCAUSE
  ) VALUES (
    new$ID,
    new$BUILDDATE,
    new$ACCEPTDATE,
    new$INCACCOUNT,
    new$BUDGETREF,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$RECORDINDEX,
    new$PROGINDEX,
    new$DOCNUMBER,
    new$TYPEOPERATIONCLS,
    new$RVERSION,
    new$REESTRDATE,
    new$REESTRNUMBER,
    new$SENDERID,
    new$SENDERRECORDID,
    new$FACIALACCCLS,
    new$REJECTCLS,
    new$CRYPTOSTATUS,
    new$STIMATEID,
    new$SUMMA,
    new$DOCSTATEREF,
    new$DEPARTMENTCLS,
    new$DOCCHANGEDATE,
    new$REJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_QUOTESTITLE_AI_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 160) AND (RecordID = :NEW.ID);

END;
/

CREATE OR REPLACE TRIGGER TR_QUOTESTITLE_IU
  INSTEAD OF UPDATE
  ON QUOTESTITLE
  FOR EACH ROW
DECLARE
  new$ID QUOTESTITLE.ID%TYPE := :NEW.ID;
  new$BUILDDATE QUOTESTITLE.BUILDDATE%TYPE := :NEW.BUILDDATE;
  new$ACCEPTDATE QUOTESTITLE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$INCACCOUNT QUOTESTITLE.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$BUDGETREF QUOTESTITLE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER QUOTESTITLE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE QUOTESTITLE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE QUOTESTITLE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER QUOTESTITLE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$RECORDINDEX QUOTESTITLE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$PROGINDEX QUOTESTITLE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$DOCNUMBER QUOTESTITLE.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$TYPEOPERATIONCLS QUOTESTITLE.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$RVERSION QUOTESTITLE.RVERSION%TYPE := :NEW.RVERSION;
  new$REESTRDATE QUOTESTITLE.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$REESTRNUMBER QUOTESTITLE.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$SENDERID QUOTESTITLE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID QUOTESTITLE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$FACIALACCCLS QUOTESTITLE.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$REJECTCLS QUOTESTITLE.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS QUOTESTITLE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$STIMATEID QUOTESTITLE.STIMATEID%TYPE := :NEW.STIMATEID;
  new$SUMMA QUOTESTITLE.SUMMA%TYPE := :NEW.SUMMA;
  new$DOCSTATEREF QUOTESTITLE.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$DEPARTMENTCLS QUOTESTITLE.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$DOCCHANGEDATE QUOTESTITLE.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$REJECTCAUSE QUOTESTITLE.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  IsReject$ NUMBER(10);
  DetCount1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (T_QUOTESTITLE_BU)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if (not((new$BudgetRef is null) and (:old.BudgetRef is null))) then
      select count(ID)       into DetCount1$ from Incomes32 where RecordIndex = :old.ID
      ;
      if (DetCount1$ > 0) then 
        RaiseException('Ex_CantModufyBudget');    
      END IF;
    END IF;
  END IF;
  if (new$IncAccount is null) then
    GetDefDFAccRefForBudget(new$BudgetRef,new$IncAccount);
  END IF;
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  if (new$DepartmentCls is null) then
    new$DepartmentCls := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (T_QUOTESTITLE_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(new$RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(new$RejectCLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = new$ID)
      or(ChildID in (select d.id from incomes32 d where d.RecordIndex = new$id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_QUOTESTITLE_BU_700)
-- Create 19.09.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_QUOTESTITLE SET
    ID = new$ID,
    BUILDDATE = new$BUILDDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    INCACCOUNT = new$INCACCOUNT,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    RECORDINDEX = new$RECORDINDEX,
    PROGINDEX = new$PROGINDEX,
    DOCNUMBER = new$DOCNUMBER,
    TYPEOPERATIONCLS = new$TYPEOPERATIONCLS,
    RVERSION = new$RVERSION,
    REESTRDATE = new$REESTRDATE,
    REESTRNUMBER = new$REESTRNUMBER,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    FACIALACCCLS = new$FACIALACCCLS,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    STIMATEID = new$STIMATEID,
    SUMMA = new$SUMMA,
    DOCSTATEREF = new$DOCSTATEREF,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    DOCCHANGEDATE = new$DOCCHANGEDATE,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_20 (T_QUOTESTITLE_AU_20)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   /*    .        */

   /*           / */
   /*       */
   /*     else, ..    null  UNKNOWN,   then  */
   
      /*    ,     */
      /*     else, ..    null  UNKNOWN,   then  */
      IF (    
              /*    /     */
              (new$IncAccount = :OLD.IncAccount)
          AND 
              /*    /     */
              (   (new$AcceptDate = :OLD.AcceptDate)
               OR ((new$AcceptDate IS NULL) AND (:OLD.AcceptDate IS NULL))
              )
          AND 
              /*    /     */
              (   (new$DocNumber = :OLD.DocNumber)
               OR ((new$DocNumber IS NULL) AND (:OLD.DocNumber IS NULL))
              )
          AND 
              /*      */
              (   (new$ReestrNumber = :OLD.ReestrNumber)
               OR ((new$ReestrNumber IS NULL) AND (:OLD.ReestrNumber IS NULL)
                  )
              )
         ) THEN
         /*   */
         NULL;                        /*  new$AcceptDate := :old.AcceptDate; */
      ELSE
         /*      (    )*/
         /*       update Incomes32,   */
         UPDATE Incomes32 i
            SET i.iDate = new$AcceptDate,
                i.IncAccount = new$IncAccount,
                i.RVersion = -1
          WHERE i.RecordIndex = new$ID;
      END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_QUOTESTITLE_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   IF (:NEW.ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes
                  (TableID, RecordId, DeleteDate
                  )
           VALUES (160, :OLD.ID, SYSDATE
                  );

      DELETE FROM DelRecIndexes
            WHERE (TableID = 160) AND (RecordId = :NEW.ID);
   END IF;

END;
/
ALTER TRIGGER TR_QUOTESTITLE_BU_500 ENABLE
/
commit work 
/
ALTER TRIGGER TR_PROMISE_CAPTION_BU_500 DISABLE
/
ALTER TABLE TB_PROMISE_CAPTION ADD (
  TempRejectCause VARCHAR2(255)
)
/

CREATE OR REPLACE VIEW PROMISE_CAPTION (
  ID,
  ACCEPTDATE,
  ACCEPTED_REVERTED,
  AGREEMENT_DATE,
  AGREEMENT_END,
  AGREEMENT_NOTE,
  AGREEMENT_TYPE,
  AGREEMENT_SUMMA,
  SUPPLIER_REF,
  DELIVERY_RULES,
  TOTALSUMM,
  BUDGETORG_REF,
  FACIALACC_CLS,
  BUDGETREF,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  ANUMBER,
  REJECT_CLS,
  REJECTCAUSE,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  DOCUMENTSTATE,
  USERSVISA,
  RVERSION,
  DOCSTATEREF,
  STIMATEID,
  BIDNUMBER,
  FAXDOCCOUNT,
  SUPPLIER_ACC_REF,
  AGREEMENT_NUM,
  INFONUMBER,
  ADVANCESUMMA,
  TEMPREJECTCAUSE)
AS
  SELECT
    ID,
    ACCEPTDATE,
    ACCEPTED_REVERTED,
    AGREEMENT_DATE,
    AGREEMENT_END,
    AGREEMENT_NOTE,
    AGREEMENT_TYPE,
    AGREEMENT_SUMMA,
    SUPPLIER_REF,
    DELIVERY_RULES,
    TOTALSUMM,
    BUDGETORG_REF,
    FACIALACC_CLS,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    ANUMBER,
    REJECT_CLS,
    REJECTCAUSE,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DOCUMENTSTATE,
    USERSVISA,
    RVERSION,
    DOCSTATEREF,
    STIMATEID,
    BIDNUMBER,
    FAXDOCCOUNT,
    SUPPLIER_ACC_REF,
    AGREEMENT_NUM,
    INFONUMBER,
    ADVANCESUMMA,
    TEMPREJECTCAUSE
  FROM TB_PROMISE_CAPTION
/

CREATE OR REPLACE TRIGGER TR_PROMISE_CAPTION_ID
  INSTEAD OF DELETE
  ON PROMISE_CAPTION
  FOR EACH ROW
DECLARE
  CNT$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_PROMISE_CAPTION_BD)
-- Last update 03.07.2006
-- - - - - - - - - - - - -

  /*       ,  */
  /*         .*/
  for R$ In (select pd.id ID, pd.registrnumber RN
    from Promise_Detail pd
    where pd.title_ref = :old.id)
  LOOP
    select count(pd2.id) into CNT$
        from promise_detail pd2
        where (pd2.parent_promise = R$.RN) and (pd2.budgetref = :old.budgetref) AND (ROWNUM = 1);

    if (CNT$ > 0) then
      RaiseException('EX_TEN_CANTDELADJUSTMENTED');
    else
      delete from Promise_Detail where Title_Ref = :old.id;    
    end if;  
  end LOOP;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_PROMISE_CAPTION
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);
   
  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_500 (TR_PROMISECAPTION_AD_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate, Summa)
    VALUES (77, :OLD.ID, SYSDATE, :OLD.Agreement_Summa);

END;
/

CREATE OR REPLACE TRIGGER TR_PROMISE_CAPTION_II
  INSTEAD OF INSERT
  ON PROMISE_CAPTION
  FOR EACH ROW
DECLARE
  new$ID PROMISE_CAPTION.ID%TYPE := :NEW.ID;
  new$ACCEPTDATE PROMISE_CAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$ACCEPTED_REVERTED PROMISE_CAPTION.ACCEPTED_REVERTED%TYPE := :NEW.ACCEPTED_REVERTED;
  new$AGREEMENT_DATE PROMISE_CAPTION.AGREEMENT_DATE%TYPE := :NEW.AGREEMENT_DATE;
  new$AGREEMENT_END PROMISE_CAPTION.AGREEMENT_END%TYPE := :NEW.AGREEMENT_END;
  new$AGREEMENT_NOTE PROMISE_CAPTION.AGREEMENT_NOTE%TYPE := :NEW.AGREEMENT_NOTE;
  new$AGREEMENT_TYPE PROMISE_CAPTION.AGREEMENT_TYPE%TYPE := :NEW.AGREEMENT_TYPE;
  new$AGREEMENT_SUMMA PROMISE_CAPTION.AGREEMENT_SUMMA%TYPE := :NEW.AGREEMENT_SUMMA;
  new$SUPPLIER_REF PROMISE_CAPTION.SUPPLIER_REF%TYPE := :NEW.SUPPLIER_REF;
  new$DELIVERY_RULES PROMISE_CAPTION.DELIVERY_RULES%TYPE := :NEW.DELIVERY_RULES;
  new$TOTALSUMM PROMISE_CAPTION.TOTALSUMM%TYPE := :NEW.TOTALSUMM;
  new$BUDGETORG_REF PROMISE_CAPTION.BUDGETORG_REF%TYPE := :NEW.BUDGETORG_REF;
  new$FACIALACC_CLS PROMISE_CAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$BUDGETREF PROMISE_CAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER PROMISE_CAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PROMISE_CAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PROMISE_CAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PROMISE_CAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$ANUMBER PROMISE_CAPTION.ANUMBER%TYPE := :NEW.ANUMBER;
  new$REJECT_CLS PROMISE_CAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE PROMISE_CAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CRYPTOSTATUS PROMISE_CAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID PROMISE_CAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PROMISE_CAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCUMENTSTATE PROMISE_CAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA PROMISE_CAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$RVERSION PROMISE_CAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$DOCSTATEREF PROMISE_CAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$STIMATEID PROMISE_CAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$BIDNUMBER PROMISE_CAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT PROMISE_CAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$SUPPLIER_ACC_REF PROMISE_CAPTION.SUPPLIER_ACC_REF%TYPE := :NEW.SUPPLIER_ACC_REF;
  new$AGREEMENT_NUM PROMISE_CAPTION.AGREEMENT_NUM%TYPE := :NEW.AGREEMENT_NUM;
  new$INFONUMBER PROMISE_CAPTION.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$ADVANCESUMMA PROMISE_CAPTION.ADVANCESUMMA%TYPE := :NEW.ADVANCESUMMA;
  new$TEMPREJECTCAUSE PROMISE_CAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  UseFax$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_PROMISE_CAPTION_BI)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$Accepted_Reverted is null) then 
    new$Accepted_Reverted := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$TotalSumm is null) then 
    new$TotalSumm := 0;
  END IF;
  if (new$Agreement_Type is null) then 
    new$Agreement_Type := 0;
  END IF;
  if (new$Agreement_Summa is null) then 
    new$Agreement_Summa := 0;
  END IF;
  if ((new$reject_cls is not null))then 
    new$Accepted_Reverted := 1;
  END IF;
  if ((new$reject_cls is null))then 
    new$Accepted_Reverted := 0;
  END IF;
      
  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then 
    BEGIN
      select fa.BudgetRef         into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then 
    BEGIN
      select ConstValue         into new$BudgetRef from IntConst where (ProgIndex = -1) and (ConstIndex = 3)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_430 (TR_PROMISE_CAPTION_BI_430)
-- Version 7.01.00.2
-- - - - - - - - - - - - -

  IF (new$SenderID IS NOT NULL) THEN 
    /*     */
    GetIntConst(30, 19,UseFax$);
    IF ((new$BidNumber IS NULL) AND (UseFax$ = 1)) THEN 
      new$BidNumber:= new$Agreement_Num;
    END IF;
    SELECT COUNT(*)         INTO
    new$FaxDocCount FROM FaxDocs WHERE 
    (OwnerDocNumber=new$BidNumber)
    AND (ClientID=new$SenderID)
    AND (FacialAcc_Cls=new$FacialAcc_CLS)
    AND (OwnerDate = new$Agreement_Date)
    ;
  ELSE
    new$FaxDocCount:= 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_PROMISE_CAPTION_BI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_PROMISE_CAPTION (
    ID,
    ACCEPTDATE,
    ACCEPTED_REVERTED,
    AGREEMENT_DATE,
    AGREEMENT_END,
    AGREEMENT_NOTE,
    AGREEMENT_TYPE,
    AGREEMENT_SUMMA,
    SUPPLIER_REF,
    DELIVERY_RULES,
    TOTALSUMM,
    BUDGETORG_REF,
    FACIALACC_CLS,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    ANUMBER,
    REJECT_CLS,
    REJECTCAUSE,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DOCUMENTSTATE,
    USERSVISA,
    RVERSION,
    DOCSTATEREF,
    STIMATEID,
    BIDNUMBER,
    FAXDOCCOUNT,
    SUPPLIER_ACC_REF,
    AGREEMENT_NUM,
    INFONUMBER,
    ADVANCESUMMA,
    TEMPREJECTCAUSE
  ) VALUES (
    new$ID,
    new$ACCEPTDATE,
    new$ACCEPTED_REVERTED,
    new$AGREEMENT_DATE,
    new$AGREEMENT_END,
    new$AGREEMENT_NOTE,
    new$AGREEMENT_TYPE,
    new$AGREEMENT_SUMMA,
    new$SUPPLIER_REF,
    new$DELIVERY_RULES,
    new$TOTALSUMM,
    new$BUDGETORG_REF,
    new$FACIALACC_CLS,
    new$BUDGETREF,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$ANUMBER,
    new$REJECT_CLS,
    new$REJECTCAUSE,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$DOCUMENTSTATE,
    new$USERSVISA,
    new$RVERSION,
    new$DOCSTATEREF,
    new$STIMATEID,
    new$BIDNUMBER,
    new$FAXDOCCOUNT,
    new$SUPPLIER_ACC_REF,
    new$AGREEMENT_NUM,
    new$INFONUMBER,
    new$ADVANCESUMMA,
    new$TEMPREJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_PROMISECAPTION_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 77) AND (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_PROMISE_CAPTION_IU
  INSTEAD OF UPDATE
  ON PROMISE_CAPTION
  FOR EACH ROW
DECLARE
  new$ID PROMISE_CAPTION.ID%TYPE := :NEW.ID;
  new$ACCEPTDATE PROMISE_CAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$ACCEPTED_REVERTED PROMISE_CAPTION.ACCEPTED_REVERTED%TYPE := :NEW.ACCEPTED_REVERTED;
  new$AGREEMENT_DATE PROMISE_CAPTION.AGREEMENT_DATE%TYPE := :NEW.AGREEMENT_DATE;
  new$AGREEMENT_END PROMISE_CAPTION.AGREEMENT_END%TYPE := :NEW.AGREEMENT_END;
  new$AGREEMENT_NOTE PROMISE_CAPTION.AGREEMENT_NOTE%TYPE := :NEW.AGREEMENT_NOTE;
  new$AGREEMENT_TYPE PROMISE_CAPTION.AGREEMENT_TYPE%TYPE := :NEW.AGREEMENT_TYPE;
  new$AGREEMENT_SUMMA PROMISE_CAPTION.AGREEMENT_SUMMA%TYPE := :NEW.AGREEMENT_SUMMA;
  new$SUPPLIER_REF PROMISE_CAPTION.SUPPLIER_REF%TYPE := :NEW.SUPPLIER_REF;
  new$DELIVERY_RULES PROMISE_CAPTION.DELIVERY_RULES%TYPE := :NEW.DELIVERY_RULES;
  new$TOTALSUMM PROMISE_CAPTION.TOTALSUMM%TYPE := :NEW.TOTALSUMM;
  new$BUDGETORG_REF PROMISE_CAPTION.BUDGETORG_REF%TYPE := :NEW.BUDGETORG_REF;
  new$FACIALACC_CLS PROMISE_CAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$BUDGETREF PROMISE_CAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER PROMISE_CAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PROMISE_CAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PROMISE_CAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PROMISE_CAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$ANUMBER PROMISE_CAPTION.ANUMBER%TYPE := :NEW.ANUMBER;
  new$REJECT_CLS PROMISE_CAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE PROMISE_CAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CRYPTOSTATUS PROMISE_CAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID PROMISE_CAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PROMISE_CAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCUMENTSTATE PROMISE_CAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA PROMISE_CAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$RVERSION PROMISE_CAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$DOCSTATEREF PROMISE_CAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$STIMATEID PROMISE_CAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$BIDNUMBER PROMISE_CAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT PROMISE_CAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$SUPPLIER_ACC_REF PROMISE_CAPTION.SUPPLIER_ACC_REF%TYPE := :NEW.SUPPLIER_ACC_REF;
  new$AGREEMENT_NUM PROMISE_CAPTION.AGREEMENT_NUM%TYPE := :NEW.AGREEMENT_NUM;
  new$INFONUMBER PROMISE_CAPTION.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$ADVANCESUMMA PROMISE_CAPTION.ADVANCESUMMA%TYPE := :NEW.ADVANCESUMMA;
  new$TEMPREJECTCAUSE PROMISE_CAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  cnt$ NUMBER (10);
  IsReject$ NUMBER(10);
  DetCount1$ NUMBER(10);
  CloseDate1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_PROMISE_CAPTION_BU)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$Accepted_Reverted is null) then 
    new$Accepted_Reverted := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$TotalSumm is null) then 
    new$TotalSumm := 0;
  END IF;
  if (new$Agreement_Type is null) then 
    new$Agreement_Type := 0;
  END IF;
  if (new$Agreement_Summa is null) then 
    new$Agreement_Summa := 0;
  END IF;
  if ((new$reject_cls is not null) and (:old.reject_cls is null) )then 
    new$Accepted_Reverted := 1;
  END IF;
  if ((new$reject_cls is null) and (:old.reject_cls is not null) )then 
    new$Accepted_Reverted := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)              into DetCount1$ from Promise_detail where Title_Ref = :old.ID
      ;
      if (DetCount1$ > 0) then 
        RaiseException('Ex_CantModufyBudget');          
      END IF;
    END IF;
  END IF;
  /*        */
  if ((new$AcceptDate is not null) and (new$Accepted_Reverted = 0) and (new$Reject_Cls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_101 (TR_PROMISECAPTION_BU_101)
-- Create 10.08.2004
-- Last update 19.03.2010
-- - - - - - - - - - - - -

  /*  ,    */
  if ( ((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted_Reverted = 0)) or
       ((:old.Accepted_Reverted = 1) and (new$Accepted_Reverted = 0) and (new$AcceptDate is not null))
     ) then
     
    /*        ,     .*/
    for R$ IN (select Parent_Promise PP, ID
        from Promise_Detail
        where (Title_Ref = new$id) and (Parent_Promise is not null) and (budgetref = new$budgetref))
    LOOP
            /*     */
      select count(pd.ID) into CNT$
      from Promise_Detail pd, promise_caption pc
      /*        .       .*/
      where ((pd.Parent_Promise = R$.PP) and (pc.id = pd.title_ref) and (pc.acceptdate is not null)
             and (pc.budgetref = pd.budgetref) and (pc.budgetref = new$budgetref) AND (pc.Accepted_Reverted = 0) AND
             (pd.id <> R$.ID)) AND (ROWNUM = 1);

      /*     ,   */
      if (cnt$ > 0) then
        RaiseException('EX_PROMISE_ADJUSTDUPLICATE');
      end if;  
    end LOOP;
  end if;

-- - - - - - - - - - - - -
-- BU_200 (TR_PROMISE_CAPTION_BU_200)
-- Create 21.02.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   /*      */
   IF (:OLD.DOCSTATEREF <> new$DOCSTATEREF) THEN
      INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
        VALUES (new$id, :OLD.DOCSTATEREF, new$DOCSTATEREF);
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_PROMISE_CAPTION_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.Reject_CLS is null)and(new$Reject_CLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.Reject_CLS is not null)and(new$Reject_CLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = new$ID)
      or(ChildID in (select d.id from Promise_Detail d where d.Title_Ref = new$id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_PROMISE_CAPTION_BU_700)
-- Create 17.09.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_PROMISE_CAPTION SET
    ID = new$ID,
    ACCEPTDATE = new$ACCEPTDATE,
    ACCEPTED_REVERTED = new$ACCEPTED_REVERTED,
    AGREEMENT_DATE = new$AGREEMENT_DATE,
    AGREEMENT_END = new$AGREEMENT_END,
    AGREEMENT_NOTE = new$AGREEMENT_NOTE,
    AGREEMENT_TYPE = new$AGREEMENT_TYPE,
    AGREEMENT_SUMMA = new$AGREEMENT_SUMMA,
    SUPPLIER_REF = new$SUPPLIER_REF,
    DELIVERY_RULES = new$DELIVERY_RULES,
    TOTALSUMM = new$TOTALSUMM,
    BUDGETORG_REF = new$BUDGETORG_REF,
    FACIALACC_CLS = new$FACIALACC_CLS,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    ANUMBER = new$ANUMBER,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    RVERSION = new$RVERSION,
    DOCSTATEREF = new$DOCSTATEREF,
    STIMATEID = new$STIMATEID,
    BIDNUMBER = new$BIDNUMBER,
    FAXDOCCOUNT = new$FAXDOCCOUNT,
    SUPPLIER_ACC_REF = new$SUPPLIER_ACC_REF,
    AGREEMENT_NUM = new$AGREEMENT_NUM,
    INFONUMBER = new$INFONUMBER,
    ADVANCESUMMA = new$ADVANCESUMMA,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_1 (TR_PROMISE_CAPTION_AU_1)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  /*          
               */
  if (  ( ((:old.AcceptDate is null) or (:old.Accepted_Reverted = 1)) and /*  */
  (new$AcceptDate is not null) and (new$Accepted_Reverted = 0)
  ) or
  (
  ((new$AcceptDate is null) or (new$Accepted_Reverted = 1)) and /*  */
  (:old.AcceptDate is not null) and (:old.Accepted_Reverted = 0)
  ) or
  ((new$AcceptDate is not null) and (:old.AcceptDate is not null) and /*  */
  (new$AcceptDate <> :old.AcceptDate)
  )
  ) then
    /*   ,      ,
                      */    
    CloseDate1$ := new$AcceptDate;
    /*   ,   NULL */
    if (new$Accepted_Reverted = 1) then
      CloseDate1$ := null;
    END IF;
    /*            */
    FOR REC$1 IN (select Parent_Promise AS PP, RegistrNumber
     AS ChildNum         from Promise_Detail
    where (Title_Ref = new$id) and (Parent_Promise is not null)
    )
    LOOP
      if (CloseDate1$ is null) then
        REC$1.ChildNum := null;
      END IF;
      update Promise_Detail set
      CloseDate = CloseDate1$,
      Child_Promise = REC$1.ChildNum

      where
      (RegistrNumber = REC$1.PP) and
      (budgetref = new$budgetref);
          
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_PROMISE_CAPTION_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (77, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
            WHERE (TableID = 77) AND (RecordId = new$ID);
   END IF;

END;
/
update PROMISE_CAPTION set
  TempRejectCause = REJECTCAUSE
/
commit work 
/
ALTER TABLE TB_PROMISE_CAPTION DROP (REJECTCAUSE)
/

CREATE OR REPLACE VIEW PROMISE_CAPTION (
  ID,
  ACCEPTDATE,
  ACCEPTED_REVERTED,
  AGREEMENT_DATE,
  AGREEMENT_END,
  AGREEMENT_NOTE,
  AGREEMENT_TYPE,
  AGREEMENT_SUMMA,
  SUPPLIER_REF,
  DELIVERY_RULES,
  TOTALSUMM,
  BUDGETORG_REF,
  FACIALACC_CLS,
  BUDGETREF,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  ANUMBER,
  REJECT_CLS,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  DOCUMENTSTATE,
  USERSVISA,
  RVERSION,
  DOCSTATEREF,
  STIMATEID,
  BIDNUMBER,
  FAXDOCCOUNT,
  SUPPLIER_ACC_REF,
  AGREEMENT_NUM,
  INFONUMBER,
  ADVANCESUMMA,
  TEMPREJECTCAUSE)
AS
  SELECT
    ID,
    ACCEPTDATE,
    ACCEPTED_REVERTED,
    AGREEMENT_DATE,
    AGREEMENT_END,
    AGREEMENT_NOTE,
    AGREEMENT_TYPE,
    AGREEMENT_SUMMA,
    SUPPLIER_REF,
    DELIVERY_RULES,
    TOTALSUMM,
    BUDGETORG_REF,
    FACIALACC_CLS,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    ANUMBER,
    REJECT_CLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DOCUMENTSTATE,
    USERSVISA,
    RVERSION,
    DOCSTATEREF,
    STIMATEID,
    BIDNUMBER,
    FAXDOCCOUNT,
    SUPPLIER_ACC_REF,
    AGREEMENT_NUM,
    INFONUMBER,
    ADVANCESUMMA,
    TEMPREJECTCAUSE
  FROM TB_PROMISE_CAPTION
/

CREATE OR REPLACE TRIGGER TR_PROMISE_CAPTION_ID
  INSTEAD OF DELETE
  ON PROMISE_CAPTION
  FOR EACH ROW
DECLARE
  CNT$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_PROMISE_CAPTION_BD)
-- Last update 03.07.2006
-- - - - - - - - - - - - -

  /*       ,  */
  /*         .*/
  for R$ In (select pd.id ID, pd.registrnumber RN
    from Promise_Detail pd
    where pd.title_ref = :old.id)
  LOOP
    select count(pd2.id) into CNT$
        from promise_detail pd2
        where (pd2.parent_promise = R$.RN) and (pd2.budgetref = :old.budgetref) AND (ROWNUM = 1);

    if (CNT$ > 0) then
      RaiseException('EX_TEN_CANTDELADJUSTMENTED');
    else
      delete from Promise_Detail where Title_Ref = :old.id;    
    end if;  
  end LOOP;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_PROMISE_CAPTION
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);
   
  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_500 (TR_PROMISECAPTION_AD_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate, Summa)
    VALUES (77, :OLD.ID, SYSDATE, :OLD.Agreement_Summa);

END;
/

CREATE OR REPLACE TRIGGER TR_PROMISE_CAPTION_II
  INSTEAD OF INSERT
  ON PROMISE_CAPTION
  FOR EACH ROW
DECLARE
  new$ID PROMISE_CAPTION.ID%TYPE := :NEW.ID;
  new$ACCEPTDATE PROMISE_CAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$ACCEPTED_REVERTED PROMISE_CAPTION.ACCEPTED_REVERTED%TYPE := :NEW.ACCEPTED_REVERTED;
  new$AGREEMENT_DATE PROMISE_CAPTION.AGREEMENT_DATE%TYPE := :NEW.AGREEMENT_DATE;
  new$AGREEMENT_END PROMISE_CAPTION.AGREEMENT_END%TYPE := :NEW.AGREEMENT_END;
  new$AGREEMENT_NOTE PROMISE_CAPTION.AGREEMENT_NOTE%TYPE := :NEW.AGREEMENT_NOTE;
  new$AGREEMENT_TYPE PROMISE_CAPTION.AGREEMENT_TYPE%TYPE := :NEW.AGREEMENT_TYPE;
  new$AGREEMENT_SUMMA PROMISE_CAPTION.AGREEMENT_SUMMA%TYPE := :NEW.AGREEMENT_SUMMA;
  new$SUPPLIER_REF PROMISE_CAPTION.SUPPLIER_REF%TYPE := :NEW.SUPPLIER_REF;
  new$DELIVERY_RULES PROMISE_CAPTION.DELIVERY_RULES%TYPE := :NEW.DELIVERY_RULES;
  new$TOTALSUMM PROMISE_CAPTION.TOTALSUMM%TYPE := :NEW.TOTALSUMM;
  new$BUDGETORG_REF PROMISE_CAPTION.BUDGETORG_REF%TYPE := :NEW.BUDGETORG_REF;
  new$FACIALACC_CLS PROMISE_CAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$BUDGETREF PROMISE_CAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER PROMISE_CAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PROMISE_CAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PROMISE_CAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PROMISE_CAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$ANUMBER PROMISE_CAPTION.ANUMBER%TYPE := :NEW.ANUMBER;
  new$REJECT_CLS PROMISE_CAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$CRYPTOSTATUS PROMISE_CAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID PROMISE_CAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PROMISE_CAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCUMENTSTATE PROMISE_CAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA PROMISE_CAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$RVERSION PROMISE_CAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$DOCSTATEREF PROMISE_CAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$STIMATEID PROMISE_CAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$BIDNUMBER PROMISE_CAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT PROMISE_CAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$SUPPLIER_ACC_REF PROMISE_CAPTION.SUPPLIER_ACC_REF%TYPE := :NEW.SUPPLIER_ACC_REF;
  new$AGREEMENT_NUM PROMISE_CAPTION.AGREEMENT_NUM%TYPE := :NEW.AGREEMENT_NUM;
  new$INFONUMBER PROMISE_CAPTION.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$ADVANCESUMMA PROMISE_CAPTION.ADVANCESUMMA%TYPE := :NEW.ADVANCESUMMA;
  new$TEMPREJECTCAUSE PROMISE_CAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  UseFax$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_PROMISE_CAPTION_BI)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$Accepted_Reverted is null) then 
    new$Accepted_Reverted := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$TotalSumm is null) then 
    new$TotalSumm := 0;
  END IF;
  if (new$Agreement_Type is null) then 
    new$Agreement_Type := 0;
  END IF;
  if (new$Agreement_Summa is null) then 
    new$Agreement_Summa := 0;
  END IF;
  if ((new$reject_cls is not null))then 
    new$Accepted_Reverted := 1;
  END IF;
  if ((new$reject_cls is null))then 
    new$Accepted_Reverted := 0;
  END IF;
      
  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then 
    BEGIN
      select fa.BudgetRef         into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then 
    BEGIN
      select ConstValue         into new$BudgetRef from IntConst where (ProgIndex = -1) and (ConstIndex = 3)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_430 (TR_PROMISE_CAPTION_BI_430)
-- Version 7.01.00.2
-- - - - - - - - - - - - -

  IF (new$SenderID IS NOT NULL) THEN 
    /*     */
    GetIntConst(30, 19,UseFax$);
    IF ((new$BidNumber IS NULL) AND (UseFax$ = 1)) THEN 
      new$BidNumber:= new$Agreement_Num;
    END IF;
    SELECT COUNT(*)         INTO
    new$FaxDocCount FROM FaxDocs WHERE 
    (OwnerDocNumber=new$BidNumber)
    AND (ClientID=new$SenderID)
    AND (FacialAcc_Cls=new$FacialAcc_CLS)
    AND (OwnerDate = new$Agreement_Date)
    ;
  ELSE
    new$FaxDocCount:= 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_PROMISE_CAPTION_BI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_PROMISE_CAPTION (
    ID,
    ACCEPTDATE,
    ACCEPTED_REVERTED,
    AGREEMENT_DATE,
    AGREEMENT_END,
    AGREEMENT_NOTE,
    AGREEMENT_TYPE,
    AGREEMENT_SUMMA,
    SUPPLIER_REF,
    DELIVERY_RULES,
    TOTALSUMM,
    BUDGETORG_REF,
    FACIALACC_CLS,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    ANUMBER,
    REJECT_CLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DOCUMENTSTATE,
    USERSVISA,
    RVERSION,
    DOCSTATEREF,
    STIMATEID,
    BIDNUMBER,
    FAXDOCCOUNT,
    SUPPLIER_ACC_REF,
    AGREEMENT_NUM,
    INFONUMBER,
    ADVANCESUMMA,
    TEMPREJECTCAUSE
  ) VALUES (
    new$ID,
    new$ACCEPTDATE,
    new$ACCEPTED_REVERTED,
    new$AGREEMENT_DATE,
    new$AGREEMENT_END,
    new$AGREEMENT_NOTE,
    new$AGREEMENT_TYPE,
    new$AGREEMENT_SUMMA,
    new$SUPPLIER_REF,
    new$DELIVERY_RULES,
    new$TOTALSUMM,
    new$BUDGETORG_REF,
    new$FACIALACC_CLS,
    new$BUDGETREF,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$ANUMBER,
    new$REJECT_CLS,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$DOCUMENTSTATE,
    new$USERSVISA,
    new$RVERSION,
    new$DOCSTATEREF,
    new$STIMATEID,
    new$BIDNUMBER,
    new$FAXDOCCOUNT,
    new$SUPPLIER_ACC_REF,
    new$AGREEMENT_NUM,
    new$INFONUMBER,
    new$ADVANCESUMMA,
    new$TEMPREJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_PROMISECAPTION_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 77) AND (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_PROMISE_CAPTION_IU
  INSTEAD OF UPDATE
  ON PROMISE_CAPTION
  FOR EACH ROW
DECLARE
  new$ID PROMISE_CAPTION.ID%TYPE := :NEW.ID;
  new$ACCEPTDATE PROMISE_CAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$ACCEPTED_REVERTED PROMISE_CAPTION.ACCEPTED_REVERTED%TYPE := :NEW.ACCEPTED_REVERTED;
  new$AGREEMENT_DATE PROMISE_CAPTION.AGREEMENT_DATE%TYPE := :NEW.AGREEMENT_DATE;
  new$AGREEMENT_END PROMISE_CAPTION.AGREEMENT_END%TYPE := :NEW.AGREEMENT_END;
  new$AGREEMENT_NOTE PROMISE_CAPTION.AGREEMENT_NOTE%TYPE := :NEW.AGREEMENT_NOTE;
  new$AGREEMENT_TYPE PROMISE_CAPTION.AGREEMENT_TYPE%TYPE := :NEW.AGREEMENT_TYPE;
  new$AGREEMENT_SUMMA PROMISE_CAPTION.AGREEMENT_SUMMA%TYPE := :NEW.AGREEMENT_SUMMA;
  new$SUPPLIER_REF PROMISE_CAPTION.SUPPLIER_REF%TYPE := :NEW.SUPPLIER_REF;
  new$DELIVERY_RULES PROMISE_CAPTION.DELIVERY_RULES%TYPE := :NEW.DELIVERY_RULES;
  new$TOTALSUMM PROMISE_CAPTION.TOTALSUMM%TYPE := :NEW.TOTALSUMM;
  new$BUDGETORG_REF PROMISE_CAPTION.BUDGETORG_REF%TYPE := :NEW.BUDGETORG_REF;
  new$FACIALACC_CLS PROMISE_CAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$BUDGETREF PROMISE_CAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER PROMISE_CAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PROMISE_CAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PROMISE_CAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PROMISE_CAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$ANUMBER PROMISE_CAPTION.ANUMBER%TYPE := :NEW.ANUMBER;
  new$REJECT_CLS PROMISE_CAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$CRYPTOSTATUS PROMISE_CAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID PROMISE_CAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PROMISE_CAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCUMENTSTATE PROMISE_CAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA PROMISE_CAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$RVERSION PROMISE_CAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$DOCSTATEREF PROMISE_CAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$STIMATEID PROMISE_CAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$BIDNUMBER PROMISE_CAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT PROMISE_CAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$SUPPLIER_ACC_REF PROMISE_CAPTION.SUPPLIER_ACC_REF%TYPE := :NEW.SUPPLIER_ACC_REF;
  new$AGREEMENT_NUM PROMISE_CAPTION.AGREEMENT_NUM%TYPE := :NEW.AGREEMENT_NUM;
  new$INFONUMBER PROMISE_CAPTION.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$ADVANCESUMMA PROMISE_CAPTION.ADVANCESUMMA%TYPE := :NEW.ADVANCESUMMA;
  new$TEMPREJECTCAUSE PROMISE_CAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  cnt$ NUMBER (10);
  IsReject$ NUMBER(10);
  DetCount1$ NUMBER(10);
  CloseDate1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_PROMISE_CAPTION_BU)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$Accepted_Reverted is null) then 
    new$Accepted_Reverted := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$TotalSumm is null) then 
    new$TotalSumm := 0;
  END IF;
  if (new$Agreement_Type is null) then 
    new$Agreement_Type := 0;
  END IF;
  if (new$Agreement_Summa is null) then 
    new$Agreement_Summa := 0;
  END IF;
  if ((new$reject_cls is not null) and (:old.reject_cls is null) )then 
    new$Accepted_Reverted := 1;
  END IF;
  if ((new$reject_cls is null) and (:old.reject_cls is not null) )then 
    new$Accepted_Reverted := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)              into DetCount1$ from Promise_detail where Title_Ref = :old.ID
      ;
      if (DetCount1$ > 0) then 
        RaiseException('Ex_CantModufyBudget');          
      END IF;
    END IF;
  END IF;
  /*        */
  if ((new$AcceptDate is not null) and (new$Accepted_Reverted = 0) and (new$Reject_Cls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_101 (TR_PROMISECAPTION_BU_101)
-- Create 10.08.2004
-- Last update 19.03.2010
-- - - - - - - - - - - - -

  /*  ,    */
  if ( ((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted_Reverted = 0)) or
       ((:old.Accepted_Reverted = 1) and (new$Accepted_Reverted = 0) and (new$AcceptDate is not null))
     ) then
     
    /*        ,     .*/
    for R$ IN (select Parent_Promise PP, ID
        from Promise_Detail
        where (Title_Ref = new$id) and (Parent_Promise is not null) and (budgetref = new$budgetref))
    LOOP
            /*     */
      select count(pd.ID) into CNT$
      from Promise_Detail pd, promise_caption pc
      /*        .       .*/
      where ((pd.Parent_Promise = R$.PP) and (pc.id = pd.title_ref) and (pc.acceptdate is not null)
             and (pc.budgetref = pd.budgetref) and (pc.budgetref = new$budgetref) AND (pc.Accepted_Reverted = 0) AND
             (pd.id <> R$.ID)) AND (ROWNUM = 1);

      /*     ,   */
      if (cnt$ > 0) then
        RaiseException('EX_PROMISE_ADJUSTDUPLICATE');
      end if;  
    end LOOP;
  end if;

-- - - - - - - - - - - - -
-- BU_200 (TR_PROMISE_CAPTION_BU_200)
-- Create 21.02.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   /*      */
   IF (:OLD.DOCSTATEREF <> new$DOCSTATEREF) THEN
      INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
        VALUES (new$id, :OLD.DOCSTATEREF, new$DOCSTATEREF);
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_PROMISE_CAPTION_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.Reject_CLS is null)and(new$Reject_CLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.Reject_CLS is not null)and(new$Reject_CLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = new$ID)
      or(ChildID in (select d.id from Promise_Detail d where d.Title_Ref = new$id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_PROMISE_CAPTION_BU_700)
-- Create 17.09.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_PROMISE_CAPTION SET
    ID = new$ID,
    ACCEPTDATE = new$ACCEPTDATE,
    ACCEPTED_REVERTED = new$ACCEPTED_REVERTED,
    AGREEMENT_DATE = new$AGREEMENT_DATE,
    AGREEMENT_END = new$AGREEMENT_END,
    AGREEMENT_NOTE = new$AGREEMENT_NOTE,
    AGREEMENT_TYPE = new$AGREEMENT_TYPE,
    AGREEMENT_SUMMA = new$AGREEMENT_SUMMA,
    SUPPLIER_REF = new$SUPPLIER_REF,
    DELIVERY_RULES = new$DELIVERY_RULES,
    TOTALSUMM = new$TOTALSUMM,
    BUDGETORG_REF = new$BUDGETORG_REF,
    FACIALACC_CLS = new$FACIALACC_CLS,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    ANUMBER = new$ANUMBER,
    REJECT_CLS = new$REJECT_CLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    RVERSION = new$RVERSION,
    DOCSTATEREF = new$DOCSTATEREF,
    STIMATEID = new$STIMATEID,
    BIDNUMBER = new$BIDNUMBER,
    FAXDOCCOUNT = new$FAXDOCCOUNT,
    SUPPLIER_ACC_REF = new$SUPPLIER_ACC_REF,
    AGREEMENT_NUM = new$AGREEMENT_NUM,
    INFONUMBER = new$INFONUMBER,
    ADVANCESUMMA = new$ADVANCESUMMA,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_1 (TR_PROMISE_CAPTION_AU_1)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  /*          
               */
  if (  ( ((:old.AcceptDate is null) or (:old.Accepted_Reverted = 1)) and /*  */
  (new$AcceptDate is not null) and (new$Accepted_Reverted = 0)
  ) or
  (
  ((new$AcceptDate is null) or (new$Accepted_Reverted = 1)) and /*  */
  (:old.AcceptDate is not null) and (:old.Accepted_Reverted = 0)
  ) or
  ((new$AcceptDate is not null) and (:old.AcceptDate is not null) and /*  */
  (new$AcceptDate <> :old.AcceptDate)
  )
  ) then
    /*   ,      ,
                      */    
    CloseDate1$ := new$AcceptDate;
    /*   ,   NULL */
    if (new$Accepted_Reverted = 1) then
      CloseDate1$ := null;
    END IF;
    /*            */
    FOR REC$1 IN (select Parent_Promise AS PP, RegistrNumber
     AS ChildNum         from Promise_Detail
    where (Title_Ref = new$id) and (Parent_Promise is not null)
    )
    LOOP
      if (CloseDate1$ is null) then
        REC$1.ChildNum := null;
      END IF;
      update Promise_Detail set
      CloseDate = CloseDate1$,
      Child_Promise = REC$1.ChildNum

      where
      (RegistrNumber = REC$1.PP) and
      (budgetref = new$budgetref);
          
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_PROMISE_CAPTION_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (77, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
            WHERE (TableID = 77) AND (RecordId = new$ID);
   END IF;

END;
/
ALTER TABLE TB_PROMISE_CAPTION ADD (
  REJECTCAUSE VARCHAR2(1000)
)
/

CREATE OR REPLACE VIEW PROMISE_CAPTION (
  ID,
  ACCEPTDATE,
  ACCEPTED_REVERTED,
  AGREEMENT_DATE,
  AGREEMENT_END,
  AGREEMENT_NOTE,
  AGREEMENT_TYPE,
  AGREEMENT_SUMMA,
  SUPPLIER_REF,
  DELIVERY_RULES,
  TOTALSUMM,
  BUDGETORG_REF,
  FACIALACC_CLS,
  BUDGETREF,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  ANUMBER,
  REJECT_CLS,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  DOCUMENTSTATE,
  USERSVISA,
  RVERSION,
  DOCSTATEREF,
  STIMATEID,
  BIDNUMBER,
  FAXDOCCOUNT,
  SUPPLIER_ACC_REF,
  AGREEMENT_NUM,
  INFONUMBER,
  ADVANCESUMMA,
  TEMPREJECTCAUSE,
  REJECTCAUSE)
AS
  SELECT
    ID,
    ACCEPTDATE,
    ACCEPTED_REVERTED,
    AGREEMENT_DATE,
    AGREEMENT_END,
    AGREEMENT_NOTE,
    AGREEMENT_TYPE,
    AGREEMENT_SUMMA,
    SUPPLIER_REF,
    DELIVERY_RULES,
    TOTALSUMM,
    BUDGETORG_REF,
    FACIALACC_CLS,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    ANUMBER,
    REJECT_CLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DOCUMENTSTATE,
    USERSVISA,
    RVERSION,
    DOCSTATEREF,
    STIMATEID,
    BIDNUMBER,
    FAXDOCCOUNT,
    SUPPLIER_ACC_REF,
    AGREEMENT_NUM,
    INFONUMBER,
    ADVANCESUMMA,
    TEMPREJECTCAUSE,
    REJECTCAUSE
  FROM TB_PROMISE_CAPTION
/

CREATE OR REPLACE TRIGGER TR_PROMISE_CAPTION_ID
  INSTEAD OF DELETE
  ON PROMISE_CAPTION
  FOR EACH ROW
DECLARE
  CNT$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_PROMISE_CAPTION_BD)
-- Last update 03.07.2006
-- - - - - - - - - - - - -

  /*       ,  */
  /*         .*/
  for R$ In (select pd.id ID, pd.registrnumber RN
    from Promise_Detail pd
    where pd.title_ref = :old.id)
  LOOP
    select count(pd2.id) into CNT$
        from promise_detail pd2
        where (pd2.parent_promise = R$.RN) and (pd2.budgetref = :old.budgetref) AND (ROWNUM = 1);

    if (CNT$ > 0) then
      RaiseException('EX_TEN_CANTDELADJUSTMENTED');
    else
      delete from Promise_Detail where Title_Ref = :old.id;    
    end if;  
  end LOOP;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_PROMISE_CAPTION
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);
   
  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_500 (TR_PROMISECAPTION_AD_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate, Summa)
    VALUES (77, :OLD.ID, SYSDATE, :OLD.Agreement_Summa);

END;
/

CREATE OR REPLACE TRIGGER TR_PROMISE_CAPTION_II
  INSTEAD OF INSERT
  ON PROMISE_CAPTION
  FOR EACH ROW
DECLARE
  new$ID PROMISE_CAPTION.ID%TYPE := :NEW.ID;
  new$ACCEPTDATE PROMISE_CAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$ACCEPTED_REVERTED PROMISE_CAPTION.ACCEPTED_REVERTED%TYPE := :NEW.ACCEPTED_REVERTED;
  new$AGREEMENT_DATE PROMISE_CAPTION.AGREEMENT_DATE%TYPE := :NEW.AGREEMENT_DATE;
  new$AGREEMENT_END PROMISE_CAPTION.AGREEMENT_END%TYPE := :NEW.AGREEMENT_END;
  new$AGREEMENT_NOTE PROMISE_CAPTION.AGREEMENT_NOTE%TYPE := :NEW.AGREEMENT_NOTE;
  new$AGREEMENT_TYPE PROMISE_CAPTION.AGREEMENT_TYPE%TYPE := :NEW.AGREEMENT_TYPE;
  new$AGREEMENT_SUMMA PROMISE_CAPTION.AGREEMENT_SUMMA%TYPE := :NEW.AGREEMENT_SUMMA;
  new$SUPPLIER_REF PROMISE_CAPTION.SUPPLIER_REF%TYPE := :NEW.SUPPLIER_REF;
  new$DELIVERY_RULES PROMISE_CAPTION.DELIVERY_RULES%TYPE := :NEW.DELIVERY_RULES;
  new$TOTALSUMM PROMISE_CAPTION.TOTALSUMM%TYPE := :NEW.TOTALSUMM;
  new$BUDGETORG_REF PROMISE_CAPTION.BUDGETORG_REF%TYPE := :NEW.BUDGETORG_REF;
  new$FACIALACC_CLS PROMISE_CAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$BUDGETREF PROMISE_CAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER PROMISE_CAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PROMISE_CAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PROMISE_CAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PROMISE_CAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$ANUMBER PROMISE_CAPTION.ANUMBER%TYPE := :NEW.ANUMBER;
  new$REJECT_CLS PROMISE_CAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$CRYPTOSTATUS PROMISE_CAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID PROMISE_CAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PROMISE_CAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCUMENTSTATE PROMISE_CAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA PROMISE_CAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$RVERSION PROMISE_CAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$DOCSTATEREF PROMISE_CAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$STIMATEID PROMISE_CAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$BIDNUMBER PROMISE_CAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT PROMISE_CAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$SUPPLIER_ACC_REF PROMISE_CAPTION.SUPPLIER_ACC_REF%TYPE := :NEW.SUPPLIER_ACC_REF;
  new$AGREEMENT_NUM PROMISE_CAPTION.AGREEMENT_NUM%TYPE := :NEW.AGREEMENT_NUM;
  new$INFONUMBER PROMISE_CAPTION.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$ADVANCESUMMA PROMISE_CAPTION.ADVANCESUMMA%TYPE := :NEW.ADVANCESUMMA;
  new$TEMPREJECTCAUSE PROMISE_CAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
  new$REJECTCAUSE PROMISE_CAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  UseFax$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_PROMISE_CAPTION_BI)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$Accepted_Reverted is null) then 
    new$Accepted_Reverted := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$TotalSumm is null) then 
    new$TotalSumm := 0;
  END IF;
  if (new$Agreement_Type is null) then 
    new$Agreement_Type := 0;
  END IF;
  if (new$Agreement_Summa is null) then 
    new$Agreement_Summa := 0;
  END IF;
  if ((new$reject_cls is not null))then 
    new$Accepted_Reverted := 1;
  END IF;
  if ((new$reject_cls is null))then 
    new$Accepted_Reverted := 0;
  END IF;
      
  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then 
    BEGIN
      select fa.BudgetRef         into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then 
    BEGIN
      select ConstValue         into new$BudgetRef from IntConst where (ProgIndex = -1) and (ConstIndex = 3)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_430 (TR_PROMISE_CAPTION_BI_430)
-- Version 7.01.00.2
-- - - - - - - - - - - - -

  IF (new$SenderID IS NOT NULL) THEN 
    /*     */
    GetIntConst(30, 19,UseFax$);
    IF ((new$BidNumber IS NULL) AND (UseFax$ = 1)) THEN 
      new$BidNumber:= new$Agreement_Num;
    END IF;
    SELECT COUNT(*)         INTO
    new$FaxDocCount FROM FaxDocs WHERE 
    (OwnerDocNumber=new$BidNumber)
    AND (ClientID=new$SenderID)
    AND (FacialAcc_Cls=new$FacialAcc_CLS)
    AND (OwnerDate = new$Agreement_Date)
    ;
  ELSE
    new$FaxDocCount:= 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_PROMISE_CAPTION_BI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_PROMISE_CAPTION (
    ID,
    ACCEPTDATE,
    ACCEPTED_REVERTED,
    AGREEMENT_DATE,
    AGREEMENT_END,
    AGREEMENT_NOTE,
    AGREEMENT_TYPE,
    AGREEMENT_SUMMA,
    SUPPLIER_REF,
    DELIVERY_RULES,
    TOTALSUMM,
    BUDGETORG_REF,
    FACIALACC_CLS,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    ANUMBER,
    REJECT_CLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DOCUMENTSTATE,
    USERSVISA,
    RVERSION,
    DOCSTATEREF,
    STIMATEID,
    BIDNUMBER,
    FAXDOCCOUNT,
    SUPPLIER_ACC_REF,
    AGREEMENT_NUM,
    INFONUMBER,
    ADVANCESUMMA,
    TEMPREJECTCAUSE,
    REJECTCAUSE
  ) VALUES (
    new$ID,
    new$ACCEPTDATE,
    new$ACCEPTED_REVERTED,
    new$AGREEMENT_DATE,
    new$AGREEMENT_END,
    new$AGREEMENT_NOTE,
    new$AGREEMENT_TYPE,
    new$AGREEMENT_SUMMA,
    new$SUPPLIER_REF,
    new$DELIVERY_RULES,
    new$TOTALSUMM,
    new$BUDGETORG_REF,
    new$FACIALACC_CLS,
    new$BUDGETREF,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$ANUMBER,
    new$REJECT_CLS,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$DOCUMENTSTATE,
    new$USERSVISA,
    new$RVERSION,
    new$DOCSTATEREF,
    new$STIMATEID,
    new$BIDNUMBER,
    new$FAXDOCCOUNT,
    new$SUPPLIER_ACC_REF,
    new$AGREEMENT_NUM,
    new$INFONUMBER,
    new$ADVANCESUMMA,
    new$TEMPREJECTCAUSE,
    new$REJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_PROMISECAPTION_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 77) AND (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_PROMISE_CAPTION_IU
  INSTEAD OF UPDATE
  ON PROMISE_CAPTION
  FOR EACH ROW
DECLARE
  new$ID PROMISE_CAPTION.ID%TYPE := :NEW.ID;
  new$ACCEPTDATE PROMISE_CAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$ACCEPTED_REVERTED PROMISE_CAPTION.ACCEPTED_REVERTED%TYPE := :NEW.ACCEPTED_REVERTED;
  new$AGREEMENT_DATE PROMISE_CAPTION.AGREEMENT_DATE%TYPE := :NEW.AGREEMENT_DATE;
  new$AGREEMENT_END PROMISE_CAPTION.AGREEMENT_END%TYPE := :NEW.AGREEMENT_END;
  new$AGREEMENT_NOTE PROMISE_CAPTION.AGREEMENT_NOTE%TYPE := :NEW.AGREEMENT_NOTE;
  new$AGREEMENT_TYPE PROMISE_CAPTION.AGREEMENT_TYPE%TYPE := :NEW.AGREEMENT_TYPE;
  new$AGREEMENT_SUMMA PROMISE_CAPTION.AGREEMENT_SUMMA%TYPE := :NEW.AGREEMENT_SUMMA;
  new$SUPPLIER_REF PROMISE_CAPTION.SUPPLIER_REF%TYPE := :NEW.SUPPLIER_REF;
  new$DELIVERY_RULES PROMISE_CAPTION.DELIVERY_RULES%TYPE := :NEW.DELIVERY_RULES;
  new$TOTALSUMM PROMISE_CAPTION.TOTALSUMM%TYPE := :NEW.TOTALSUMM;
  new$BUDGETORG_REF PROMISE_CAPTION.BUDGETORG_REF%TYPE := :NEW.BUDGETORG_REF;
  new$FACIALACC_CLS PROMISE_CAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$BUDGETREF PROMISE_CAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER PROMISE_CAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PROMISE_CAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PROMISE_CAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PROMISE_CAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$ANUMBER PROMISE_CAPTION.ANUMBER%TYPE := :NEW.ANUMBER;
  new$REJECT_CLS PROMISE_CAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$CRYPTOSTATUS PROMISE_CAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID PROMISE_CAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PROMISE_CAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCUMENTSTATE PROMISE_CAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA PROMISE_CAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$RVERSION PROMISE_CAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$DOCSTATEREF PROMISE_CAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$STIMATEID PROMISE_CAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$BIDNUMBER PROMISE_CAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT PROMISE_CAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$SUPPLIER_ACC_REF PROMISE_CAPTION.SUPPLIER_ACC_REF%TYPE := :NEW.SUPPLIER_ACC_REF;
  new$AGREEMENT_NUM PROMISE_CAPTION.AGREEMENT_NUM%TYPE := :NEW.AGREEMENT_NUM;
  new$INFONUMBER PROMISE_CAPTION.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$ADVANCESUMMA PROMISE_CAPTION.ADVANCESUMMA%TYPE := :NEW.ADVANCESUMMA;
  new$TEMPREJECTCAUSE PROMISE_CAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
  new$REJECTCAUSE PROMISE_CAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  cnt$ NUMBER (10);
  IsReject$ NUMBER(10);
  DetCount1$ NUMBER(10);
  CloseDate1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_PROMISE_CAPTION_BU)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$Accepted_Reverted is null) then 
    new$Accepted_Reverted := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$TotalSumm is null) then 
    new$TotalSumm := 0;
  END IF;
  if (new$Agreement_Type is null) then 
    new$Agreement_Type := 0;
  END IF;
  if (new$Agreement_Summa is null) then 
    new$Agreement_Summa := 0;
  END IF;
  if ((new$reject_cls is not null) and (:old.reject_cls is null) )then 
    new$Accepted_Reverted := 1;
  END IF;
  if ((new$reject_cls is null) and (:old.reject_cls is not null) )then 
    new$Accepted_Reverted := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)              into DetCount1$ from Promise_detail where Title_Ref = :old.ID
      ;
      if (DetCount1$ > 0) then 
        RaiseException('Ex_CantModufyBudget');          
      END IF;
    END IF;
  END IF;
  /*        */
  if ((new$AcceptDate is not null) and (new$Accepted_Reverted = 0) and (new$Reject_Cls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_101 (TR_PROMISECAPTION_BU_101)
-- Create 10.08.2004
-- Last update 19.03.2010
-- - - - - - - - - - - - -

  /*  ,    */
  if ( ((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted_Reverted = 0)) or
       ((:old.Accepted_Reverted = 1) and (new$Accepted_Reverted = 0) and (new$AcceptDate is not null))
     ) then
     
    /*        ,     .*/
    for R$ IN (select Parent_Promise PP, ID
        from Promise_Detail
        where (Title_Ref = new$id) and (Parent_Promise is not null) and (budgetref = new$budgetref))
    LOOP
            /*     */
      select count(pd.ID) into CNT$
      from Promise_Detail pd, promise_caption pc
      /*        .       .*/
      where ((pd.Parent_Promise = R$.PP) and (pc.id = pd.title_ref) and (pc.acceptdate is not null)
             and (pc.budgetref = pd.budgetref) and (pc.budgetref = new$budgetref) AND (pc.Accepted_Reverted = 0) AND
             (pd.id <> R$.ID)) AND (ROWNUM = 1);

      /*     ,   */
      if (cnt$ > 0) then
        RaiseException('EX_PROMISE_ADJUSTDUPLICATE');
      end if;  
    end LOOP;
  end if;

-- - - - - - - - - - - - -
-- BU_200 (TR_PROMISE_CAPTION_BU_200)
-- Create 21.02.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   /*      */
   IF (:OLD.DOCSTATEREF <> new$DOCSTATEREF) THEN
      INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
        VALUES (new$id, :OLD.DOCSTATEREF, new$DOCSTATEREF);
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_PROMISE_CAPTION_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.Reject_CLS is null)and(new$Reject_CLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.Reject_CLS is not null)and(new$Reject_CLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = new$ID)
      or(ChildID in (select d.id from Promise_Detail d where d.Title_Ref = new$id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_PROMISE_CAPTION_BU_700)
-- Create 17.09.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_PROMISE_CAPTION SET
    ID = new$ID,
    ACCEPTDATE = new$ACCEPTDATE,
    ACCEPTED_REVERTED = new$ACCEPTED_REVERTED,
    AGREEMENT_DATE = new$AGREEMENT_DATE,
    AGREEMENT_END = new$AGREEMENT_END,
    AGREEMENT_NOTE = new$AGREEMENT_NOTE,
    AGREEMENT_TYPE = new$AGREEMENT_TYPE,
    AGREEMENT_SUMMA = new$AGREEMENT_SUMMA,
    SUPPLIER_REF = new$SUPPLIER_REF,
    DELIVERY_RULES = new$DELIVERY_RULES,
    TOTALSUMM = new$TOTALSUMM,
    BUDGETORG_REF = new$BUDGETORG_REF,
    FACIALACC_CLS = new$FACIALACC_CLS,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    ANUMBER = new$ANUMBER,
    REJECT_CLS = new$REJECT_CLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    RVERSION = new$RVERSION,
    DOCSTATEREF = new$DOCSTATEREF,
    STIMATEID = new$STIMATEID,
    BIDNUMBER = new$BIDNUMBER,
    FAXDOCCOUNT = new$FAXDOCCOUNT,
    SUPPLIER_ACC_REF = new$SUPPLIER_ACC_REF,
    AGREEMENT_NUM = new$AGREEMENT_NUM,
    INFONUMBER = new$INFONUMBER,
    ADVANCESUMMA = new$ADVANCESUMMA,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_1 (TR_PROMISE_CAPTION_AU_1)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  /*          
               */
  if (  ( ((:old.AcceptDate is null) or (:old.Accepted_Reverted = 1)) and /*  */
  (new$AcceptDate is not null) and (new$Accepted_Reverted = 0)
  ) or
  (
  ((new$AcceptDate is null) or (new$Accepted_Reverted = 1)) and /*  */
  (:old.AcceptDate is not null) and (:old.Accepted_Reverted = 0)
  ) or
  ((new$AcceptDate is not null) and (:old.AcceptDate is not null) and /*  */
  (new$AcceptDate <> :old.AcceptDate)
  )
  ) then
    /*   ,      ,
                      */    
    CloseDate1$ := new$AcceptDate;
    /*   ,   NULL */
    if (new$Accepted_Reverted = 1) then
      CloseDate1$ := null;
    END IF;
    /*            */
    FOR REC$1 IN (select Parent_Promise AS PP, RegistrNumber
     AS ChildNum         from Promise_Detail
    where (Title_Ref = new$id) and (Parent_Promise is not null)
    )
    LOOP
      if (CloseDate1$ is null) then
        REC$1.ChildNum := null;
      END IF;
      update Promise_Detail set
      CloseDate = CloseDate1$,
      Child_Promise = REC$1.ChildNum

      where
      (RegistrNumber = REC$1.PP) and
      (budgetref = new$budgetref);
          
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_PROMISE_CAPTION_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (77, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
            WHERE (TableID = 77) AND (RecordId = new$ID);
   END IF;

END;
/
update PROMISE_CAPTION set
  REJECTCAUSE = TempRejectCause
/
commit work 
/
ALTER TABLE TB_PROMISE_CAPTION DROP (TempRejectCause)
/

CREATE OR REPLACE VIEW PROMISE_CAPTION (
  ID,
  ACCEPTDATE,
  ACCEPTED_REVERTED,
  AGREEMENT_DATE,
  AGREEMENT_END,
  AGREEMENT_NOTE,
  AGREEMENT_TYPE,
  AGREEMENT_SUMMA,
  SUPPLIER_REF,
  DELIVERY_RULES,
  TOTALSUMM,
  BUDGETORG_REF,
  FACIALACC_CLS,
  BUDGETREF,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  ANUMBER,
  REJECT_CLS,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  DOCUMENTSTATE,
  USERSVISA,
  RVERSION,
  DOCSTATEREF,
  STIMATEID,
  BIDNUMBER,
  FAXDOCCOUNT,
  SUPPLIER_ACC_REF,
  AGREEMENT_NUM,
  INFONUMBER,
  ADVANCESUMMA,
  REJECTCAUSE)
AS
  SELECT
    ID,
    ACCEPTDATE,
    ACCEPTED_REVERTED,
    AGREEMENT_DATE,
    AGREEMENT_END,
    AGREEMENT_NOTE,
    AGREEMENT_TYPE,
    AGREEMENT_SUMMA,
    SUPPLIER_REF,
    DELIVERY_RULES,
    TOTALSUMM,
    BUDGETORG_REF,
    FACIALACC_CLS,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    ANUMBER,
    REJECT_CLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DOCUMENTSTATE,
    USERSVISA,
    RVERSION,
    DOCSTATEREF,
    STIMATEID,
    BIDNUMBER,
    FAXDOCCOUNT,
    SUPPLIER_ACC_REF,
    AGREEMENT_NUM,
    INFONUMBER,
    ADVANCESUMMA,
    REJECTCAUSE
  FROM TB_PROMISE_CAPTION
/

CREATE OR REPLACE TRIGGER TR_PROMISE_CAPTION_ID
  INSTEAD OF DELETE
  ON PROMISE_CAPTION
  FOR EACH ROW
DECLARE
  CNT$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_PROMISE_CAPTION_BD)
-- Last update 03.07.2006
-- - - - - - - - - - - - -

  /*       ,  */
  /*         .*/
  for R$ In (select pd.id ID, pd.registrnumber RN
    from Promise_Detail pd
    where pd.title_ref = :old.id)
  LOOP
    select count(pd2.id) into CNT$
        from promise_detail pd2
        where (pd2.parent_promise = R$.RN) and (pd2.budgetref = :old.budgetref) AND (ROWNUM = 1);

    if (CNT$ > 0) then
      RaiseException('EX_TEN_CANTDELADJUSTMENTED');
    else
      delete from Promise_Detail where Title_Ref = :old.id;    
    end if;  
  end LOOP;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_PROMISE_CAPTION
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);
   
  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_500 (TR_PROMISECAPTION_AD_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate, Summa)
    VALUES (77, :OLD.ID, SYSDATE, :OLD.Agreement_Summa);

END;
/

CREATE OR REPLACE TRIGGER TR_PROMISE_CAPTION_II
  INSTEAD OF INSERT
  ON PROMISE_CAPTION
  FOR EACH ROW
DECLARE
  new$ID PROMISE_CAPTION.ID%TYPE := :NEW.ID;
  new$ACCEPTDATE PROMISE_CAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$ACCEPTED_REVERTED PROMISE_CAPTION.ACCEPTED_REVERTED%TYPE := :NEW.ACCEPTED_REVERTED;
  new$AGREEMENT_DATE PROMISE_CAPTION.AGREEMENT_DATE%TYPE := :NEW.AGREEMENT_DATE;
  new$AGREEMENT_END PROMISE_CAPTION.AGREEMENT_END%TYPE := :NEW.AGREEMENT_END;
  new$AGREEMENT_NOTE PROMISE_CAPTION.AGREEMENT_NOTE%TYPE := :NEW.AGREEMENT_NOTE;
  new$AGREEMENT_TYPE PROMISE_CAPTION.AGREEMENT_TYPE%TYPE := :NEW.AGREEMENT_TYPE;
  new$AGREEMENT_SUMMA PROMISE_CAPTION.AGREEMENT_SUMMA%TYPE := :NEW.AGREEMENT_SUMMA;
  new$SUPPLIER_REF PROMISE_CAPTION.SUPPLIER_REF%TYPE := :NEW.SUPPLIER_REF;
  new$DELIVERY_RULES PROMISE_CAPTION.DELIVERY_RULES%TYPE := :NEW.DELIVERY_RULES;
  new$TOTALSUMM PROMISE_CAPTION.TOTALSUMM%TYPE := :NEW.TOTALSUMM;
  new$BUDGETORG_REF PROMISE_CAPTION.BUDGETORG_REF%TYPE := :NEW.BUDGETORG_REF;
  new$FACIALACC_CLS PROMISE_CAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$BUDGETREF PROMISE_CAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER PROMISE_CAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PROMISE_CAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PROMISE_CAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PROMISE_CAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$ANUMBER PROMISE_CAPTION.ANUMBER%TYPE := :NEW.ANUMBER;
  new$REJECT_CLS PROMISE_CAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$CRYPTOSTATUS PROMISE_CAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID PROMISE_CAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PROMISE_CAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCUMENTSTATE PROMISE_CAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA PROMISE_CAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$RVERSION PROMISE_CAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$DOCSTATEREF PROMISE_CAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$STIMATEID PROMISE_CAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$BIDNUMBER PROMISE_CAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT PROMISE_CAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$SUPPLIER_ACC_REF PROMISE_CAPTION.SUPPLIER_ACC_REF%TYPE := :NEW.SUPPLIER_ACC_REF;
  new$AGREEMENT_NUM PROMISE_CAPTION.AGREEMENT_NUM%TYPE := :NEW.AGREEMENT_NUM;
  new$INFONUMBER PROMISE_CAPTION.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$ADVANCESUMMA PROMISE_CAPTION.ADVANCESUMMA%TYPE := :NEW.ADVANCESUMMA;
  new$REJECTCAUSE PROMISE_CAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  UseFax$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_PROMISE_CAPTION_BI)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$Accepted_Reverted is null) then 
    new$Accepted_Reverted := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$TotalSumm is null) then 
    new$TotalSumm := 0;
  END IF;
  if (new$Agreement_Type is null) then 
    new$Agreement_Type := 0;
  END IF;
  if (new$Agreement_Summa is null) then 
    new$Agreement_Summa := 0;
  END IF;
  if ((new$reject_cls is not null))then 
    new$Accepted_Reverted := 1;
  END IF;
  if ((new$reject_cls is null))then 
    new$Accepted_Reverted := 0;
  END IF;
      
  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then 
    BEGIN
      select fa.BudgetRef         into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then 
    BEGIN
      select ConstValue         into new$BudgetRef from IntConst where (ProgIndex = -1) and (ConstIndex = 3)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_430 (TR_PROMISE_CAPTION_BI_430)
-- Version 7.01.00.2
-- - - - - - - - - - - - -

  IF (new$SenderID IS NOT NULL) THEN 
    /*     */
    GetIntConst(30, 19,UseFax$);
    IF ((new$BidNumber IS NULL) AND (UseFax$ = 1)) THEN 
      new$BidNumber:= new$Agreement_Num;
    END IF;
    SELECT COUNT(*)         INTO
    new$FaxDocCount FROM FaxDocs WHERE 
    (OwnerDocNumber=new$BidNumber)
    AND (ClientID=new$SenderID)
    AND (FacialAcc_Cls=new$FacialAcc_CLS)
    AND (OwnerDate = new$Agreement_Date)
    ;
  ELSE
    new$FaxDocCount:= 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_PROMISE_CAPTION_BI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_PROMISE_CAPTION (
    ID,
    ACCEPTDATE,
    ACCEPTED_REVERTED,
    AGREEMENT_DATE,
    AGREEMENT_END,
    AGREEMENT_NOTE,
    AGREEMENT_TYPE,
    AGREEMENT_SUMMA,
    SUPPLIER_REF,
    DELIVERY_RULES,
    TOTALSUMM,
    BUDGETORG_REF,
    FACIALACC_CLS,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    ANUMBER,
    REJECT_CLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DOCUMENTSTATE,
    USERSVISA,
    RVERSION,
    DOCSTATEREF,
    STIMATEID,
    BIDNUMBER,
    FAXDOCCOUNT,
    SUPPLIER_ACC_REF,
    AGREEMENT_NUM,
    INFONUMBER,
    ADVANCESUMMA,
    REJECTCAUSE
  ) VALUES (
    new$ID,
    new$ACCEPTDATE,
    new$ACCEPTED_REVERTED,
    new$AGREEMENT_DATE,
    new$AGREEMENT_END,
    new$AGREEMENT_NOTE,
    new$AGREEMENT_TYPE,
    new$AGREEMENT_SUMMA,
    new$SUPPLIER_REF,
    new$DELIVERY_RULES,
    new$TOTALSUMM,
    new$BUDGETORG_REF,
    new$FACIALACC_CLS,
    new$BUDGETREF,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$ANUMBER,
    new$REJECT_CLS,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$DOCUMENTSTATE,
    new$USERSVISA,
    new$RVERSION,
    new$DOCSTATEREF,
    new$STIMATEID,
    new$BIDNUMBER,
    new$FAXDOCCOUNT,
    new$SUPPLIER_ACC_REF,
    new$AGREEMENT_NUM,
    new$INFONUMBER,
    new$ADVANCESUMMA,
    new$REJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_PROMISECAPTION_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 77) AND (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_PROMISE_CAPTION_IU
  INSTEAD OF UPDATE
  ON PROMISE_CAPTION
  FOR EACH ROW
DECLARE
  new$ID PROMISE_CAPTION.ID%TYPE := :NEW.ID;
  new$ACCEPTDATE PROMISE_CAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$ACCEPTED_REVERTED PROMISE_CAPTION.ACCEPTED_REVERTED%TYPE := :NEW.ACCEPTED_REVERTED;
  new$AGREEMENT_DATE PROMISE_CAPTION.AGREEMENT_DATE%TYPE := :NEW.AGREEMENT_DATE;
  new$AGREEMENT_END PROMISE_CAPTION.AGREEMENT_END%TYPE := :NEW.AGREEMENT_END;
  new$AGREEMENT_NOTE PROMISE_CAPTION.AGREEMENT_NOTE%TYPE := :NEW.AGREEMENT_NOTE;
  new$AGREEMENT_TYPE PROMISE_CAPTION.AGREEMENT_TYPE%TYPE := :NEW.AGREEMENT_TYPE;
  new$AGREEMENT_SUMMA PROMISE_CAPTION.AGREEMENT_SUMMA%TYPE := :NEW.AGREEMENT_SUMMA;
  new$SUPPLIER_REF PROMISE_CAPTION.SUPPLIER_REF%TYPE := :NEW.SUPPLIER_REF;
  new$DELIVERY_RULES PROMISE_CAPTION.DELIVERY_RULES%TYPE := :NEW.DELIVERY_RULES;
  new$TOTALSUMM PROMISE_CAPTION.TOTALSUMM%TYPE := :NEW.TOTALSUMM;
  new$BUDGETORG_REF PROMISE_CAPTION.BUDGETORG_REF%TYPE := :NEW.BUDGETORG_REF;
  new$FACIALACC_CLS PROMISE_CAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$BUDGETREF PROMISE_CAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER PROMISE_CAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PROMISE_CAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PROMISE_CAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PROMISE_CAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$ANUMBER PROMISE_CAPTION.ANUMBER%TYPE := :NEW.ANUMBER;
  new$REJECT_CLS PROMISE_CAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$CRYPTOSTATUS PROMISE_CAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID PROMISE_CAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PROMISE_CAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCUMENTSTATE PROMISE_CAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA PROMISE_CAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$RVERSION PROMISE_CAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$DOCSTATEREF PROMISE_CAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$STIMATEID PROMISE_CAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$BIDNUMBER PROMISE_CAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT PROMISE_CAPTION.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$SUPPLIER_ACC_REF PROMISE_CAPTION.SUPPLIER_ACC_REF%TYPE := :NEW.SUPPLIER_ACC_REF;
  new$AGREEMENT_NUM PROMISE_CAPTION.AGREEMENT_NUM%TYPE := :NEW.AGREEMENT_NUM;
  new$INFONUMBER PROMISE_CAPTION.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$ADVANCESUMMA PROMISE_CAPTION.ADVANCESUMMA%TYPE := :NEW.ADVANCESUMMA;
  new$REJECTCAUSE PROMISE_CAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  cnt$ NUMBER (10);
  IsReject$ NUMBER(10);
  DetCount1$ NUMBER(10);
  CloseDate1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_PROMISE_CAPTION_BU)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$Accepted_Reverted is null) then 
    new$Accepted_Reverted := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$TotalSumm is null) then 
    new$TotalSumm := 0;
  END IF;
  if (new$Agreement_Type is null) then 
    new$Agreement_Type := 0;
  END IF;
  if (new$Agreement_Summa is null) then 
    new$Agreement_Summa := 0;
  END IF;
  if ((new$reject_cls is not null) and (:old.reject_cls is null) )then 
    new$Accepted_Reverted := 1;
  END IF;
  if ((new$reject_cls is null) and (:old.reject_cls is not null) )then 
    new$Accepted_Reverted := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)              into DetCount1$ from Promise_detail where Title_Ref = :old.ID
      ;
      if (DetCount1$ > 0) then 
        RaiseException('Ex_CantModufyBudget');          
      END IF;
    END IF;
  END IF;
  /*        */
  if ((new$AcceptDate is not null) and (new$Accepted_Reverted = 0) and (new$Reject_Cls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_101 (TR_PROMISECAPTION_BU_101)
-- Create 10.08.2004
-- Last update 19.03.2010
-- - - - - - - - - - - - -

  /*  ,    */
  if ( ((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted_Reverted = 0)) or
       ((:old.Accepted_Reverted = 1) and (new$Accepted_Reverted = 0) and (new$AcceptDate is not null))
     ) then
     
    /*        ,     .*/
    for R$ IN (select Parent_Promise PP, ID
        from Promise_Detail
        where (Title_Ref = new$id) and (Parent_Promise is not null) and (budgetref = new$budgetref))
    LOOP
            /*     */
      select count(pd.ID) into CNT$
      from Promise_Detail pd, promise_caption pc
      /*        .       .*/
      where ((pd.Parent_Promise = R$.PP) and (pc.id = pd.title_ref) and (pc.acceptdate is not null)
             and (pc.budgetref = pd.budgetref) and (pc.budgetref = new$budgetref) AND (pc.Accepted_Reverted = 0) AND
             (pd.id <> R$.ID)) AND (ROWNUM = 1);

      /*     ,   */
      if (cnt$ > 0) then
        RaiseException('EX_PROMISE_ADJUSTDUPLICATE');
      end if;  
    end LOOP;
  end if;

-- - - - - - - - - - - - -
-- BU_200 (TR_PROMISE_CAPTION_BU_200)
-- Create 21.02.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   /*      */
   IF (:OLD.DOCSTATEREF <> new$DOCSTATEREF) THEN
      INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
        VALUES (new$id, :OLD.DOCSTATEREF, new$DOCSTATEREF);
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_PROMISE_CAPTION_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.Reject_CLS is null)and(new$Reject_CLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.Reject_CLS is not null)and(new$Reject_CLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = new$ID)
      or(ChildID in (select d.id from Promise_Detail d where d.Title_Ref = new$id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_PROMISE_CAPTION_BU_700)
-- Create 17.09.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_PROMISE_CAPTION SET
    ID = new$ID,
    ACCEPTDATE = new$ACCEPTDATE,
    ACCEPTED_REVERTED = new$ACCEPTED_REVERTED,
    AGREEMENT_DATE = new$AGREEMENT_DATE,
    AGREEMENT_END = new$AGREEMENT_END,
    AGREEMENT_NOTE = new$AGREEMENT_NOTE,
    AGREEMENT_TYPE = new$AGREEMENT_TYPE,
    AGREEMENT_SUMMA = new$AGREEMENT_SUMMA,
    SUPPLIER_REF = new$SUPPLIER_REF,
    DELIVERY_RULES = new$DELIVERY_RULES,
    TOTALSUMM = new$TOTALSUMM,
    BUDGETORG_REF = new$BUDGETORG_REF,
    FACIALACC_CLS = new$FACIALACC_CLS,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    ANUMBER = new$ANUMBER,
    REJECT_CLS = new$REJECT_CLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    RVERSION = new$RVERSION,
    DOCSTATEREF = new$DOCSTATEREF,
    STIMATEID = new$STIMATEID,
    BIDNUMBER = new$BIDNUMBER,
    FAXDOCCOUNT = new$FAXDOCCOUNT,
    SUPPLIER_ACC_REF = new$SUPPLIER_ACC_REF,
    AGREEMENT_NUM = new$AGREEMENT_NUM,
    INFONUMBER = new$INFONUMBER,
    ADVANCESUMMA = new$ADVANCESUMMA,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_1 (TR_PROMISE_CAPTION_AU_1)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  /*          
               */
  if (  ( ((:old.AcceptDate is null) or (:old.Accepted_Reverted = 1)) and /*  */
  (new$AcceptDate is not null) and (new$Accepted_Reverted = 0)
  ) or
  (
  ((new$AcceptDate is null) or (new$Accepted_Reverted = 1)) and /*  */
  (:old.AcceptDate is not null) and (:old.Accepted_Reverted = 0)
  ) or
  ((new$AcceptDate is not null) and (:old.AcceptDate is not null) and /*  */
  (new$AcceptDate <> :old.AcceptDate)
  )
  ) then
    /*   ,      ,
                      */    
    CloseDate1$ := new$AcceptDate;
    /*   ,   NULL */
    if (new$Accepted_Reverted = 1) then
      CloseDate1$ := null;
    END IF;
    /*            */
    FOR REC$1 IN (select Parent_Promise AS PP, RegistrNumber
     AS ChildNum         from Promise_Detail
    where (Title_Ref = new$id) and (Parent_Promise is not null)
    )
    LOOP
      if (CloseDate1$ is null) then
        REC$1.ChildNum := null;
      END IF;
      update Promise_Detail set
      CloseDate = CloseDate1$,
      Child_Promise = REC$1.ChildNum

      where
      (RegistrNumber = REC$1.PP) and
      (budgetref = new$budgetref);
          
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_PROMISE_CAPTION_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (77, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
            WHERE (TableID = 77) AND (RecordId = new$ID);
   END IF;

END;
/
ALTER TRIGGER TR_PROMISE_CAPTION_BU_500 ENABLE
/
commit work 
/
ALTER TRIGGER TR_BUDNOTIFY_BU_500 DISABLE
/
ALTER TABLE TB_BUDNOTIFY ADD (
  TempRejectCause VARCHAR2(255)
)
/

CREATE OR REPLACE VIEW BUDNOTIFY (
  ID,
  DAT,
  DOCDAT,
  NOTIFYTYPE,
  BUDGETREF,
  DOCBASE,
  VARIANT,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  SENDERID,
  SENDERRECORDID,
  ANUMBER,
  ATYPE,
  DOCUMENTSTATE,
  USERSVISA,
  DATEINPUT,
  ORGREF,
  REJECTCLS,
  REJECTNOTE,
  PLANDOCTYPE,
  RECORDINDEX,
  STIMATEID,
  CRYPTOSTATUS,
  RVERSION,
  DOCSTATEREF,
  DOCNUMBER,
  FACIALACCCLS,
  LASTEXTRCHANGE,
  BIDNUMBER,
  FAXDOCCOUNT,
  PLANKIND,
  ASSIGNMENTSOURCE,
  BA_LBO_FLAG,
  KPPERIOD,
  CLSTYPE,
  DATE_UTV_PP,
  PROGINDEX,
  NOTE,
  NOTE2,
  DOCCHANGEDATE,
  SIGNERS,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  EXTID,
  EXTROOTID,
  NOTE1,
  TEMPREJECTCAUSE)
AS
  SELECT
    ID,
    DAT,
    DOCDAT,
    NOTIFYTYPE,
    BUDGETREF,
    DOCBASE,
    VARIANT,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SENDERID,
    SENDERRECORDID,
    ANUMBER,
    ATYPE,
    DOCUMENTSTATE,
    USERSVISA,
    DATEINPUT,
    ORGREF,
    REJECTCLS,
    REJECTNOTE,
    PLANDOCTYPE,
    RECORDINDEX,
    STIMATEID,
    CRYPTOSTATUS,
    RVERSION,
    DOCSTATEREF,
    DOCNUMBER,
    FACIALACCCLS,
    LASTEXTRCHANGE,
    BIDNUMBER,
    FAXDOCCOUNT,
    PLANKIND,
    ASSIGNMENTSOURCE,
    BA_LBO_FLAG,
    KPPERIOD,
    CLSTYPE,
    DATE_UTV_PP,
    PROGINDEX,
    NOTE,
    NOTE2,
    DOCCHANGEDATE,
    SIGNERS,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    EXTID,
    EXTROOTID,
    NOTE1,
    TEMPREJECTCAUSE
  FROM TB_BUDNOTIFY
/

CREATE OR REPLACE TRIGGER TR_BUDNOTIFY_ID
  INSTEAD OF DELETE
  ON BUDNOTIFY
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_BUDNOTIFY_BD)
-- - - - - - - - - - - - -

  delete from BudgetData where (RecordIndex = :old.id);

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_BUDNOTIFY
  WHERE id=:old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_BUDNOTIFY_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(tableid, recordid, deletedate, createruser, progindex) values(28, :old.id, SYSDATE, user, :old.progindex);

END;
/

CREATE OR REPLACE TRIGGER TR_BUDNOTIFY_II
  INSTEAD OF INSERT
  ON BUDNOTIFY
  FOR EACH ROW
DECLARE
  new$ID BUDNOTIFY.ID%TYPE := :NEW.ID;
  new$DAT BUDNOTIFY.DAT%TYPE := :NEW.DAT;
  new$DOCDAT BUDNOTIFY.DOCDAT%TYPE := :NEW.DOCDAT;
  new$NOTIFYTYPE BUDNOTIFY.NOTIFYTYPE%TYPE := :NEW.NOTIFYTYPE;
  new$BUDGETREF BUDNOTIFY.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DOCBASE BUDNOTIFY.DOCBASE%TYPE := :NEW.DOCBASE;
  new$VARIANT BUDNOTIFY.VARIANT%TYPE := :NEW.VARIANT;
  new$CREATERUSER BUDNOTIFY.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE BUDNOTIFY.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE BUDNOTIFY.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER BUDNOTIFY.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SENDERID BUDNOTIFY.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID BUDNOTIFY.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$ANUMBER BUDNOTIFY.ANUMBER%TYPE := :NEW.ANUMBER;
  new$ATYPE BUDNOTIFY.ATYPE%TYPE := :NEW.ATYPE;
  new$DOCUMENTSTATE BUDNOTIFY.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA BUDNOTIFY.USERSVISA%TYPE := :NEW.USERSVISA;
  new$DATEINPUT BUDNOTIFY.DATEINPUT%TYPE := :NEW.DATEINPUT;
  new$ORGREF BUDNOTIFY.ORGREF%TYPE := :NEW.ORGREF;
  new$REJECTCLS BUDNOTIFY.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTNOTE BUDNOTIFY.REJECTNOTE%TYPE := :NEW.REJECTNOTE;
  new$PLANDOCTYPE BUDNOTIFY.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$RECORDINDEX BUDNOTIFY.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$STIMATEID BUDNOTIFY.STIMATEID%TYPE := :NEW.STIMATEID;
  new$CRYPTOSTATUS BUDNOTIFY.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$RVERSION BUDNOTIFY.RVERSION%TYPE := :NEW.RVERSION;
  new$DOCSTATEREF BUDNOTIFY.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$DOCNUMBER BUDNOTIFY.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$FACIALACCCLS BUDNOTIFY.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$LASTEXTRCHANGE BUDNOTIFY.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$BIDNUMBER BUDNOTIFY.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT BUDNOTIFY.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$PLANKIND BUDNOTIFY.PLANKIND%TYPE := :NEW.PLANKIND;
  new$ASSIGNMENTSOURCE BUDNOTIFY.ASSIGNMENTSOURCE%TYPE := :NEW.ASSIGNMENTSOURCE;
  new$BA_LBO_FLAG BUDNOTIFY.BA_LBO_FLAG%TYPE := :NEW.BA_LBO_FLAG;
  new$KPPERIOD BUDNOTIFY.KPPERIOD%TYPE := :NEW.KPPERIOD;
  new$CLSTYPE BUDNOTIFY.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$DATE_UTV_PP BUDNOTIFY.DATE_UTV_PP%TYPE := :NEW.DATE_UTV_PP;
  new$PROGINDEX BUDNOTIFY.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE BUDNOTIFY.NOTE%TYPE := :NEW.NOTE;
  new$NOTE2 BUDNOTIFY.NOTE2%TYPE := :NEW.NOTE2;
  new$DOCCHANGEDATE BUDNOTIFY.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$SIGNERS BUDNOTIFY.SIGNERS%TYPE := :NEW.SIGNERS;
  new$SENDERIDKEY BUDNOTIFY.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY BUDNOTIFY.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXTID BUDNOTIFY.EXTID%TYPE := :NEW.EXTID;
  new$EXTROOTID BUDNOTIFY.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$NOTE1 BUDNOTIFY.NOTE1%TYPE := :NEW.NOTE1;
  new$TEMPREJECTCAUSE BUDNOTIFY.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  UseFax$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_BUDNOTIFY_BI)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$NotifyType is null) then
    new$NotifyType := 0;
  END IF;
  if (new$DocBase is null) then
    new$DocBase := 0;
  END IF;
  if (new$PlanKind is null) then
    new$PlanKind := 0;
  END IF;
  if (new$AssignmentSource is null) then
    new$AssignmentSource := 0;
  END IF;
  if ((new$PlanDocType is null) or (new$PlanDocType < 100)) then
    new$PlanDocType := 200;
  END IF;
  if ((new$PlanDocType > 99)and(new$PlanDocType < 200)) then
    new$AType := 0;

  else
    new$AType := 1;
  END IF;
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  if (new$BA_LBO_Flag is null) then
    new$BA_LBO_Flag := 0;
  END IF;
  if (new$KPPeriod is null) then
    new$KPPeriod := 0;
  END IF;
  if (new$ClsType is null) then
    new$ClsType := 3;
  END IF;
  if ((new$ProgIndex = 262)and(new$FacialAccCLS <> 0)and(new$OrgRef is null)) then
    BEGIN
      /*         
             - \  */
      select
      fac.ORG_REF
      into new$OrgRef     from
      FacialACC_CLS fac
      where
      (fac.ID = new$FacialAccCLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*         */
  if ((new$Dat is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_BUDNOTIFY_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;

  else
    new$SenderIDKey := new$SenderID;
  END IF;

  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;

  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_430 (TR_BUDNOTIFY_BI_430)
-- Create 18.09.2006
-- - - - - - - - - - - - -

  IF (NEW$SenderID IS NOT NULL) THEN
    /*        */
    GetIntConst(30, 19, UseFax$);
    IF ((NEW$BidNumber IS NULL) AND (UseFax$ = 1)) THEN
      NEW$BidNumber := NEW$ANumber;
    end if;
    NEW$FaxDocCount := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_BUDNOTIFY_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$DocChangeDate := new$UpdateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_BUDNOTIFY (
    ID,
    DAT,
    DOCDAT,
    NOTIFYTYPE,
    BUDGETREF,
    DOCBASE,
    VARIANT,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SENDERID,
    SENDERRECORDID,
    ANUMBER,
    ATYPE,
    DOCUMENTSTATE,
    USERSVISA,
    DATEINPUT,
    ORGREF,
    REJECTCLS,
    REJECTNOTE,
    PLANDOCTYPE,
    RECORDINDEX,
    STIMATEID,
    CRYPTOSTATUS,
    RVERSION,
    DOCSTATEREF,
    DOCNUMBER,
    FACIALACCCLS,
    LASTEXTRCHANGE,
    BIDNUMBER,
    FAXDOCCOUNT,
    PLANKIND,
    ASSIGNMENTSOURCE,
    BA_LBO_FLAG,
    KPPERIOD,
    CLSTYPE,
    DATE_UTV_PP,
    PROGINDEX,
    NOTE,
    NOTE2,
    DOCCHANGEDATE,
    SIGNERS,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    EXTID,
    EXTROOTID,
    NOTE1,
    TEMPREJECTCAUSE
  ) VALUES (
    new$ID,
    new$DAT,
    new$DOCDAT,
    new$NOTIFYTYPE,
    new$BUDGETREF,
    new$DOCBASE,
    new$VARIANT,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$SENDERID,
    new$SENDERRECORDID,
    new$ANUMBER,
    new$ATYPE,
    new$DOCUMENTSTATE,
    new$USERSVISA,
    new$DATEINPUT,
    new$ORGREF,
    new$REJECTCLS,
    new$REJECTNOTE,
    new$PLANDOCTYPE,
    new$RECORDINDEX,
    new$STIMATEID,
    new$CRYPTOSTATUS,
    new$RVERSION,
    new$DOCSTATEREF,
    new$DOCNUMBER,
    new$FACIALACCCLS,
    new$LASTEXTRCHANGE,
    new$BIDNUMBER,
    new$FAXDOCCOUNT,
    new$PLANKIND,
    new$ASSIGNMENTSOURCE,
    new$BA_LBO_FLAG,
    new$KPPERIOD,
    new$CLSTYPE,
    new$DATE_UTV_PP,
    new$PROGINDEX,
    new$NOTE,
    new$NOTE2,
    new$DOCCHANGEDATE,
    new$SIGNERS,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$EXTID,
    new$EXTROOTID,
    new$NOTE1,
    new$TEMPREJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_BUDNOTIFY_AI_500)
-- - - - - - - - - - - - -

        delete from DelRecIndexes where (TableID = 28) and (RecordID = NEW$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_BUDNOTIFY_IU
  INSTEAD OF UPDATE
  ON BUDNOTIFY
  FOR EACH ROW
DECLARE
  new$ID BUDNOTIFY.ID%TYPE := :NEW.ID;
  new$DAT BUDNOTIFY.DAT%TYPE := :NEW.DAT;
  new$DOCDAT BUDNOTIFY.DOCDAT%TYPE := :NEW.DOCDAT;
  new$NOTIFYTYPE BUDNOTIFY.NOTIFYTYPE%TYPE := :NEW.NOTIFYTYPE;
  new$BUDGETREF BUDNOTIFY.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DOCBASE BUDNOTIFY.DOCBASE%TYPE := :NEW.DOCBASE;
  new$VARIANT BUDNOTIFY.VARIANT%TYPE := :NEW.VARIANT;
  new$CREATERUSER BUDNOTIFY.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE BUDNOTIFY.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE BUDNOTIFY.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER BUDNOTIFY.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SENDERID BUDNOTIFY.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID BUDNOTIFY.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$ANUMBER BUDNOTIFY.ANUMBER%TYPE := :NEW.ANUMBER;
  new$ATYPE BUDNOTIFY.ATYPE%TYPE := :NEW.ATYPE;
  new$DOCUMENTSTATE BUDNOTIFY.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA BUDNOTIFY.USERSVISA%TYPE := :NEW.USERSVISA;
  new$DATEINPUT BUDNOTIFY.DATEINPUT%TYPE := :NEW.DATEINPUT;
  new$ORGREF BUDNOTIFY.ORGREF%TYPE := :NEW.ORGREF;
  new$REJECTCLS BUDNOTIFY.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTNOTE BUDNOTIFY.REJECTNOTE%TYPE := :NEW.REJECTNOTE;
  new$PLANDOCTYPE BUDNOTIFY.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$RECORDINDEX BUDNOTIFY.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$STIMATEID BUDNOTIFY.STIMATEID%TYPE := :NEW.STIMATEID;
  new$CRYPTOSTATUS BUDNOTIFY.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$RVERSION BUDNOTIFY.RVERSION%TYPE := :NEW.RVERSION;
  new$DOCSTATEREF BUDNOTIFY.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$DOCNUMBER BUDNOTIFY.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$FACIALACCCLS BUDNOTIFY.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$LASTEXTRCHANGE BUDNOTIFY.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$BIDNUMBER BUDNOTIFY.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT BUDNOTIFY.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$PLANKIND BUDNOTIFY.PLANKIND%TYPE := :NEW.PLANKIND;
  new$ASSIGNMENTSOURCE BUDNOTIFY.ASSIGNMENTSOURCE%TYPE := :NEW.ASSIGNMENTSOURCE;
  new$BA_LBO_FLAG BUDNOTIFY.BA_LBO_FLAG%TYPE := :NEW.BA_LBO_FLAG;
  new$KPPERIOD BUDNOTIFY.KPPERIOD%TYPE := :NEW.KPPERIOD;
  new$CLSTYPE BUDNOTIFY.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$DATE_UTV_PP BUDNOTIFY.DATE_UTV_PP%TYPE := :NEW.DATE_UTV_PP;
  new$PROGINDEX BUDNOTIFY.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE BUDNOTIFY.NOTE%TYPE := :NEW.NOTE;
  new$NOTE2 BUDNOTIFY.NOTE2%TYPE := :NEW.NOTE2;
  new$DOCCHANGEDATE BUDNOTIFY.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$SIGNERS BUDNOTIFY.SIGNERS%TYPE := :NEW.SIGNERS;
  new$SENDERIDKEY BUDNOTIFY.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY BUDNOTIFY.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXTID BUDNOTIFY.EXTID%TYPE := :NEW.EXTID;
  new$EXTROOTID BUDNOTIFY.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$NOTE1 BUDNOTIFY.NOTE1%TYPE := :NEW.NOTE1;
  new$TEMPREJECTCAUSE BUDNOTIFY.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  IsReject$ NUMBER(10);
  DetCount$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_BUDNOTIFY_BU)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$NotifyType is null) then
    new$NotifyType := 0;
  END IF;
  if (new$DocBase is null) then
    new$DocBase := 0;
  END IF;
  if (new$PlanKind is null) then
    new$PlanKind := 0;
  END IF;
  if (new$AssignmentSource is null) then
    new$AssignmentSource := 0;
  END IF;
  if ((new$PlanDocType > 99)and(new$PlanDocType < 200)) then
    new$AType := 0;

  else
    if (new$PlanDocType > 199) then
      new$AType := 1;
    END IF;
  END IF;
  if (new$PlanDocType is null) then
    if (new$AType = 1) then
      new$PlanDocType := 200;

    else
      new$PlanDocType := 100;

    END IF;
  END IF;
  /*    */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)              into DetCount$ from BudgetData where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  if (new$BA_LBO_Flag is null) then
    new$BA_LBO_Flag := 0;
  END IF;
  if (new$KPPeriod is null) then
    new$KPPeriod := 0;
  END IF;
  if (new$ClsType is null) then
    new$ClsType := 3;
  END IF;
  if ((new$ProgIndex = 262)and(new$FacialAccCLS <> :old.FacialAccCLS)
  and(new$FacialAccCLS <> 0)) then
    BEGIN
      /*     -    \   
             - \  ,
           ,   \  */
      select
      fac.ORG_REF
      into new$OrgRef     from
      FacialACC_CLS fac
      where
      (fac.ID = new$FacialAccCLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*        */
  if ((new$Dat is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_BUDNOTIFY_BU_200)
-- Create 08.02.2005
-- - - - - - - - - - - - -

   --     
  IF (:OLD.DOCSTATEREF <> NEW$DOCSTATEREF) THEN
    INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
      VALUES (NEW$ID, :OLD.DOCSTATEREF, NEW$DOCSTATEREF);
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_BUDNOTIFY_BU_300)
-- Create 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from BudgetData d where d.RecordIndex = :new.id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_BUDNOTIFY_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

  IF (NEW$RVersion IS NULL) THEN
    NEW$RVersion := 1;
  ELSIF ((NEW$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
    NEW$RVersion := :OLD.RVersion;
  ELSE
    NEW$RVersion := :OLD.RVersion + 1;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_BUDNOTIFY SET
    ID = new$ID,
    DAT = new$DAT,
    DOCDAT = new$DOCDAT,
    NOTIFYTYPE = new$NOTIFYTYPE,
    BUDGETREF = new$BUDGETREF,
    DOCBASE = new$DOCBASE,
    VARIANT = new$VARIANT,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    ANUMBER = new$ANUMBER,
    ATYPE = new$ATYPE,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    DATEINPUT = new$DATEINPUT,
    ORGREF = new$ORGREF,
    REJECTCLS = new$REJECTCLS,
    REJECTNOTE = new$REJECTNOTE,
    PLANDOCTYPE = new$PLANDOCTYPE,
    RECORDINDEX = new$RECORDINDEX,
    STIMATEID = new$STIMATEID,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    RVERSION = new$RVERSION,
    DOCSTATEREF = new$DOCSTATEREF,
    DOCNUMBER = new$DOCNUMBER,
    FACIALACCCLS = new$FACIALACCCLS,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    BIDNUMBER = new$BIDNUMBER,
    FAXDOCCOUNT = new$FAXDOCCOUNT,
    PLANKIND = new$PLANKIND,
    ASSIGNMENTSOURCE = new$ASSIGNMENTSOURCE,
    BA_LBO_FLAG = new$BA_LBO_FLAG,
    KPPERIOD = new$KPPERIOD,
    CLSTYPE = new$CLSTYPE,
    DATE_UTV_PP = new$DATE_UTV_PP,
    PROGINDEX = new$PROGINDEX,
    NOTE = new$NOTE,
    NOTE2 = new$NOTE2,
    DOCCHANGEDATE = new$DOCCHANGEDATE,
    SIGNERS = new$SIGNERS,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    EXTID = new$EXTID,
    EXTROOTID = new$EXTROOTID,
    NOTE1 = new$NOTE1,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_300 (TR_BudNotify_AU_300)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((new$ClsType <> :old.ClsType)and(new$ClsType <> 3)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$ClsType = 0) then
      update BudgetData set
      KD = 0,
      IFS = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 1) then
      update BudgetData set
      KD = 0,
      KVSR = 0,
      KFSR = 0,
      KCSR = 0,
      KVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 2) then
      update BudgetData set
      IFS = 0,
      KVSR = 0,
      KFSR = 0,
      KCSR = 0,
      KVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);

    END IF;
  END IF;
  if ((new$ProgIndex in (252, 253))and(new$FacialAccCLS <> :old.FacialAccCLS)) then
    update BudgetData set
    facialacc_cls = new$FacialAccCLS
    where
    RecordIndex = new$id;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_BUDNOTIFY_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (NEW$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (28, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=28) and (RecordId=NEW$ID);
  end if;

END;
/
update BUDNOTIFY set
  TempRejectCause = REJECTNOTE
/
commit work 
/
ALTER TABLE TB_BUDNOTIFY DROP (REJECTNOTE)
/

CREATE OR REPLACE VIEW BUDNOTIFY (
  ID,
  DAT,
  DOCDAT,
  NOTIFYTYPE,
  BUDGETREF,
  DOCBASE,
  VARIANT,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  SENDERID,
  SENDERRECORDID,
  ANUMBER,
  ATYPE,
  DOCUMENTSTATE,
  USERSVISA,
  DATEINPUT,
  ORGREF,
  REJECTCLS,
  PLANDOCTYPE,
  RECORDINDEX,
  STIMATEID,
  CRYPTOSTATUS,
  RVERSION,
  DOCSTATEREF,
  DOCNUMBER,
  FACIALACCCLS,
  LASTEXTRCHANGE,
  BIDNUMBER,
  FAXDOCCOUNT,
  PLANKIND,
  ASSIGNMENTSOURCE,
  BA_LBO_FLAG,
  KPPERIOD,
  CLSTYPE,
  DATE_UTV_PP,
  PROGINDEX,
  NOTE,
  NOTE2,
  DOCCHANGEDATE,
  SIGNERS,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  EXTID,
  EXTROOTID,
  NOTE1,
  TEMPREJECTCAUSE)
AS
  SELECT
    ID,
    DAT,
    DOCDAT,
    NOTIFYTYPE,
    BUDGETREF,
    DOCBASE,
    VARIANT,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SENDERID,
    SENDERRECORDID,
    ANUMBER,
    ATYPE,
    DOCUMENTSTATE,
    USERSVISA,
    DATEINPUT,
    ORGREF,
    REJECTCLS,
    PLANDOCTYPE,
    RECORDINDEX,
    STIMATEID,
    CRYPTOSTATUS,
    RVERSION,
    DOCSTATEREF,
    DOCNUMBER,
    FACIALACCCLS,
    LASTEXTRCHANGE,
    BIDNUMBER,
    FAXDOCCOUNT,
    PLANKIND,
    ASSIGNMENTSOURCE,
    BA_LBO_FLAG,
    KPPERIOD,
    CLSTYPE,
    DATE_UTV_PP,
    PROGINDEX,
    NOTE,
    NOTE2,
    DOCCHANGEDATE,
    SIGNERS,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    EXTID,
    EXTROOTID,
    NOTE1,
    TEMPREJECTCAUSE
  FROM TB_BUDNOTIFY
/

CREATE OR REPLACE TRIGGER TR_BUDNOTIFY_ID
  INSTEAD OF DELETE
  ON BUDNOTIFY
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_BUDNOTIFY_BD)
-- - - - - - - - - - - - -

  delete from BudgetData where (RecordIndex = :old.id);

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_BUDNOTIFY
  WHERE id=:old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_BUDNOTIFY_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(tableid, recordid, deletedate, createruser, progindex) values(28, :old.id, SYSDATE, user, :old.progindex);

END;
/

CREATE OR REPLACE TRIGGER TR_BUDNOTIFY_II
  INSTEAD OF INSERT
  ON BUDNOTIFY
  FOR EACH ROW
DECLARE
  new$ID BUDNOTIFY.ID%TYPE := :NEW.ID;
  new$DAT BUDNOTIFY.DAT%TYPE := :NEW.DAT;
  new$DOCDAT BUDNOTIFY.DOCDAT%TYPE := :NEW.DOCDAT;
  new$NOTIFYTYPE BUDNOTIFY.NOTIFYTYPE%TYPE := :NEW.NOTIFYTYPE;
  new$BUDGETREF BUDNOTIFY.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DOCBASE BUDNOTIFY.DOCBASE%TYPE := :NEW.DOCBASE;
  new$VARIANT BUDNOTIFY.VARIANT%TYPE := :NEW.VARIANT;
  new$CREATERUSER BUDNOTIFY.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE BUDNOTIFY.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE BUDNOTIFY.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER BUDNOTIFY.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SENDERID BUDNOTIFY.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID BUDNOTIFY.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$ANUMBER BUDNOTIFY.ANUMBER%TYPE := :NEW.ANUMBER;
  new$ATYPE BUDNOTIFY.ATYPE%TYPE := :NEW.ATYPE;
  new$DOCUMENTSTATE BUDNOTIFY.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA BUDNOTIFY.USERSVISA%TYPE := :NEW.USERSVISA;
  new$DATEINPUT BUDNOTIFY.DATEINPUT%TYPE := :NEW.DATEINPUT;
  new$ORGREF BUDNOTIFY.ORGREF%TYPE := :NEW.ORGREF;
  new$REJECTCLS BUDNOTIFY.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$PLANDOCTYPE BUDNOTIFY.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$RECORDINDEX BUDNOTIFY.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$STIMATEID BUDNOTIFY.STIMATEID%TYPE := :NEW.STIMATEID;
  new$CRYPTOSTATUS BUDNOTIFY.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$RVERSION BUDNOTIFY.RVERSION%TYPE := :NEW.RVERSION;
  new$DOCSTATEREF BUDNOTIFY.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$DOCNUMBER BUDNOTIFY.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$FACIALACCCLS BUDNOTIFY.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$LASTEXTRCHANGE BUDNOTIFY.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$BIDNUMBER BUDNOTIFY.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT BUDNOTIFY.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$PLANKIND BUDNOTIFY.PLANKIND%TYPE := :NEW.PLANKIND;
  new$ASSIGNMENTSOURCE BUDNOTIFY.ASSIGNMENTSOURCE%TYPE := :NEW.ASSIGNMENTSOURCE;
  new$BA_LBO_FLAG BUDNOTIFY.BA_LBO_FLAG%TYPE := :NEW.BA_LBO_FLAG;
  new$KPPERIOD BUDNOTIFY.KPPERIOD%TYPE := :NEW.KPPERIOD;
  new$CLSTYPE BUDNOTIFY.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$DATE_UTV_PP BUDNOTIFY.DATE_UTV_PP%TYPE := :NEW.DATE_UTV_PP;
  new$PROGINDEX BUDNOTIFY.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE BUDNOTIFY.NOTE%TYPE := :NEW.NOTE;
  new$NOTE2 BUDNOTIFY.NOTE2%TYPE := :NEW.NOTE2;
  new$DOCCHANGEDATE BUDNOTIFY.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$SIGNERS BUDNOTIFY.SIGNERS%TYPE := :NEW.SIGNERS;
  new$SENDERIDKEY BUDNOTIFY.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY BUDNOTIFY.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXTID BUDNOTIFY.EXTID%TYPE := :NEW.EXTID;
  new$EXTROOTID BUDNOTIFY.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$NOTE1 BUDNOTIFY.NOTE1%TYPE := :NEW.NOTE1;
  new$TEMPREJECTCAUSE BUDNOTIFY.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  UseFax$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_BUDNOTIFY_BI)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$NotifyType is null) then
    new$NotifyType := 0;
  END IF;
  if (new$DocBase is null) then
    new$DocBase := 0;
  END IF;
  if (new$PlanKind is null) then
    new$PlanKind := 0;
  END IF;
  if (new$AssignmentSource is null) then
    new$AssignmentSource := 0;
  END IF;
  if ((new$PlanDocType is null) or (new$PlanDocType < 100)) then
    new$PlanDocType := 200;
  END IF;
  if ((new$PlanDocType > 99)and(new$PlanDocType < 200)) then
    new$AType := 0;

  else
    new$AType := 1;
  END IF;
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  if (new$BA_LBO_Flag is null) then
    new$BA_LBO_Flag := 0;
  END IF;
  if (new$KPPeriod is null) then
    new$KPPeriod := 0;
  END IF;
  if (new$ClsType is null) then
    new$ClsType := 3;
  END IF;
  if ((new$ProgIndex = 262)and(new$FacialAccCLS <> 0)and(new$OrgRef is null)) then
    BEGIN
      /*         
             - \  */
      select
      fac.ORG_REF
      into new$OrgRef     from
      FacialACC_CLS fac
      where
      (fac.ID = new$FacialAccCLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*         */
  if ((new$Dat is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_BUDNOTIFY_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;

  else
    new$SenderIDKey := new$SenderID;
  END IF;

  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;

  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_430 (TR_BUDNOTIFY_BI_430)
-- Create 18.09.2006
-- - - - - - - - - - - - -

  IF (NEW$SenderID IS NOT NULL) THEN
    /*        */
    GetIntConst(30, 19, UseFax$);
    IF ((NEW$BidNumber IS NULL) AND (UseFax$ = 1)) THEN
      NEW$BidNumber := NEW$ANumber;
    end if;
    NEW$FaxDocCount := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_BUDNOTIFY_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$DocChangeDate := new$UpdateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_BUDNOTIFY (
    ID,
    DAT,
    DOCDAT,
    NOTIFYTYPE,
    BUDGETREF,
    DOCBASE,
    VARIANT,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SENDERID,
    SENDERRECORDID,
    ANUMBER,
    ATYPE,
    DOCUMENTSTATE,
    USERSVISA,
    DATEINPUT,
    ORGREF,
    REJECTCLS,
    PLANDOCTYPE,
    RECORDINDEX,
    STIMATEID,
    CRYPTOSTATUS,
    RVERSION,
    DOCSTATEREF,
    DOCNUMBER,
    FACIALACCCLS,
    LASTEXTRCHANGE,
    BIDNUMBER,
    FAXDOCCOUNT,
    PLANKIND,
    ASSIGNMENTSOURCE,
    BA_LBO_FLAG,
    KPPERIOD,
    CLSTYPE,
    DATE_UTV_PP,
    PROGINDEX,
    NOTE,
    NOTE2,
    DOCCHANGEDATE,
    SIGNERS,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    EXTID,
    EXTROOTID,
    NOTE1,
    TEMPREJECTCAUSE
  ) VALUES (
    new$ID,
    new$DAT,
    new$DOCDAT,
    new$NOTIFYTYPE,
    new$BUDGETREF,
    new$DOCBASE,
    new$VARIANT,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$SENDERID,
    new$SENDERRECORDID,
    new$ANUMBER,
    new$ATYPE,
    new$DOCUMENTSTATE,
    new$USERSVISA,
    new$DATEINPUT,
    new$ORGREF,
    new$REJECTCLS,
    new$PLANDOCTYPE,
    new$RECORDINDEX,
    new$STIMATEID,
    new$CRYPTOSTATUS,
    new$RVERSION,
    new$DOCSTATEREF,
    new$DOCNUMBER,
    new$FACIALACCCLS,
    new$LASTEXTRCHANGE,
    new$BIDNUMBER,
    new$FAXDOCCOUNT,
    new$PLANKIND,
    new$ASSIGNMENTSOURCE,
    new$BA_LBO_FLAG,
    new$KPPERIOD,
    new$CLSTYPE,
    new$DATE_UTV_PP,
    new$PROGINDEX,
    new$NOTE,
    new$NOTE2,
    new$DOCCHANGEDATE,
    new$SIGNERS,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$EXTID,
    new$EXTROOTID,
    new$NOTE1,
    new$TEMPREJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_BUDNOTIFY_AI_500)
-- - - - - - - - - - - - -

        delete from DelRecIndexes where (TableID = 28) and (RecordID = NEW$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_BUDNOTIFY_IU
  INSTEAD OF UPDATE
  ON BUDNOTIFY
  FOR EACH ROW
DECLARE
  new$ID BUDNOTIFY.ID%TYPE := :NEW.ID;
  new$DAT BUDNOTIFY.DAT%TYPE := :NEW.DAT;
  new$DOCDAT BUDNOTIFY.DOCDAT%TYPE := :NEW.DOCDAT;
  new$NOTIFYTYPE BUDNOTIFY.NOTIFYTYPE%TYPE := :NEW.NOTIFYTYPE;
  new$BUDGETREF BUDNOTIFY.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DOCBASE BUDNOTIFY.DOCBASE%TYPE := :NEW.DOCBASE;
  new$VARIANT BUDNOTIFY.VARIANT%TYPE := :NEW.VARIANT;
  new$CREATERUSER BUDNOTIFY.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE BUDNOTIFY.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE BUDNOTIFY.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER BUDNOTIFY.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SENDERID BUDNOTIFY.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID BUDNOTIFY.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$ANUMBER BUDNOTIFY.ANUMBER%TYPE := :NEW.ANUMBER;
  new$ATYPE BUDNOTIFY.ATYPE%TYPE := :NEW.ATYPE;
  new$DOCUMENTSTATE BUDNOTIFY.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA BUDNOTIFY.USERSVISA%TYPE := :NEW.USERSVISA;
  new$DATEINPUT BUDNOTIFY.DATEINPUT%TYPE := :NEW.DATEINPUT;
  new$ORGREF BUDNOTIFY.ORGREF%TYPE := :NEW.ORGREF;
  new$REJECTCLS BUDNOTIFY.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$PLANDOCTYPE BUDNOTIFY.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$RECORDINDEX BUDNOTIFY.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$STIMATEID BUDNOTIFY.STIMATEID%TYPE := :NEW.STIMATEID;
  new$CRYPTOSTATUS BUDNOTIFY.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$RVERSION BUDNOTIFY.RVERSION%TYPE := :NEW.RVERSION;
  new$DOCSTATEREF BUDNOTIFY.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$DOCNUMBER BUDNOTIFY.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$FACIALACCCLS BUDNOTIFY.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$LASTEXTRCHANGE BUDNOTIFY.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$BIDNUMBER BUDNOTIFY.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT BUDNOTIFY.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$PLANKIND BUDNOTIFY.PLANKIND%TYPE := :NEW.PLANKIND;
  new$ASSIGNMENTSOURCE BUDNOTIFY.ASSIGNMENTSOURCE%TYPE := :NEW.ASSIGNMENTSOURCE;
  new$BA_LBO_FLAG BUDNOTIFY.BA_LBO_FLAG%TYPE := :NEW.BA_LBO_FLAG;
  new$KPPERIOD BUDNOTIFY.KPPERIOD%TYPE := :NEW.KPPERIOD;
  new$CLSTYPE BUDNOTIFY.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$DATE_UTV_PP BUDNOTIFY.DATE_UTV_PP%TYPE := :NEW.DATE_UTV_PP;
  new$PROGINDEX BUDNOTIFY.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE BUDNOTIFY.NOTE%TYPE := :NEW.NOTE;
  new$NOTE2 BUDNOTIFY.NOTE2%TYPE := :NEW.NOTE2;
  new$DOCCHANGEDATE BUDNOTIFY.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$SIGNERS BUDNOTIFY.SIGNERS%TYPE := :NEW.SIGNERS;
  new$SENDERIDKEY BUDNOTIFY.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY BUDNOTIFY.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXTID BUDNOTIFY.EXTID%TYPE := :NEW.EXTID;
  new$EXTROOTID BUDNOTIFY.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$NOTE1 BUDNOTIFY.NOTE1%TYPE := :NEW.NOTE1;
  new$TEMPREJECTCAUSE BUDNOTIFY.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  IsReject$ NUMBER(10);
  DetCount$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_BUDNOTIFY_BU)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$NotifyType is null) then
    new$NotifyType := 0;
  END IF;
  if (new$DocBase is null) then
    new$DocBase := 0;
  END IF;
  if (new$PlanKind is null) then
    new$PlanKind := 0;
  END IF;
  if (new$AssignmentSource is null) then
    new$AssignmentSource := 0;
  END IF;
  if ((new$PlanDocType > 99)and(new$PlanDocType < 200)) then
    new$AType := 0;

  else
    if (new$PlanDocType > 199) then
      new$AType := 1;
    END IF;
  END IF;
  if (new$PlanDocType is null) then
    if (new$AType = 1) then
      new$PlanDocType := 200;

    else
      new$PlanDocType := 100;

    END IF;
  END IF;
  /*    */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)              into DetCount$ from BudgetData where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  if (new$BA_LBO_Flag is null) then
    new$BA_LBO_Flag := 0;
  END IF;
  if (new$KPPeriod is null) then
    new$KPPeriod := 0;
  END IF;
  if (new$ClsType is null) then
    new$ClsType := 3;
  END IF;
  if ((new$ProgIndex = 262)and(new$FacialAccCLS <> :old.FacialAccCLS)
  and(new$FacialAccCLS <> 0)) then
    BEGIN
      /*     -    \   
             - \  ,
           ,   \  */
      select
      fac.ORG_REF
      into new$OrgRef     from
      FacialACC_CLS fac
      where
      (fac.ID = new$FacialAccCLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*        */
  if ((new$Dat is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_BUDNOTIFY_BU_200)
-- Create 08.02.2005
-- - - - - - - - - - - - -

   --     
  IF (:OLD.DOCSTATEREF <> NEW$DOCSTATEREF) THEN
    INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
      VALUES (NEW$ID, :OLD.DOCSTATEREF, NEW$DOCSTATEREF);
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_BUDNOTIFY_BU_300)
-- Create 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from BudgetData d where d.RecordIndex = :new.id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_BUDNOTIFY_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

  IF (NEW$RVersion IS NULL) THEN
    NEW$RVersion := 1;
  ELSIF ((NEW$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
    NEW$RVersion := :OLD.RVersion;
  ELSE
    NEW$RVersion := :OLD.RVersion + 1;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_BUDNOTIFY SET
    ID = new$ID,
    DAT = new$DAT,
    DOCDAT = new$DOCDAT,
    NOTIFYTYPE = new$NOTIFYTYPE,
    BUDGETREF = new$BUDGETREF,
    DOCBASE = new$DOCBASE,
    VARIANT = new$VARIANT,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    ANUMBER = new$ANUMBER,
    ATYPE = new$ATYPE,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    DATEINPUT = new$DATEINPUT,
    ORGREF = new$ORGREF,
    REJECTCLS = new$REJECTCLS,
    PLANDOCTYPE = new$PLANDOCTYPE,
    RECORDINDEX = new$RECORDINDEX,
    STIMATEID = new$STIMATEID,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    RVERSION = new$RVERSION,
    DOCSTATEREF = new$DOCSTATEREF,
    DOCNUMBER = new$DOCNUMBER,
    FACIALACCCLS = new$FACIALACCCLS,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    BIDNUMBER = new$BIDNUMBER,
    FAXDOCCOUNT = new$FAXDOCCOUNT,
    PLANKIND = new$PLANKIND,
    ASSIGNMENTSOURCE = new$ASSIGNMENTSOURCE,
    BA_LBO_FLAG = new$BA_LBO_FLAG,
    KPPERIOD = new$KPPERIOD,
    CLSTYPE = new$CLSTYPE,
    DATE_UTV_PP = new$DATE_UTV_PP,
    PROGINDEX = new$PROGINDEX,
    NOTE = new$NOTE,
    NOTE2 = new$NOTE2,
    DOCCHANGEDATE = new$DOCCHANGEDATE,
    SIGNERS = new$SIGNERS,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    EXTID = new$EXTID,
    EXTROOTID = new$EXTROOTID,
    NOTE1 = new$NOTE1,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_300 (TR_BudNotify_AU_300)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((new$ClsType <> :old.ClsType)and(new$ClsType <> 3)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$ClsType = 0) then
      update BudgetData set
      KD = 0,
      IFS = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 1) then
      update BudgetData set
      KD = 0,
      KVSR = 0,
      KFSR = 0,
      KCSR = 0,
      KVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 2) then
      update BudgetData set
      IFS = 0,
      KVSR = 0,
      KFSR = 0,
      KCSR = 0,
      KVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);

    END IF;
  END IF;
  if ((new$ProgIndex in (252, 253))and(new$FacialAccCLS <> :old.FacialAccCLS)) then
    update BudgetData set
    facialacc_cls = new$FacialAccCLS
    where
    RecordIndex = new$id;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_BUDNOTIFY_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (NEW$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (28, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=28) and (RecordId=NEW$ID);
  end if;

END;
/
ALTER TABLE TB_BUDNOTIFY ADD (
  REJECTNOTE VARCHAR2(1000)
)
/

CREATE OR REPLACE VIEW BUDNOTIFY (
  ID,
  DAT,
  DOCDAT,
  NOTIFYTYPE,
  BUDGETREF,
  DOCBASE,
  VARIANT,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  SENDERID,
  SENDERRECORDID,
  ANUMBER,
  ATYPE,
  DOCUMENTSTATE,
  USERSVISA,
  DATEINPUT,
  ORGREF,
  REJECTCLS,
  PLANDOCTYPE,
  RECORDINDEX,
  STIMATEID,
  CRYPTOSTATUS,
  RVERSION,
  DOCSTATEREF,
  DOCNUMBER,
  FACIALACCCLS,
  LASTEXTRCHANGE,
  BIDNUMBER,
  FAXDOCCOUNT,
  PLANKIND,
  ASSIGNMENTSOURCE,
  BA_LBO_FLAG,
  KPPERIOD,
  CLSTYPE,
  DATE_UTV_PP,
  PROGINDEX,
  NOTE,
  NOTE2,
  DOCCHANGEDATE,
  SIGNERS,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  EXTID,
  EXTROOTID,
  NOTE1,
  TEMPREJECTCAUSE,
  REJECTNOTE)
AS
  SELECT
    ID,
    DAT,
    DOCDAT,
    NOTIFYTYPE,
    BUDGETREF,
    DOCBASE,
    VARIANT,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SENDERID,
    SENDERRECORDID,
    ANUMBER,
    ATYPE,
    DOCUMENTSTATE,
    USERSVISA,
    DATEINPUT,
    ORGREF,
    REJECTCLS,
    PLANDOCTYPE,
    RECORDINDEX,
    STIMATEID,
    CRYPTOSTATUS,
    RVERSION,
    DOCSTATEREF,
    DOCNUMBER,
    FACIALACCCLS,
    LASTEXTRCHANGE,
    BIDNUMBER,
    FAXDOCCOUNT,
    PLANKIND,
    ASSIGNMENTSOURCE,
    BA_LBO_FLAG,
    KPPERIOD,
    CLSTYPE,
    DATE_UTV_PP,
    PROGINDEX,
    NOTE,
    NOTE2,
    DOCCHANGEDATE,
    SIGNERS,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    EXTID,
    EXTROOTID,
    NOTE1,
    TEMPREJECTCAUSE,
    REJECTNOTE
  FROM TB_BUDNOTIFY
/

CREATE OR REPLACE TRIGGER TR_BUDNOTIFY_ID
  INSTEAD OF DELETE
  ON BUDNOTIFY
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_BUDNOTIFY_BD)
-- - - - - - - - - - - - -

  delete from BudgetData where (RecordIndex = :old.id);

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_BUDNOTIFY
  WHERE id=:old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_BUDNOTIFY_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(tableid, recordid, deletedate, createruser, progindex) values(28, :old.id, SYSDATE, user, :old.progindex);

END;
/

CREATE OR REPLACE TRIGGER TR_BUDNOTIFY_II
  INSTEAD OF INSERT
  ON BUDNOTIFY
  FOR EACH ROW
DECLARE
  new$ID BUDNOTIFY.ID%TYPE := :NEW.ID;
  new$DAT BUDNOTIFY.DAT%TYPE := :NEW.DAT;
  new$DOCDAT BUDNOTIFY.DOCDAT%TYPE := :NEW.DOCDAT;
  new$NOTIFYTYPE BUDNOTIFY.NOTIFYTYPE%TYPE := :NEW.NOTIFYTYPE;
  new$BUDGETREF BUDNOTIFY.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DOCBASE BUDNOTIFY.DOCBASE%TYPE := :NEW.DOCBASE;
  new$VARIANT BUDNOTIFY.VARIANT%TYPE := :NEW.VARIANT;
  new$CREATERUSER BUDNOTIFY.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE BUDNOTIFY.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE BUDNOTIFY.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER BUDNOTIFY.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SENDERID BUDNOTIFY.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID BUDNOTIFY.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$ANUMBER BUDNOTIFY.ANUMBER%TYPE := :NEW.ANUMBER;
  new$ATYPE BUDNOTIFY.ATYPE%TYPE := :NEW.ATYPE;
  new$DOCUMENTSTATE BUDNOTIFY.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA BUDNOTIFY.USERSVISA%TYPE := :NEW.USERSVISA;
  new$DATEINPUT BUDNOTIFY.DATEINPUT%TYPE := :NEW.DATEINPUT;
  new$ORGREF BUDNOTIFY.ORGREF%TYPE := :NEW.ORGREF;
  new$REJECTCLS BUDNOTIFY.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$PLANDOCTYPE BUDNOTIFY.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$RECORDINDEX BUDNOTIFY.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$STIMATEID BUDNOTIFY.STIMATEID%TYPE := :NEW.STIMATEID;
  new$CRYPTOSTATUS BUDNOTIFY.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$RVERSION BUDNOTIFY.RVERSION%TYPE := :NEW.RVERSION;
  new$DOCSTATEREF BUDNOTIFY.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$DOCNUMBER BUDNOTIFY.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$FACIALACCCLS BUDNOTIFY.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$LASTEXTRCHANGE BUDNOTIFY.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$BIDNUMBER BUDNOTIFY.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT BUDNOTIFY.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$PLANKIND BUDNOTIFY.PLANKIND%TYPE := :NEW.PLANKIND;
  new$ASSIGNMENTSOURCE BUDNOTIFY.ASSIGNMENTSOURCE%TYPE := :NEW.ASSIGNMENTSOURCE;
  new$BA_LBO_FLAG BUDNOTIFY.BA_LBO_FLAG%TYPE := :NEW.BA_LBO_FLAG;
  new$KPPERIOD BUDNOTIFY.KPPERIOD%TYPE := :NEW.KPPERIOD;
  new$CLSTYPE BUDNOTIFY.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$DATE_UTV_PP BUDNOTIFY.DATE_UTV_PP%TYPE := :NEW.DATE_UTV_PP;
  new$PROGINDEX BUDNOTIFY.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE BUDNOTIFY.NOTE%TYPE := :NEW.NOTE;
  new$NOTE2 BUDNOTIFY.NOTE2%TYPE := :NEW.NOTE2;
  new$DOCCHANGEDATE BUDNOTIFY.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$SIGNERS BUDNOTIFY.SIGNERS%TYPE := :NEW.SIGNERS;
  new$SENDERIDKEY BUDNOTIFY.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY BUDNOTIFY.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXTID BUDNOTIFY.EXTID%TYPE := :NEW.EXTID;
  new$EXTROOTID BUDNOTIFY.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$NOTE1 BUDNOTIFY.NOTE1%TYPE := :NEW.NOTE1;
  new$TEMPREJECTCAUSE BUDNOTIFY.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
  new$REJECTNOTE BUDNOTIFY.REJECTNOTE%TYPE := :NEW.REJECTNOTE;
--
  UseFax$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_BUDNOTIFY_BI)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$NotifyType is null) then
    new$NotifyType := 0;
  END IF;
  if (new$DocBase is null) then
    new$DocBase := 0;
  END IF;
  if (new$PlanKind is null) then
    new$PlanKind := 0;
  END IF;
  if (new$AssignmentSource is null) then
    new$AssignmentSource := 0;
  END IF;
  if ((new$PlanDocType is null) or (new$PlanDocType < 100)) then
    new$PlanDocType := 200;
  END IF;
  if ((new$PlanDocType > 99)and(new$PlanDocType < 200)) then
    new$AType := 0;

  else
    new$AType := 1;
  END IF;
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  if (new$BA_LBO_Flag is null) then
    new$BA_LBO_Flag := 0;
  END IF;
  if (new$KPPeriod is null) then
    new$KPPeriod := 0;
  END IF;
  if (new$ClsType is null) then
    new$ClsType := 3;
  END IF;
  if ((new$ProgIndex = 262)and(new$FacialAccCLS <> 0)and(new$OrgRef is null)) then
    BEGIN
      /*         
             - \  */
      select
      fac.ORG_REF
      into new$OrgRef     from
      FacialACC_CLS fac
      where
      (fac.ID = new$FacialAccCLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*         */
  if ((new$Dat is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_BUDNOTIFY_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;

  else
    new$SenderIDKey := new$SenderID;
  END IF;

  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;

  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_430 (TR_BUDNOTIFY_BI_430)
-- Create 18.09.2006
-- - - - - - - - - - - - -

  IF (NEW$SenderID IS NOT NULL) THEN
    /*        */
    GetIntConst(30, 19, UseFax$);
    IF ((NEW$BidNumber IS NULL) AND (UseFax$ = 1)) THEN
      NEW$BidNumber := NEW$ANumber;
    end if;
    NEW$FaxDocCount := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_BUDNOTIFY_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$DocChangeDate := new$UpdateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_BUDNOTIFY (
    ID,
    DAT,
    DOCDAT,
    NOTIFYTYPE,
    BUDGETREF,
    DOCBASE,
    VARIANT,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SENDERID,
    SENDERRECORDID,
    ANUMBER,
    ATYPE,
    DOCUMENTSTATE,
    USERSVISA,
    DATEINPUT,
    ORGREF,
    REJECTCLS,
    PLANDOCTYPE,
    RECORDINDEX,
    STIMATEID,
    CRYPTOSTATUS,
    RVERSION,
    DOCSTATEREF,
    DOCNUMBER,
    FACIALACCCLS,
    LASTEXTRCHANGE,
    BIDNUMBER,
    FAXDOCCOUNT,
    PLANKIND,
    ASSIGNMENTSOURCE,
    BA_LBO_FLAG,
    KPPERIOD,
    CLSTYPE,
    DATE_UTV_PP,
    PROGINDEX,
    NOTE,
    NOTE2,
    DOCCHANGEDATE,
    SIGNERS,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    EXTID,
    EXTROOTID,
    NOTE1,
    TEMPREJECTCAUSE,
    REJECTNOTE
  ) VALUES (
    new$ID,
    new$DAT,
    new$DOCDAT,
    new$NOTIFYTYPE,
    new$BUDGETREF,
    new$DOCBASE,
    new$VARIANT,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$SENDERID,
    new$SENDERRECORDID,
    new$ANUMBER,
    new$ATYPE,
    new$DOCUMENTSTATE,
    new$USERSVISA,
    new$DATEINPUT,
    new$ORGREF,
    new$REJECTCLS,
    new$PLANDOCTYPE,
    new$RECORDINDEX,
    new$STIMATEID,
    new$CRYPTOSTATUS,
    new$RVERSION,
    new$DOCSTATEREF,
    new$DOCNUMBER,
    new$FACIALACCCLS,
    new$LASTEXTRCHANGE,
    new$BIDNUMBER,
    new$FAXDOCCOUNT,
    new$PLANKIND,
    new$ASSIGNMENTSOURCE,
    new$BA_LBO_FLAG,
    new$KPPERIOD,
    new$CLSTYPE,
    new$DATE_UTV_PP,
    new$PROGINDEX,
    new$NOTE,
    new$NOTE2,
    new$DOCCHANGEDATE,
    new$SIGNERS,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$EXTID,
    new$EXTROOTID,
    new$NOTE1,
    new$TEMPREJECTCAUSE,
    new$REJECTNOTE);

-- - - - - - - - - - - - -
-- AI_500 (TR_BUDNOTIFY_AI_500)
-- - - - - - - - - - - - -

        delete from DelRecIndexes where (TableID = 28) and (RecordID = NEW$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_BUDNOTIFY_IU
  INSTEAD OF UPDATE
  ON BUDNOTIFY
  FOR EACH ROW
DECLARE
  new$ID BUDNOTIFY.ID%TYPE := :NEW.ID;
  new$DAT BUDNOTIFY.DAT%TYPE := :NEW.DAT;
  new$DOCDAT BUDNOTIFY.DOCDAT%TYPE := :NEW.DOCDAT;
  new$NOTIFYTYPE BUDNOTIFY.NOTIFYTYPE%TYPE := :NEW.NOTIFYTYPE;
  new$BUDGETREF BUDNOTIFY.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DOCBASE BUDNOTIFY.DOCBASE%TYPE := :NEW.DOCBASE;
  new$VARIANT BUDNOTIFY.VARIANT%TYPE := :NEW.VARIANT;
  new$CREATERUSER BUDNOTIFY.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE BUDNOTIFY.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE BUDNOTIFY.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER BUDNOTIFY.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SENDERID BUDNOTIFY.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID BUDNOTIFY.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$ANUMBER BUDNOTIFY.ANUMBER%TYPE := :NEW.ANUMBER;
  new$ATYPE BUDNOTIFY.ATYPE%TYPE := :NEW.ATYPE;
  new$DOCUMENTSTATE BUDNOTIFY.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA BUDNOTIFY.USERSVISA%TYPE := :NEW.USERSVISA;
  new$DATEINPUT BUDNOTIFY.DATEINPUT%TYPE := :NEW.DATEINPUT;
  new$ORGREF BUDNOTIFY.ORGREF%TYPE := :NEW.ORGREF;
  new$REJECTCLS BUDNOTIFY.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$PLANDOCTYPE BUDNOTIFY.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$RECORDINDEX BUDNOTIFY.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$STIMATEID BUDNOTIFY.STIMATEID%TYPE := :NEW.STIMATEID;
  new$CRYPTOSTATUS BUDNOTIFY.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$RVERSION BUDNOTIFY.RVERSION%TYPE := :NEW.RVERSION;
  new$DOCSTATEREF BUDNOTIFY.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$DOCNUMBER BUDNOTIFY.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$FACIALACCCLS BUDNOTIFY.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$LASTEXTRCHANGE BUDNOTIFY.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$BIDNUMBER BUDNOTIFY.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT BUDNOTIFY.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$PLANKIND BUDNOTIFY.PLANKIND%TYPE := :NEW.PLANKIND;
  new$ASSIGNMENTSOURCE BUDNOTIFY.ASSIGNMENTSOURCE%TYPE := :NEW.ASSIGNMENTSOURCE;
  new$BA_LBO_FLAG BUDNOTIFY.BA_LBO_FLAG%TYPE := :NEW.BA_LBO_FLAG;
  new$KPPERIOD BUDNOTIFY.KPPERIOD%TYPE := :NEW.KPPERIOD;
  new$CLSTYPE BUDNOTIFY.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$DATE_UTV_PP BUDNOTIFY.DATE_UTV_PP%TYPE := :NEW.DATE_UTV_PP;
  new$PROGINDEX BUDNOTIFY.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE BUDNOTIFY.NOTE%TYPE := :NEW.NOTE;
  new$NOTE2 BUDNOTIFY.NOTE2%TYPE := :NEW.NOTE2;
  new$DOCCHANGEDATE BUDNOTIFY.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$SIGNERS BUDNOTIFY.SIGNERS%TYPE := :NEW.SIGNERS;
  new$SENDERIDKEY BUDNOTIFY.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY BUDNOTIFY.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXTID BUDNOTIFY.EXTID%TYPE := :NEW.EXTID;
  new$EXTROOTID BUDNOTIFY.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$NOTE1 BUDNOTIFY.NOTE1%TYPE := :NEW.NOTE1;
  new$TEMPREJECTCAUSE BUDNOTIFY.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
  new$REJECTNOTE BUDNOTIFY.REJECTNOTE%TYPE := :NEW.REJECTNOTE;
--
  IsReject$ NUMBER(10);
  DetCount$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_BUDNOTIFY_BU)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$NotifyType is null) then
    new$NotifyType := 0;
  END IF;
  if (new$DocBase is null) then
    new$DocBase := 0;
  END IF;
  if (new$PlanKind is null) then
    new$PlanKind := 0;
  END IF;
  if (new$AssignmentSource is null) then
    new$AssignmentSource := 0;
  END IF;
  if ((new$PlanDocType > 99)and(new$PlanDocType < 200)) then
    new$AType := 0;

  else
    if (new$PlanDocType > 199) then
      new$AType := 1;
    END IF;
  END IF;
  if (new$PlanDocType is null) then
    if (new$AType = 1) then
      new$PlanDocType := 200;

    else
      new$PlanDocType := 100;

    END IF;
  END IF;
  /*    */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)              into DetCount$ from BudgetData where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  if (new$BA_LBO_Flag is null) then
    new$BA_LBO_Flag := 0;
  END IF;
  if (new$KPPeriod is null) then
    new$KPPeriod := 0;
  END IF;
  if (new$ClsType is null) then
    new$ClsType := 3;
  END IF;
  if ((new$ProgIndex = 262)and(new$FacialAccCLS <> :old.FacialAccCLS)
  and(new$FacialAccCLS <> 0)) then
    BEGIN
      /*     -    \   
             - \  ,
           ,   \  */
      select
      fac.ORG_REF
      into new$OrgRef     from
      FacialACC_CLS fac
      where
      (fac.ID = new$FacialAccCLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*        */
  if ((new$Dat is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_BUDNOTIFY_BU_200)
-- Create 08.02.2005
-- - - - - - - - - - - - -

   --     
  IF (:OLD.DOCSTATEREF <> NEW$DOCSTATEREF) THEN
    INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
      VALUES (NEW$ID, :OLD.DOCSTATEREF, NEW$DOCSTATEREF);
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_BUDNOTIFY_BU_300)
-- Create 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from BudgetData d where d.RecordIndex = :new.id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_BUDNOTIFY_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

  IF (NEW$RVersion IS NULL) THEN
    NEW$RVersion := 1;
  ELSIF ((NEW$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
    NEW$RVersion := :OLD.RVersion;
  ELSE
    NEW$RVersion := :OLD.RVersion + 1;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_BUDNOTIFY SET
    ID = new$ID,
    DAT = new$DAT,
    DOCDAT = new$DOCDAT,
    NOTIFYTYPE = new$NOTIFYTYPE,
    BUDGETREF = new$BUDGETREF,
    DOCBASE = new$DOCBASE,
    VARIANT = new$VARIANT,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    ANUMBER = new$ANUMBER,
    ATYPE = new$ATYPE,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    DATEINPUT = new$DATEINPUT,
    ORGREF = new$ORGREF,
    REJECTCLS = new$REJECTCLS,
    PLANDOCTYPE = new$PLANDOCTYPE,
    RECORDINDEX = new$RECORDINDEX,
    STIMATEID = new$STIMATEID,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    RVERSION = new$RVERSION,
    DOCSTATEREF = new$DOCSTATEREF,
    DOCNUMBER = new$DOCNUMBER,
    FACIALACCCLS = new$FACIALACCCLS,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    BIDNUMBER = new$BIDNUMBER,
    FAXDOCCOUNT = new$FAXDOCCOUNT,
    PLANKIND = new$PLANKIND,
    ASSIGNMENTSOURCE = new$ASSIGNMENTSOURCE,
    BA_LBO_FLAG = new$BA_LBO_FLAG,
    KPPERIOD = new$KPPERIOD,
    CLSTYPE = new$CLSTYPE,
    DATE_UTV_PP = new$DATE_UTV_PP,
    PROGINDEX = new$PROGINDEX,
    NOTE = new$NOTE,
    NOTE2 = new$NOTE2,
    DOCCHANGEDATE = new$DOCCHANGEDATE,
    SIGNERS = new$SIGNERS,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    EXTID = new$EXTID,
    EXTROOTID = new$EXTROOTID,
    NOTE1 = new$NOTE1,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE,
    REJECTNOTE = new$REJECTNOTE
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_300 (TR_BudNotify_AU_300)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((new$ClsType <> :old.ClsType)and(new$ClsType <> 3)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$ClsType = 0) then
      update BudgetData set
      KD = 0,
      IFS = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 1) then
      update BudgetData set
      KD = 0,
      KVSR = 0,
      KFSR = 0,
      KCSR = 0,
      KVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 2) then
      update BudgetData set
      IFS = 0,
      KVSR = 0,
      KFSR = 0,
      KCSR = 0,
      KVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);

    END IF;
  END IF;
  if ((new$ProgIndex in (252, 253))and(new$FacialAccCLS <> :old.FacialAccCLS)) then
    update BudgetData set
    facialacc_cls = new$FacialAccCLS
    where
    RecordIndex = new$id;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_BUDNOTIFY_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (NEW$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (28, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=28) and (RecordId=NEW$ID);
  end if;

END;
/
update BUDNOTIFY set
  REJECTNOTE = TempRejectCause
/
commit work 
/
ALTER TABLE TB_BUDNOTIFY DROP (TempRejectCause)
/

CREATE OR REPLACE VIEW BUDNOTIFY (
  ID,
  DAT,
  DOCDAT,
  NOTIFYTYPE,
  BUDGETREF,
  DOCBASE,
  VARIANT,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  SENDERID,
  SENDERRECORDID,
  ANUMBER,
  ATYPE,
  DOCUMENTSTATE,
  USERSVISA,
  DATEINPUT,
  ORGREF,
  REJECTCLS,
  PLANDOCTYPE,
  RECORDINDEX,
  STIMATEID,
  CRYPTOSTATUS,
  RVERSION,
  DOCSTATEREF,
  DOCNUMBER,
  FACIALACCCLS,
  LASTEXTRCHANGE,
  BIDNUMBER,
  FAXDOCCOUNT,
  PLANKIND,
  ASSIGNMENTSOURCE,
  BA_LBO_FLAG,
  KPPERIOD,
  CLSTYPE,
  DATE_UTV_PP,
  PROGINDEX,
  NOTE,
  NOTE2,
  DOCCHANGEDATE,
  SIGNERS,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  EXTID,
  EXTROOTID,
  NOTE1,
  REJECTNOTE)
AS
  SELECT
    ID,
    DAT,
    DOCDAT,
    NOTIFYTYPE,
    BUDGETREF,
    DOCBASE,
    VARIANT,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SENDERID,
    SENDERRECORDID,
    ANUMBER,
    ATYPE,
    DOCUMENTSTATE,
    USERSVISA,
    DATEINPUT,
    ORGREF,
    REJECTCLS,
    PLANDOCTYPE,
    RECORDINDEX,
    STIMATEID,
    CRYPTOSTATUS,
    RVERSION,
    DOCSTATEREF,
    DOCNUMBER,
    FACIALACCCLS,
    LASTEXTRCHANGE,
    BIDNUMBER,
    FAXDOCCOUNT,
    PLANKIND,
    ASSIGNMENTSOURCE,
    BA_LBO_FLAG,
    KPPERIOD,
    CLSTYPE,
    DATE_UTV_PP,
    PROGINDEX,
    NOTE,
    NOTE2,
    DOCCHANGEDATE,
    SIGNERS,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    EXTID,
    EXTROOTID,
    NOTE1,
    REJECTNOTE
  FROM TB_BUDNOTIFY
/

CREATE OR REPLACE TRIGGER TR_BUDNOTIFY_ID
  INSTEAD OF DELETE
  ON BUDNOTIFY
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_BUDNOTIFY_BD)
-- - - - - - - - - - - - -

  delete from BudgetData where (RecordIndex = :old.id);

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_BUDNOTIFY
  WHERE id=:old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_BUDNOTIFY_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(tableid, recordid, deletedate, createruser, progindex) values(28, :old.id, SYSDATE, user, :old.progindex);

END;
/

CREATE OR REPLACE TRIGGER TR_BUDNOTIFY_II
  INSTEAD OF INSERT
  ON BUDNOTIFY
  FOR EACH ROW
DECLARE
  new$ID BUDNOTIFY.ID%TYPE := :NEW.ID;
  new$DAT BUDNOTIFY.DAT%TYPE := :NEW.DAT;
  new$DOCDAT BUDNOTIFY.DOCDAT%TYPE := :NEW.DOCDAT;
  new$NOTIFYTYPE BUDNOTIFY.NOTIFYTYPE%TYPE := :NEW.NOTIFYTYPE;
  new$BUDGETREF BUDNOTIFY.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DOCBASE BUDNOTIFY.DOCBASE%TYPE := :NEW.DOCBASE;
  new$VARIANT BUDNOTIFY.VARIANT%TYPE := :NEW.VARIANT;
  new$CREATERUSER BUDNOTIFY.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE BUDNOTIFY.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE BUDNOTIFY.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER BUDNOTIFY.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SENDERID BUDNOTIFY.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID BUDNOTIFY.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$ANUMBER BUDNOTIFY.ANUMBER%TYPE := :NEW.ANUMBER;
  new$ATYPE BUDNOTIFY.ATYPE%TYPE := :NEW.ATYPE;
  new$DOCUMENTSTATE BUDNOTIFY.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA BUDNOTIFY.USERSVISA%TYPE := :NEW.USERSVISA;
  new$DATEINPUT BUDNOTIFY.DATEINPUT%TYPE := :NEW.DATEINPUT;
  new$ORGREF BUDNOTIFY.ORGREF%TYPE := :NEW.ORGREF;
  new$REJECTCLS BUDNOTIFY.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$PLANDOCTYPE BUDNOTIFY.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$RECORDINDEX BUDNOTIFY.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$STIMATEID BUDNOTIFY.STIMATEID%TYPE := :NEW.STIMATEID;
  new$CRYPTOSTATUS BUDNOTIFY.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$RVERSION BUDNOTIFY.RVERSION%TYPE := :NEW.RVERSION;
  new$DOCSTATEREF BUDNOTIFY.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$DOCNUMBER BUDNOTIFY.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$FACIALACCCLS BUDNOTIFY.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$LASTEXTRCHANGE BUDNOTIFY.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$BIDNUMBER BUDNOTIFY.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT BUDNOTIFY.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$PLANKIND BUDNOTIFY.PLANKIND%TYPE := :NEW.PLANKIND;
  new$ASSIGNMENTSOURCE BUDNOTIFY.ASSIGNMENTSOURCE%TYPE := :NEW.ASSIGNMENTSOURCE;
  new$BA_LBO_FLAG BUDNOTIFY.BA_LBO_FLAG%TYPE := :NEW.BA_LBO_FLAG;
  new$KPPERIOD BUDNOTIFY.KPPERIOD%TYPE := :NEW.KPPERIOD;
  new$CLSTYPE BUDNOTIFY.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$DATE_UTV_PP BUDNOTIFY.DATE_UTV_PP%TYPE := :NEW.DATE_UTV_PP;
  new$PROGINDEX BUDNOTIFY.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE BUDNOTIFY.NOTE%TYPE := :NEW.NOTE;
  new$NOTE2 BUDNOTIFY.NOTE2%TYPE := :NEW.NOTE2;
  new$DOCCHANGEDATE BUDNOTIFY.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$SIGNERS BUDNOTIFY.SIGNERS%TYPE := :NEW.SIGNERS;
  new$SENDERIDKEY BUDNOTIFY.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY BUDNOTIFY.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXTID BUDNOTIFY.EXTID%TYPE := :NEW.EXTID;
  new$EXTROOTID BUDNOTIFY.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$NOTE1 BUDNOTIFY.NOTE1%TYPE := :NEW.NOTE1;
  new$REJECTNOTE BUDNOTIFY.REJECTNOTE%TYPE := :NEW.REJECTNOTE;
--
  UseFax$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_BUDNOTIFY_BI)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$NotifyType is null) then
    new$NotifyType := 0;
  END IF;
  if (new$DocBase is null) then
    new$DocBase := 0;
  END IF;
  if (new$PlanKind is null) then
    new$PlanKind := 0;
  END IF;
  if (new$AssignmentSource is null) then
    new$AssignmentSource := 0;
  END IF;
  if ((new$PlanDocType is null) or (new$PlanDocType < 100)) then
    new$PlanDocType := 200;
  END IF;
  if ((new$PlanDocType > 99)and(new$PlanDocType < 200)) then
    new$AType := 0;

  else
    new$AType := 1;
  END IF;
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  if (new$BA_LBO_Flag is null) then
    new$BA_LBO_Flag := 0;
  END IF;
  if (new$KPPeriod is null) then
    new$KPPeriod := 0;
  END IF;
  if (new$ClsType is null) then
    new$ClsType := 3;
  END IF;
  if ((new$ProgIndex = 262)and(new$FacialAccCLS <> 0)and(new$OrgRef is null)) then
    BEGIN
      /*         
             - \  */
      select
      fac.ORG_REF
      into new$OrgRef     from
      FacialACC_CLS fac
      where
      (fac.ID = new$FacialAccCLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*         */
  if ((new$Dat is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_BUDNOTIFY_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;

  else
    new$SenderIDKey := new$SenderID;
  END IF;

  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;

  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_430 (TR_BUDNOTIFY_BI_430)
-- Create 18.09.2006
-- - - - - - - - - - - - -

  IF (NEW$SenderID IS NOT NULL) THEN
    /*        */
    GetIntConst(30, 19, UseFax$);
    IF ((NEW$BidNumber IS NULL) AND (UseFax$ = 1)) THEN
      NEW$BidNumber := NEW$ANumber;
    end if;
    NEW$FaxDocCount := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_BUDNOTIFY_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$DocChangeDate := new$UpdateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_BUDNOTIFY (
    ID,
    DAT,
    DOCDAT,
    NOTIFYTYPE,
    BUDGETREF,
    DOCBASE,
    VARIANT,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SENDERID,
    SENDERRECORDID,
    ANUMBER,
    ATYPE,
    DOCUMENTSTATE,
    USERSVISA,
    DATEINPUT,
    ORGREF,
    REJECTCLS,
    PLANDOCTYPE,
    RECORDINDEX,
    STIMATEID,
    CRYPTOSTATUS,
    RVERSION,
    DOCSTATEREF,
    DOCNUMBER,
    FACIALACCCLS,
    LASTEXTRCHANGE,
    BIDNUMBER,
    FAXDOCCOUNT,
    PLANKIND,
    ASSIGNMENTSOURCE,
    BA_LBO_FLAG,
    KPPERIOD,
    CLSTYPE,
    DATE_UTV_PP,
    PROGINDEX,
    NOTE,
    NOTE2,
    DOCCHANGEDATE,
    SIGNERS,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    EXTID,
    EXTROOTID,
    NOTE1,
    REJECTNOTE
  ) VALUES (
    new$ID,
    new$DAT,
    new$DOCDAT,
    new$NOTIFYTYPE,
    new$BUDGETREF,
    new$DOCBASE,
    new$VARIANT,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$SENDERID,
    new$SENDERRECORDID,
    new$ANUMBER,
    new$ATYPE,
    new$DOCUMENTSTATE,
    new$USERSVISA,
    new$DATEINPUT,
    new$ORGREF,
    new$REJECTCLS,
    new$PLANDOCTYPE,
    new$RECORDINDEX,
    new$STIMATEID,
    new$CRYPTOSTATUS,
    new$RVERSION,
    new$DOCSTATEREF,
    new$DOCNUMBER,
    new$FACIALACCCLS,
    new$LASTEXTRCHANGE,
    new$BIDNUMBER,
    new$FAXDOCCOUNT,
    new$PLANKIND,
    new$ASSIGNMENTSOURCE,
    new$BA_LBO_FLAG,
    new$KPPERIOD,
    new$CLSTYPE,
    new$DATE_UTV_PP,
    new$PROGINDEX,
    new$NOTE,
    new$NOTE2,
    new$DOCCHANGEDATE,
    new$SIGNERS,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$EXTID,
    new$EXTROOTID,
    new$NOTE1,
    new$REJECTNOTE);

-- - - - - - - - - - - - -
-- AI_500 (TR_BUDNOTIFY_AI_500)
-- - - - - - - - - - - - -

        delete from DelRecIndexes where (TableID = 28) and (RecordID = NEW$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_BUDNOTIFY_IU
  INSTEAD OF UPDATE
  ON BUDNOTIFY
  FOR EACH ROW
DECLARE
  new$ID BUDNOTIFY.ID%TYPE := :NEW.ID;
  new$DAT BUDNOTIFY.DAT%TYPE := :NEW.DAT;
  new$DOCDAT BUDNOTIFY.DOCDAT%TYPE := :NEW.DOCDAT;
  new$NOTIFYTYPE BUDNOTIFY.NOTIFYTYPE%TYPE := :NEW.NOTIFYTYPE;
  new$BUDGETREF BUDNOTIFY.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DOCBASE BUDNOTIFY.DOCBASE%TYPE := :NEW.DOCBASE;
  new$VARIANT BUDNOTIFY.VARIANT%TYPE := :NEW.VARIANT;
  new$CREATERUSER BUDNOTIFY.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE BUDNOTIFY.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE BUDNOTIFY.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER BUDNOTIFY.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SENDERID BUDNOTIFY.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID BUDNOTIFY.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$ANUMBER BUDNOTIFY.ANUMBER%TYPE := :NEW.ANUMBER;
  new$ATYPE BUDNOTIFY.ATYPE%TYPE := :NEW.ATYPE;
  new$DOCUMENTSTATE BUDNOTIFY.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA BUDNOTIFY.USERSVISA%TYPE := :NEW.USERSVISA;
  new$DATEINPUT BUDNOTIFY.DATEINPUT%TYPE := :NEW.DATEINPUT;
  new$ORGREF BUDNOTIFY.ORGREF%TYPE := :NEW.ORGREF;
  new$REJECTCLS BUDNOTIFY.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$PLANDOCTYPE BUDNOTIFY.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$RECORDINDEX BUDNOTIFY.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$STIMATEID BUDNOTIFY.STIMATEID%TYPE := :NEW.STIMATEID;
  new$CRYPTOSTATUS BUDNOTIFY.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$RVERSION BUDNOTIFY.RVERSION%TYPE := :NEW.RVERSION;
  new$DOCSTATEREF BUDNOTIFY.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$DOCNUMBER BUDNOTIFY.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$FACIALACCCLS BUDNOTIFY.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$LASTEXTRCHANGE BUDNOTIFY.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$BIDNUMBER BUDNOTIFY.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT BUDNOTIFY.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$PLANKIND BUDNOTIFY.PLANKIND%TYPE := :NEW.PLANKIND;
  new$ASSIGNMENTSOURCE BUDNOTIFY.ASSIGNMENTSOURCE%TYPE := :NEW.ASSIGNMENTSOURCE;
  new$BA_LBO_FLAG BUDNOTIFY.BA_LBO_FLAG%TYPE := :NEW.BA_LBO_FLAG;
  new$KPPERIOD BUDNOTIFY.KPPERIOD%TYPE := :NEW.KPPERIOD;
  new$CLSTYPE BUDNOTIFY.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$DATE_UTV_PP BUDNOTIFY.DATE_UTV_PP%TYPE := :NEW.DATE_UTV_PP;
  new$PROGINDEX BUDNOTIFY.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE BUDNOTIFY.NOTE%TYPE := :NEW.NOTE;
  new$NOTE2 BUDNOTIFY.NOTE2%TYPE := :NEW.NOTE2;
  new$DOCCHANGEDATE BUDNOTIFY.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$SIGNERS BUDNOTIFY.SIGNERS%TYPE := :NEW.SIGNERS;
  new$SENDERIDKEY BUDNOTIFY.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY BUDNOTIFY.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXTID BUDNOTIFY.EXTID%TYPE := :NEW.EXTID;
  new$EXTROOTID BUDNOTIFY.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$NOTE1 BUDNOTIFY.NOTE1%TYPE := :NEW.NOTE1;
  new$REJECTNOTE BUDNOTIFY.REJECTNOTE%TYPE := :NEW.REJECTNOTE;
--
  IsReject$ NUMBER(10);
  DetCount$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_BUDNOTIFY_BU)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$NotifyType is null) then
    new$NotifyType := 0;
  END IF;
  if (new$DocBase is null) then
    new$DocBase := 0;
  END IF;
  if (new$PlanKind is null) then
    new$PlanKind := 0;
  END IF;
  if (new$AssignmentSource is null) then
    new$AssignmentSource := 0;
  END IF;
  if ((new$PlanDocType > 99)and(new$PlanDocType < 200)) then
    new$AType := 0;

  else
    if (new$PlanDocType > 199) then
      new$AType := 1;
    END IF;
  END IF;
  if (new$PlanDocType is null) then
    if (new$AType = 1) then
      new$PlanDocType := 200;

    else
      new$PlanDocType := 100;

    END IF;
  END IF;
  /*    */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)              into DetCount$ from BudgetData where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  if (new$BA_LBO_Flag is null) then
    new$BA_LBO_Flag := 0;
  END IF;
  if (new$KPPeriod is null) then
    new$KPPeriod := 0;
  END IF;
  if (new$ClsType is null) then
    new$ClsType := 3;
  END IF;
  if ((new$ProgIndex = 262)and(new$FacialAccCLS <> :old.FacialAccCLS)
  and(new$FacialAccCLS <> 0)) then
    BEGIN
      /*     -    \   
             - \  ,
           ,   \  */
      select
      fac.ORG_REF
      into new$OrgRef     from
      FacialACC_CLS fac
      where
      (fac.ID = new$FacialAccCLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*        */
  if ((new$Dat is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_BUDNOTIFY_BU_200)
-- Create 08.02.2005
-- - - - - - - - - - - - -

   --     
  IF (:OLD.DOCSTATEREF <> NEW$DOCSTATEREF) THEN
    INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
      VALUES (NEW$ID, :OLD.DOCSTATEREF, NEW$DOCSTATEREF);
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_BUDNOTIFY_BU_300)
-- Create 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from BudgetData d where d.RecordIndex = :new.id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_BUDNOTIFY_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

  IF (NEW$RVersion IS NULL) THEN
    NEW$RVersion := 1;
  ELSIF ((NEW$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
    NEW$RVersion := :OLD.RVersion;
  ELSE
    NEW$RVersion := :OLD.RVersion + 1;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_BUDNOTIFY SET
    ID = new$ID,
    DAT = new$DAT,
    DOCDAT = new$DOCDAT,
    NOTIFYTYPE = new$NOTIFYTYPE,
    BUDGETREF = new$BUDGETREF,
    DOCBASE = new$DOCBASE,
    VARIANT = new$VARIANT,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    ANUMBER = new$ANUMBER,
    ATYPE = new$ATYPE,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    DATEINPUT = new$DATEINPUT,
    ORGREF = new$ORGREF,
    REJECTCLS = new$REJECTCLS,
    PLANDOCTYPE = new$PLANDOCTYPE,
    RECORDINDEX = new$RECORDINDEX,
    STIMATEID = new$STIMATEID,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    RVERSION = new$RVERSION,
    DOCSTATEREF = new$DOCSTATEREF,
    DOCNUMBER = new$DOCNUMBER,
    FACIALACCCLS = new$FACIALACCCLS,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    BIDNUMBER = new$BIDNUMBER,
    FAXDOCCOUNT = new$FAXDOCCOUNT,
    PLANKIND = new$PLANKIND,
    ASSIGNMENTSOURCE = new$ASSIGNMENTSOURCE,
    BA_LBO_FLAG = new$BA_LBO_FLAG,
    KPPERIOD = new$KPPERIOD,
    CLSTYPE = new$CLSTYPE,
    DATE_UTV_PP = new$DATE_UTV_PP,
    PROGINDEX = new$PROGINDEX,
    NOTE = new$NOTE,
    NOTE2 = new$NOTE2,
    DOCCHANGEDATE = new$DOCCHANGEDATE,
    SIGNERS = new$SIGNERS,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    EXTID = new$EXTID,
    EXTROOTID = new$EXTROOTID,
    NOTE1 = new$NOTE1,
    REJECTNOTE = new$REJECTNOTE
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_300 (TR_BudNotify_AU_300)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((new$ClsType <> :old.ClsType)and(new$ClsType <> 3)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$ClsType = 0) then
      update BudgetData set
      KD = 0,
      IFS = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 1) then
      update BudgetData set
      KD = 0,
      KVSR = 0,
      KFSR = 0,
      KCSR = 0,
      KVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 2) then
      update BudgetData set
      IFS = 0,
      KVSR = 0,
      KFSR = 0,
      KCSR = 0,
      KVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);

    END IF;
  END IF;
  if ((new$ProgIndex in (252, 253))and(new$FacialAccCLS <> :old.FacialAccCLS)) then
    update BudgetData set
    facialacc_cls = new$FacialAccCLS
    where
    RecordIndex = new$id;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_BUDNOTIFY_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (NEW$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (28, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=28) and (RecordId=NEW$ID);
  end if;

END;
/
ALTER TRIGGER TR_BUDNOTIFY_BU_500 ENABLE
/
commit work 
/
ALTER TRIGGER TR_AGREEMENTS_BU_500 DISABLE
/
-- ALTER TRIGGER TR_AGREEMENTS_BU_300
CREATE OR REPLACE TRIGGER TR_AGREEMENTS_IU
  INSTEAD OF UPDATE
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  new$ID AGREEMENTS.ID%TYPE := :NEW.ID;
  new$SUMMA AGREEMENTS.SUMMA%TYPE := :NEW.SUMMA;
  new$AGREEMENTDATE AGREEMENTS.AGREEMENTDATE%TYPE := :NEW.AGREEMENTDATE;
  new$AGREEMENTENDDATE AGREEMENTS.AGREEMENTENDDATE%TYPE := :NEW.AGREEMENTENDDATE;
  new$EXECUTER_REF AGREEMENTS.EXECUTER_REF%TYPE := :NEW.EXECUTER_REF;
  new$CLIENT_REF AGREEMENTS.CLIENT_REF%TYPE := :NEW.CLIENT_REF;
  new$FACIALACC_CLS AGREEMENTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$AGREEMENTTYPE AGREEMENTS.AGREEMENTTYPE%TYPE := :NEW.AGREEMENTTYPE;
  new$ACCEPTED AGREEMENTS.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$ACCEPTDATE AGREEMENTS.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$CARDADVANCEPERCENT AGREEMENTS.CARDADVANCEPERCENT%TYPE := :NEW.CARDADVANCEPERCENT;
  new$CARDADVANCE AGREEMENTS.CARDADVANCE%TYPE := :NEW.CARDADVANCE;
  new$CLOSEDOC AGREEMENTS.CLOSEDOC%TYPE := :NEW.CLOSEDOC;
  new$CREATERUSER AGREEMENTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE AGREEMENTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE AGREEMENTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER AGREEMENTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF AGREEMENTS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$LASTADJUSTMENT AGREEMENTS.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED AGREEMENTS.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$FACT AGREEMENTS.FACT%TYPE := :NEW.FACT;
  new$REGION AGREEMENTS.REGION%TYPE := :NEW.REGION;
  new$CLOSEDATE AGREEMENTS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$DELIVERYRULES AGREEMENTS.DELIVERYRULES%TYPE := :NEW.DELIVERYRULES;
  new$AGREEMENTSUMMA AGREEMENTS.AGREEMENTSUMMA%TYPE := :NEW.AGREEMENTSUMMA;
  new$AGREEMENTFINSUMMA AGREEMENTS.AGREEMENTFINSUMMA%TYPE := :NEW.AGREEMENTFINSUMMA;
  new$ADJUSTMENTREF AGREEMENTS.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$REESTRNUMBER AGREEMENTS.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$PAYMENTDATE AGREEMENTS.PAYMENTDATE%TYPE := :NEW.PAYMENTDATE;
  new$AGREEMENTCARDADVANCE AGREEMENTS.AGREEMENTCARDADVANCE%TYPE := :NEW.AGREEMENTCARDADVANCE;
  new$FINCARDADVANCE AGREEMENTS.FINCARDADVANCE%TYPE := :NEW.FINCARDADVANCE;
  new$STATEORDERREF AGREEMENTS.STATEORDERREF%TYPE := :NEW.STATEORDERREF;
  new$REJECTCLS AGREEMENTS.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTCAUSE AGREEMENTS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CRYPTOSTATUS AGREEMENTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID AGREEMENTS.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID AGREEMENTS.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$AGREEMENTBEGINDATE AGREEMENTS.AGREEMENTBEGINDATE%TYPE := :NEW.AGREEMENTBEGINDATE;
  new$PROTOCOLNUMBER AGREEMENTS.PROTOCOLNUMBER%TYPE := :NEW.PROTOCOLNUMBER;
  new$PROTOCOLDATE AGREEMENTS.PROTOCOLDATE%TYPE := :NEW.PROTOCOLDATE;
  new$REVIEWNOTE AGREEMENTS.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF AGREEMENTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION AGREEMENTS.RVERSION%TYPE := :NEW.RVERSION;
  new$EXPORTDATE AGREEMENTS.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$FSORGAN AGREEMENTS.FSORGAN%TYPE := :NEW.FSORGAN;
  new$FSBUDGETNAME AGREEMENTS.FSBUDGETNAME%TYPE := :NEW.FSBUDGETNAME;
  new$FSOFFBUDGET AGREEMENTS.FSOFFBUDGET%TYPE := :NEW.FSOFFBUDGET;
  new$RNYEAR AGREEMENTS.RNYEAR%TYPE := :NEW.RNYEAR;
  new$RNNUMBER AGREEMENTS.RNNUMBER%TYPE := :NEW.RNNUMBER;
  new$RNDATE AGREEMENTS.RNDATE%TYPE := :NEW.RNDATE;
  new$PROTOCOLNOTICE AGREEMENTS.PROTOCOLNOTICE%TYPE := :NEW.PROTOCOLNOTICE;
  new$PROTOCOLRESULTDATE AGREEMENTS.PROTOCOLRESULTDATE%TYPE := :NEW.PROTOCOLRESULTDATE;
  new$PROTOCOLDOCTYPE AGREEMENTS.PROTOCOLDOCTYPE%TYPE := :NEW.PROTOCOLDOCTYPE;
  new$PROTOCOLSALETYPE AGREEMENTS.PROTOCOLSALETYPE%TYPE := :NEW.PROTOCOLSALETYPE;
  new$NOTIFYDATE AGREEMENTS.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$EXECUTERACCREF AGREEMENTS.EXECUTERACCREF%TYPE := :NEW.EXECUTERACCREF;
  new$DOCBASEDATE AGREEMENTS.DOCBASEDATE%TYPE := :NEW.DOCBASEDATE;
  new$DOCBASENOTIFYDATE AGREEMENTS.DOCBASENOTIFYDATE%TYPE := :NEW.DOCBASENOTIFYDATE;
  new$DOCBASETEXT AGREEMENTS.DOCBASETEXT%TYPE := :NEW.DOCBASETEXT;
  new$DOCBASETYPE AGREEMENTS.DOCBASETYPE%TYPE := :NEW.DOCBASETYPE;
  new$DOCBASESUMMA AGREEMENTS.DOCBASESUMMA%TYPE := :NEW.DOCBASESUMMA;
  new$UNKNOWNAMOUNT AGREEMENTS.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PROTOCOLREASON AGREEMENTS.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$DOCNUMBER AGREEMENTS.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$ADJUSTMENTDOCNUMBER AGREEMENTS.ADJUSTMENTDOCNUMBER%TYPE := :NEW.ADJUSTMENTDOCNUMBER;
  new$OLDDOCNUMBER AGREEMENTS.OLDDOCNUMBER%TYPE := :NEW.OLDDOCNUMBER;
  new$LOTMAXSUM AGREEMENTS.LOTMAXSUM%TYPE := :NEW.LOTMAXSUM;
  new$CLIENT_INN AGREEMENTS.CLIENT_INN%TYPE := :NEW.CLIENT_INN;
  new$CLIENT_INN20 AGREEMENTS.CLIENT_INN20%TYPE := :NEW.CLIENT_INN20;
  new$CLIENT_NAME AGREEMENTS.CLIENT_NAME%TYPE := :NEW.CLIENT_NAME;
  new$EXECUTER_INN AGREEMENTS.EXECUTER_INN%TYPE := :NEW.EXECUTER_INN;
  new$EXECUTER_INN20 AGREEMENTS.EXECUTER_INN20%TYPE := :NEW.EXECUTER_INN20;
  new$EXECUTER_NAME AGREEMENTS.EXECUTER_NAME%TYPE := :NEW.EXECUTER_NAME;
  new$EXECUTER_STATUS AGREEMENTS.EXECUTER_STATUS%TYPE := :NEW.EXECUTER_STATUS;
  new$EXECUTER_COUNTRY AGREEMENTS.EXECUTER_COUNTRY%TYPE := :NEW.EXECUTER_COUNTRY;
  new$EXECUTER_ADDRESS AGREEMENTS.EXECUTER_ADDRESS%TYPE := :NEW.EXECUTER_ADDRESS;
  new$EXECUTER_PHONE AGREEMENTS.EXECUTER_PHONE%TYPE := :NEW.EXECUTER_PHONE;
  new$REALID AGREEMENTS.REALID%TYPE := :NEW.REALID;
  new$ADJUSTMENTNUMBER AGREEMENTS.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$INNERNUMBER AGREEMENTS.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$SENDERIDKEY AGREEMENTS.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY AGREEMENTS.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REESTRVERSION AGREEMENTS.REESTRVERSION%TYPE := :NEW.REESTRVERSION;
  new$DOCTYPE AGREEMENTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$RNCLIENTID AGREEMENTS.RNCLIENTID%TYPE := :NEW.RNCLIENTID;
  new$INFONUMBER AGREEMENTS.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$STATEORDERINNERNUMBER AGREEMENTS.STATEORDERINNERNUMBER%TYPE := :NEW.STATEORDERINNERNUMBER;
  new$PROGINDEX AGREEMENTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE AGREEMENTS.NOTE%TYPE := :NEW.NOTE;
  new$PURPORTDOC AGREEMENTS.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$REESTRRECORDNUMBER AGREEMENTS.REESTRRECORDNUMBER%TYPE := :NEW.REESTRRECORDNUMBER;
  new$EXECUTERSTOREDPROPS AGREEMENTS.EXECUTERSTOREDPROPS%TYPE := :NEW.EXECUTERSTOREDPROPS;
  new$AUTOSANCTION AGREEMENTS.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$PURCHASECODE AGREEMENTS.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$DOCUMENTNUMBER AGREEMENTS.DOCUMENTNUMBER%TYPE := :NEW.DOCUMENTNUMBER;
--
  MaxNumber$ NUMBER (10);
  CurVal$ NUMBER (10);
  CNT$1 NUMBER(10);
  DetCount$ NUMBER(10);
  CountAcc$ NUMBER(10);
  rnClientID1$ VARCHAR2(15);
  rnYear1$ VARCHAR2(15);
  rnNumber1$ VARCHAR2(15);
  ReestrVersion1$ VARCHAR2(15);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_AGREEMENTS_BU)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   3.1*/
  /*    -*/
  if (new$CardAdvancePercent is null) then
    new$CardAdvancePercent := 0;
  END IF;
  if (new$CardAdvance is null) then
    new$CardAdvance := 0;
  END IF;
  if (new$AgreementCardAdvance is null) then
    new$AgreementCardAdvance := 0;
  END IF;
  if (new$FinCardAdvance is null) then
    new$FinCardAdvance := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$AgreementSumma is null) then
    new$AgreementSumma := 0;
  END IF;
  if (new$AgreementFinSumma is null) then
    new$AgreementFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$Region is null) then
    new$Region := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$client_ref is null) then
    new$client_ref := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount$ from AgreementSteps where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      select count(ID)       into DetCount$ from Estimate where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*         -   InnerNumber*/
  if (((new$ProgIndex = 305) or (new$ProgIndex = 304) or (new$ProgIndex = 314)) and (new$InnerNumber is null)) then
    new$InnerNumber := GEN_ID('G_AgreementNumber',1);
  END IF;
  /*   */
  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  /*    .  */

  new$stateorderinnernumber := null;
  if (new$stateorderref is not null) then
    BEGIN
      select
      innernumber
      into new$stateorderinnernumber     from agreements
      where
      id = new$stateorderref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_3 (TR_AGREEMENTS_BU_3)
-- Create 03.12.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*            */
   new$AdjustmentRef := :OLD.AdjustmentRef;

-- - - - - - - - - - - - -
-- BU_5 (TR_AGREEMENTS_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_AGREEMENTS_BU_10)
-- Last update 08.02.2010
-- - - - - - - - - - - - -

/*   5.0*/
    /* ,      ,   */
    if ((new$InnerNumber <> :old.InnerNumber) or
        (new$AdjustmentNumber <> :old.AdjustmentNumber) or
        (new$AgreementType <> :old.AgreementType)) then
        RaiseException('EX_AGR_ChangeInnerNums');
    end if;

    /*    !!!*/
    if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and
        ((new$Accepted = 1) or (new$AcceptDate is null))) then
        RaiseException('EX_RollbackCancel');
    end if;

    /*   ,     LastAccepted*/
    if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) or
        ((:old.Accepted = 0) and (new$Accepted = 1) and (new$AcceptDate is not null))) then
        /*  LastAccepted         */
        if (new$LastAdjustment = 1) then
            new$LastAccepted := 1;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;
    end if;

    /*    ,     LastAccepted*/
    if (((:old.AcceptDate is not null) and (:old.Accepted = 1)) and
        ((new$Accepted = 0) or (new$AcceptDate is null))) then
        /*  LastAccepted         */
        if (new$LastAdjustment = 1) then
            new$LastAccepted := 0;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;
    end if;

    /*   ,     LastAdjustment*/
    if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 0)) or
        ((:old.Accepted = 1) and (new$Accepted = 0) and (new$AcceptDate is not null))) then

        if (new$LastAdjustment = 1) then
            new$LastAdjustment := 0;
            new$LastAccepted := 0;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;

        SELECT Max(AdjustmentNumber) INTO MaxNumber$ FROm AgreementS
        WHERE (InnerNumber = new$InnerNumber);
        /*    ,     */
        if ((new$adjustmentNumber=0) and (MaxNumber$<>0)) then
          RaiseException('EX_Agr_PrimaryAgrHasNotify');
        end if;
    end if;

-- - - - - - - - - - - - -
-- BU_20 (TR_AGREEMENTS_BU_20)
-- Create 21.05.2009
-- - - - - - - - - - - - -

  /*    -,      */
  if ((new$Client_Ref <> :old.Client_Ref) and
      (((new$Client_INN is null) and
        (:old.Client_INN is null)) or
       (new$Client_INN = :old.Client_INN)) and
      (((new$Client_INN20 is null) and
        (:old.Client_INN20 is null)) or
       (new$Client_INN20 = :old.Client_INN20)) and
      (new$Client_Name = :old.Client_Name)) then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name
      into
        new$Client_INN,
        new$Client_INN20,
        new$Client_Name
      from Organizations o
      where o.Id=new$Client_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Client_INN := NULL;
        new$Client_INN20 := NULL;
        new$Client_Name := NULL;
    END;
  END IF;

  /*    -,      */
  if ((new$Executer_Ref <> :old.Executer_Ref) and
      (((new$Executer_INN is null) and
        (:old.Executer_INN is null)) or
       (new$Executer_INN = :old.Executer_INN)) and
      (((new$Executer_INN20 is null) and
        (:old.Executer_INN20 is null)) or
       (new$Executer_INN20 = :old.Executer_INN20)) and
      (new$Executer_Name = :old.Executer_Name) and
      (((new$Executer_Status is null) and
        (:old.Executer_Status is null)) or
       (new$Executer_Status = :old.Executer_Status)) and
      (((new$Executer_Country is null) and
        (:old.Executer_Country is null)) or
       (new$Executer_Country = :old.Executer_Country)) and
      (((new$Executer_Address is null) and
        (:old.Executer_Address is null)) or
       (new$Executer_Address = :old.Executer_Address)) and
      (((new$Executer_Phone is null) and
        (:old.Executer_Phone is null)) or
       (new$Executer_Phone = :old.Executer_Phone))) then
     BEGIN
      select
        o.INN,
        o.INN20,
        o.Name,
        o.SupplierStatus,
        o.Country,
        o.Address,
        o.Phone
      into
        new$Executer_INN,
        new$Executer_INN20,
        new$Executer_Name,
        new$Executer_Status,
        new$Executer_Country,
        new$Executer_Address,
        new$Executer_Phone
      from Organizations o
      where o.Id=new$Executer_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Executer_INN := NULL;
        new$Executer_INN20 := NULL;
        new$Executer_Name := NULL;
        new$Executer_Status := NULL;
        new$Executer_Country := NULL;
        new$Executer_Address := NULL;
        new$Executer_Phone := NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_50 (TR_AGREEMENTS_BU_50)
-- Create 06.08.2010
-- - - - - - - - - - - - -

    if (new$InnerNumber is not null) then
        CurVal$ := gen_id('G_AgreementNumber', 0);
        if (CurVal$ < new$InnerNumber) then
          CurVal$ := gen_id('G_AgreementNumber', new$InnerNumber - CurVal$);
        end if;
    end if;

-- - - - - - - - - - - - -
-- BU_60 (tr_agreements_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*        ,     */
  if (:old.accepted = 1 and new$accepted = 0 and new$acceptdate is not null and new$adjustmentnumber = 0) then
    SELECT COUNT(*) INTO CNT$1
    from executiondocumentscaption
    where
    (            agreementinnernumber = new$innernumber
    and (accepted <> 0 or acceptdate is null)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_Agr_CannotReject');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_AGREEMENTS_BU_200)
-- Create 04.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$id, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (tr_agreements_bu_300)
-- Version 8.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ExecuterAccRef is not null) then
--     select count(ID)
--     into CountAcc$     from org_accounts oa
--     where oa.id = new$ExecuterAccRef and oa.Org_ref = new$Executer_Ref
--     ;
--     if (CountAcc$ = 0) then
--       RaiseException('EX_AGR_ACCORGCHECK');
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_400 (TR_AGREEMENTS_BU_400)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (((new$rnClientID <> :old.rnClientID) or (new$rnYear <> :old.rnYear) or
  (new$rnNumber <> :old.rnNumber) or (new$ReestrVersion <> :old.ReestrVersion)) and
  (new$rnClientID is not null) and (new$rnYear is not null) and (new$rnNumber is not null)) then

    rnClientID1$ := new$rnClientID;
    rnYear1$ := new$rnYear;
    rnNumber1$ := new$rnNumber;
    ReestrVersion1$ := new$ReestrVersion;
    while (LENGTH(rnClientID1$) < 11) LOOP
      rnClientID1$ := '0' || rnClientID1$;
    END LOOP;
    while (LENGTH(rnNumber1$) < 6) LOOP
      rnNumber1$ := '0' || rnNumber1$;
    END LOOP;
    if (LENGTH(ReestrVersion1$) < 2) then
      ReestrVersion1$ := '0' || ReestrVersion1$;
    END IF;
    /*  ReestrRecordNumber*/
    if (new$ReestrVersion is null) then
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$;

    else
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$ || ReestrVersion1$;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_600 (agreements_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_AGREEMENTS_BU_700)
-- Create 14.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_AGREEMENTS SET
    ID = new$ID,
    SUMMA = new$SUMMA,
    AGREEMENTDATE = new$AGREEMENTDATE,
    AGREEMENTENDDATE = new$AGREEMENTENDDATE,
    EXECUTER_REF = new$EXECUTER_REF,
    CLIENT_REF = new$CLIENT_REF,
    FACIALACC_CLS = new$FACIALACC_CLS,
    AGREEMENTTYPE = new$AGREEMENTTYPE,
    ACCEPTED = new$ACCEPTED,
    ACCEPTDATE = new$ACCEPTDATE,
    CARDADVANCEPERCENT = new$CARDADVANCEPERCENT,
    CARDADVANCE = new$CARDADVANCE,
    CLOSEDOC = new$CLOSEDOC,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    FACT = new$FACT,
    REGION = new$REGION,
    CLOSEDATE = new$CLOSEDATE,
    DELIVERYRULES = new$DELIVERYRULES,
    AGREEMENTSUMMA = new$AGREEMENTSUMMA,
    AGREEMENTFINSUMMA = new$AGREEMENTFINSUMMA,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    REESTRNUMBER = new$REESTRNUMBER,
    PAYMENTDATE = new$PAYMENTDATE,
    AGREEMENTCARDADVANCE = new$AGREEMENTCARDADVANCE,
    FINCARDADVANCE = new$FINCARDADVANCE,
    STATEORDERREF = new$STATEORDERREF,
    REJECTCLS = new$REJECTCLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    AGREEMENTBEGINDATE = new$AGREEMENTBEGINDATE,
    PROTOCOLNUMBER = new$PROTOCOLNUMBER,
    PROTOCOLDATE = new$PROTOCOLDATE,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXPORTDATE = new$EXPORTDATE,
    FSORGAN = new$FSORGAN,
    FSBUDGETNAME = new$FSBUDGETNAME,
    FSOFFBUDGET = new$FSOFFBUDGET,
    RNYEAR = new$RNYEAR,
    RNNUMBER = new$RNNUMBER,
    RNDATE = new$RNDATE,
    PROTOCOLNOTICE = new$PROTOCOLNOTICE,
    PROTOCOLRESULTDATE = new$PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE = new$PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE = new$PROTOCOLSALETYPE,
    NOTIFYDATE = new$NOTIFYDATE,
    EXECUTERACCREF = new$EXECUTERACCREF,
    DOCBASEDATE = new$DOCBASEDATE,
    DOCBASENOTIFYDATE = new$DOCBASENOTIFYDATE,
    DOCBASETEXT = new$DOCBASETEXT,
    DOCBASETYPE = new$DOCBASETYPE,
    DOCBASESUMMA = new$DOCBASESUMMA,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PROTOCOLREASON = new$PROTOCOLREASON,
    DOCNUMBER = new$DOCNUMBER,
    ADJUSTMENTDOCNUMBER = new$ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER = new$OLDDOCNUMBER,
    LOTMAXSUM = new$LOTMAXSUM,
    CLIENT_INN = new$CLIENT_INN,
    CLIENT_INN20 = new$CLIENT_INN20,
    CLIENT_NAME = new$CLIENT_NAME,
    EXECUTER_INN = new$EXECUTER_INN,
    EXECUTER_INN20 = new$EXECUTER_INN20,
    EXECUTER_NAME = new$EXECUTER_NAME,
    EXECUTER_STATUS = new$EXECUTER_STATUS,
    EXECUTER_COUNTRY = new$EXECUTER_COUNTRY,
    EXECUTER_ADDRESS = new$EXECUTER_ADDRESS,
    EXECUTER_PHONE = new$EXECUTER_PHONE,
    REALID = new$REALID,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    INNERNUMBER = new$INNERNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REESTRVERSION = new$REESTRVERSION,
    DOCTYPE = new$DOCTYPE,
    RNCLIENTID = new$RNCLIENTID,
    INFONUMBER = new$INFONUMBER,
    STATEORDERINNERNUMBER = new$STATEORDERINNERNUMBER,
    PROGINDEX = new$PROGINDEX,
    NOTE = new$NOTE,
    PURPORTDOC = new$PURPORTDOC,
    REESTRRECORDNUMBER = new$REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS = new$EXECUTERSTOREDPROPS,
    AUTOSANCTION = new$AUTOSANCTION,
    PURCHASECODE = new$PURCHASECODE,
    DOCUMENTNUMBER = new$DOCUMENTNUMBER
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_AGREEMENTS_AU_10)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   6.0*/
  /*      */
  /*     ,       */
  if ((new$AdjustmentNumber > 0) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update Agreements set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentNumber > 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update Agreements set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*          */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 304)or(new$ProgIndex = 314)))then
    update Estimate
    set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    (RecordIndex = new$Id);
  END IF;
  /*         */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 305) or (new$ProgIndex = 314))) then
    update paymentschedule set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    AgreementRef = new$ID and
    ProgIndex in (317, 318);

  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_AGREEMENTS_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*      */
  if ((new$ProgIndex = 305) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null
    where
    StateOrder = :old.ID;
  END IF;
  /*      */
  if ((new$ProgIndex = 314) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null,
    Agreement = null
    where
    StateOrder = :old.ID;
  END IF;
  /*     */
  if ((:old.ProgIndex = 304) and (new$AdjustmentNumber = 0) and (new$Accepted = 0) and
  (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    Agreement = null
    where
    Agreement = :old.ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_AGREEMENTS_AU_30)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$ProgIndex = 304) or (new$ProgIndex = 314)) and
  ((new$Accepted <> :old.Accepted) or
  (new$AcceptDate is not null and :old.AcceptDate is null) or
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where AgreementRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_AGREEMENTS_AU_500)
-- Create 28.04.2005
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes
                  (TableID, RecordId, DeleteDate
                  )
           VALUES (110, :OLD.ID, SYSDATE
                  );

      DELETE FROM DelRecIndexes
            WHERE (TableID = 110) AND (RecordId = new$ID);
   END IF;

END;
/
ALTER TABLE TB_AGREEMENTS ADD (
  TempRejectCause VARCHAR2(255)
)
/

CREATE OR REPLACE VIEW AGREEMENTS (
  ID,
  SUMMA,
  AGREEMENTDATE,
  AGREEMENTENDDATE,
  EXECUTER_REF,
  CLIENT_REF,
  FACIALACC_CLS,
  AGREEMENTTYPE,
  ACCEPTED,
  ACCEPTDATE,
  CARDADVANCEPERCENT,
  CARDADVANCE,
  CLOSEDOC,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  BUDGETREF,
  LASTADJUSTMENT,
  LASTACCEPTED,
  FACT,
  REGION,
  CLOSEDATE,
  DELIVERYRULES,
  AGREEMENTSUMMA,
  AGREEMENTFINSUMMA,
  ADJUSTMENTREF,
  REESTRNUMBER,
  PAYMENTDATE,
  AGREEMENTCARDADVANCE,
  FINCARDADVANCE,
  STATEORDERREF,
  REJECTCLS,
  REJECTCAUSE,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  AGREEMENTBEGINDATE,
  PROTOCOLNUMBER,
  PROTOCOLDATE,
  REVIEWNOTE,
  DOCSTATEREF,
  RVERSION,
  EXPORTDATE,
  FSORGAN,
  FSBUDGETNAME,
  FSOFFBUDGET,
  RNYEAR,
  RNNUMBER,
  RNDATE,
  PROTOCOLNOTICE,
  PROTOCOLRESULTDATE,
  PROTOCOLDOCTYPE,
  PROTOCOLSALETYPE,
  NOTIFYDATE,
  EXECUTERACCREF,
  DOCBASEDATE,
  DOCBASENOTIFYDATE,
  DOCBASETEXT,
  DOCBASETYPE,
  DOCBASESUMMA,
  UNKNOWNAMOUNT,
  PROTOCOLREASON,
  DOCNUMBER,
  ADJUSTMENTDOCNUMBER,
  OLDDOCNUMBER,
  LOTMAXSUM,
  CLIENT_INN,
  CLIENT_INN20,
  CLIENT_NAME,
  EXECUTER_INN,
  EXECUTER_INN20,
  EXECUTER_NAME,
  EXECUTER_STATUS,
  EXECUTER_COUNTRY,
  EXECUTER_ADDRESS,
  EXECUTER_PHONE,
  REALID,
  ADJUSTMENTNUMBER,
  INNERNUMBER,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  REESTRVERSION,
  DOCTYPE,
  RNCLIENTID,
  INFONUMBER,
  STATEORDERINNERNUMBER,
  PROGINDEX,
  NOTE,
  PURPORTDOC,
  REESTRRECORDNUMBER,
  EXECUTERSTOREDPROPS,
  AUTOSANCTION,
  PURCHASECODE,
  DOCUMENTNUMBER,
  TEMPREJECTCAUSE)
AS
  SELECT
    ID,
    SUMMA,
    AGREEMENTDATE,
    AGREEMENTENDDATE,
    EXECUTER_REF,
    CLIENT_REF,
    FACIALACC_CLS,
    AGREEMENTTYPE,
    ACCEPTED,
    ACCEPTDATE,
    CARDADVANCEPERCENT,
    CARDADVANCE,
    CLOSEDOC,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    LASTADJUSTMENT,
    LASTACCEPTED,
    FACT,
    REGION,
    CLOSEDATE,
    DELIVERYRULES,
    AGREEMENTSUMMA,
    AGREEMENTFINSUMMA,
    ADJUSTMENTREF,
    REESTRNUMBER,
    PAYMENTDATE,
    AGREEMENTCARDADVANCE,
    FINCARDADVANCE,
    STATEORDERREF,
    REJECTCLS,
    REJECTCAUSE,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    AGREEMENTBEGINDATE,
    PROTOCOLNUMBER,
    PROTOCOLDATE,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXPORTDATE,
    FSORGAN,
    FSBUDGETNAME,
    FSOFFBUDGET,
    RNYEAR,
    RNNUMBER,
    RNDATE,
    PROTOCOLNOTICE,
    PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE,
    NOTIFYDATE,
    EXECUTERACCREF,
    DOCBASEDATE,
    DOCBASENOTIFYDATE,
    DOCBASETEXT,
    DOCBASETYPE,
    DOCBASESUMMA,
    UNKNOWNAMOUNT,
    PROTOCOLREASON,
    DOCNUMBER,
    ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER,
    LOTMAXSUM,
    CLIENT_INN,
    CLIENT_INN20,
    CLIENT_NAME,
    EXECUTER_INN,
    EXECUTER_INN20,
    EXECUTER_NAME,
    EXECUTER_STATUS,
    EXECUTER_COUNTRY,
    EXECUTER_ADDRESS,
    EXECUTER_PHONE,
    REALID,
    ADJUSTMENTNUMBER,
    INNERNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REESTRVERSION,
    DOCTYPE,
    RNCLIENTID,
    INFONUMBER,
    STATEORDERINNERNUMBER,
    PROGINDEX,
    NOTE,
    PURPORTDOC,
    REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS,
    AUTOSANCTION,
    PURCHASECODE,
    DOCUMENTNUMBER,
    TEMPREJECTCAUSE
  FROM TB_AGREEMENTS
/

CREATE OR REPLACE TRIGGER TR_AGREEMENTS_ID
  INSTEAD OF DELETE
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  cnt1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_AGREEMENTS_BD)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*   5.0*/
  select count(id) into cnt1$ from agreements where (adjustmentref = :old.id) ;
  /*  .       .*/
  if (cnt1$ = 0) then
    delete from estimate where (recordindex = :old.id);
    delete from agreementsteps where (recordindex = :old.id);
    delete from paymentschedule where agreementref = :old.id;

  else
    RaiseException('ex_agr_cantdeladjustmented');
  END IF;

-- - - - - - - - - - - - -
-- BD_20 (TR_AGREEMENTS_BD_20)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  /*          */
  if ((:old.ProgIndex = 305)and(:old.AdjustmentNumber = 0)) then
    update tenderresultcaption set
    StateOrder = null
    where
    StateOrder = :old.ID;
  END IF;
  if ((:old.ProgIndex = 314)and(:old.AdjustmentNumber = 0)) then
    update tenderresultcaption set
    StateOrder = null,
    Agreement = null
    where
    StateOrder = :old.ID;
  END IF;
  if ((:old.ProgIndex = 304)and(:old.AdjustmentNumber = 0)) then
    update tenderresultcaption set
    Agreement = null
    where
    Agreement = :old.ID;
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_AGREEMENTS
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_10 (TR_AGREEMENTS_AD_10)
-- Last update 05.02.2010
-- - - - - - - - - - - - -

/*   5.0*/
    /*   LastAdjustment     */
    if ((:old.AdjustmentNumber > 0) and (:old.LastAdjustment = 1)) then
        update Agreements set
            LastAdjustment = 1,
            RVersion = -1
        where (ID = :old.AdjustmentRef);
    end if;
    /*   LastAccepted     */
    if ((:old.AdjustmentNumber > 0) and (:old.LastAccepted = 1)) then
        update Agreements set
            LastAccepted = 1,
            RVersion = -1
        where (ID = :old.AdjustmentRef);
    end if;

-- - - - - - - - - - - - -
-- AD_200 (TR_AGREEMENTS_AD_200)
-- Create 04.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

  /*        */
  delete from StateJumpHistory where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_AGREEMENTS_AD_500)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordId, DeleteDate, Summa, ProgIndex)
  values (110, :old.ID, SYSDATE, :old.AgreementSumma, :old.ProgIndex);

END;
/

CREATE OR REPLACE TRIGGER TR_AGREEMENTS_II
  INSTEAD OF INSERT
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  new$ID AGREEMENTS.ID%TYPE := :NEW.ID;
  new$SUMMA AGREEMENTS.SUMMA%TYPE := :NEW.SUMMA;
  new$AGREEMENTDATE AGREEMENTS.AGREEMENTDATE%TYPE := :NEW.AGREEMENTDATE;
  new$AGREEMENTENDDATE AGREEMENTS.AGREEMENTENDDATE%TYPE := :NEW.AGREEMENTENDDATE;
  new$EXECUTER_REF AGREEMENTS.EXECUTER_REF%TYPE := :NEW.EXECUTER_REF;
  new$CLIENT_REF AGREEMENTS.CLIENT_REF%TYPE := :NEW.CLIENT_REF;
  new$FACIALACC_CLS AGREEMENTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$AGREEMENTTYPE AGREEMENTS.AGREEMENTTYPE%TYPE := :NEW.AGREEMENTTYPE;
  new$ACCEPTED AGREEMENTS.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$ACCEPTDATE AGREEMENTS.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$CARDADVANCEPERCENT AGREEMENTS.CARDADVANCEPERCENT%TYPE := :NEW.CARDADVANCEPERCENT;
  new$CARDADVANCE AGREEMENTS.CARDADVANCE%TYPE := :NEW.CARDADVANCE;
  new$CLOSEDOC AGREEMENTS.CLOSEDOC%TYPE := :NEW.CLOSEDOC;
  new$CREATERUSER AGREEMENTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE AGREEMENTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE AGREEMENTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER AGREEMENTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF AGREEMENTS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$LASTADJUSTMENT AGREEMENTS.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED AGREEMENTS.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$FACT AGREEMENTS.FACT%TYPE := :NEW.FACT;
  new$REGION AGREEMENTS.REGION%TYPE := :NEW.REGION;
  new$CLOSEDATE AGREEMENTS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$DELIVERYRULES AGREEMENTS.DELIVERYRULES%TYPE := :NEW.DELIVERYRULES;
  new$AGREEMENTSUMMA AGREEMENTS.AGREEMENTSUMMA%TYPE := :NEW.AGREEMENTSUMMA;
  new$AGREEMENTFINSUMMA AGREEMENTS.AGREEMENTFINSUMMA%TYPE := :NEW.AGREEMENTFINSUMMA;
  new$ADJUSTMENTREF AGREEMENTS.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$REESTRNUMBER AGREEMENTS.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$PAYMENTDATE AGREEMENTS.PAYMENTDATE%TYPE := :NEW.PAYMENTDATE;
  new$AGREEMENTCARDADVANCE AGREEMENTS.AGREEMENTCARDADVANCE%TYPE := :NEW.AGREEMENTCARDADVANCE;
  new$FINCARDADVANCE AGREEMENTS.FINCARDADVANCE%TYPE := :NEW.FINCARDADVANCE;
  new$STATEORDERREF AGREEMENTS.STATEORDERREF%TYPE := :NEW.STATEORDERREF;
  new$REJECTCLS AGREEMENTS.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTCAUSE AGREEMENTS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CRYPTOSTATUS AGREEMENTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID AGREEMENTS.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID AGREEMENTS.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$AGREEMENTBEGINDATE AGREEMENTS.AGREEMENTBEGINDATE%TYPE := :NEW.AGREEMENTBEGINDATE;
  new$PROTOCOLNUMBER AGREEMENTS.PROTOCOLNUMBER%TYPE := :NEW.PROTOCOLNUMBER;
  new$PROTOCOLDATE AGREEMENTS.PROTOCOLDATE%TYPE := :NEW.PROTOCOLDATE;
  new$REVIEWNOTE AGREEMENTS.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF AGREEMENTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION AGREEMENTS.RVERSION%TYPE := :NEW.RVERSION;
  new$EXPORTDATE AGREEMENTS.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$FSORGAN AGREEMENTS.FSORGAN%TYPE := :NEW.FSORGAN;
  new$FSBUDGETNAME AGREEMENTS.FSBUDGETNAME%TYPE := :NEW.FSBUDGETNAME;
  new$FSOFFBUDGET AGREEMENTS.FSOFFBUDGET%TYPE := :NEW.FSOFFBUDGET;
  new$RNYEAR AGREEMENTS.RNYEAR%TYPE := :NEW.RNYEAR;
  new$RNNUMBER AGREEMENTS.RNNUMBER%TYPE := :NEW.RNNUMBER;
  new$RNDATE AGREEMENTS.RNDATE%TYPE := :NEW.RNDATE;
  new$PROTOCOLNOTICE AGREEMENTS.PROTOCOLNOTICE%TYPE := :NEW.PROTOCOLNOTICE;
  new$PROTOCOLRESULTDATE AGREEMENTS.PROTOCOLRESULTDATE%TYPE := :NEW.PROTOCOLRESULTDATE;
  new$PROTOCOLDOCTYPE AGREEMENTS.PROTOCOLDOCTYPE%TYPE := :NEW.PROTOCOLDOCTYPE;
  new$PROTOCOLSALETYPE AGREEMENTS.PROTOCOLSALETYPE%TYPE := :NEW.PROTOCOLSALETYPE;
  new$NOTIFYDATE AGREEMENTS.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$EXECUTERACCREF AGREEMENTS.EXECUTERACCREF%TYPE := :NEW.EXECUTERACCREF;
  new$DOCBASEDATE AGREEMENTS.DOCBASEDATE%TYPE := :NEW.DOCBASEDATE;
  new$DOCBASENOTIFYDATE AGREEMENTS.DOCBASENOTIFYDATE%TYPE := :NEW.DOCBASENOTIFYDATE;
  new$DOCBASETEXT AGREEMENTS.DOCBASETEXT%TYPE := :NEW.DOCBASETEXT;
  new$DOCBASETYPE AGREEMENTS.DOCBASETYPE%TYPE := :NEW.DOCBASETYPE;
  new$DOCBASESUMMA AGREEMENTS.DOCBASESUMMA%TYPE := :NEW.DOCBASESUMMA;
  new$UNKNOWNAMOUNT AGREEMENTS.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PROTOCOLREASON AGREEMENTS.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$DOCNUMBER AGREEMENTS.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$ADJUSTMENTDOCNUMBER AGREEMENTS.ADJUSTMENTDOCNUMBER%TYPE := :NEW.ADJUSTMENTDOCNUMBER;
  new$OLDDOCNUMBER AGREEMENTS.OLDDOCNUMBER%TYPE := :NEW.OLDDOCNUMBER;
  new$LOTMAXSUM AGREEMENTS.LOTMAXSUM%TYPE := :NEW.LOTMAXSUM;
  new$CLIENT_INN AGREEMENTS.CLIENT_INN%TYPE := :NEW.CLIENT_INN;
  new$CLIENT_INN20 AGREEMENTS.CLIENT_INN20%TYPE := :NEW.CLIENT_INN20;
  new$CLIENT_NAME AGREEMENTS.CLIENT_NAME%TYPE := :NEW.CLIENT_NAME;
  new$EXECUTER_INN AGREEMENTS.EXECUTER_INN%TYPE := :NEW.EXECUTER_INN;
  new$EXECUTER_INN20 AGREEMENTS.EXECUTER_INN20%TYPE := :NEW.EXECUTER_INN20;
  new$EXECUTER_NAME AGREEMENTS.EXECUTER_NAME%TYPE := :NEW.EXECUTER_NAME;
  new$EXECUTER_STATUS AGREEMENTS.EXECUTER_STATUS%TYPE := :NEW.EXECUTER_STATUS;
  new$EXECUTER_COUNTRY AGREEMENTS.EXECUTER_COUNTRY%TYPE := :NEW.EXECUTER_COUNTRY;
  new$EXECUTER_ADDRESS AGREEMENTS.EXECUTER_ADDRESS%TYPE := :NEW.EXECUTER_ADDRESS;
  new$EXECUTER_PHONE AGREEMENTS.EXECUTER_PHONE%TYPE := :NEW.EXECUTER_PHONE;
  new$REALID AGREEMENTS.REALID%TYPE := :NEW.REALID;
  new$ADJUSTMENTNUMBER AGREEMENTS.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$INNERNUMBER AGREEMENTS.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$SENDERIDKEY AGREEMENTS.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY AGREEMENTS.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REESTRVERSION AGREEMENTS.REESTRVERSION%TYPE := :NEW.REESTRVERSION;
  new$DOCTYPE AGREEMENTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$RNCLIENTID AGREEMENTS.RNCLIENTID%TYPE := :NEW.RNCLIENTID;
  new$INFONUMBER AGREEMENTS.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$STATEORDERINNERNUMBER AGREEMENTS.STATEORDERINNERNUMBER%TYPE := :NEW.STATEORDERINNERNUMBER;
  new$PROGINDEX AGREEMENTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE AGREEMENTS.NOTE%TYPE := :NEW.NOTE;
  new$PURPORTDOC AGREEMENTS.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$REESTRRECORDNUMBER AGREEMENTS.REESTRRECORDNUMBER%TYPE := :NEW.REESTRRECORDNUMBER;
  new$EXECUTERSTOREDPROPS AGREEMENTS.EXECUTERSTOREDPROPS%TYPE := :NEW.EXECUTERSTOREDPROPS;
  new$AUTOSANCTION AGREEMENTS.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$PURCHASECODE AGREEMENTS.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$DOCUMENTNUMBER AGREEMENTS.DOCUMENTNUMBER%TYPE := :NEW.DOCUMENTNUMBER;
  new$TEMPREJECTCAUSE AGREEMENTS.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  CurVal$ NUMBER (10);
  CountAcc$ NUMBER(10);
  rnClientID1$ VARCHAR2(15);
  rnYear1$ VARCHAR2(15);
  rnNumber1$ VARCHAR2(15);
  ReestrVersion1$ VARCHAR2(15);
  Tmp$ NUMBER(10);
  AdjID$ NUMBER(10);
  AdjDocNum$ VARCHAR2(150);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_AGREEMENTS_BI)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   3.1.2*/
  /*    -*/
  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$CardAdvancePercent is null) then
    new$CardAdvancePercent := 0;
  END IF;
  if (new$CardAdvance is null) then
    new$CardAdvance := 0;
  END IF;
  if (new$AgreementCardAdvance is null) then
    new$AgreementCardAdvance := 0;
  END IF;
  if (new$FinCardAdvance is null) then
    new$FinCardAdvance := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$AgreementSumma is null) then
    new$AgreementSumma := 0;
  END IF;
  if (new$AgreementFinSumma is null) then
    new$AgreementFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$Region is null) then
    new$Region := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  if (new$client_ref is null) then
    new$client_ref := 0;
  END IF;

  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    BEGIN
      select fa.BudgetRef     into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;

  /*    
         -   InnerNumber*/
  if (((new$ProgIndex = 305) or (new$ProgIndex = 304) or (new$ProgIndex = 314)) and (new$InnerNumber is null)) then
    new$InnerNumber := GEN_ID('G_AgreementNumber',1);
  END IF;
  /*   */
  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  /*    .  */

  new$stateorderinnernumber := null;
  if (new$stateorderref is not null) then
    BEGIN
      select
      innernumber
      into new$stateorderinnernumber     from agreements
      where
      id = new$stateorderref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_AGREEMENTS_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_AGREEMENTS_BI_10)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  /*   5.0*/

  /*    .*/
  if (new$InnerNumber is null) then
    RaiseException('EX_AGR_InnerNumsIsNull');
  END IF;

  /*    */
  select max(AdjustmentNumber)
  into Tmp$         from Agreements
  where (InnerNumber = new$InnerNumber)
  ;
  /*      ,   0*/
  if (Tmp$ is null) then
    new$AdjustmentNumber := 0;

  else
    new$AdjustmentNumber := Tmp$ + 1;
  END IF;
  /*        */
  if (((new$AgreementType = 0) and (new$AdjustmentNumber > 0)) or
  ((new$AgreementType = 1) and (new$AdjustmentNumber = 0))) then
    RaiseException('EX_AGR_AgrTypeViolation');
  END IF;
  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;

  else
    new$LastAdjustment := 1;
  END IF;
  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then
    new$LastAccepted := 1;

  else
    new$LastAccepted := 0;
  END IF;
  /*    */
  if (new$AdjustmentNumber > 0) then
    /*      -    */
    select count(ID), max(ID), max(DocNumber)
    into Tmp$, AdjID$, AdjDocNum$             from Agreements
    where (InnerNumber = new$InnerNumber) and (LastAccepted = 1)
    ;
    /*   ,  */
    if (Tmp$ <> 1) then
      RaiseException('EX_AGR_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID)
    into Tmp$             from Agreements
    where (InnerNumber = new$InnerNumber) and (AcceptDate is null)
    ;
    if (Tmp$ > 0) then
      RaiseException('EX_AGR_AdjustDuplicate');
    END IF;
    /* ,    ,    */
    new$AdjustmentRef := AdjID$;
    new$AdjustmentDocNumber := AdjDocNum$;

  else /*     */
    /*       (    )*/
    new$AdjustmentRef := null;
    new$AdjustmentDocNumber := null;

  END IF;

-- - - - - - - - - - - - -
-- BI_20 (TR_AGREEMENTS_BI_20)
-- Create 21.05.2009
-- - - - - - - - - - - - -

  /*    -,     */
  if ((new$Client_INN   is null) and
      (new$Client_INN20 is null) and
      (new$Client_Name  is null))then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name
      into
        new$Client_INN,
        new$Client_INN20,
        new$Client_Name
      from Organizations o
      where o.Id=new$Client_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Client_INN := NULL;
        new$Client_INN20 := NULL;
        new$Client_Name := NULL;
    END;
  END IF;

  /*    -,     */
  if ((new$Executer_INN     is null) and
      (new$Executer_INN20   is null) and
      (new$Executer_Name    is null) and
      (new$Executer_Status  is null) and
      (new$Executer_Country is null) and
      (new$Executer_Address is null) and
      (new$Executer_Phone   is null))then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name,
        o.SupplierStatus,
        o.Country,
        o.Address,
        o.Phone
      into
        new$Executer_INN,
        new$Executer_INN20,
        new$Executer_Name,
        new$Executer_Status,
        new$Executer_Country,
        new$Executer_Address,
        new$Executer_Phone
      from Organizations o
      where o.Id=new$Executer_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Executer_INN := NULL;
        new$Executer_INN20 := NULL;
        new$Executer_Name := NULL;
        new$Executer_Status := NULL;
        new$Executer_Country := NULL;
        new$Executer_Address := NULL;
        new$Executer_Phone := NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_40 (TR_AGREEMENTS_BI_40)
-- Create 06.08.2010
-- - - - - - - - - - - - -

  /*       */
  if (new$senderId is null) then
    new$senderIdKey := -1;
  else
    new$senderIdKey := new$senderId;
  end if;

  if (new$SenderRecordID is null)then
    new$SenderRecordIDKey := new$ID;
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  end if;

-- - - - - - - - - - - - -
-- BI_50 (TR_AGREEMENTS_BI_50)
-- Create 06.08.2010
-- - - - - - - - - - - - -

    if (new$InnerNumber is not null) then
        CurVal$ := gen_id('G_AgreementNumber', 0);
        if (CurVal$ < new$InnerNumber) then
          CurVal$ := gen_id('G_AgreementNumber', new$InnerNumber - CurVal$);
        end if;
    end if;

-- - - - - - - - - - - - -
-- BI_300 (tr_agreements_bi_300)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$ExecuterAccRef is not null) then
    select count(ID)
    into CountAcc$     from org_accounts oa
    where oa.id = new$ExecuterAccRef and oa.Org_ref = new$Executer_Ref
    ;
    if (CountAcc$ = 0) then
      RaiseException('EX_AGR_ACCORGCHECK');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_400 (TR_AGREEMENTS_BI_400)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if ((new$rnClientID is not null) and (new$rnYear is not null) and (new$rnNumber is not null)) then

    rnClientID1$ := new$rnClientID;
    rnYear1$ := new$rnYear;
    rnNumber1$ := new$rnNumber;
    ReestrVersion1$ := new$ReestrVersion;
    while (LENGTH(rnClientID1$) < 11) LOOP
      rnClientID1$ := '0' || rnClientID1$;
    END LOOP;
    while (LENGTH(rnNumber1$) < 6) LOOP
      rnNumber1$ := '0' || rnNumber1$;
    END LOOP;
    if (LENGTH(ReestrVersion1$) < 2) then
      ReestrVersion1$ := '0' || ReestrVersion1$;
    END IF;
    /*  ReestrRecordNumber*/
    if (new$ReestrVersion is null) then
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$;

    else
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$ || ReestrVersion1$;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_AGREEMENTS_BI_500)
-- Last update 19.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- BI_600 (agreements_realid_bi_600)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_AGREEMENTS (
    ID,
    SUMMA,
    AGREEMENTDATE,
    AGREEMENTENDDATE,
    EXECUTER_REF,
    CLIENT_REF,
    FACIALACC_CLS,
    AGREEMENTTYPE,
    ACCEPTED,
    ACCEPTDATE,
    CARDADVANCEPERCENT,
    CARDADVANCE,
    CLOSEDOC,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    LASTADJUSTMENT,
    LASTACCEPTED,
    FACT,
    REGION,
    CLOSEDATE,
    DELIVERYRULES,
    AGREEMENTSUMMA,
    AGREEMENTFINSUMMA,
    ADJUSTMENTREF,
    REESTRNUMBER,
    PAYMENTDATE,
    AGREEMENTCARDADVANCE,
    FINCARDADVANCE,
    STATEORDERREF,
    REJECTCLS,
    REJECTCAUSE,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    AGREEMENTBEGINDATE,
    PROTOCOLNUMBER,
    PROTOCOLDATE,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXPORTDATE,
    FSORGAN,
    FSBUDGETNAME,
    FSOFFBUDGET,
    RNYEAR,
    RNNUMBER,
    RNDATE,
    PROTOCOLNOTICE,
    PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE,
    NOTIFYDATE,
    EXECUTERACCREF,
    DOCBASEDATE,
    DOCBASENOTIFYDATE,
    DOCBASETEXT,
    DOCBASETYPE,
    DOCBASESUMMA,
    UNKNOWNAMOUNT,
    PROTOCOLREASON,
    DOCNUMBER,
    ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER,
    LOTMAXSUM,
    CLIENT_INN,
    CLIENT_INN20,
    CLIENT_NAME,
    EXECUTER_INN,
    EXECUTER_INN20,
    EXECUTER_NAME,
    EXECUTER_STATUS,
    EXECUTER_COUNTRY,
    EXECUTER_ADDRESS,
    EXECUTER_PHONE,
    REALID,
    ADJUSTMENTNUMBER,
    INNERNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REESTRVERSION,
    DOCTYPE,
    RNCLIENTID,
    INFONUMBER,
    STATEORDERINNERNUMBER,
    PROGINDEX,
    NOTE,
    PURPORTDOC,
    REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS,
    AUTOSANCTION,
    PURCHASECODE,
    DOCUMENTNUMBER,
    TEMPREJECTCAUSE
  ) VALUES (
    new$ID,
    new$SUMMA,
    new$AGREEMENTDATE,
    new$AGREEMENTENDDATE,
    new$EXECUTER_REF,
    new$CLIENT_REF,
    new$FACIALACC_CLS,
    new$AGREEMENTTYPE,
    new$ACCEPTED,
    new$ACCEPTDATE,
    new$CARDADVANCEPERCENT,
    new$CARDADVANCE,
    new$CLOSEDOC,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$LASTADJUSTMENT,
    new$LASTACCEPTED,
    new$FACT,
    new$REGION,
    new$CLOSEDATE,
    new$DELIVERYRULES,
    new$AGREEMENTSUMMA,
    new$AGREEMENTFINSUMMA,
    new$ADJUSTMENTREF,
    new$REESTRNUMBER,
    new$PAYMENTDATE,
    new$AGREEMENTCARDADVANCE,
    new$FINCARDADVANCE,
    new$STATEORDERREF,
    new$REJECTCLS,
    new$REJECTCAUSE,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$AGREEMENTBEGINDATE,
    new$PROTOCOLNUMBER,
    new$PROTOCOLDATE,
    new$REVIEWNOTE,
    new$DOCSTATEREF,
    new$RVERSION,
    new$EXPORTDATE,
    new$FSORGAN,
    new$FSBUDGETNAME,
    new$FSOFFBUDGET,
    new$RNYEAR,
    new$RNNUMBER,
    new$RNDATE,
    new$PROTOCOLNOTICE,
    new$PROTOCOLRESULTDATE,
    new$PROTOCOLDOCTYPE,
    new$PROTOCOLSALETYPE,
    new$NOTIFYDATE,
    new$EXECUTERACCREF,
    new$DOCBASEDATE,
    new$DOCBASENOTIFYDATE,
    new$DOCBASETEXT,
    new$DOCBASETYPE,
    new$DOCBASESUMMA,
    new$UNKNOWNAMOUNT,
    new$PROTOCOLREASON,
    new$DOCNUMBER,
    new$ADJUSTMENTDOCNUMBER,
    new$OLDDOCNUMBER,
    new$LOTMAXSUM,
    new$CLIENT_INN,
    new$CLIENT_INN20,
    new$CLIENT_NAME,
    new$EXECUTER_INN,
    new$EXECUTER_INN20,
    new$EXECUTER_NAME,
    new$EXECUTER_STATUS,
    new$EXECUTER_COUNTRY,
    new$EXECUTER_ADDRESS,
    new$EXECUTER_PHONE,
    new$REALID,
    new$ADJUSTMENTNUMBER,
    new$INNERNUMBER,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$REESTRVERSION,
    new$DOCTYPE,
    new$RNCLIENTID,
    new$INFONUMBER,
    new$STATEORDERINNERNUMBER,
    new$PROGINDEX,
    new$NOTE,
    new$PURPORTDOC,
    new$REESTRRECORDNUMBER,
    new$EXECUTERSTOREDPROPS,
    new$AUTOSANCTION,
    new$PURCHASECODE,
    new$DOCUMENTNUMBER,
    new$TEMPREJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_10 (TR_AGREEMENTS_AI_10)
-- Last update 05.02.2010
-- - - - - - - - - - - - -

/*   5.0*/
    if ((new$AdjustmentNumber > 0) and (new$LastAdjustment = 1)) then
        update Agreements set
            LastAdjustment = 0,
            RVersion = -1
        where (ID = new$AdjustmentRef);
        if (new$LastAccepted = 1) then
            update Agreements set
                LastAccepted = 0,
                RVersion = -1
            where (ID = new$AdjustmentRef);
        end if;
    end if;

-- - - - - - - - - - - - -
-- AI_500 (TR_AGREEMENTS_AI_500)
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 110) AND (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_AGREEMENTS_IU
  INSTEAD OF UPDATE
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  new$ID AGREEMENTS.ID%TYPE := :NEW.ID;
  new$SUMMA AGREEMENTS.SUMMA%TYPE := :NEW.SUMMA;
  new$AGREEMENTDATE AGREEMENTS.AGREEMENTDATE%TYPE := :NEW.AGREEMENTDATE;
  new$AGREEMENTENDDATE AGREEMENTS.AGREEMENTENDDATE%TYPE := :NEW.AGREEMENTENDDATE;
  new$EXECUTER_REF AGREEMENTS.EXECUTER_REF%TYPE := :NEW.EXECUTER_REF;
  new$CLIENT_REF AGREEMENTS.CLIENT_REF%TYPE := :NEW.CLIENT_REF;
  new$FACIALACC_CLS AGREEMENTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$AGREEMENTTYPE AGREEMENTS.AGREEMENTTYPE%TYPE := :NEW.AGREEMENTTYPE;
  new$ACCEPTED AGREEMENTS.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$ACCEPTDATE AGREEMENTS.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$CARDADVANCEPERCENT AGREEMENTS.CARDADVANCEPERCENT%TYPE := :NEW.CARDADVANCEPERCENT;
  new$CARDADVANCE AGREEMENTS.CARDADVANCE%TYPE := :NEW.CARDADVANCE;
  new$CLOSEDOC AGREEMENTS.CLOSEDOC%TYPE := :NEW.CLOSEDOC;
  new$CREATERUSER AGREEMENTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE AGREEMENTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE AGREEMENTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER AGREEMENTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF AGREEMENTS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$LASTADJUSTMENT AGREEMENTS.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED AGREEMENTS.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$FACT AGREEMENTS.FACT%TYPE := :NEW.FACT;
  new$REGION AGREEMENTS.REGION%TYPE := :NEW.REGION;
  new$CLOSEDATE AGREEMENTS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$DELIVERYRULES AGREEMENTS.DELIVERYRULES%TYPE := :NEW.DELIVERYRULES;
  new$AGREEMENTSUMMA AGREEMENTS.AGREEMENTSUMMA%TYPE := :NEW.AGREEMENTSUMMA;
  new$AGREEMENTFINSUMMA AGREEMENTS.AGREEMENTFINSUMMA%TYPE := :NEW.AGREEMENTFINSUMMA;
  new$ADJUSTMENTREF AGREEMENTS.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$REESTRNUMBER AGREEMENTS.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$PAYMENTDATE AGREEMENTS.PAYMENTDATE%TYPE := :NEW.PAYMENTDATE;
  new$AGREEMENTCARDADVANCE AGREEMENTS.AGREEMENTCARDADVANCE%TYPE := :NEW.AGREEMENTCARDADVANCE;
  new$FINCARDADVANCE AGREEMENTS.FINCARDADVANCE%TYPE := :NEW.FINCARDADVANCE;
  new$STATEORDERREF AGREEMENTS.STATEORDERREF%TYPE := :NEW.STATEORDERREF;
  new$REJECTCLS AGREEMENTS.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTCAUSE AGREEMENTS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CRYPTOSTATUS AGREEMENTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID AGREEMENTS.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID AGREEMENTS.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$AGREEMENTBEGINDATE AGREEMENTS.AGREEMENTBEGINDATE%TYPE := :NEW.AGREEMENTBEGINDATE;
  new$PROTOCOLNUMBER AGREEMENTS.PROTOCOLNUMBER%TYPE := :NEW.PROTOCOLNUMBER;
  new$PROTOCOLDATE AGREEMENTS.PROTOCOLDATE%TYPE := :NEW.PROTOCOLDATE;
  new$REVIEWNOTE AGREEMENTS.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF AGREEMENTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION AGREEMENTS.RVERSION%TYPE := :NEW.RVERSION;
  new$EXPORTDATE AGREEMENTS.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$FSORGAN AGREEMENTS.FSORGAN%TYPE := :NEW.FSORGAN;
  new$FSBUDGETNAME AGREEMENTS.FSBUDGETNAME%TYPE := :NEW.FSBUDGETNAME;
  new$FSOFFBUDGET AGREEMENTS.FSOFFBUDGET%TYPE := :NEW.FSOFFBUDGET;
  new$RNYEAR AGREEMENTS.RNYEAR%TYPE := :NEW.RNYEAR;
  new$RNNUMBER AGREEMENTS.RNNUMBER%TYPE := :NEW.RNNUMBER;
  new$RNDATE AGREEMENTS.RNDATE%TYPE := :NEW.RNDATE;
  new$PROTOCOLNOTICE AGREEMENTS.PROTOCOLNOTICE%TYPE := :NEW.PROTOCOLNOTICE;
  new$PROTOCOLRESULTDATE AGREEMENTS.PROTOCOLRESULTDATE%TYPE := :NEW.PROTOCOLRESULTDATE;
  new$PROTOCOLDOCTYPE AGREEMENTS.PROTOCOLDOCTYPE%TYPE := :NEW.PROTOCOLDOCTYPE;
  new$PROTOCOLSALETYPE AGREEMENTS.PROTOCOLSALETYPE%TYPE := :NEW.PROTOCOLSALETYPE;
  new$NOTIFYDATE AGREEMENTS.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$EXECUTERACCREF AGREEMENTS.EXECUTERACCREF%TYPE := :NEW.EXECUTERACCREF;
  new$DOCBASEDATE AGREEMENTS.DOCBASEDATE%TYPE := :NEW.DOCBASEDATE;
  new$DOCBASENOTIFYDATE AGREEMENTS.DOCBASENOTIFYDATE%TYPE := :NEW.DOCBASENOTIFYDATE;
  new$DOCBASETEXT AGREEMENTS.DOCBASETEXT%TYPE := :NEW.DOCBASETEXT;
  new$DOCBASETYPE AGREEMENTS.DOCBASETYPE%TYPE := :NEW.DOCBASETYPE;
  new$DOCBASESUMMA AGREEMENTS.DOCBASESUMMA%TYPE := :NEW.DOCBASESUMMA;
  new$UNKNOWNAMOUNT AGREEMENTS.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PROTOCOLREASON AGREEMENTS.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$DOCNUMBER AGREEMENTS.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$ADJUSTMENTDOCNUMBER AGREEMENTS.ADJUSTMENTDOCNUMBER%TYPE := :NEW.ADJUSTMENTDOCNUMBER;
  new$OLDDOCNUMBER AGREEMENTS.OLDDOCNUMBER%TYPE := :NEW.OLDDOCNUMBER;
  new$LOTMAXSUM AGREEMENTS.LOTMAXSUM%TYPE := :NEW.LOTMAXSUM;
  new$CLIENT_INN AGREEMENTS.CLIENT_INN%TYPE := :NEW.CLIENT_INN;
  new$CLIENT_INN20 AGREEMENTS.CLIENT_INN20%TYPE := :NEW.CLIENT_INN20;
  new$CLIENT_NAME AGREEMENTS.CLIENT_NAME%TYPE := :NEW.CLIENT_NAME;
  new$EXECUTER_INN AGREEMENTS.EXECUTER_INN%TYPE := :NEW.EXECUTER_INN;
  new$EXECUTER_INN20 AGREEMENTS.EXECUTER_INN20%TYPE := :NEW.EXECUTER_INN20;
  new$EXECUTER_NAME AGREEMENTS.EXECUTER_NAME%TYPE := :NEW.EXECUTER_NAME;
  new$EXECUTER_STATUS AGREEMENTS.EXECUTER_STATUS%TYPE := :NEW.EXECUTER_STATUS;
  new$EXECUTER_COUNTRY AGREEMENTS.EXECUTER_COUNTRY%TYPE := :NEW.EXECUTER_COUNTRY;
  new$EXECUTER_ADDRESS AGREEMENTS.EXECUTER_ADDRESS%TYPE := :NEW.EXECUTER_ADDRESS;
  new$EXECUTER_PHONE AGREEMENTS.EXECUTER_PHONE%TYPE := :NEW.EXECUTER_PHONE;
  new$REALID AGREEMENTS.REALID%TYPE := :NEW.REALID;
  new$ADJUSTMENTNUMBER AGREEMENTS.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$INNERNUMBER AGREEMENTS.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$SENDERIDKEY AGREEMENTS.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY AGREEMENTS.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REESTRVERSION AGREEMENTS.REESTRVERSION%TYPE := :NEW.REESTRVERSION;
  new$DOCTYPE AGREEMENTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$RNCLIENTID AGREEMENTS.RNCLIENTID%TYPE := :NEW.RNCLIENTID;
  new$INFONUMBER AGREEMENTS.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$STATEORDERINNERNUMBER AGREEMENTS.STATEORDERINNERNUMBER%TYPE := :NEW.STATEORDERINNERNUMBER;
  new$PROGINDEX AGREEMENTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE AGREEMENTS.NOTE%TYPE := :NEW.NOTE;
  new$PURPORTDOC AGREEMENTS.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$REESTRRECORDNUMBER AGREEMENTS.REESTRRECORDNUMBER%TYPE := :NEW.REESTRRECORDNUMBER;
  new$EXECUTERSTOREDPROPS AGREEMENTS.EXECUTERSTOREDPROPS%TYPE := :NEW.EXECUTERSTOREDPROPS;
  new$AUTOSANCTION AGREEMENTS.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$PURCHASECODE AGREEMENTS.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$DOCUMENTNUMBER AGREEMENTS.DOCUMENTNUMBER%TYPE := :NEW.DOCUMENTNUMBER;
  new$TEMPREJECTCAUSE AGREEMENTS.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  MaxNumber$ NUMBER (10);
  CurVal$ NUMBER (10);
  CNT$1 NUMBER(10);
  DetCount$ NUMBER(10);
  CountAcc$ NUMBER(10);
  rnClientID1$ VARCHAR2(15);
  rnYear1$ VARCHAR2(15);
  rnNumber1$ VARCHAR2(15);
  ReestrVersion1$ VARCHAR2(15);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_AGREEMENTS_BU)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   3.1*/
  /*    -*/
  if (new$CardAdvancePercent is null) then
    new$CardAdvancePercent := 0;
  END IF;
  if (new$CardAdvance is null) then
    new$CardAdvance := 0;
  END IF;
  if (new$AgreementCardAdvance is null) then
    new$AgreementCardAdvance := 0;
  END IF;
  if (new$FinCardAdvance is null) then
    new$FinCardAdvance := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$AgreementSumma is null) then
    new$AgreementSumma := 0;
  END IF;
  if (new$AgreementFinSumma is null) then
    new$AgreementFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$Region is null) then
    new$Region := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$client_ref is null) then
    new$client_ref := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount$ from AgreementSteps where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      select count(ID)       into DetCount$ from Estimate where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*         -   InnerNumber*/
  if (((new$ProgIndex = 305) or (new$ProgIndex = 304) or (new$ProgIndex = 314)) and (new$InnerNumber is null)) then
    new$InnerNumber := GEN_ID('G_AgreementNumber',1);
  END IF;
  /*   */
  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  /*    .  */

  new$stateorderinnernumber := null;
  if (new$stateorderref is not null) then
    BEGIN
      select
      innernumber
      into new$stateorderinnernumber     from agreements
      where
      id = new$stateorderref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_3 (TR_AGREEMENTS_BU_3)
-- Create 03.12.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*            */
   new$AdjustmentRef := :OLD.AdjustmentRef;

-- - - - - - - - - - - - -
-- BU_5 (TR_AGREEMENTS_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_AGREEMENTS_BU_10)
-- Last update 08.02.2010
-- - - - - - - - - - - - -

/*   5.0*/
    /* ,      ,   */
    if ((new$InnerNumber <> :old.InnerNumber) or
        (new$AdjustmentNumber <> :old.AdjustmentNumber) or
        (new$AgreementType <> :old.AgreementType)) then
        RaiseException('EX_AGR_ChangeInnerNums');
    end if;

    /*    !!!*/
    if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and
        ((new$Accepted = 1) or (new$AcceptDate is null))) then
        RaiseException('EX_RollbackCancel');
    end if;

    /*   ,     LastAccepted*/
    if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) or
        ((:old.Accepted = 0) and (new$Accepted = 1) and (new$AcceptDate is not null))) then
        /*  LastAccepted         */
        if (new$LastAdjustment = 1) then
            new$LastAccepted := 1;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;
    end if;

    /*    ,     LastAccepted*/
    if (((:old.AcceptDate is not null) and (:old.Accepted = 1)) and
        ((new$Accepted = 0) or (new$AcceptDate is null))) then
        /*  LastAccepted         */
        if (new$LastAdjustment = 1) then
            new$LastAccepted := 0;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;
    end if;

    /*   ,     LastAdjustment*/
    if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 0)) or
        ((:old.Accepted = 1) and (new$Accepted = 0) and (new$AcceptDate is not null))) then

        if (new$LastAdjustment = 1) then
            new$LastAdjustment := 0;
            new$LastAccepted := 0;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;

        SELECT Max(AdjustmentNumber) INTO MaxNumber$ FROm AgreementS
        WHERE (InnerNumber = new$InnerNumber);
        /*    ,     */
        if ((new$adjustmentNumber=0) and (MaxNumber$<>0)) then
          RaiseException('EX_Agr_PrimaryAgrHasNotify');
        end if;
    end if;

-- - - - - - - - - - - - -
-- BU_20 (TR_AGREEMENTS_BU_20)
-- Create 21.05.2009
-- - - - - - - - - - - - -

  /*    -,      */
  if ((new$Client_Ref <> :old.Client_Ref) and
      (((new$Client_INN is null) and
        (:old.Client_INN is null)) or
       (new$Client_INN = :old.Client_INN)) and
      (((new$Client_INN20 is null) and
        (:old.Client_INN20 is null)) or
       (new$Client_INN20 = :old.Client_INN20)) and
      (new$Client_Name = :old.Client_Name)) then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name
      into
        new$Client_INN,
        new$Client_INN20,
        new$Client_Name
      from Organizations o
      where o.Id=new$Client_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Client_INN := NULL;
        new$Client_INN20 := NULL;
        new$Client_Name := NULL;
    END;
  END IF;

  /*    -,      */
  if ((new$Executer_Ref <> :old.Executer_Ref) and
      (((new$Executer_INN is null) and
        (:old.Executer_INN is null)) or
       (new$Executer_INN = :old.Executer_INN)) and
      (((new$Executer_INN20 is null) and
        (:old.Executer_INN20 is null)) or
       (new$Executer_INN20 = :old.Executer_INN20)) and
      (new$Executer_Name = :old.Executer_Name) and
      (((new$Executer_Status is null) and
        (:old.Executer_Status is null)) or
       (new$Executer_Status = :old.Executer_Status)) and
      (((new$Executer_Country is null) and
        (:old.Executer_Country is null)) or
       (new$Executer_Country = :old.Executer_Country)) and
      (((new$Executer_Address is null) and
        (:old.Executer_Address is null)) or
       (new$Executer_Address = :old.Executer_Address)) and
      (((new$Executer_Phone is null) and
        (:old.Executer_Phone is null)) or
       (new$Executer_Phone = :old.Executer_Phone))) then
     BEGIN
      select
        o.INN,
        o.INN20,
        o.Name,
        o.SupplierStatus,
        o.Country,
        o.Address,
        o.Phone
      into
        new$Executer_INN,
        new$Executer_INN20,
        new$Executer_Name,
        new$Executer_Status,
        new$Executer_Country,
        new$Executer_Address,
        new$Executer_Phone
      from Organizations o
      where o.Id=new$Executer_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Executer_INN := NULL;
        new$Executer_INN20 := NULL;
        new$Executer_Name := NULL;
        new$Executer_Status := NULL;
        new$Executer_Country := NULL;
        new$Executer_Address := NULL;
        new$Executer_Phone := NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_50 (TR_AGREEMENTS_BU_50)
-- Create 06.08.2010
-- - - - - - - - - - - - -

    if (new$InnerNumber is not null) then
        CurVal$ := gen_id('G_AgreementNumber', 0);
        if (CurVal$ < new$InnerNumber) then
          CurVal$ := gen_id('G_AgreementNumber', new$InnerNumber - CurVal$);
        end if;
    end if;

-- - - - - - - - - - - - -
-- BU_60 (tr_agreements_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*        ,     */
  if (:old.accepted = 1 and new$accepted = 0 and new$acceptdate is not null and new$adjustmentnumber = 0) then
    SELECT COUNT(*) INTO CNT$1
    from executiondocumentscaption
    where
    (            agreementinnernumber = new$innernumber
    and (accepted <> 0 or acceptdate is null)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_Agr_CannotReject');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_AGREEMENTS_BU_200)
-- Create 04.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$id, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (tr_agreements_bu_300)
-- Version 8.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ExecuterAccRef is not null) then
--     select count(ID)
--     into CountAcc$     from org_accounts oa
--     where oa.id = new$ExecuterAccRef and oa.Org_ref = new$Executer_Ref
--     ;
--     if (CountAcc$ = 0) then
--       RaiseException('EX_AGR_ACCORGCHECK');
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_400 (TR_AGREEMENTS_BU_400)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (((new$rnClientID <> :old.rnClientID) or (new$rnYear <> :old.rnYear) or
  (new$rnNumber <> :old.rnNumber) or (new$ReestrVersion <> :old.ReestrVersion)) and
  (new$rnClientID is not null) and (new$rnYear is not null) and (new$rnNumber is not null)) then

    rnClientID1$ := new$rnClientID;
    rnYear1$ := new$rnYear;
    rnNumber1$ := new$rnNumber;
    ReestrVersion1$ := new$ReestrVersion;
    while (LENGTH(rnClientID1$) < 11) LOOP
      rnClientID1$ := '0' || rnClientID1$;
    END LOOP;
    while (LENGTH(rnNumber1$) < 6) LOOP
      rnNumber1$ := '0' || rnNumber1$;
    END LOOP;
    if (LENGTH(ReestrVersion1$) < 2) then
      ReestrVersion1$ := '0' || ReestrVersion1$;
    END IF;
    /*  ReestrRecordNumber*/
    if (new$ReestrVersion is null) then
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$;

    else
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$ || ReestrVersion1$;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_600 (agreements_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_AGREEMENTS_BU_700)
-- Create 14.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_AGREEMENTS SET
    ID = new$ID,
    SUMMA = new$SUMMA,
    AGREEMENTDATE = new$AGREEMENTDATE,
    AGREEMENTENDDATE = new$AGREEMENTENDDATE,
    EXECUTER_REF = new$EXECUTER_REF,
    CLIENT_REF = new$CLIENT_REF,
    FACIALACC_CLS = new$FACIALACC_CLS,
    AGREEMENTTYPE = new$AGREEMENTTYPE,
    ACCEPTED = new$ACCEPTED,
    ACCEPTDATE = new$ACCEPTDATE,
    CARDADVANCEPERCENT = new$CARDADVANCEPERCENT,
    CARDADVANCE = new$CARDADVANCE,
    CLOSEDOC = new$CLOSEDOC,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    FACT = new$FACT,
    REGION = new$REGION,
    CLOSEDATE = new$CLOSEDATE,
    DELIVERYRULES = new$DELIVERYRULES,
    AGREEMENTSUMMA = new$AGREEMENTSUMMA,
    AGREEMENTFINSUMMA = new$AGREEMENTFINSUMMA,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    REESTRNUMBER = new$REESTRNUMBER,
    PAYMENTDATE = new$PAYMENTDATE,
    AGREEMENTCARDADVANCE = new$AGREEMENTCARDADVANCE,
    FINCARDADVANCE = new$FINCARDADVANCE,
    STATEORDERREF = new$STATEORDERREF,
    REJECTCLS = new$REJECTCLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    AGREEMENTBEGINDATE = new$AGREEMENTBEGINDATE,
    PROTOCOLNUMBER = new$PROTOCOLNUMBER,
    PROTOCOLDATE = new$PROTOCOLDATE,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXPORTDATE = new$EXPORTDATE,
    FSORGAN = new$FSORGAN,
    FSBUDGETNAME = new$FSBUDGETNAME,
    FSOFFBUDGET = new$FSOFFBUDGET,
    RNYEAR = new$RNYEAR,
    RNNUMBER = new$RNNUMBER,
    RNDATE = new$RNDATE,
    PROTOCOLNOTICE = new$PROTOCOLNOTICE,
    PROTOCOLRESULTDATE = new$PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE = new$PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE = new$PROTOCOLSALETYPE,
    NOTIFYDATE = new$NOTIFYDATE,
    EXECUTERACCREF = new$EXECUTERACCREF,
    DOCBASEDATE = new$DOCBASEDATE,
    DOCBASENOTIFYDATE = new$DOCBASENOTIFYDATE,
    DOCBASETEXT = new$DOCBASETEXT,
    DOCBASETYPE = new$DOCBASETYPE,
    DOCBASESUMMA = new$DOCBASESUMMA,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PROTOCOLREASON = new$PROTOCOLREASON,
    DOCNUMBER = new$DOCNUMBER,
    ADJUSTMENTDOCNUMBER = new$ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER = new$OLDDOCNUMBER,
    LOTMAXSUM = new$LOTMAXSUM,
    CLIENT_INN = new$CLIENT_INN,
    CLIENT_INN20 = new$CLIENT_INN20,
    CLIENT_NAME = new$CLIENT_NAME,
    EXECUTER_INN = new$EXECUTER_INN,
    EXECUTER_INN20 = new$EXECUTER_INN20,
    EXECUTER_NAME = new$EXECUTER_NAME,
    EXECUTER_STATUS = new$EXECUTER_STATUS,
    EXECUTER_COUNTRY = new$EXECUTER_COUNTRY,
    EXECUTER_ADDRESS = new$EXECUTER_ADDRESS,
    EXECUTER_PHONE = new$EXECUTER_PHONE,
    REALID = new$REALID,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    INNERNUMBER = new$INNERNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REESTRVERSION = new$REESTRVERSION,
    DOCTYPE = new$DOCTYPE,
    RNCLIENTID = new$RNCLIENTID,
    INFONUMBER = new$INFONUMBER,
    STATEORDERINNERNUMBER = new$STATEORDERINNERNUMBER,
    PROGINDEX = new$PROGINDEX,
    NOTE = new$NOTE,
    PURPORTDOC = new$PURPORTDOC,
    REESTRRECORDNUMBER = new$REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS = new$EXECUTERSTOREDPROPS,
    AUTOSANCTION = new$AUTOSANCTION,
    PURCHASECODE = new$PURCHASECODE,
    DOCUMENTNUMBER = new$DOCUMENTNUMBER,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_AGREEMENTS_AU_10)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   6.0*/
  /*      */
  /*     ,       */
  if ((new$AdjustmentNumber > 0) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update Agreements set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentNumber > 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update Agreements set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*          */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 304)or(new$ProgIndex = 314)))then
    update Estimate
    set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    (RecordIndex = new$Id);
  END IF;
  /*         */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 305) or (new$ProgIndex = 314))) then
    update paymentschedule set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    AgreementRef = new$ID and
    ProgIndex in (317, 318);

  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_AGREEMENTS_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*      */
  if ((new$ProgIndex = 305) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null
    where
    StateOrder = :old.ID;
  END IF;
  /*      */
  if ((new$ProgIndex = 314) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null,
    Agreement = null
    where
    StateOrder = :old.ID;
  END IF;
  /*     */
  if ((:old.ProgIndex = 304) and (new$AdjustmentNumber = 0) and (new$Accepted = 0) and
  (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    Agreement = null
    where
    Agreement = :old.ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_AGREEMENTS_AU_30)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$ProgIndex = 304) or (new$ProgIndex = 314)) and
  ((new$Accepted <> :old.Accepted) or
  (new$AcceptDate is not null and :old.AcceptDate is null) or
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where AgreementRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_AGREEMENTS_AU_500)
-- Create 28.04.2005
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes
                  (TableID, RecordId, DeleteDate
                  )
           VALUES (110, :OLD.ID, SYSDATE
                  );

      DELETE FROM DelRecIndexes
            WHERE (TableID = 110) AND (RecordId = new$ID);
   END IF;

END;
/
update AGREEMENTS set
  TempRejectCause = REJECTCAUSE
/
commit work 
/
ALTER TABLE TB_AGREEMENTS DROP (REJECTCAUSE)
/

CREATE OR REPLACE VIEW AGREEMENTS (
  ID,
  SUMMA,
  AGREEMENTDATE,
  AGREEMENTENDDATE,
  EXECUTER_REF,
  CLIENT_REF,
  FACIALACC_CLS,
  AGREEMENTTYPE,
  ACCEPTED,
  ACCEPTDATE,
  CARDADVANCEPERCENT,
  CARDADVANCE,
  CLOSEDOC,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  BUDGETREF,
  LASTADJUSTMENT,
  LASTACCEPTED,
  FACT,
  REGION,
  CLOSEDATE,
  DELIVERYRULES,
  AGREEMENTSUMMA,
  AGREEMENTFINSUMMA,
  ADJUSTMENTREF,
  REESTRNUMBER,
  PAYMENTDATE,
  AGREEMENTCARDADVANCE,
  FINCARDADVANCE,
  STATEORDERREF,
  REJECTCLS,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  AGREEMENTBEGINDATE,
  PROTOCOLNUMBER,
  PROTOCOLDATE,
  REVIEWNOTE,
  DOCSTATEREF,
  RVERSION,
  EXPORTDATE,
  FSORGAN,
  FSBUDGETNAME,
  FSOFFBUDGET,
  RNYEAR,
  RNNUMBER,
  RNDATE,
  PROTOCOLNOTICE,
  PROTOCOLRESULTDATE,
  PROTOCOLDOCTYPE,
  PROTOCOLSALETYPE,
  NOTIFYDATE,
  EXECUTERACCREF,
  DOCBASEDATE,
  DOCBASENOTIFYDATE,
  DOCBASETEXT,
  DOCBASETYPE,
  DOCBASESUMMA,
  UNKNOWNAMOUNT,
  PROTOCOLREASON,
  DOCNUMBER,
  ADJUSTMENTDOCNUMBER,
  OLDDOCNUMBER,
  LOTMAXSUM,
  CLIENT_INN,
  CLIENT_INN20,
  CLIENT_NAME,
  EXECUTER_INN,
  EXECUTER_INN20,
  EXECUTER_NAME,
  EXECUTER_STATUS,
  EXECUTER_COUNTRY,
  EXECUTER_ADDRESS,
  EXECUTER_PHONE,
  REALID,
  ADJUSTMENTNUMBER,
  INNERNUMBER,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  REESTRVERSION,
  DOCTYPE,
  RNCLIENTID,
  INFONUMBER,
  STATEORDERINNERNUMBER,
  PROGINDEX,
  NOTE,
  PURPORTDOC,
  REESTRRECORDNUMBER,
  EXECUTERSTOREDPROPS,
  AUTOSANCTION,
  PURCHASECODE,
  DOCUMENTNUMBER,
  TEMPREJECTCAUSE)
AS
  SELECT
    ID,
    SUMMA,
    AGREEMENTDATE,
    AGREEMENTENDDATE,
    EXECUTER_REF,
    CLIENT_REF,
    FACIALACC_CLS,
    AGREEMENTTYPE,
    ACCEPTED,
    ACCEPTDATE,
    CARDADVANCEPERCENT,
    CARDADVANCE,
    CLOSEDOC,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    LASTADJUSTMENT,
    LASTACCEPTED,
    FACT,
    REGION,
    CLOSEDATE,
    DELIVERYRULES,
    AGREEMENTSUMMA,
    AGREEMENTFINSUMMA,
    ADJUSTMENTREF,
    REESTRNUMBER,
    PAYMENTDATE,
    AGREEMENTCARDADVANCE,
    FINCARDADVANCE,
    STATEORDERREF,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    AGREEMENTBEGINDATE,
    PROTOCOLNUMBER,
    PROTOCOLDATE,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXPORTDATE,
    FSORGAN,
    FSBUDGETNAME,
    FSOFFBUDGET,
    RNYEAR,
    RNNUMBER,
    RNDATE,
    PROTOCOLNOTICE,
    PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE,
    NOTIFYDATE,
    EXECUTERACCREF,
    DOCBASEDATE,
    DOCBASENOTIFYDATE,
    DOCBASETEXT,
    DOCBASETYPE,
    DOCBASESUMMA,
    UNKNOWNAMOUNT,
    PROTOCOLREASON,
    DOCNUMBER,
    ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER,
    LOTMAXSUM,
    CLIENT_INN,
    CLIENT_INN20,
    CLIENT_NAME,
    EXECUTER_INN,
    EXECUTER_INN20,
    EXECUTER_NAME,
    EXECUTER_STATUS,
    EXECUTER_COUNTRY,
    EXECUTER_ADDRESS,
    EXECUTER_PHONE,
    REALID,
    ADJUSTMENTNUMBER,
    INNERNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REESTRVERSION,
    DOCTYPE,
    RNCLIENTID,
    INFONUMBER,
    STATEORDERINNERNUMBER,
    PROGINDEX,
    NOTE,
    PURPORTDOC,
    REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS,
    AUTOSANCTION,
    PURCHASECODE,
    DOCUMENTNUMBER,
    TEMPREJECTCAUSE
  FROM TB_AGREEMENTS
/

CREATE OR REPLACE TRIGGER TR_AGREEMENTS_ID
  INSTEAD OF DELETE
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  cnt1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_AGREEMENTS_BD)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*   5.0*/
  select count(id) into cnt1$ from agreements where (adjustmentref = :old.id) ;
  /*  .       .*/
  if (cnt1$ = 0) then
    delete from estimate where (recordindex = :old.id);
    delete from agreementsteps where (recordindex = :old.id);
    delete from paymentschedule where agreementref = :old.id;

  else
    RaiseException('ex_agr_cantdeladjustmented');
  END IF;

-- - - - - - - - - - - - -
-- BD_20 (TR_AGREEMENTS_BD_20)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  /*          */
  if ((:old.ProgIndex = 305)and(:old.AdjustmentNumber = 0)) then
    update tenderresultcaption set
    StateOrder = null
    where
    StateOrder = :old.ID;
  END IF;
  if ((:old.ProgIndex = 314)and(:old.AdjustmentNumber = 0)) then
    update tenderresultcaption set
    StateOrder = null,
    Agreement = null
    where
    StateOrder = :old.ID;
  END IF;
  if ((:old.ProgIndex = 304)and(:old.AdjustmentNumber = 0)) then
    update tenderresultcaption set
    Agreement = null
    where
    Agreement = :old.ID;
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_AGREEMENTS
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_10 (TR_AGREEMENTS_AD_10)
-- Last update 05.02.2010
-- - - - - - - - - - - - -

/*   5.0*/
    /*   LastAdjustment     */
    if ((:old.AdjustmentNumber > 0) and (:old.LastAdjustment = 1)) then
        update Agreements set
            LastAdjustment = 1,
            RVersion = -1
        where (ID = :old.AdjustmentRef);
    end if;
    /*   LastAccepted     */
    if ((:old.AdjustmentNumber > 0) and (:old.LastAccepted = 1)) then
        update Agreements set
            LastAccepted = 1,
            RVersion = -1
        where (ID = :old.AdjustmentRef);
    end if;

-- - - - - - - - - - - - -
-- AD_200 (TR_AGREEMENTS_AD_200)
-- Create 04.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

  /*        */
  delete from StateJumpHistory where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_AGREEMENTS_AD_500)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordId, DeleteDate, Summa, ProgIndex)
  values (110, :old.ID, SYSDATE, :old.AgreementSumma, :old.ProgIndex);

END;
/

CREATE OR REPLACE TRIGGER TR_AGREEMENTS_II
  INSTEAD OF INSERT
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  new$ID AGREEMENTS.ID%TYPE := :NEW.ID;
  new$SUMMA AGREEMENTS.SUMMA%TYPE := :NEW.SUMMA;
  new$AGREEMENTDATE AGREEMENTS.AGREEMENTDATE%TYPE := :NEW.AGREEMENTDATE;
  new$AGREEMENTENDDATE AGREEMENTS.AGREEMENTENDDATE%TYPE := :NEW.AGREEMENTENDDATE;
  new$EXECUTER_REF AGREEMENTS.EXECUTER_REF%TYPE := :NEW.EXECUTER_REF;
  new$CLIENT_REF AGREEMENTS.CLIENT_REF%TYPE := :NEW.CLIENT_REF;
  new$FACIALACC_CLS AGREEMENTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$AGREEMENTTYPE AGREEMENTS.AGREEMENTTYPE%TYPE := :NEW.AGREEMENTTYPE;
  new$ACCEPTED AGREEMENTS.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$ACCEPTDATE AGREEMENTS.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$CARDADVANCEPERCENT AGREEMENTS.CARDADVANCEPERCENT%TYPE := :NEW.CARDADVANCEPERCENT;
  new$CARDADVANCE AGREEMENTS.CARDADVANCE%TYPE := :NEW.CARDADVANCE;
  new$CLOSEDOC AGREEMENTS.CLOSEDOC%TYPE := :NEW.CLOSEDOC;
  new$CREATERUSER AGREEMENTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE AGREEMENTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE AGREEMENTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER AGREEMENTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF AGREEMENTS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$LASTADJUSTMENT AGREEMENTS.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED AGREEMENTS.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$FACT AGREEMENTS.FACT%TYPE := :NEW.FACT;
  new$REGION AGREEMENTS.REGION%TYPE := :NEW.REGION;
  new$CLOSEDATE AGREEMENTS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$DELIVERYRULES AGREEMENTS.DELIVERYRULES%TYPE := :NEW.DELIVERYRULES;
  new$AGREEMENTSUMMA AGREEMENTS.AGREEMENTSUMMA%TYPE := :NEW.AGREEMENTSUMMA;
  new$AGREEMENTFINSUMMA AGREEMENTS.AGREEMENTFINSUMMA%TYPE := :NEW.AGREEMENTFINSUMMA;
  new$ADJUSTMENTREF AGREEMENTS.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$REESTRNUMBER AGREEMENTS.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$PAYMENTDATE AGREEMENTS.PAYMENTDATE%TYPE := :NEW.PAYMENTDATE;
  new$AGREEMENTCARDADVANCE AGREEMENTS.AGREEMENTCARDADVANCE%TYPE := :NEW.AGREEMENTCARDADVANCE;
  new$FINCARDADVANCE AGREEMENTS.FINCARDADVANCE%TYPE := :NEW.FINCARDADVANCE;
  new$STATEORDERREF AGREEMENTS.STATEORDERREF%TYPE := :NEW.STATEORDERREF;
  new$REJECTCLS AGREEMENTS.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS AGREEMENTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID AGREEMENTS.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID AGREEMENTS.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$AGREEMENTBEGINDATE AGREEMENTS.AGREEMENTBEGINDATE%TYPE := :NEW.AGREEMENTBEGINDATE;
  new$PROTOCOLNUMBER AGREEMENTS.PROTOCOLNUMBER%TYPE := :NEW.PROTOCOLNUMBER;
  new$PROTOCOLDATE AGREEMENTS.PROTOCOLDATE%TYPE := :NEW.PROTOCOLDATE;
  new$REVIEWNOTE AGREEMENTS.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF AGREEMENTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION AGREEMENTS.RVERSION%TYPE := :NEW.RVERSION;
  new$EXPORTDATE AGREEMENTS.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$FSORGAN AGREEMENTS.FSORGAN%TYPE := :NEW.FSORGAN;
  new$FSBUDGETNAME AGREEMENTS.FSBUDGETNAME%TYPE := :NEW.FSBUDGETNAME;
  new$FSOFFBUDGET AGREEMENTS.FSOFFBUDGET%TYPE := :NEW.FSOFFBUDGET;
  new$RNYEAR AGREEMENTS.RNYEAR%TYPE := :NEW.RNYEAR;
  new$RNNUMBER AGREEMENTS.RNNUMBER%TYPE := :NEW.RNNUMBER;
  new$RNDATE AGREEMENTS.RNDATE%TYPE := :NEW.RNDATE;
  new$PROTOCOLNOTICE AGREEMENTS.PROTOCOLNOTICE%TYPE := :NEW.PROTOCOLNOTICE;
  new$PROTOCOLRESULTDATE AGREEMENTS.PROTOCOLRESULTDATE%TYPE := :NEW.PROTOCOLRESULTDATE;
  new$PROTOCOLDOCTYPE AGREEMENTS.PROTOCOLDOCTYPE%TYPE := :NEW.PROTOCOLDOCTYPE;
  new$PROTOCOLSALETYPE AGREEMENTS.PROTOCOLSALETYPE%TYPE := :NEW.PROTOCOLSALETYPE;
  new$NOTIFYDATE AGREEMENTS.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$EXECUTERACCREF AGREEMENTS.EXECUTERACCREF%TYPE := :NEW.EXECUTERACCREF;
  new$DOCBASEDATE AGREEMENTS.DOCBASEDATE%TYPE := :NEW.DOCBASEDATE;
  new$DOCBASENOTIFYDATE AGREEMENTS.DOCBASENOTIFYDATE%TYPE := :NEW.DOCBASENOTIFYDATE;
  new$DOCBASETEXT AGREEMENTS.DOCBASETEXT%TYPE := :NEW.DOCBASETEXT;
  new$DOCBASETYPE AGREEMENTS.DOCBASETYPE%TYPE := :NEW.DOCBASETYPE;
  new$DOCBASESUMMA AGREEMENTS.DOCBASESUMMA%TYPE := :NEW.DOCBASESUMMA;
  new$UNKNOWNAMOUNT AGREEMENTS.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PROTOCOLREASON AGREEMENTS.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$DOCNUMBER AGREEMENTS.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$ADJUSTMENTDOCNUMBER AGREEMENTS.ADJUSTMENTDOCNUMBER%TYPE := :NEW.ADJUSTMENTDOCNUMBER;
  new$OLDDOCNUMBER AGREEMENTS.OLDDOCNUMBER%TYPE := :NEW.OLDDOCNUMBER;
  new$LOTMAXSUM AGREEMENTS.LOTMAXSUM%TYPE := :NEW.LOTMAXSUM;
  new$CLIENT_INN AGREEMENTS.CLIENT_INN%TYPE := :NEW.CLIENT_INN;
  new$CLIENT_INN20 AGREEMENTS.CLIENT_INN20%TYPE := :NEW.CLIENT_INN20;
  new$CLIENT_NAME AGREEMENTS.CLIENT_NAME%TYPE := :NEW.CLIENT_NAME;
  new$EXECUTER_INN AGREEMENTS.EXECUTER_INN%TYPE := :NEW.EXECUTER_INN;
  new$EXECUTER_INN20 AGREEMENTS.EXECUTER_INN20%TYPE := :NEW.EXECUTER_INN20;
  new$EXECUTER_NAME AGREEMENTS.EXECUTER_NAME%TYPE := :NEW.EXECUTER_NAME;
  new$EXECUTER_STATUS AGREEMENTS.EXECUTER_STATUS%TYPE := :NEW.EXECUTER_STATUS;
  new$EXECUTER_COUNTRY AGREEMENTS.EXECUTER_COUNTRY%TYPE := :NEW.EXECUTER_COUNTRY;
  new$EXECUTER_ADDRESS AGREEMENTS.EXECUTER_ADDRESS%TYPE := :NEW.EXECUTER_ADDRESS;
  new$EXECUTER_PHONE AGREEMENTS.EXECUTER_PHONE%TYPE := :NEW.EXECUTER_PHONE;
  new$REALID AGREEMENTS.REALID%TYPE := :NEW.REALID;
  new$ADJUSTMENTNUMBER AGREEMENTS.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$INNERNUMBER AGREEMENTS.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$SENDERIDKEY AGREEMENTS.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY AGREEMENTS.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REESTRVERSION AGREEMENTS.REESTRVERSION%TYPE := :NEW.REESTRVERSION;
  new$DOCTYPE AGREEMENTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$RNCLIENTID AGREEMENTS.RNCLIENTID%TYPE := :NEW.RNCLIENTID;
  new$INFONUMBER AGREEMENTS.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$STATEORDERINNERNUMBER AGREEMENTS.STATEORDERINNERNUMBER%TYPE := :NEW.STATEORDERINNERNUMBER;
  new$PROGINDEX AGREEMENTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE AGREEMENTS.NOTE%TYPE := :NEW.NOTE;
  new$PURPORTDOC AGREEMENTS.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$REESTRRECORDNUMBER AGREEMENTS.REESTRRECORDNUMBER%TYPE := :NEW.REESTRRECORDNUMBER;
  new$EXECUTERSTOREDPROPS AGREEMENTS.EXECUTERSTOREDPROPS%TYPE := :NEW.EXECUTERSTOREDPROPS;
  new$AUTOSANCTION AGREEMENTS.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$PURCHASECODE AGREEMENTS.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$DOCUMENTNUMBER AGREEMENTS.DOCUMENTNUMBER%TYPE := :NEW.DOCUMENTNUMBER;
  new$TEMPREJECTCAUSE AGREEMENTS.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  CurVal$ NUMBER (10);
  CountAcc$ NUMBER(10);
  rnClientID1$ VARCHAR2(15);
  rnYear1$ VARCHAR2(15);
  rnNumber1$ VARCHAR2(15);
  ReestrVersion1$ VARCHAR2(15);
  Tmp$ NUMBER(10);
  AdjID$ NUMBER(10);
  AdjDocNum$ VARCHAR2(150);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_AGREEMENTS_BI)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   3.1.2*/
  /*    -*/
  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$CardAdvancePercent is null) then
    new$CardAdvancePercent := 0;
  END IF;
  if (new$CardAdvance is null) then
    new$CardAdvance := 0;
  END IF;
  if (new$AgreementCardAdvance is null) then
    new$AgreementCardAdvance := 0;
  END IF;
  if (new$FinCardAdvance is null) then
    new$FinCardAdvance := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$AgreementSumma is null) then
    new$AgreementSumma := 0;
  END IF;
  if (new$AgreementFinSumma is null) then
    new$AgreementFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$Region is null) then
    new$Region := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  if (new$client_ref is null) then
    new$client_ref := 0;
  END IF;

  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    BEGIN
      select fa.BudgetRef     into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;

  /*    
         -   InnerNumber*/
  if (((new$ProgIndex = 305) or (new$ProgIndex = 304) or (new$ProgIndex = 314)) and (new$InnerNumber is null)) then
    new$InnerNumber := GEN_ID('G_AgreementNumber',1);
  END IF;
  /*   */
  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  /*    .  */

  new$stateorderinnernumber := null;
  if (new$stateorderref is not null) then
    BEGIN
      select
      innernumber
      into new$stateorderinnernumber     from agreements
      where
      id = new$stateorderref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_AGREEMENTS_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_AGREEMENTS_BI_10)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  /*   5.0*/

  /*    .*/
  if (new$InnerNumber is null) then
    RaiseException('EX_AGR_InnerNumsIsNull');
  END IF;

  /*    */
  select max(AdjustmentNumber)
  into Tmp$         from Agreements
  where (InnerNumber = new$InnerNumber)
  ;
  /*      ,   0*/
  if (Tmp$ is null) then
    new$AdjustmentNumber := 0;

  else
    new$AdjustmentNumber := Tmp$ + 1;
  END IF;
  /*        */
  if (((new$AgreementType = 0) and (new$AdjustmentNumber > 0)) or
  ((new$AgreementType = 1) and (new$AdjustmentNumber = 0))) then
    RaiseException('EX_AGR_AgrTypeViolation');
  END IF;
  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;

  else
    new$LastAdjustment := 1;
  END IF;
  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then
    new$LastAccepted := 1;

  else
    new$LastAccepted := 0;
  END IF;
  /*    */
  if (new$AdjustmentNumber > 0) then
    /*      -    */
    select count(ID), max(ID), max(DocNumber)
    into Tmp$, AdjID$, AdjDocNum$             from Agreements
    where (InnerNumber = new$InnerNumber) and (LastAccepted = 1)
    ;
    /*   ,  */
    if (Tmp$ <> 1) then
      RaiseException('EX_AGR_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID)
    into Tmp$             from Agreements
    where (InnerNumber = new$InnerNumber) and (AcceptDate is null)
    ;
    if (Tmp$ > 0) then
      RaiseException('EX_AGR_AdjustDuplicate');
    END IF;
    /* ,    ,    */
    new$AdjustmentRef := AdjID$;
    new$AdjustmentDocNumber := AdjDocNum$;

  else /*     */
    /*       (    )*/
    new$AdjustmentRef := null;
    new$AdjustmentDocNumber := null;

  END IF;

-- - - - - - - - - - - - -
-- BI_20 (TR_AGREEMENTS_BI_20)
-- Create 21.05.2009
-- - - - - - - - - - - - -

  /*    -,     */
  if ((new$Client_INN   is null) and
      (new$Client_INN20 is null) and
      (new$Client_Name  is null))then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name
      into
        new$Client_INN,
        new$Client_INN20,
        new$Client_Name
      from Organizations o
      where o.Id=new$Client_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Client_INN := NULL;
        new$Client_INN20 := NULL;
        new$Client_Name := NULL;
    END;
  END IF;

  /*    -,     */
  if ((new$Executer_INN     is null) and
      (new$Executer_INN20   is null) and
      (new$Executer_Name    is null) and
      (new$Executer_Status  is null) and
      (new$Executer_Country is null) and
      (new$Executer_Address is null) and
      (new$Executer_Phone   is null))then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name,
        o.SupplierStatus,
        o.Country,
        o.Address,
        o.Phone
      into
        new$Executer_INN,
        new$Executer_INN20,
        new$Executer_Name,
        new$Executer_Status,
        new$Executer_Country,
        new$Executer_Address,
        new$Executer_Phone
      from Organizations o
      where o.Id=new$Executer_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Executer_INN := NULL;
        new$Executer_INN20 := NULL;
        new$Executer_Name := NULL;
        new$Executer_Status := NULL;
        new$Executer_Country := NULL;
        new$Executer_Address := NULL;
        new$Executer_Phone := NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_40 (TR_AGREEMENTS_BI_40)
-- Create 06.08.2010
-- - - - - - - - - - - - -

  /*       */
  if (new$senderId is null) then
    new$senderIdKey := -1;
  else
    new$senderIdKey := new$senderId;
  end if;

  if (new$SenderRecordID is null)then
    new$SenderRecordIDKey := new$ID;
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  end if;

-- - - - - - - - - - - - -
-- BI_50 (TR_AGREEMENTS_BI_50)
-- Create 06.08.2010
-- - - - - - - - - - - - -

    if (new$InnerNumber is not null) then
        CurVal$ := gen_id('G_AgreementNumber', 0);
        if (CurVal$ < new$InnerNumber) then
          CurVal$ := gen_id('G_AgreementNumber', new$InnerNumber - CurVal$);
        end if;
    end if;

-- - - - - - - - - - - - -
-- BI_300 (tr_agreements_bi_300)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$ExecuterAccRef is not null) then
    select count(ID)
    into CountAcc$     from org_accounts oa
    where oa.id = new$ExecuterAccRef and oa.Org_ref = new$Executer_Ref
    ;
    if (CountAcc$ = 0) then
      RaiseException('EX_AGR_ACCORGCHECK');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_400 (TR_AGREEMENTS_BI_400)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if ((new$rnClientID is not null) and (new$rnYear is not null) and (new$rnNumber is not null)) then

    rnClientID1$ := new$rnClientID;
    rnYear1$ := new$rnYear;
    rnNumber1$ := new$rnNumber;
    ReestrVersion1$ := new$ReestrVersion;
    while (LENGTH(rnClientID1$) < 11) LOOP
      rnClientID1$ := '0' || rnClientID1$;
    END LOOP;
    while (LENGTH(rnNumber1$) < 6) LOOP
      rnNumber1$ := '0' || rnNumber1$;
    END LOOP;
    if (LENGTH(ReestrVersion1$) < 2) then
      ReestrVersion1$ := '0' || ReestrVersion1$;
    END IF;
    /*  ReestrRecordNumber*/
    if (new$ReestrVersion is null) then
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$;

    else
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$ || ReestrVersion1$;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_AGREEMENTS_BI_500)
-- Last update 19.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- BI_600 (agreements_realid_bi_600)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_AGREEMENTS (
    ID,
    SUMMA,
    AGREEMENTDATE,
    AGREEMENTENDDATE,
    EXECUTER_REF,
    CLIENT_REF,
    FACIALACC_CLS,
    AGREEMENTTYPE,
    ACCEPTED,
    ACCEPTDATE,
    CARDADVANCEPERCENT,
    CARDADVANCE,
    CLOSEDOC,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    LASTADJUSTMENT,
    LASTACCEPTED,
    FACT,
    REGION,
    CLOSEDATE,
    DELIVERYRULES,
    AGREEMENTSUMMA,
    AGREEMENTFINSUMMA,
    ADJUSTMENTREF,
    REESTRNUMBER,
    PAYMENTDATE,
    AGREEMENTCARDADVANCE,
    FINCARDADVANCE,
    STATEORDERREF,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    AGREEMENTBEGINDATE,
    PROTOCOLNUMBER,
    PROTOCOLDATE,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXPORTDATE,
    FSORGAN,
    FSBUDGETNAME,
    FSOFFBUDGET,
    RNYEAR,
    RNNUMBER,
    RNDATE,
    PROTOCOLNOTICE,
    PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE,
    NOTIFYDATE,
    EXECUTERACCREF,
    DOCBASEDATE,
    DOCBASENOTIFYDATE,
    DOCBASETEXT,
    DOCBASETYPE,
    DOCBASESUMMA,
    UNKNOWNAMOUNT,
    PROTOCOLREASON,
    DOCNUMBER,
    ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER,
    LOTMAXSUM,
    CLIENT_INN,
    CLIENT_INN20,
    CLIENT_NAME,
    EXECUTER_INN,
    EXECUTER_INN20,
    EXECUTER_NAME,
    EXECUTER_STATUS,
    EXECUTER_COUNTRY,
    EXECUTER_ADDRESS,
    EXECUTER_PHONE,
    REALID,
    ADJUSTMENTNUMBER,
    INNERNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REESTRVERSION,
    DOCTYPE,
    RNCLIENTID,
    INFONUMBER,
    STATEORDERINNERNUMBER,
    PROGINDEX,
    NOTE,
    PURPORTDOC,
    REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS,
    AUTOSANCTION,
    PURCHASECODE,
    DOCUMENTNUMBER,
    TEMPREJECTCAUSE
  ) VALUES (
    new$ID,
    new$SUMMA,
    new$AGREEMENTDATE,
    new$AGREEMENTENDDATE,
    new$EXECUTER_REF,
    new$CLIENT_REF,
    new$FACIALACC_CLS,
    new$AGREEMENTTYPE,
    new$ACCEPTED,
    new$ACCEPTDATE,
    new$CARDADVANCEPERCENT,
    new$CARDADVANCE,
    new$CLOSEDOC,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$LASTADJUSTMENT,
    new$LASTACCEPTED,
    new$FACT,
    new$REGION,
    new$CLOSEDATE,
    new$DELIVERYRULES,
    new$AGREEMENTSUMMA,
    new$AGREEMENTFINSUMMA,
    new$ADJUSTMENTREF,
    new$REESTRNUMBER,
    new$PAYMENTDATE,
    new$AGREEMENTCARDADVANCE,
    new$FINCARDADVANCE,
    new$STATEORDERREF,
    new$REJECTCLS,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$AGREEMENTBEGINDATE,
    new$PROTOCOLNUMBER,
    new$PROTOCOLDATE,
    new$REVIEWNOTE,
    new$DOCSTATEREF,
    new$RVERSION,
    new$EXPORTDATE,
    new$FSORGAN,
    new$FSBUDGETNAME,
    new$FSOFFBUDGET,
    new$RNYEAR,
    new$RNNUMBER,
    new$RNDATE,
    new$PROTOCOLNOTICE,
    new$PROTOCOLRESULTDATE,
    new$PROTOCOLDOCTYPE,
    new$PROTOCOLSALETYPE,
    new$NOTIFYDATE,
    new$EXECUTERACCREF,
    new$DOCBASEDATE,
    new$DOCBASENOTIFYDATE,
    new$DOCBASETEXT,
    new$DOCBASETYPE,
    new$DOCBASESUMMA,
    new$UNKNOWNAMOUNT,
    new$PROTOCOLREASON,
    new$DOCNUMBER,
    new$ADJUSTMENTDOCNUMBER,
    new$OLDDOCNUMBER,
    new$LOTMAXSUM,
    new$CLIENT_INN,
    new$CLIENT_INN20,
    new$CLIENT_NAME,
    new$EXECUTER_INN,
    new$EXECUTER_INN20,
    new$EXECUTER_NAME,
    new$EXECUTER_STATUS,
    new$EXECUTER_COUNTRY,
    new$EXECUTER_ADDRESS,
    new$EXECUTER_PHONE,
    new$REALID,
    new$ADJUSTMENTNUMBER,
    new$INNERNUMBER,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$REESTRVERSION,
    new$DOCTYPE,
    new$RNCLIENTID,
    new$INFONUMBER,
    new$STATEORDERINNERNUMBER,
    new$PROGINDEX,
    new$NOTE,
    new$PURPORTDOC,
    new$REESTRRECORDNUMBER,
    new$EXECUTERSTOREDPROPS,
    new$AUTOSANCTION,
    new$PURCHASECODE,
    new$DOCUMENTNUMBER,
    new$TEMPREJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_10 (TR_AGREEMENTS_AI_10)
-- Last update 05.02.2010
-- - - - - - - - - - - - -

/*   5.0*/
    if ((new$AdjustmentNumber > 0) and (new$LastAdjustment = 1)) then
        update Agreements set
            LastAdjustment = 0,
            RVersion = -1
        where (ID = new$AdjustmentRef);
        if (new$LastAccepted = 1) then
            update Agreements set
                LastAccepted = 0,
                RVersion = -1
            where (ID = new$AdjustmentRef);
        end if;
    end if;

-- - - - - - - - - - - - -
-- AI_500 (TR_AGREEMENTS_AI_500)
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 110) AND (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_AGREEMENTS_IU
  INSTEAD OF UPDATE
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  new$ID AGREEMENTS.ID%TYPE := :NEW.ID;
  new$SUMMA AGREEMENTS.SUMMA%TYPE := :NEW.SUMMA;
  new$AGREEMENTDATE AGREEMENTS.AGREEMENTDATE%TYPE := :NEW.AGREEMENTDATE;
  new$AGREEMENTENDDATE AGREEMENTS.AGREEMENTENDDATE%TYPE := :NEW.AGREEMENTENDDATE;
  new$EXECUTER_REF AGREEMENTS.EXECUTER_REF%TYPE := :NEW.EXECUTER_REF;
  new$CLIENT_REF AGREEMENTS.CLIENT_REF%TYPE := :NEW.CLIENT_REF;
  new$FACIALACC_CLS AGREEMENTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$AGREEMENTTYPE AGREEMENTS.AGREEMENTTYPE%TYPE := :NEW.AGREEMENTTYPE;
  new$ACCEPTED AGREEMENTS.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$ACCEPTDATE AGREEMENTS.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$CARDADVANCEPERCENT AGREEMENTS.CARDADVANCEPERCENT%TYPE := :NEW.CARDADVANCEPERCENT;
  new$CARDADVANCE AGREEMENTS.CARDADVANCE%TYPE := :NEW.CARDADVANCE;
  new$CLOSEDOC AGREEMENTS.CLOSEDOC%TYPE := :NEW.CLOSEDOC;
  new$CREATERUSER AGREEMENTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE AGREEMENTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE AGREEMENTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER AGREEMENTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF AGREEMENTS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$LASTADJUSTMENT AGREEMENTS.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED AGREEMENTS.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$FACT AGREEMENTS.FACT%TYPE := :NEW.FACT;
  new$REGION AGREEMENTS.REGION%TYPE := :NEW.REGION;
  new$CLOSEDATE AGREEMENTS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$DELIVERYRULES AGREEMENTS.DELIVERYRULES%TYPE := :NEW.DELIVERYRULES;
  new$AGREEMENTSUMMA AGREEMENTS.AGREEMENTSUMMA%TYPE := :NEW.AGREEMENTSUMMA;
  new$AGREEMENTFINSUMMA AGREEMENTS.AGREEMENTFINSUMMA%TYPE := :NEW.AGREEMENTFINSUMMA;
  new$ADJUSTMENTREF AGREEMENTS.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$REESTRNUMBER AGREEMENTS.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$PAYMENTDATE AGREEMENTS.PAYMENTDATE%TYPE := :NEW.PAYMENTDATE;
  new$AGREEMENTCARDADVANCE AGREEMENTS.AGREEMENTCARDADVANCE%TYPE := :NEW.AGREEMENTCARDADVANCE;
  new$FINCARDADVANCE AGREEMENTS.FINCARDADVANCE%TYPE := :NEW.FINCARDADVANCE;
  new$STATEORDERREF AGREEMENTS.STATEORDERREF%TYPE := :NEW.STATEORDERREF;
  new$REJECTCLS AGREEMENTS.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS AGREEMENTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID AGREEMENTS.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID AGREEMENTS.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$AGREEMENTBEGINDATE AGREEMENTS.AGREEMENTBEGINDATE%TYPE := :NEW.AGREEMENTBEGINDATE;
  new$PROTOCOLNUMBER AGREEMENTS.PROTOCOLNUMBER%TYPE := :NEW.PROTOCOLNUMBER;
  new$PROTOCOLDATE AGREEMENTS.PROTOCOLDATE%TYPE := :NEW.PROTOCOLDATE;
  new$REVIEWNOTE AGREEMENTS.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF AGREEMENTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION AGREEMENTS.RVERSION%TYPE := :NEW.RVERSION;
  new$EXPORTDATE AGREEMENTS.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$FSORGAN AGREEMENTS.FSORGAN%TYPE := :NEW.FSORGAN;
  new$FSBUDGETNAME AGREEMENTS.FSBUDGETNAME%TYPE := :NEW.FSBUDGETNAME;
  new$FSOFFBUDGET AGREEMENTS.FSOFFBUDGET%TYPE := :NEW.FSOFFBUDGET;
  new$RNYEAR AGREEMENTS.RNYEAR%TYPE := :NEW.RNYEAR;
  new$RNNUMBER AGREEMENTS.RNNUMBER%TYPE := :NEW.RNNUMBER;
  new$RNDATE AGREEMENTS.RNDATE%TYPE := :NEW.RNDATE;
  new$PROTOCOLNOTICE AGREEMENTS.PROTOCOLNOTICE%TYPE := :NEW.PROTOCOLNOTICE;
  new$PROTOCOLRESULTDATE AGREEMENTS.PROTOCOLRESULTDATE%TYPE := :NEW.PROTOCOLRESULTDATE;
  new$PROTOCOLDOCTYPE AGREEMENTS.PROTOCOLDOCTYPE%TYPE := :NEW.PROTOCOLDOCTYPE;
  new$PROTOCOLSALETYPE AGREEMENTS.PROTOCOLSALETYPE%TYPE := :NEW.PROTOCOLSALETYPE;
  new$NOTIFYDATE AGREEMENTS.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$EXECUTERACCREF AGREEMENTS.EXECUTERACCREF%TYPE := :NEW.EXECUTERACCREF;
  new$DOCBASEDATE AGREEMENTS.DOCBASEDATE%TYPE := :NEW.DOCBASEDATE;
  new$DOCBASENOTIFYDATE AGREEMENTS.DOCBASENOTIFYDATE%TYPE := :NEW.DOCBASENOTIFYDATE;
  new$DOCBASETEXT AGREEMENTS.DOCBASETEXT%TYPE := :NEW.DOCBASETEXT;
  new$DOCBASETYPE AGREEMENTS.DOCBASETYPE%TYPE := :NEW.DOCBASETYPE;
  new$DOCBASESUMMA AGREEMENTS.DOCBASESUMMA%TYPE := :NEW.DOCBASESUMMA;
  new$UNKNOWNAMOUNT AGREEMENTS.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PROTOCOLREASON AGREEMENTS.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$DOCNUMBER AGREEMENTS.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$ADJUSTMENTDOCNUMBER AGREEMENTS.ADJUSTMENTDOCNUMBER%TYPE := :NEW.ADJUSTMENTDOCNUMBER;
  new$OLDDOCNUMBER AGREEMENTS.OLDDOCNUMBER%TYPE := :NEW.OLDDOCNUMBER;
  new$LOTMAXSUM AGREEMENTS.LOTMAXSUM%TYPE := :NEW.LOTMAXSUM;
  new$CLIENT_INN AGREEMENTS.CLIENT_INN%TYPE := :NEW.CLIENT_INN;
  new$CLIENT_INN20 AGREEMENTS.CLIENT_INN20%TYPE := :NEW.CLIENT_INN20;
  new$CLIENT_NAME AGREEMENTS.CLIENT_NAME%TYPE := :NEW.CLIENT_NAME;
  new$EXECUTER_INN AGREEMENTS.EXECUTER_INN%TYPE := :NEW.EXECUTER_INN;
  new$EXECUTER_INN20 AGREEMENTS.EXECUTER_INN20%TYPE := :NEW.EXECUTER_INN20;
  new$EXECUTER_NAME AGREEMENTS.EXECUTER_NAME%TYPE := :NEW.EXECUTER_NAME;
  new$EXECUTER_STATUS AGREEMENTS.EXECUTER_STATUS%TYPE := :NEW.EXECUTER_STATUS;
  new$EXECUTER_COUNTRY AGREEMENTS.EXECUTER_COUNTRY%TYPE := :NEW.EXECUTER_COUNTRY;
  new$EXECUTER_ADDRESS AGREEMENTS.EXECUTER_ADDRESS%TYPE := :NEW.EXECUTER_ADDRESS;
  new$EXECUTER_PHONE AGREEMENTS.EXECUTER_PHONE%TYPE := :NEW.EXECUTER_PHONE;
  new$REALID AGREEMENTS.REALID%TYPE := :NEW.REALID;
  new$ADJUSTMENTNUMBER AGREEMENTS.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$INNERNUMBER AGREEMENTS.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$SENDERIDKEY AGREEMENTS.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY AGREEMENTS.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REESTRVERSION AGREEMENTS.REESTRVERSION%TYPE := :NEW.REESTRVERSION;
  new$DOCTYPE AGREEMENTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$RNCLIENTID AGREEMENTS.RNCLIENTID%TYPE := :NEW.RNCLIENTID;
  new$INFONUMBER AGREEMENTS.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$STATEORDERINNERNUMBER AGREEMENTS.STATEORDERINNERNUMBER%TYPE := :NEW.STATEORDERINNERNUMBER;
  new$PROGINDEX AGREEMENTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE AGREEMENTS.NOTE%TYPE := :NEW.NOTE;
  new$PURPORTDOC AGREEMENTS.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$REESTRRECORDNUMBER AGREEMENTS.REESTRRECORDNUMBER%TYPE := :NEW.REESTRRECORDNUMBER;
  new$EXECUTERSTOREDPROPS AGREEMENTS.EXECUTERSTOREDPROPS%TYPE := :NEW.EXECUTERSTOREDPROPS;
  new$AUTOSANCTION AGREEMENTS.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$PURCHASECODE AGREEMENTS.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$DOCUMENTNUMBER AGREEMENTS.DOCUMENTNUMBER%TYPE := :NEW.DOCUMENTNUMBER;
  new$TEMPREJECTCAUSE AGREEMENTS.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  MaxNumber$ NUMBER (10);
  CurVal$ NUMBER (10);
  CNT$1 NUMBER(10);
  DetCount$ NUMBER(10);
  CountAcc$ NUMBER(10);
  rnClientID1$ VARCHAR2(15);
  rnYear1$ VARCHAR2(15);
  rnNumber1$ VARCHAR2(15);
  ReestrVersion1$ VARCHAR2(15);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_AGREEMENTS_BU)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   3.1*/
  /*    -*/
  if (new$CardAdvancePercent is null) then
    new$CardAdvancePercent := 0;
  END IF;
  if (new$CardAdvance is null) then
    new$CardAdvance := 0;
  END IF;
  if (new$AgreementCardAdvance is null) then
    new$AgreementCardAdvance := 0;
  END IF;
  if (new$FinCardAdvance is null) then
    new$FinCardAdvance := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$AgreementSumma is null) then
    new$AgreementSumma := 0;
  END IF;
  if (new$AgreementFinSumma is null) then
    new$AgreementFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$Region is null) then
    new$Region := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$client_ref is null) then
    new$client_ref := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount$ from AgreementSteps where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      select count(ID)       into DetCount$ from Estimate where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*         -   InnerNumber*/
  if (((new$ProgIndex = 305) or (new$ProgIndex = 304) or (new$ProgIndex = 314)) and (new$InnerNumber is null)) then
    new$InnerNumber := GEN_ID('G_AgreementNumber',1);
  END IF;
  /*   */
  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  /*    .  */

  new$stateorderinnernumber := null;
  if (new$stateorderref is not null) then
    BEGIN
      select
      innernumber
      into new$stateorderinnernumber     from agreements
      where
      id = new$stateorderref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_3 (TR_AGREEMENTS_BU_3)
-- Create 03.12.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*            */
   new$AdjustmentRef := :OLD.AdjustmentRef;

-- - - - - - - - - - - - -
-- BU_5 (TR_AGREEMENTS_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_AGREEMENTS_BU_10)
-- Last update 08.02.2010
-- - - - - - - - - - - - -

/*   5.0*/
    /* ,      ,   */
    if ((new$InnerNumber <> :old.InnerNumber) or
        (new$AdjustmentNumber <> :old.AdjustmentNumber) or
        (new$AgreementType <> :old.AgreementType)) then
        RaiseException('EX_AGR_ChangeInnerNums');
    end if;

    /*    !!!*/
    if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and
        ((new$Accepted = 1) or (new$AcceptDate is null))) then
        RaiseException('EX_RollbackCancel');
    end if;

    /*   ,     LastAccepted*/
    if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) or
        ((:old.Accepted = 0) and (new$Accepted = 1) and (new$AcceptDate is not null))) then
        /*  LastAccepted         */
        if (new$LastAdjustment = 1) then
            new$LastAccepted := 1;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;
    end if;

    /*    ,     LastAccepted*/
    if (((:old.AcceptDate is not null) and (:old.Accepted = 1)) and
        ((new$Accepted = 0) or (new$AcceptDate is null))) then
        /*  LastAccepted         */
        if (new$LastAdjustment = 1) then
            new$LastAccepted := 0;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;
    end if;

    /*   ,     LastAdjustment*/
    if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 0)) or
        ((:old.Accepted = 1) and (new$Accepted = 0) and (new$AcceptDate is not null))) then

        if (new$LastAdjustment = 1) then
            new$LastAdjustment := 0;
            new$LastAccepted := 0;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;

        SELECT Max(AdjustmentNumber) INTO MaxNumber$ FROm AgreementS
        WHERE (InnerNumber = new$InnerNumber);
        /*    ,     */
        if ((new$adjustmentNumber=0) and (MaxNumber$<>0)) then
          RaiseException('EX_Agr_PrimaryAgrHasNotify');
        end if;
    end if;

-- - - - - - - - - - - - -
-- BU_20 (TR_AGREEMENTS_BU_20)
-- Create 21.05.2009
-- - - - - - - - - - - - -

  /*    -,      */
  if ((new$Client_Ref <> :old.Client_Ref) and
      (((new$Client_INN is null) and
        (:old.Client_INN is null)) or
       (new$Client_INN = :old.Client_INN)) and
      (((new$Client_INN20 is null) and
        (:old.Client_INN20 is null)) or
       (new$Client_INN20 = :old.Client_INN20)) and
      (new$Client_Name = :old.Client_Name)) then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name
      into
        new$Client_INN,
        new$Client_INN20,
        new$Client_Name
      from Organizations o
      where o.Id=new$Client_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Client_INN := NULL;
        new$Client_INN20 := NULL;
        new$Client_Name := NULL;
    END;
  END IF;

  /*    -,      */
  if ((new$Executer_Ref <> :old.Executer_Ref) and
      (((new$Executer_INN is null) and
        (:old.Executer_INN is null)) or
       (new$Executer_INN = :old.Executer_INN)) and
      (((new$Executer_INN20 is null) and
        (:old.Executer_INN20 is null)) or
       (new$Executer_INN20 = :old.Executer_INN20)) and
      (new$Executer_Name = :old.Executer_Name) and
      (((new$Executer_Status is null) and
        (:old.Executer_Status is null)) or
       (new$Executer_Status = :old.Executer_Status)) and
      (((new$Executer_Country is null) and
        (:old.Executer_Country is null)) or
       (new$Executer_Country = :old.Executer_Country)) and
      (((new$Executer_Address is null) and
        (:old.Executer_Address is null)) or
       (new$Executer_Address = :old.Executer_Address)) and
      (((new$Executer_Phone is null) and
        (:old.Executer_Phone is null)) or
       (new$Executer_Phone = :old.Executer_Phone))) then
     BEGIN
      select
        o.INN,
        o.INN20,
        o.Name,
        o.SupplierStatus,
        o.Country,
        o.Address,
        o.Phone
      into
        new$Executer_INN,
        new$Executer_INN20,
        new$Executer_Name,
        new$Executer_Status,
        new$Executer_Country,
        new$Executer_Address,
        new$Executer_Phone
      from Organizations o
      where o.Id=new$Executer_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Executer_INN := NULL;
        new$Executer_INN20 := NULL;
        new$Executer_Name := NULL;
        new$Executer_Status := NULL;
        new$Executer_Country := NULL;
        new$Executer_Address := NULL;
        new$Executer_Phone := NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_50 (TR_AGREEMENTS_BU_50)
-- Create 06.08.2010
-- - - - - - - - - - - - -

    if (new$InnerNumber is not null) then
        CurVal$ := gen_id('G_AgreementNumber', 0);
        if (CurVal$ < new$InnerNumber) then
          CurVal$ := gen_id('G_AgreementNumber', new$InnerNumber - CurVal$);
        end if;
    end if;

-- - - - - - - - - - - - -
-- BU_60 (tr_agreements_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*        ,     */
  if (:old.accepted = 1 and new$accepted = 0 and new$acceptdate is not null and new$adjustmentnumber = 0) then
    SELECT COUNT(*) INTO CNT$1
    from executiondocumentscaption
    where
    (            agreementinnernumber = new$innernumber
    and (accepted <> 0 or acceptdate is null)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_Agr_CannotReject');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_AGREEMENTS_BU_200)
-- Create 04.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$id, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (tr_agreements_bu_300)
-- Version 8.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ExecuterAccRef is not null) then
--     select count(ID)
--     into CountAcc$     from org_accounts oa
--     where oa.id = new$ExecuterAccRef and oa.Org_ref = new$Executer_Ref
--     ;
--     if (CountAcc$ = 0) then
--       RaiseException('EX_AGR_ACCORGCHECK');
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_400 (TR_AGREEMENTS_BU_400)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (((new$rnClientID <> :old.rnClientID) or (new$rnYear <> :old.rnYear) or
  (new$rnNumber <> :old.rnNumber) or (new$ReestrVersion <> :old.ReestrVersion)) and
  (new$rnClientID is not null) and (new$rnYear is not null) and (new$rnNumber is not null)) then

    rnClientID1$ := new$rnClientID;
    rnYear1$ := new$rnYear;
    rnNumber1$ := new$rnNumber;
    ReestrVersion1$ := new$ReestrVersion;
    while (LENGTH(rnClientID1$) < 11) LOOP
      rnClientID1$ := '0' || rnClientID1$;
    END LOOP;
    while (LENGTH(rnNumber1$) < 6) LOOP
      rnNumber1$ := '0' || rnNumber1$;
    END LOOP;
    if (LENGTH(ReestrVersion1$) < 2) then
      ReestrVersion1$ := '0' || ReestrVersion1$;
    END IF;
    /*  ReestrRecordNumber*/
    if (new$ReestrVersion is null) then
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$;

    else
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$ || ReestrVersion1$;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_600 (agreements_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_AGREEMENTS_BU_700)
-- Create 14.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_AGREEMENTS SET
    ID = new$ID,
    SUMMA = new$SUMMA,
    AGREEMENTDATE = new$AGREEMENTDATE,
    AGREEMENTENDDATE = new$AGREEMENTENDDATE,
    EXECUTER_REF = new$EXECUTER_REF,
    CLIENT_REF = new$CLIENT_REF,
    FACIALACC_CLS = new$FACIALACC_CLS,
    AGREEMENTTYPE = new$AGREEMENTTYPE,
    ACCEPTED = new$ACCEPTED,
    ACCEPTDATE = new$ACCEPTDATE,
    CARDADVANCEPERCENT = new$CARDADVANCEPERCENT,
    CARDADVANCE = new$CARDADVANCE,
    CLOSEDOC = new$CLOSEDOC,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    FACT = new$FACT,
    REGION = new$REGION,
    CLOSEDATE = new$CLOSEDATE,
    DELIVERYRULES = new$DELIVERYRULES,
    AGREEMENTSUMMA = new$AGREEMENTSUMMA,
    AGREEMENTFINSUMMA = new$AGREEMENTFINSUMMA,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    REESTRNUMBER = new$REESTRNUMBER,
    PAYMENTDATE = new$PAYMENTDATE,
    AGREEMENTCARDADVANCE = new$AGREEMENTCARDADVANCE,
    FINCARDADVANCE = new$FINCARDADVANCE,
    STATEORDERREF = new$STATEORDERREF,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    AGREEMENTBEGINDATE = new$AGREEMENTBEGINDATE,
    PROTOCOLNUMBER = new$PROTOCOLNUMBER,
    PROTOCOLDATE = new$PROTOCOLDATE,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXPORTDATE = new$EXPORTDATE,
    FSORGAN = new$FSORGAN,
    FSBUDGETNAME = new$FSBUDGETNAME,
    FSOFFBUDGET = new$FSOFFBUDGET,
    RNYEAR = new$RNYEAR,
    RNNUMBER = new$RNNUMBER,
    RNDATE = new$RNDATE,
    PROTOCOLNOTICE = new$PROTOCOLNOTICE,
    PROTOCOLRESULTDATE = new$PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE = new$PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE = new$PROTOCOLSALETYPE,
    NOTIFYDATE = new$NOTIFYDATE,
    EXECUTERACCREF = new$EXECUTERACCREF,
    DOCBASEDATE = new$DOCBASEDATE,
    DOCBASENOTIFYDATE = new$DOCBASENOTIFYDATE,
    DOCBASETEXT = new$DOCBASETEXT,
    DOCBASETYPE = new$DOCBASETYPE,
    DOCBASESUMMA = new$DOCBASESUMMA,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PROTOCOLREASON = new$PROTOCOLREASON,
    DOCNUMBER = new$DOCNUMBER,
    ADJUSTMENTDOCNUMBER = new$ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER = new$OLDDOCNUMBER,
    LOTMAXSUM = new$LOTMAXSUM,
    CLIENT_INN = new$CLIENT_INN,
    CLIENT_INN20 = new$CLIENT_INN20,
    CLIENT_NAME = new$CLIENT_NAME,
    EXECUTER_INN = new$EXECUTER_INN,
    EXECUTER_INN20 = new$EXECUTER_INN20,
    EXECUTER_NAME = new$EXECUTER_NAME,
    EXECUTER_STATUS = new$EXECUTER_STATUS,
    EXECUTER_COUNTRY = new$EXECUTER_COUNTRY,
    EXECUTER_ADDRESS = new$EXECUTER_ADDRESS,
    EXECUTER_PHONE = new$EXECUTER_PHONE,
    REALID = new$REALID,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    INNERNUMBER = new$INNERNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REESTRVERSION = new$REESTRVERSION,
    DOCTYPE = new$DOCTYPE,
    RNCLIENTID = new$RNCLIENTID,
    INFONUMBER = new$INFONUMBER,
    STATEORDERINNERNUMBER = new$STATEORDERINNERNUMBER,
    PROGINDEX = new$PROGINDEX,
    NOTE = new$NOTE,
    PURPORTDOC = new$PURPORTDOC,
    REESTRRECORDNUMBER = new$REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS = new$EXECUTERSTOREDPROPS,
    AUTOSANCTION = new$AUTOSANCTION,
    PURCHASECODE = new$PURCHASECODE,
    DOCUMENTNUMBER = new$DOCUMENTNUMBER,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_AGREEMENTS_AU_10)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   6.0*/
  /*      */
  /*     ,       */
  if ((new$AdjustmentNumber > 0) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update Agreements set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentNumber > 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update Agreements set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*          */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 304)or(new$ProgIndex = 314)))then
    update Estimate
    set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    (RecordIndex = new$Id);
  END IF;
  /*         */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 305) or (new$ProgIndex = 314))) then
    update paymentschedule set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    AgreementRef = new$ID and
    ProgIndex in (317, 318);

  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_AGREEMENTS_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*      */
  if ((new$ProgIndex = 305) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null
    where
    StateOrder = :old.ID;
  END IF;
  /*      */
  if ((new$ProgIndex = 314) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null,
    Agreement = null
    where
    StateOrder = :old.ID;
  END IF;
  /*     */
  if ((:old.ProgIndex = 304) and (new$AdjustmentNumber = 0) and (new$Accepted = 0) and
  (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    Agreement = null
    where
    Agreement = :old.ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_AGREEMENTS_AU_30)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$ProgIndex = 304) or (new$ProgIndex = 314)) and
  ((new$Accepted <> :old.Accepted) or
  (new$AcceptDate is not null and :old.AcceptDate is null) or
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where AgreementRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_AGREEMENTS_AU_500)
-- Create 28.04.2005
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes
                  (TableID, RecordId, DeleteDate
                  )
           VALUES (110, :OLD.ID, SYSDATE
                  );

      DELETE FROM DelRecIndexes
            WHERE (TableID = 110) AND (RecordId = new$ID);
   END IF;

END;
/
ALTER TABLE TB_AGREEMENTS ADD (
  REJECTCAUSE VARCHAR2(1000)
)
/

CREATE OR REPLACE VIEW AGREEMENTS (
  ID,
  SUMMA,
  AGREEMENTDATE,
  AGREEMENTENDDATE,
  EXECUTER_REF,
  CLIENT_REF,
  FACIALACC_CLS,
  AGREEMENTTYPE,
  ACCEPTED,
  ACCEPTDATE,
  CARDADVANCEPERCENT,
  CARDADVANCE,
  CLOSEDOC,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  BUDGETREF,
  LASTADJUSTMENT,
  LASTACCEPTED,
  FACT,
  REGION,
  CLOSEDATE,
  DELIVERYRULES,
  AGREEMENTSUMMA,
  AGREEMENTFINSUMMA,
  ADJUSTMENTREF,
  REESTRNUMBER,
  PAYMENTDATE,
  AGREEMENTCARDADVANCE,
  FINCARDADVANCE,
  STATEORDERREF,
  REJECTCLS,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  AGREEMENTBEGINDATE,
  PROTOCOLNUMBER,
  PROTOCOLDATE,
  REVIEWNOTE,
  DOCSTATEREF,
  RVERSION,
  EXPORTDATE,
  FSORGAN,
  FSBUDGETNAME,
  FSOFFBUDGET,
  RNYEAR,
  RNNUMBER,
  RNDATE,
  PROTOCOLNOTICE,
  PROTOCOLRESULTDATE,
  PROTOCOLDOCTYPE,
  PROTOCOLSALETYPE,
  NOTIFYDATE,
  EXECUTERACCREF,
  DOCBASEDATE,
  DOCBASENOTIFYDATE,
  DOCBASETEXT,
  DOCBASETYPE,
  DOCBASESUMMA,
  UNKNOWNAMOUNT,
  PROTOCOLREASON,
  DOCNUMBER,
  ADJUSTMENTDOCNUMBER,
  OLDDOCNUMBER,
  LOTMAXSUM,
  CLIENT_INN,
  CLIENT_INN20,
  CLIENT_NAME,
  EXECUTER_INN,
  EXECUTER_INN20,
  EXECUTER_NAME,
  EXECUTER_STATUS,
  EXECUTER_COUNTRY,
  EXECUTER_ADDRESS,
  EXECUTER_PHONE,
  REALID,
  ADJUSTMENTNUMBER,
  INNERNUMBER,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  REESTRVERSION,
  DOCTYPE,
  RNCLIENTID,
  INFONUMBER,
  STATEORDERINNERNUMBER,
  PROGINDEX,
  NOTE,
  PURPORTDOC,
  REESTRRECORDNUMBER,
  EXECUTERSTOREDPROPS,
  AUTOSANCTION,
  PURCHASECODE,
  DOCUMENTNUMBER,
  TEMPREJECTCAUSE,
  REJECTCAUSE)
AS
  SELECT
    ID,
    SUMMA,
    AGREEMENTDATE,
    AGREEMENTENDDATE,
    EXECUTER_REF,
    CLIENT_REF,
    FACIALACC_CLS,
    AGREEMENTTYPE,
    ACCEPTED,
    ACCEPTDATE,
    CARDADVANCEPERCENT,
    CARDADVANCE,
    CLOSEDOC,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    LASTADJUSTMENT,
    LASTACCEPTED,
    FACT,
    REGION,
    CLOSEDATE,
    DELIVERYRULES,
    AGREEMENTSUMMA,
    AGREEMENTFINSUMMA,
    ADJUSTMENTREF,
    REESTRNUMBER,
    PAYMENTDATE,
    AGREEMENTCARDADVANCE,
    FINCARDADVANCE,
    STATEORDERREF,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    AGREEMENTBEGINDATE,
    PROTOCOLNUMBER,
    PROTOCOLDATE,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXPORTDATE,
    FSORGAN,
    FSBUDGETNAME,
    FSOFFBUDGET,
    RNYEAR,
    RNNUMBER,
    RNDATE,
    PROTOCOLNOTICE,
    PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE,
    NOTIFYDATE,
    EXECUTERACCREF,
    DOCBASEDATE,
    DOCBASENOTIFYDATE,
    DOCBASETEXT,
    DOCBASETYPE,
    DOCBASESUMMA,
    UNKNOWNAMOUNT,
    PROTOCOLREASON,
    DOCNUMBER,
    ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER,
    LOTMAXSUM,
    CLIENT_INN,
    CLIENT_INN20,
    CLIENT_NAME,
    EXECUTER_INN,
    EXECUTER_INN20,
    EXECUTER_NAME,
    EXECUTER_STATUS,
    EXECUTER_COUNTRY,
    EXECUTER_ADDRESS,
    EXECUTER_PHONE,
    REALID,
    ADJUSTMENTNUMBER,
    INNERNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REESTRVERSION,
    DOCTYPE,
    RNCLIENTID,
    INFONUMBER,
    STATEORDERINNERNUMBER,
    PROGINDEX,
    NOTE,
    PURPORTDOC,
    REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS,
    AUTOSANCTION,
    PURCHASECODE,
    DOCUMENTNUMBER,
    TEMPREJECTCAUSE,
    REJECTCAUSE
  FROM TB_AGREEMENTS
/

CREATE OR REPLACE TRIGGER TR_AGREEMENTS_ID
  INSTEAD OF DELETE
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  cnt1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_AGREEMENTS_BD)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*   5.0*/
  select count(id) into cnt1$ from agreements where (adjustmentref = :old.id) ;
  /*  .       .*/
  if (cnt1$ = 0) then
    delete from estimate where (recordindex = :old.id);
    delete from agreementsteps where (recordindex = :old.id);
    delete from paymentschedule where agreementref = :old.id;

  else
    RaiseException('ex_agr_cantdeladjustmented');
  END IF;

-- - - - - - - - - - - - -
-- BD_20 (TR_AGREEMENTS_BD_20)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  /*          */
  if ((:old.ProgIndex = 305)and(:old.AdjustmentNumber = 0)) then
    update tenderresultcaption set
    StateOrder = null
    where
    StateOrder = :old.ID;
  END IF;
  if ((:old.ProgIndex = 314)and(:old.AdjustmentNumber = 0)) then
    update tenderresultcaption set
    StateOrder = null,
    Agreement = null
    where
    StateOrder = :old.ID;
  END IF;
  if ((:old.ProgIndex = 304)and(:old.AdjustmentNumber = 0)) then
    update tenderresultcaption set
    Agreement = null
    where
    Agreement = :old.ID;
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_AGREEMENTS
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_10 (TR_AGREEMENTS_AD_10)
-- Last update 05.02.2010
-- - - - - - - - - - - - -

/*   5.0*/
    /*   LastAdjustment     */
    if ((:old.AdjustmentNumber > 0) and (:old.LastAdjustment = 1)) then
        update Agreements set
            LastAdjustment = 1,
            RVersion = -1
        where (ID = :old.AdjustmentRef);
    end if;
    /*   LastAccepted     */
    if ((:old.AdjustmentNumber > 0) and (:old.LastAccepted = 1)) then
        update Agreements set
            LastAccepted = 1,
            RVersion = -1
        where (ID = :old.AdjustmentRef);
    end if;

-- - - - - - - - - - - - -
-- AD_200 (TR_AGREEMENTS_AD_200)
-- Create 04.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

  /*        */
  delete from StateJumpHistory where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_AGREEMENTS_AD_500)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordId, DeleteDate, Summa, ProgIndex)
  values (110, :old.ID, SYSDATE, :old.AgreementSumma, :old.ProgIndex);

END;
/

CREATE OR REPLACE TRIGGER TR_AGREEMENTS_II
  INSTEAD OF INSERT
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  new$ID AGREEMENTS.ID%TYPE := :NEW.ID;
  new$SUMMA AGREEMENTS.SUMMA%TYPE := :NEW.SUMMA;
  new$AGREEMENTDATE AGREEMENTS.AGREEMENTDATE%TYPE := :NEW.AGREEMENTDATE;
  new$AGREEMENTENDDATE AGREEMENTS.AGREEMENTENDDATE%TYPE := :NEW.AGREEMENTENDDATE;
  new$EXECUTER_REF AGREEMENTS.EXECUTER_REF%TYPE := :NEW.EXECUTER_REF;
  new$CLIENT_REF AGREEMENTS.CLIENT_REF%TYPE := :NEW.CLIENT_REF;
  new$FACIALACC_CLS AGREEMENTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$AGREEMENTTYPE AGREEMENTS.AGREEMENTTYPE%TYPE := :NEW.AGREEMENTTYPE;
  new$ACCEPTED AGREEMENTS.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$ACCEPTDATE AGREEMENTS.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$CARDADVANCEPERCENT AGREEMENTS.CARDADVANCEPERCENT%TYPE := :NEW.CARDADVANCEPERCENT;
  new$CARDADVANCE AGREEMENTS.CARDADVANCE%TYPE := :NEW.CARDADVANCE;
  new$CLOSEDOC AGREEMENTS.CLOSEDOC%TYPE := :NEW.CLOSEDOC;
  new$CREATERUSER AGREEMENTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE AGREEMENTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE AGREEMENTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER AGREEMENTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF AGREEMENTS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$LASTADJUSTMENT AGREEMENTS.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED AGREEMENTS.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$FACT AGREEMENTS.FACT%TYPE := :NEW.FACT;
  new$REGION AGREEMENTS.REGION%TYPE := :NEW.REGION;
  new$CLOSEDATE AGREEMENTS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$DELIVERYRULES AGREEMENTS.DELIVERYRULES%TYPE := :NEW.DELIVERYRULES;
  new$AGREEMENTSUMMA AGREEMENTS.AGREEMENTSUMMA%TYPE := :NEW.AGREEMENTSUMMA;
  new$AGREEMENTFINSUMMA AGREEMENTS.AGREEMENTFINSUMMA%TYPE := :NEW.AGREEMENTFINSUMMA;
  new$ADJUSTMENTREF AGREEMENTS.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$REESTRNUMBER AGREEMENTS.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$PAYMENTDATE AGREEMENTS.PAYMENTDATE%TYPE := :NEW.PAYMENTDATE;
  new$AGREEMENTCARDADVANCE AGREEMENTS.AGREEMENTCARDADVANCE%TYPE := :NEW.AGREEMENTCARDADVANCE;
  new$FINCARDADVANCE AGREEMENTS.FINCARDADVANCE%TYPE := :NEW.FINCARDADVANCE;
  new$STATEORDERREF AGREEMENTS.STATEORDERREF%TYPE := :NEW.STATEORDERREF;
  new$REJECTCLS AGREEMENTS.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS AGREEMENTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID AGREEMENTS.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID AGREEMENTS.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$AGREEMENTBEGINDATE AGREEMENTS.AGREEMENTBEGINDATE%TYPE := :NEW.AGREEMENTBEGINDATE;
  new$PROTOCOLNUMBER AGREEMENTS.PROTOCOLNUMBER%TYPE := :NEW.PROTOCOLNUMBER;
  new$PROTOCOLDATE AGREEMENTS.PROTOCOLDATE%TYPE := :NEW.PROTOCOLDATE;
  new$REVIEWNOTE AGREEMENTS.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF AGREEMENTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION AGREEMENTS.RVERSION%TYPE := :NEW.RVERSION;
  new$EXPORTDATE AGREEMENTS.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$FSORGAN AGREEMENTS.FSORGAN%TYPE := :NEW.FSORGAN;
  new$FSBUDGETNAME AGREEMENTS.FSBUDGETNAME%TYPE := :NEW.FSBUDGETNAME;
  new$FSOFFBUDGET AGREEMENTS.FSOFFBUDGET%TYPE := :NEW.FSOFFBUDGET;
  new$RNYEAR AGREEMENTS.RNYEAR%TYPE := :NEW.RNYEAR;
  new$RNNUMBER AGREEMENTS.RNNUMBER%TYPE := :NEW.RNNUMBER;
  new$RNDATE AGREEMENTS.RNDATE%TYPE := :NEW.RNDATE;
  new$PROTOCOLNOTICE AGREEMENTS.PROTOCOLNOTICE%TYPE := :NEW.PROTOCOLNOTICE;
  new$PROTOCOLRESULTDATE AGREEMENTS.PROTOCOLRESULTDATE%TYPE := :NEW.PROTOCOLRESULTDATE;
  new$PROTOCOLDOCTYPE AGREEMENTS.PROTOCOLDOCTYPE%TYPE := :NEW.PROTOCOLDOCTYPE;
  new$PROTOCOLSALETYPE AGREEMENTS.PROTOCOLSALETYPE%TYPE := :NEW.PROTOCOLSALETYPE;
  new$NOTIFYDATE AGREEMENTS.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$EXECUTERACCREF AGREEMENTS.EXECUTERACCREF%TYPE := :NEW.EXECUTERACCREF;
  new$DOCBASEDATE AGREEMENTS.DOCBASEDATE%TYPE := :NEW.DOCBASEDATE;
  new$DOCBASENOTIFYDATE AGREEMENTS.DOCBASENOTIFYDATE%TYPE := :NEW.DOCBASENOTIFYDATE;
  new$DOCBASETEXT AGREEMENTS.DOCBASETEXT%TYPE := :NEW.DOCBASETEXT;
  new$DOCBASETYPE AGREEMENTS.DOCBASETYPE%TYPE := :NEW.DOCBASETYPE;
  new$DOCBASESUMMA AGREEMENTS.DOCBASESUMMA%TYPE := :NEW.DOCBASESUMMA;
  new$UNKNOWNAMOUNT AGREEMENTS.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PROTOCOLREASON AGREEMENTS.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$DOCNUMBER AGREEMENTS.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$ADJUSTMENTDOCNUMBER AGREEMENTS.ADJUSTMENTDOCNUMBER%TYPE := :NEW.ADJUSTMENTDOCNUMBER;
  new$OLDDOCNUMBER AGREEMENTS.OLDDOCNUMBER%TYPE := :NEW.OLDDOCNUMBER;
  new$LOTMAXSUM AGREEMENTS.LOTMAXSUM%TYPE := :NEW.LOTMAXSUM;
  new$CLIENT_INN AGREEMENTS.CLIENT_INN%TYPE := :NEW.CLIENT_INN;
  new$CLIENT_INN20 AGREEMENTS.CLIENT_INN20%TYPE := :NEW.CLIENT_INN20;
  new$CLIENT_NAME AGREEMENTS.CLIENT_NAME%TYPE := :NEW.CLIENT_NAME;
  new$EXECUTER_INN AGREEMENTS.EXECUTER_INN%TYPE := :NEW.EXECUTER_INN;
  new$EXECUTER_INN20 AGREEMENTS.EXECUTER_INN20%TYPE := :NEW.EXECUTER_INN20;
  new$EXECUTER_NAME AGREEMENTS.EXECUTER_NAME%TYPE := :NEW.EXECUTER_NAME;
  new$EXECUTER_STATUS AGREEMENTS.EXECUTER_STATUS%TYPE := :NEW.EXECUTER_STATUS;
  new$EXECUTER_COUNTRY AGREEMENTS.EXECUTER_COUNTRY%TYPE := :NEW.EXECUTER_COUNTRY;
  new$EXECUTER_ADDRESS AGREEMENTS.EXECUTER_ADDRESS%TYPE := :NEW.EXECUTER_ADDRESS;
  new$EXECUTER_PHONE AGREEMENTS.EXECUTER_PHONE%TYPE := :NEW.EXECUTER_PHONE;
  new$REALID AGREEMENTS.REALID%TYPE := :NEW.REALID;
  new$ADJUSTMENTNUMBER AGREEMENTS.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$INNERNUMBER AGREEMENTS.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$SENDERIDKEY AGREEMENTS.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY AGREEMENTS.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REESTRVERSION AGREEMENTS.REESTRVERSION%TYPE := :NEW.REESTRVERSION;
  new$DOCTYPE AGREEMENTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$RNCLIENTID AGREEMENTS.RNCLIENTID%TYPE := :NEW.RNCLIENTID;
  new$INFONUMBER AGREEMENTS.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$STATEORDERINNERNUMBER AGREEMENTS.STATEORDERINNERNUMBER%TYPE := :NEW.STATEORDERINNERNUMBER;
  new$PROGINDEX AGREEMENTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE AGREEMENTS.NOTE%TYPE := :NEW.NOTE;
  new$PURPORTDOC AGREEMENTS.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$REESTRRECORDNUMBER AGREEMENTS.REESTRRECORDNUMBER%TYPE := :NEW.REESTRRECORDNUMBER;
  new$EXECUTERSTOREDPROPS AGREEMENTS.EXECUTERSTOREDPROPS%TYPE := :NEW.EXECUTERSTOREDPROPS;
  new$AUTOSANCTION AGREEMENTS.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$PURCHASECODE AGREEMENTS.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$DOCUMENTNUMBER AGREEMENTS.DOCUMENTNUMBER%TYPE := :NEW.DOCUMENTNUMBER;
  new$TEMPREJECTCAUSE AGREEMENTS.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
  new$REJECTCAUSE AGREEMENTS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  CurVal$ NUMBER (10);
  CountAcc$ NUMBER(10);
  rnClientID1$ VARCHAR2(15);
  rnYear1$ VARCHAR2(15);
  rnNumber1$ VARCHAR2(15);
  ReestrVersion1$ VARCHAR2(15);
  Tmp$ NUMBER(10);
  AdjID$ NUMBER(10);
  AdjDocNum$ VARCHAR2(150);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_AGREEMENTS_BI)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   3.1.2*/
  /*    -*/
  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$CardAdvancePercent is null) then
    new$CardAdvancePercent := 0;
  END IF;
  if (new$CardAdvance is null) then
    new$CardAdvance := 0;
  END IF;
  if (new$AgreementCardAdvance is null) then
    new$AgreementCardAdvance := 0;
  END IF;
  if (new$FinCardAdvance is null) then
    new$FinCardAdvance := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$AgreementSumma is null) then
    new$AgreementSumma := 0;
  END IF;
  if (new$AgreementFinSumma is null) then
    new$AgreementFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$Region is null) then
    new$Region := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  if (new$client_ref is null) then
    new$client_ref := 0;
  END IF;

  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    BEGIN
      select fa.BudgetRef     into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;

  /*    
         -   InnerNumber*/
  if (((new$ProgIndex = 305) or (new$ProgIndex = 304) or (new$ProgIndex = 314)) and (new$InnerNumber is null)) then
    new$InnerNumber := GEN_ID('G_AgreementNumber',1);
  END IF;
  /*   */
  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  /*    .  */

  new$stateorderinnernumber := null;
  if (new$stateorderref is not null) then
    BEGIN
      select
      innernumber
      into new$stateorderinnernumber     from agreements
      where
      id = new$stateorderref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_AGREEMENTS_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_AGREEMENTS_BI_10)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  /*   5.0*/

  /*    .*/
  if (new$InnerNumber is null) then
    RaiseException('EX_AGR_InnerNumsIsNull');
  END IF;

  /*    */
  select max(AdjustmentNumber)
  into Tmp$         from Agreements
  where (InnerNumber = new$InnerNumber)
  ;
  /*      ,   0*/
  if (Tmp$ is null) then
    new$AdjustmentNumber := 0;

  else
    new$AdjustmentNumber := Tmp$ + 1;
  END IF;
  /*        */
  if (((new$AgreementType = 0) and (new$AdjustmentNumber > 0)) or
  ((new$AgreementType = 1) and (new$AdjustmentNumber = 0))) then
    RaiseException('EX_AGR_AgrTypeViolation');
  END IF;
  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;

  else
    new$LastAdjustment := 1;
  END IF;
  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then
    new$LastAccepted := 1;

  else
    new$LastAccepted := 0;
  END IF;
  /*    */
  if (new$AdjustmentNumber > 0) then
    /*      -    */
    select count(ID), max(ID), max(DocNumber)
    into Tmp$, AdjID$, AdjDocNum$             from Agreements
    where (InnerNumber = new$InnerNumber) and (LastAccepted = 1)
    ;
    /*   ,  */
    if (Tmp$ <> 1) then
      RaiseException('EX_AGR_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID)
    into Tmp$             from Agreements
    where (InnerNumber = new$InnerNumber) and (AcceptDate is null)
    ;
    if (Tmp$ > 0) then
      RaiseException('EX_AGR_AdjustDuplicate');
    END IF;
    /* ,    ,    */
    new$AdjustmentRef := AdjID$;
    new$AdjustmentDocNumber := AdjDocNum$;

  else /*     */
    /*       (    )*/
    new$AdjustmentRef := null;
    new$AdjustmentDocNumber := null;

  END IF;

-- - - - - - - - - - - - -
-- BI_20 (TR_AGREEMENTS_BI_20)
-- Create 21.05.2009
-- - - - - - - - - - - - -

  /*    -,     */
  if ((new$Client_INN   is null) and
      (new$Client_INN20 is null) and
      (new$Client_Name  is null))then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name
      into
        new$Client_INN,
        new$Client_INN20,
        new$Client_Name
      from Organizations o
      where o.Id=new$Client_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Client_INN := NULL;
        new$Client_INN20 := NULL;
        new$Client_Name := NULL;
    END;
  END IF;

  /*    -,     */
  if ((new$Executer_INN     is null) and
      (new$Executer_INN20   is null) and
      (new$Executer_Name    is null) and
      (new$Executer_Status  is null) and
      (new$Executer_Country is null) and
      (new$Executer_Address is null) and
      (new$Executer_Phone   is null))then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name,
        o.SupplierStatus,
        o.Country,
        o.Address,
        o.Phone
      into
        new$Executer_INN,
        new$Executer_INN20,
        new$Executer_Name,
        new$Executer_Status,
        new$Executer_Country,
        new$Executer_Address,
        new$Executer_Phone
      from Organizations o
      where o.Id=new$Executer_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Executer_INN := NULL;
        new$Executer_INN20 := NULL;
        new$Executer_Name := NULL;
        new$Executer_Status := NULL;
        new$Executer_Country := NULL;
        new$Executer_Address := NULL;
        new$Executer_Phone := NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_40 (TR_AGREEMENTS_BI_40)
-- Create 06.08.2010
-- - - - - - - - - - - - -

  /*       */
  if (new$senderId is null) then
    new$senderIdKey := -1;
  else
    new$senderIdKey := new$senderId;
  end if;

  if (new$SenderRecordID is null)then
    new$SenderRecordIDKey := new$ID;
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  end if;

-- - - - - - - - - - - - -
-- BI_50 (TR_AGREEMENTS_BI_50)
-- Create 06.08.2010
-- - - - - - - - - - - - -

    if (new$InnerNumber is not null) then
        CurVal$ := gen_id('G_AgreementNumber', 0);
        if (CurVal$ < new$InnerNumber) then
          CurVal$ := gen_id('G_AgreementNumber', new$InnerNumber - CurVal$);
        end if;
    end if;

-- - - - - - - - - - - - -
-- BI_300 (tr_agreements_bi_300)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$ExecuterAccRef is not null) then
    select count(ID)
    into CountAcc$     from org_accounts oa
    where oa.id = new$ExecuterAccRef and oa.Org_ref = new$Executer_Ref
    ;
    if (CountAcc$ = 0) then
      RaiseException('EX_AGR_ACCORGCHECK');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_400 (TR_AGREEMENTS_BI_400)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if ((new$rnClientID is not null) and (new$rnYear is not null) and (new$rnNumber is not null)) then

    rnClientID1$ := new$rnClientID;
    rnYear1$ := new$rnYear;
    rnNumber1$ := new$rnNumber;
    ReestrVersion1$ := new$ReestrVersion;
    while (LENGTH(rnClientID1$) < 11) LOOP
      rnClientID1$ := '0' || rnClientID1$;
    END LOOP;
    while (LENGTH(rnNumber1$) < 6) LOOP
      rnNumber1$ := '0' || rnNumber1$;
    END LOOP;
    if (LENGTH(ReestrVersion1$) < 2) then
      ReestrVersion1$ := '0' || ReestrVersion1$;
    END IF;
    /*  ReestrRecordNumber*/
    if (new$ReestrVersion is null) then
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$;

    else
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$ || ReestrVersion1$;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_AGREEMENTS_BI_500)
-- Last update 19.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- BI_600 (agreements_realid_bi_600)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_AGREEMENTS (
    ID,
    SUMMA,
    AGREEMENTDATE,
    AGREEMENTENDDATE,
    EXECUTER_REF,
    CLIENT_REF,
    FACIALACC_CLS,
    AGREEMENTTYPE,
    ACCEPTED,
    ACCEPTDATE,
    CARDADVANCEPERCENT,
    CARDADVANCE,
    CLOSEDOC,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    LASTADJUSTMENT,
    LASTACCEPTED,
    FACT,
    REGION,
    CLOSEDATE,
    DELIVERYRULES,
    AGREEMENTSUMMA,
    AGREEMENTFINSUMMA,
    ADJUSTMENTREF,
    REESTRNUMBER,
    PAYMENTDATE,
    AGREEMENTCARDADVANCE,
    FINCARDADVANCE,
    STATEORDERREF,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    AGREEMENTBEGINDATE,
    PROTOCOLNUMBER,
    PROTOCOLDATE,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXPORTDATE,
    FSORGAN,
    FSBUDGETNAME,
    FSOFFBUDGET,
    RNYEAR,
    RNNUMBER,
    RNDATE,
    PROTOCOLNOTICE,
    PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE,
    NOTIFYDATE,
    EXECUTERACCREF,
    DOCBASEDATE,
    DOCBASENOTIFYDATE,
    DOCBASETEXT,
    DOCBASETYPE,
    DOCBASESUMMA,
    UNKNOWNAMOUNT,
    PROTOCOLREASON,
    DOCNUMBER,
    ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER,
    LOTMAXSUM,
    CLIENT_INN,
    CLIENT_INN20,
    CLIENT_NAME,
    EXECUTER_INN,
    EXECUTER_INN20,
    EXECUTER_NAME,
    EXECUTER_STATUS,
    EXECUTER_COUNTRY,
    EXECUTER_ADDRESS,
    EXECUTER_PHONE,
    REALID,
    ADJUSTMENTNUMBER,
    INNERNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REESTRVERSION,
    DOCTYPE,
    RNCLIENTID,
    INFONUMBER,
    STATEORDERINNERNUMBER,
    PROGINDEX,
    NOTE,
    PURPORTDOC,
    REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS,
    AUTOSANCTION,
    PURCHASECODE,
    DOCUMENTNUMBER,
    TEMPREJECTCAUSE,
    REJECTCAUSE
  ) VALUES (
    new$ID,
    new$SUMMA,
    new$AGREEMENTDATE,
    new$AGREEMENTENDDATE,
    new$EXECUTER_REF,
    new$CLIENT_REF,
    new$FACIALACC_CLS,
    new$AGREEMENTTYPE,
    new$ACCEPTED,
    new$ACCEPTDATE,
    new$CARDADVANCEPERCENT,
    new$CARDADVANCE,
    new$CLOSEDOC,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$LASTADJUSTMENT,
    new$LASTACCEPTED,
    new$FACT,
    new$REGION,
    new$CLOSEDATE,
    new$DELIVERYRULES,
    new$AGREEMENTSUMMA,
    new$AGREEMENTFINSUMMA,
    new$ADJUSTMENTREF,
    new$REESTRNUMBER,
    new$PAYMENTDATE,
    new$AGREEMENTCARDADVANCE,
    new$FINCARDADVANCE,
    new$STATEORDERREF,
    new$REJECTCLS,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$AGREEMENTBEGINDATE,
    new$PROTOCOLNUMBER,
    new$PROTOCOLDATE,
    new$REVIEWNOTE,
    new$DOCSTATEREF,
    new$RVERSION,
    new$EXPORTDATE,
    new$FSORGAN,
    new$FSBUDGETNAME,
    new$FSOFFBUDGET,
    new$RNYEAR,
    new$RNNUMBER,
    new$RNDATE,
    new$PROTOCOLNOTICE,
    new$PROTOCOLRESULTDATE,
    new$PROTOCOLDOCTYPE,
    new$PROTOCOLSALETYPE,
    new$NOTIFYDATE,
    new$EXECUTERACCREF,
    new$DOCBASEDATE,
    new$DOCBASENOTIFYDATE,
    new$DOCBASETEXT,
    new$DOCBASETYPE,
    new$DOCBASESUMMA,
    new$UNKNOWNAMOUNT,
    new$PROTOCOLREASON,
    new$DOCNUMBER,
    new$ADJUSTMENTDOCNUMBER,
    new$OLDDOCNUMBER,
    new$LOTMAXSUM,
    new$CLIENT_INN,
    new$CLIENT_INN20,
    new$CLIENT_NAME,
    new$EXECUTER_INN,
    new$EXECUTER_INN20,
    new$EXECUTER_NAME,
    new$EXECUTER_STATUS,
    new$EXECUTER_COUNTRY,
    new$EXECUTER_ADDRESS,
    new$EXECUTER_PHONE,
    new$REALID,
    new$ADJUSTMENTNUMBER,
    new$INNERNUMBER,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$REESTRVERSION,
    new$DOCTYPE,
    new$RNCLIENTID,
    new$INFONUMBER,
    new$STATEORDERINNERNUMBER,
    new$PROGINDEX,
    new$NOTE,
    new$PURPORTDOC,
    new$REESTRRECORDNUMBER,
    new$EXECUTERSTOREDPROPS,
    new$AUTOSANCTION,
    new$PURCHASECODE,
    new$DOCUMENTNUMBER,
    new$TEMPREJECTCAUSE,
    new$REJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_10 (TR_AGREEMENTS_AI_10)
-- Last update 05.02.2010
-- - - - - - - - - - - - -

/*   5.0*/
    if ((new$AdjustmentNumber > 0) and (new$LastAdjustment = 1)) then
        update Agreements set
            LastAdjustment = 0,
            RVersion = -1
        where (ID = new$AdjustmentRef);
        if (new$LastAccepted = 1) then
            update Agreements set
                LastAccepted = 0,
                RVersion = -1
            where (ID = new$AdjustmentRef);
        end if;
    end if;

-- - - - - - - - - - - - -
-- AI_500 (TR_AGREEMENTS_AI_500)
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 110) AND (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_AGREEMENTS_IU
  INSTEAD OF UPDATE
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  new$ID AGREEMENTS.ID%TYPE := :NEW.ID;
  new$SUMMA AGREEMENTS.SUMMA%TYPE := :NEW.SUMMA;
  new$AGREEMENTDATE AGREEMENTS.AGREEMENTDATE%TYPE := :NEW.AGREEMENTDATE;
  new$AGREEMENTENDDATE AGREEMENTS.AGREEMENTENDDATE%TYPE := :NEW.AGREEMENTENDDATE;
  new$EXECUTER_REF AGREEMENTS.EXECUTER_REF%TYPE := :NEW.EXECUTER_REF;
  new$CLIENT_REF AGREEMENTS.CLIENT_REF%TYPE := :NEW.CLIENT_REF;
  new$FACIALACC_CLS AGREEMENTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$AGREEMENTTYPE AGREEMENTS.AGREEMENTTYPE%TYPE := :NEW.AGREEMENTTYPE;
  new$ACCEPTED AGREEMENTS.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$ACCEPTDATE AGREEMENTS.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$CARDADVANCEPERCENT AGREEMENTS.CARDADVANCEPERCENT%TYPE := :NEW.CARDADVANCEPERCENT;
  new$CARDADVANCE AGREEMENTS.CARDADVANCE%TYPE := :NEW.CARDADVANCE;
  new$CLOSEDOC AGREEMENTS.CLOSEDOC%TYPE := :NEW.CLOSEDOC;
  new$CREATERUSER AGREEMENTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE AGREEMENTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE AGREEMENTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER AGREEMENTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF AGREEMENTS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$LASTADJUSTMENT AGREEMENTS.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED AGREEMENTS.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$FACT AGREEMENTS.FACT%TYPE := :NEW.FACT;
  new$REGION AGREEMENTS.REGION%TYPE := :NEW.REGION;
  new$CLOSEDATE AGREEMENTS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$DELIVERYRULES AGREEMENTS.DELIVERYRULES%TYPE := :NEW.DELIVERYRULES;
  new$AGREEMENTSUMMA AGREEMENTS.AGREEMENTSUMMA%TYPE := :NEW.AGREEMENTSUMMA;
  new$AGREEMENTFINSUMMA AGREEMENTS.AGREEMENTFINSUMMA%TYPE := :NEW.AGREEMENTFINSUMMA;
  new$ADJUSTMENTREF AGREEMENTS.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$REESTRNUMBER AGREEMENTS.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$PAYMENTDATE AGREEMENTS.PAYMENTDATE%TYPE := :NEW.PAYMENTDATE;
  new$AGREEMENTCARDADVANCE AGREEMENTS.AGREEMENTCARDADVANCE%TYPE := :NEW.AGREEMENTCARDADVANCE;
  new$FINCARDADVANCE AGREEMENTS.FINCARDADVANCE%TYPE := :NEW.FINCARDADVANCE;
  new$STATEORDERREF AGREEMENTS.STATEORDERREF%TYPE := :NEW.STATEORDERREF;
  new$REJECTCLS AGREEMENTS.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS AGREEMENTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID AGREEMENTS.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID AGREEMENTS.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$AGREEMENTBEGINDATE AGREEMENTS.AGREEMENTBEGINDATE%TYPE := :NEW.AGREEMENTBEGINDATE;
  new$PROTOCOLNUMBER AGREEMENTS.PROTOCOLNUMBER%TYPE := :NEW.PROTOCOLNUMBER;
  new$PROTOCOLDATE AGREEMENTS.PROTOCOLDATE%TYPE := :NEW.PROTOCOLDATE;
  new$REVIEWNOTE AGREEMENTS.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF AGREEMENTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION AGREEMENTS.RVERSION%TYPE := :NEW.RVERSION;
  new$EXPORTDATE AGREEMENTS.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$FSORGAN AGREEMENTS.FSORGAN%TYPE := :NEW.FSORGAN;
  new$FSBUDGETNAME AGREEMENTS.FSBUDGETNAME%TYPE := :NEW.FSBUDGETNAME;
  new$FSOFFBUDGET AGREEMENTS.FSOFFBUDGET%TYPE := :NEW.FSOFFBUDGET;
  new$RNYEAR AGREEMENTS.RNYEAR%TYPE := :NEW.RNYEAR;
  new$RNNUMBER AGREEMENTS.RNNUMBER%TYPE := :NEW.RNNUMBER;
  new$RNDATE AGREEMENTS.RNDATE%TYPE := :NEW.RNDATE;
  new$PROTOCOLNOTICE AGREEMENTS.PROTOCOLNOTICE%TYPE := :NEW.PROTOCOLNOTICE;
  new$PROTOCOLRESULTDATE AGREEMENTS.PROTOCOLRESULTDATE%TYPE := :NEW.PROTOCOLRESULTDATE;
  new$PROTOCOLDOCTYPE AGREEMENTS.PROTOCOLDOCTYPE%TYPE := :NEW.PROTOCOLDOCTYPE;
  new$PROTOCOLSALETYPE AGREEMENTS.PROTOCOLSALETYPE%TYPE := :NEW.PROTOCOLSALETYPE;
  new$NOTIFYDATE AGREEMENTS.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$EXECUTERACCREF AGREEMENTS.EXECUTERACCREF%TYPE := :NEW.EXECUTERACCREF;
  new$DOCBASEDATE AGREEMENTS.DOCBASEDATE%TYPE := :NEW.DOCBASEDATE;
  new$DOCBASENOTIFYDATE AGREEMENTS.DOCBASENOTIFYDATE%TYPE := :NEW.DOCBASENOTIFYDATE;
  new$DOCBASETEXT AGREEMENTS.DOCBASETEXT%TYPE := :NEW.DOCBASETEXT;
  new$DOCBASETYPE AGREEMENTS.DOCBASETYPE%TYPE := :NEW.DOCBASETYPE;
  new$DOCBASESUMMA AGREEMENTS.DOCBASESUMMA%TYPE := :NEW.DOCBASESUMMA;
  new$UNKNOWNAMOUNT AGREEMENTS.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PROTOCOLREASON AGREEMENTS.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$DOCNUMBER AGREEMENTS.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$ADJUSTMENTDOCNUMBER AGREEMENTS.ADJUSTMENTDOCNUMBER%TYPE := :NEW.ADJUSTMENTDOCNUMBER;
  new$OLDDOCNUMBER AGREEMENTS.OLDDOCNUMBER%TYPE := :NEW.OLDDOCNUMBER;
  new$LOTMAXSUM AGREEMENTS.LOTMAXSUM%TYPE := :NEW.LOTMAXSUM;
  new$CLIENT_INN AGREEMENTS.CLIENT_INN%TYPE := :NEW.CLIENT_INN;
  new$CLIENT_INN20 AGREEMENTS.CLIENT_INN20%TYPE := :NEW.CLIENT_INN20;
  new$CLIENT_NAME AGREEMENTS.CLIENT_NAME%TYPE := :NEW.CLIENT_NAME;
  new$EXECUTER_INN AGREEMENTS.EXECUTER_INN%TYPE := :NEW.EXECUTER_INN;
  new$EXECUTER_INN20 AGREEMENTS.EXECUTER_INN20%TYPE := :NEW.EXECUTER_INN20;
  new$EXECUTER_NAME AGREEMENTS.EXECUTER_NAME%TYPE := :NEW.EXECUTER_NAME;
  new$EXECUTER_STATUS AGREEMENTS.EXECUTER_STATUS%TYPE := :NEW.EXECUTER_STATUS;
  new$EXECUTER_COUNTRY AGREEMENTS.EXECUTER_COUNTRY%TYPE := :NEW.EXECUTER_COUNTRY;
  new$EXECUTER_ADDRESS AGREEMENTS.EXECUTER_ADDRESS%TYPE := :NEW.EXECUTER_ADDRESS;
  new$EXECUTER_PHONE AGREEMENTS.EXECUTER_PHONE%TYPE := :NEW.EXECUTER_PHONE;
  new$REALID AGREEMENTS.REALID%TYPE := :NEW.REALID;
  new$ADJUSTMENTNUMBER AGREEMENTS.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$INNERNUMBER AGREEMENTS.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$SENDERIDKEY AGREEMENTS.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY AGREEMENTS.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REESTRVERSION AGREEMENTS.REESTRVERSION%TYPE := :NEW.REESTRVERSION;
  new$DOCTYPE AGREEMENTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$RNCLIENTID AGREEMENTS.RNCLIENTID%TYPE := :NEW.RNCLIENTID;
  new$INFONUMBER AGREEMENTS.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$STATEORDERINNERNUMBER AGREEMENTS.STATEORDERINNERNUMBER%TYPE := :NEW.STATEORDERINNERNUMBER;
  new$PROGINDEX AGREEMENTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE AGREEMENTS.NOTE%TYPE := :NEW.NOTE;
  new$PURPORTDOC AGREEMENTS.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$REESTRRECORDNUMBER AGREEMENTS.REESTRRECORDNUMBER%TYPE := :NEW.REESTRRECORDNUMBER;
  new$EXECUTERSTOREDPROPS AGREEMENTS.EXECUTERSTOREDPROPS%TYPE := :NEW.EXECUTERSTOREDPROPS;
  new$AUTOSANCTION AGREEMENTS.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$PURCHASECODE AGREEMENTS.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$DOCUMENTNUMBER AGREEMENTS.DOCUMENTNUMBER%TYPE := :NEW.DOCUMENTNUMBER;
  new$TEMPREJECTCAUSE AGREEMENTS.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
  new$REJECTCAUSE AGREEMENTS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  MaxNumber$ NUMBER (10);
  CurVal$ NUMBER (10);
  CNT$1 NUMBER(10);
  DetCount$ NUMBER(10);
  CountAcc$ NUMBER(10);
  rnClientID1$ VARCHAR2(15);
  rnYear1$ VARCHAR2(15);
  rnNumber1$ VARCHAR2(15);
  ReestrVersion1$ VARCHAR2(15);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_AGREEMENTS_BU)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   3.1*/
  /*    -*/
  if (new$CardAdvancePercent is null) then
    new$CardAdvancePercent := 0;
  END IF;
  if (new$CardAdvance is null) then
    new$CardAdvance := 0;
  END IF;
  if (new$AgreementCardAdvance is null) then
    new$AgreementCardAdvance := 0;
  END IF;
  if (new$FinCardAdvance is null) then
    new$FinCardAdvance := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$AgreementSumma is null) then
    new$AgreementSumma := 0;
  END IF;
  if (new$AgreementFinSumma is null) then
    new$AgreementFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$Region is null) then
    new$Region := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$client_ref is null) then
    new$client_ref := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount$ from AgreementSteps where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      select count(ID)       into DetCount$ from Estimate where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*         -   InnerNumber*/
  if (((new$ProgIndex = 305) or (new$ProgIndex = 304) or (new$ProgIndex = 314)) and (new$InnerNumber is null)) then
    new$InnerNumber := GEN_ID('G_AgreementNumber',1);
  END IF;
  /*   */
  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  /*    .  */

  new$stateorderinnernumber := null;
  if (new$stateorderref is not null) then
    BEGIN
      select
      innernumber
      into new$stateorderinnernumber     from agreements
      where
      id = new$stateorderref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_3 (TR_AGREEMENTS_BU_3)
-- Create 03.12.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*            */
   new$AdjustmentRef := :OLD.AdjustmentRef;

-- - - - - - - - - - - - -
-- BU_5 (TR_AGREEMENTS_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_AGREEMENTS_BU_10)
-- Last update 08.02.2010
-- - - - - - - - - - - - -

/*   5.0*/
    /* ,      ,   */
    if ((new$InnerNumber <> :old.InnerNumber) or
        (new$AdjustmentNumber <> :old.AdjustmentNumber) or
        (new$AgreementType <> :old.AgreementType)) then
        RaiseException('EX_AGR_ChangeInnerNums');
    end if;

    /*    !!!*/
    if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and
        ((new$Accepted = 1) or (new$AcceptDate is null))) then
        RaiseException('EX_RollbackCancel');
    end if;

    /*   ,     LastAccepted*/
    if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) or
        ((:old.Accepted = 0) and (new$Accepted = 1) and (new$AcceptDate is not null))) then
        /*  LastAccepted         */
        if (new$LastAdjustment = 1) then
            new$LastAccepted := 1;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;
    end if;

    /*    ,     LastAccepted*/
    if (((:old.AcceptDate is not null) and (:old.Accepted = 1)) and
        ((new$Accepted = 0) or (new$AcceptDate is null))) then
        /*  LastAccepted         */
        if (new$LastAdjustment = 1) then
            new$LastAccepted := 0;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;
    end if;

    /*   ,     LastAdjustment*/
    if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 0)) or
        ((:old.Accepted = 1) and (new$Accepted = 0) and (new$AcceptDate is not null))) then

        if (new$LastAdjustment = 1) then
            new$LastAdjustment := 0;
            new$LastAccepted := 0;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;

        SELECT Max(AdjustmentNumber) INTO MaxNumber$ FROm AgreementS
        WHERE (InnerNumber = new$InnerNumber);
        /*    ,     */
        if ((new$adjustmentNumber=0) and (MaxNumber$<>0)) then
          RaiseException('EX_Agr_PrimaryAgrHasNotify');
        end if;
    end if;

-- - - - - - - - - - - - -
-- BU_20 (TR_AGREEMENTS_BU_20)
-- Create 21.05.2009
-- - - - - - - - - - - - -

  /*    -,      */
  if ((new$Client_Ref <> :old.Client_Ref) and
      (((new$Client_INN is null) and
        (:old.Client_INN is null)) or
       (new$Client_INN = :old.Client_INN)) and
      (((new$Client_INN20 is null) and
        (:old.Client_INN20 is null)) or
       (new$Client_INN20 = :old.Client_INN20)) and
      (new$Client_Name = :old.Client_Name)) then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name
      into
        new$Client_INN,
        new$Client_INN20,
        new$Client_Name
      from Organizations o
      where o.Id=new$Client_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Client_INN := NULL;
        new$Client_INN20 := NULL;
        new$Client_Name := NULL;
    END;
  END IF;

  /*    -,      */
  if ((new$Executer_Ref <> :old.Executer_Ref) and
      (((new$Executer_INN is null) and
        (:old.Executer_INN is null)) or
       (new$Executer_INN = :old.Executer_INN)) and
      (((new$Executer_INN20 is null) and
        (:old.Executer_INN20 is null)) or
       (new$Executer_INN20 = :old.Executer_INN20)) and
      (new$Executer_Name = :old.Executer_Name) and
      (((new$Executer_Status is null) and
        (:old.Executer_Status is null)) or
       (new$Executer_Status = :old.Executer_Status)) and
      (((new$Executer_Country is null) and
        (:old.Executer_Country is null)) or
       (new$Executer_Country = :old.Executer_Country)) and
      (((new$Executer_Address is null) and
        (:old.Executer_Address is null)) or
       (new$Executer_Address = :old.Executer_Address)) and
      (((new$Executer_Phone is null) and
        (:old.Executer_Phone is null)) or
       (new$Executer_Phone = :old.Executer_Phone))) then
     BEGIN
      select
        o.INN,
        o.INN20,
        o.Name,
        o.SupplierStatus,
        o.Country,
        o.Address,
        o.Phone
      into
        new$Executer_INN,
        new$Executer_INN20,
        new$Executer_Name,
        new$Executer_Status,
        new$Executer_Country,
        new$Executer_Address,
        new$Executer_Phone
      from Organizations o
      where o.Id=new$Executer_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Executer_INN := NULL;
        new$Executer_INN20 := NULL;
        new$Executer_Name := NULL;
        new$Executer_Status := NULL;
        new$Executer_Country := NULL;
        new$Executer_Address := NULL;
        new$Executer_Phone := NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_50 (TR_AGREEMENTS_BU_50)
-- Create 06.08.2010
-- - - - - - - - - - - - -

    if (new$InnerNumber is not null) then
        CurVal$ := gen_id('G_AgreementNumber', 0);
        if (CurVal$ < new$InnerNumber) then
          CurVal$ := gen_id('G_AgreementNumber', new$InnerNumber - CurVal$);
        end if;
    end if;

-- - - - - - - - - - - - -
-- BU_60 (tr_agreements_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*        ,     */
  if (:old.accepted = 1 and new$accepted = 0 and new$acceptdate is not null and new$adjustmentnumber = 0) then
    SELECT COUNT(*) INTO CNT$1
    from executiondocumentscaption
    where
    (            agreementinnernumber = new$innernumber
    and (accepted <> 0 or acceptdate is null)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_Agr_CannotReject');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_AGREEMENTS_BU_200)
-- Create 04.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$id, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (tr_agreements_bu_300)
-- Version 8.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ExecuterAccRef is not null) then
--     select count(ID)
--     into CountAcc$     from org_accounts oa
--     where oa.id = new$ExecuterAccRef and oa.Org_ref = new$Executer_Ref
--     ;
--     if (CountAcc$ = 0) then
--       RaiseException('EX_AGR_ACCORGCHECK');
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_400 (TR_AGREEMENTS_BU_400)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (((new$rnClientID <> :old.rnClientID) or (new$rnYear <> :old.rnYear) or
  (new$rnNumber <> :old.rnNumber) or (new$ReestrVersion <> :old.ReestrVersion)) and
  (new$rnClientID is not null) and (new$rnYear is not null) and (new$rnNumber is not null)) then

    rnClientID1$ := new$rnClientID;
    rnYear1$ := new$rnYear;
    rnNumber1$ := new$rnNumber;
    ReestrVersion1$ := new$ReestrVersion;
    while (LENGTH(rnClientID1$) < 11) LOOP
      rnClientID1$ := '0' || rnClientID1$;
    END LOOP;
    while (LENGTH(rnNumber1$) < 6) LOOP
      rnNumber1$ := '0' || rnNumber1$;
    END LOOP;
    if (LENGTH(ReestrVersion1$) < 2) then
      ReestrVersion1$ := '0' || ReestrVersion1$;
    END IF;
    /*  ReestrRecordNumber*/
    if (new$ReestrVersion is null) then
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$;

    else
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$ || ReestrVersion1$;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_600 (agreements_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_AGREEMENTS_BU_700)
-- Create 14.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_AGREEMENTS SET
    ID = new$ID,
    SUMMA = new$SUMMA,
    AGREEMENTDATE = new$AGREEMENTDATE,
    AGREEMENTENDDATE = new$AGREEMENTENDDATE,
    EXECUTER_REF = new$EXECUTER_REF,
    CLIENT_REF = new$CLIENT_REF,
    FACIALACC_CLS = new$FACIALACC_CLS,
    AGREEMENTTYPE = new$AGREEMENTTYPE,
    ACCEPTED = new$ACCEPTED,
    ACCEPTDATE = new$ACCEPTDATE,
    CARDADVANCEPERCENT = new$CARDADVANCEPERCENT,
    CARDADVANCE = new$CARDADVANCE,
    CLOSEDOC = new$CLOSEDOC,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    FACT = new$FACT,
    REGION = new$REGION,
    CLOSEDATE = new$CLOSEDATE,
    DELIVERYRULES = new$DELIVERYRULES,
    AGREEMENTSUMMA = new$AGREEMENTSUMMA,
    AGREEMENTFINSUMMA = new$AGREEMENTFINSUMMA,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    REESTRNUMBER = new$REESTRNUMBER,
    PAYMENTDATE = new$PAYMENTDATE,
    AGREEMENTCARDADVANCE = new$AGREEMENTCARDADVANCE,
    FINCARDADVANCE = new$FINCARDADVANCE,
    STATEORDERREF = new$STATEORDERREF,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    AGREEMENTBEGINDATE = new$AGREEMENTBEGINDATE,
    PROTOCOLNUMBER = new$PROTOCOLNUMBER,
    PROTOCOLDATE = new$PROTOCOLDATE,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXPORTDATE = new$EXPORTDATE,
    FSORGAN = new$FSORGAN,
    FSBUDGETNAME = new$FSBUDGETNAME,
    FSOFFBUDGET = new$FSOFFBUDGET,
    RNYEAR = new$RNYEAR,
    RNNUMBER = new$RNNUMBER,
    RNDATE = new$RNDATE,
    PROTOCOLNOTICE = new$PROTOCOLNOTICE,
    PROTOCOLRESULTDATE = new$PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE = new$PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE = new$PROTOCOLSALETYPE,
    NOTIFYDATE = new$NOTIFYDATE,
    EXECUTERACCREF = new$EXECUTERACCREF,
    DOCBASEDATE = new$DOCBASEDATE,
    DOCBASENOTIFYDATE = new$DOCBASENOTIFYDATE,
    DOCBASETEXT = new$DOCBASETEXT,
    DOCBASETYPE = new$DOCBASETYPE,
    DOCBASESUMMA = new$DOCBASESUMMA,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PROTOCOLREASON = new$PROTOCOLREASON,
    DOCNUMBER = new$DOCNUMBER,
    ADJUSTMENTDOCNUMBER = new$ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER = new$OLDDOCNUMBER,
    LOTMAXSUM = new$LOTMAXSUM,
    CLIENT_INN = new$CLIENT_INN,
    CLIENT_INN20 = new$CLIENT_INN20,
    CLIENT_NAME = new$CLIENT_NAME,
    EXECUTER_INN = new$EXECUTER_INN,
    EXECUTER_INN20 = new$EXECUTER_INN20,
    EXECUTER_NAME = new$EXECUTER_NAME,
    EXECUTER_STATUS = new$EXECUTER_STATUS,
    EXECUTER_COUNTRY = new$EXECUTER_COUNTRY,
    EXECUTER_ADDRESS = new$EXECUTER_ADDRESS,
    EXECUTER_PHONE = new$EXECUTER_PHONE,
    REALID = new$REALID,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    INNERNUMBER = new$INNERNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REESTRVERSION = new$REESTRVERSION,
    DOCTYPE = new$DOCTYPE,
    RNCLIENTID = new$RNCLIENTID,
    INFONUMBER = new$INFONUMBER,
    STATEORDERINNERNUMBER = new$STATEORDERINNERNUMBER,
    PROGINDEX = new$PROGINDEX,
    NOTE = new$NOTE,
    PURPORTDOC = new$PURPORTDOC,
    REESTRRECORDNUMBER = new$REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS = new$EXECUTERSTOREDPROPS,
    AUTOSANCTION = new$AUTOSANCTION,
    PURCHASECODE = new$PURCHASECODE,
    DOCUMENTNUMBER = new$DOCUMENTNUMBER,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_AGREEMENTS_AU_10)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   6.0*/
  /*      */
  /*     ,       */
  if ((new$AdjustmentNumber > 0) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update Agreements set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentNumber > 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update Agreements set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*          */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 304)or(new$ProgIndex = 314)))then
    update Estimate
    set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    (RecordIndex = new$Id);
  END IF;
  /*         */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 305) or (new$ProgIndex = 314))) then
    update paymentschedule set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    AgreementRef = new$ID and
    ProgIndex in (317, 318);

  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_AGREEMENTS_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*      */
  if ((new$ProgIndex = 305) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null
    where
    StateOrder = :old.ID;
  END IF;
  /*      */
  if ((new$ProgIndex = 314) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null,
    Agreement = null
    where
    StateOrder = :old.ID;
  END IF;
  /*     */
  if ((:old.ProgIndex = 304) and (new$AdjustmentNumber = 0) and (new$Accepted = 0) and
  (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    Agreement = null
    where
    Agreement = :old.ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_AGREEMENTS_AU_30)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$ProgIndex = 304) or (new$ProgIndex = 314)) and
  ((new$Accepted <> :old.Accepted) or
  (new$AcceptDate is not null and :old.AcceptDate is null) or
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where AgreementRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_AGREEMENTS_AU_500)
-- Create 28.04.2005
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes
                  (TableID, RecordId, DeleteDate
                  )
           VALUES (110, :OLD.ID, SYSDATE
                  );

      DELETE FROM DelRecIndexes
            WHERE (TableID = 110) AND (RecordId = new$ID);
   END IF;

END;
/
update AGREEMENTS set
  REJECTCAUSE = TempRejectCause
/
commit work 
/
ALTER TABLE TB_AGREEMENTS DROP (TempRejectCause)
/

CREATE OR REPLACE VIEW AGREEMENTS (
  ID,
  SUMMA,
  AGREEMENTDATE,
  AGREEMENTENDDATE,
  EXECUTER_REF,
  CLIENT_REF,
  FACIALACC_CLS,
  AGREEMENTTYPE,
  ACCEPTED,
  ACCEPTDATE,
  CARDADVANCEPERCENT,
  CARDADVANCE,
  CLOSEDOC,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  BUDGETREF,
  LASTADJUSTMENT,
  LASTACCEPTED,
  FACT,
  REGION,
  CLOSEDATE,
  DELIVERYRULES,
  AGREEMENTSUMMA,
  AGREEMENTFINSUMMA,
  ADJUSTMENTREF,
  REESTRNUMBER,
  PAYMENTDATE,
  AGREEMENTCARDADVANCE,
  FINCARDADVANCE,
  STATEORDERREF,
  REJECTCLS,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  AGREEMENTBEGINDATE,
  PROTOCOLNUMBER,
  PROTOCOLDATE,
  REVIEWNOTE,
  DOCSTATEREF,
  RVERSION,
  EXPORTDATE,
  FSORGAN,
  FSBUDGETNAME,
  FSOFFBUDGET,
  RNYEAR,
  RNNUMBER,
  RNDATE,
  PROTOCOLNOTICE,
  PROTOCOLRESULTDATE,
  PROTOCOLDOCTYPE,
  PROTOCOLSALETYPE,
  NOTIFYDATE,
  EXECUTERACCREF,
  DOCBASEDATE,
  DOCBASENOTIFYDATE,
  DOCBASETEXT,
  DOCBASETYPE,
  DOCBASESUMMA,
  UNKNOWNAMOUNT,
  PROTOCOLREASON,
  DOCNUMBER,
  ADJUSTMENTDOCNUMBER,
  OLDDOCNUMBER,
  LOTMAXSUM,
  CLIENT_INN,
  CLIENT_INN20,
  CLIENT_NAME,
  EXECUTER_INN,
  EXECUTER_INN20,
  EXECUTER_NAME,
  EXECUTER_STATUS,
  EXECUTER_COUNTRY,
  EXECUTER_ADDRESS,
  EXECUTER_PHONE,
  REALID,
  ADJUSTMENTNUMBER,
  INNERNUMBER,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  REESTRVERSION,
  DOCTYPE,
  RNCLIENTID,
  INFONUMBER,
  STATEORDERINNERNUMBER,
  PROGINDEX,
  NOTE,
  PURPORTDOC,
  REESTRRECORDNUMBER,
  EXECUTERSTOREDPROPS,
  AUTOSANCTION,
  PURCHASECODE,
  DOCUMENTNUMBER,
  REJECTCAUSE)
AS
  SELECT
    ID,
    SUMMA,
    AGREEMENTDATE,
    AGREEMENTENDDATE,
    EXECUTER_REF,
    CLIENT_REF,
    FACIALACC_CLS,
    AGREEMENTTYPE,
    ACCEPTED,
    ACCEPTDATE,
    CARDADVANCEPERCENT,
    CARDADVANCE,
    CLOSEDOC,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    LASTADJUSTMENT,
    LASTACCEPTED,
    FACT,
    REGION,
    CLOSEDATE,
    DELIVERYRULES,
    AGREEMENTSUMMA,
    AGREEMENTFINSUMMA,
    ADJUSTMENTREF,
    REESTRNUMBER,
    PAYMENTDATE,
    AGREEMENTCARDADVANCE,
    FINCARDADVANCE,
    STATEORDERREF,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    AGREEMENTBEGINDATE,
    PROTOCOLNUMBER,
    PROTOCOLDATE,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXPORTDATE,
    FSORGAN,
    FSBUDGETNAME,
    FSOFFBUDGET,
    RNYEAR,
    RNNUMBER,
    RNDATE,
    PROTOCOLNOTICE,
    PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE,
    NOTIFYDATE,
    EXECUTERACCREF,
    DOCBASEDATE,
    DOCBASENOTIFYDATE,
    DOCBASETEXT,
    DOCBASETYPE,
    DOCBASESUMMA,
    UNKNOWNAMOUNT,
    PROTOCOLREASON,
    DOCNUMBER,
    ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER,
    LOTMAXSUM,
    CLIENT_INN,
    CLIENT_INN20,
    CLIENT_NAME,
    EXECUTER_INN,
    EXECUTER_INN20,
    EXECUTER_NAME,
    EXECUTER_STATUS,
    EXECUTER_COUNTRY,
    EXECUTER_ADDRESS,
    EXECUTER_PHONE,
    REALID,
    ADJUSTMENTNUMBER,
    INNERNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REESTRVERSION,
    DOCTYPE,
    RNCLIENTID,
    INFONUMBER,
    STATEORDERINNERNUMBER,
    PROGINDEX,
    NOTE,
    PURPORTDOC,
    REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS,
    AUTOSANCTION,
    PURCHASECODE,
    DOCUMENTNUMBER,
    REJECTCAUSE
  FROM TB_AGREEMENTS
/

CREATE OR REPLACE TRIGGER TR_AGREEMENTS_ID
  INSTEAD OF DELETE
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  cnt1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_AGREEMENTS_BD)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*   5.0*/
  select count(id) into cnt1$ from agreements where (adjustmentref = :old.id) ;
  /*  .       .*/
  if (cnt1$ = 0) then
    delete from estimate where (recordindex = :old.id);
    delete from agreementsteps where (recordindex = :old.id);
    delete from paymentschedule where agreementref = :old.id;

  else
    RaiseException('ex_agr_cantdeladjustmented');
  END IF;

-- - - - - - - - - - - - -
-- BD_20 (TR_AGREEMENTS_BD_20)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  /*          */
  if ((:old.ProgIndex = 305)and(:old.AdjustmentNumber = 0)) then
    update tenderresultcaption set
    StateOrder = null
    where
    StateOrder = :old.ID;
  END IF;
  if ((:old.ProgIndex = 314)and(:old.AdjustmentNumber = 0)) then
    update tenderresultcaption set
    StateOrder = null,
    Agreement = null
    where
    StateOrder = :old.ID;
  END IF;
  if ((:old.ProgIndex = 304)and(:old.AdjustmentNumber = 0)) then
    update tenderresultcaption set
    Agreement = null
    where
    Agreement = :old.ID;
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_AGREEMENTS
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_10 (TR_AGREEMENTS_AD_10)
-- Last update 05.02.2010
-- - - - - - - - - - - - -

/*   5.0*/
    /*   LastAdjustment     */
    if ((:old.AdjustmentNumber > 0) and (:old.LastAdjustment = 1)) then
        update Agreements set
            LastAdjustment = 1,
            RVersion = -1
        where (ID = :old.AdjustmentRef);
    end if;
    /*   LastAccepted     */
    if ((:old.AdjustmentNumber > 0) and (:old.LastAccepted = 1)) then
        update Agreements set
            LastAccepted = 1,
            RVersion = -1
        where (ID = :old.AdjustmentRef);
    end if;

-- - - - - - - - - - - - -
-- AD_200 (TR_AGREEMENTS_AD_200)
-- Create 04.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

  /*        */
  delete from StateJumpHistory where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_AGREEMENTS_AD_500)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordId, DeleteDate, Summa, ProgIndex)
  values (110, :old.ID, SYSDATE, :old.AgreementSumma, :old.ProgIndex);

END;
/

CREATE OR REPLACE TRIGGER TR_AGREEMENTS_II
  INSTEAD OF INSERT
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  new$ID AGREEMENTS.ID%TYPE := :NEW.ID;
  new$SUMMA AGREEMENTS.SUMMA%TYPE := :NEW.SUMMA;
  new$AGREEMENTDATE AGREEMENTS.AGREEMENTDATE%TYPE := :NEW.AGREEMENTDATE;
  new$AGREEMENTENDDATE AGREEMENTS.AGREEMENTENDDATE%TYPE := :NEW.AGREEMENTENDDATE;
  new$EXECUTER_REF AGREEMENTS.EXECUTER_REF%TYPE := :NEW.EXECUTER_REF;
  new$CLIENT_REF AGREEMENTS.CLIENT_REF%TYPE := :NEW.CLIENT_REF;
  new$FACIALACC_CLS AGREEMENTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$AGREEMENTTYPE AGREEMENTS.AGREEMENTTYPE%TYPE := :NEW.AGREEMENTTYPE;
  new$ACCEPTED AGREEMENTS.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$ACCEPTDATE AGREEMENTS.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$CARDADVANCEPERCENT AGREEMENTS.CARDADVANCEPERCENT%TYPE := :NEW.CARDADVANCEPERCENT;
  new$CARDADVANCE AGREEMENTS.CARDADVANCE%TYPE := :NEW.CARDADVANCE;
  new$CLOSEDOC AGREEMENTS.CLOSEDOC%TYPE := :NEW.CLOSEDOC;
  new$CREATERUSER AGREEMENTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE AGREEMENTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE AGREEMENTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER AGREEMENTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF AGREEMENTS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$LASTADJUSTMENT AGREEMENTS.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED AGREEMENTS.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$FACT AGREEMENTS.FACT%TYPE := :NEW.FACT;
  new$REGION AGREEMENTS.REGION%TYPE := :NEW.REGION;
  new$CLOSEDATE AGREEMENTS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$DELIVERYRULES AGREEMENTS.DELIVERYRULES%TYPE := :NEW.DELIVERYRULES;
  new$AGREEMENTSUMMA AGREEMENTS.AGREEMENTSUMMA%TYPE := :NEW.AGREEMENTSUMMA;
  new$AGREEMENTFINSUMMA AGREEMENTS.AGREEMENTFINSUMMA%TYPE := :NEW.AGREEMENTFINSUMMA;
  new$ADJUSTMENTREF AGREEMENTS.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$REESTRNUMBER AGREEMENTS.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$PAYMENTDATE AGREEMENTS.PAYMENTDATE%TYPE := :NEW.PAYMENTDATE;
  new$AGREEMENTCARDADVANCE AGREEMENTS.AGREEMENTCARDADVANCE%TYPE := :NEW.AGREEMENTCARDADVANCE;
  new$FINCARDADVANCE AGREEMENTS.FINCARDADVANCE%TYPE := :NEW.FINCARDADVANCE;
  new$STATEORDERREF AGREEMENTS.STATEORDERREF%TYPE := :NEW.STATEORDERREF;
  new$REJECTCLS AGREEMENTS.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS AGREEMENTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID AGREEMENTS.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID AGREEMENTS.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$AGREEMENTBEGINDATE AGREEMENTS.AGREEMENTBEGINDATE%TYPE := :NEW.AGREEMENTBEGINDATE;
  new$PROTOCOLNUMBER AGREEMENTS.PROTOCOLNUMBER%TYPE := :NEW.PROTOCOLNUMBER;
  new$PROTOCOLDATE AGREEMENTS.PROTOCOLDATE%TYPE := :NEW.PROTOCOLDATE;
  new$REVIEWNOTE AGREEMENTS.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF AGREEMENTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION AGREEMENTS.RVERSION%TYPE := :NEW.RVERSION;
  new$EXPORTDATE AGREEMENTS.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$FSORGAN AGREEMENTS.FSORGAN%TYPE := :NEW.FSORGAN;
  new$FSBUDGETNAME AGREEMENTS.FSBUDGETNAME%TYPE := :NEW.FSBUDGETNAME;
  new$FSOFFBUDGET AGREEMENTS.FSOFFBUDGET%TYPE := :NEW.FSOFFBUDGET;
  new$RNYEAR AGREEMENTS.RNYEAR%TYPE := :NEW.RNYEAR;
  new$RNNUMBER AGREEMENTS.RNNUMBER%TYPE := :NEW.RNNUMBER;
  new$RNDATE AGREEMENTS.RNDATE%TYPE := :NEW.RNDATE;
  new$PROTOCOLNOTICE AGREEMENTS.PROTOCOLNOTICE%TYPE := :NEW.PROTOCOLNOTICE;
  new$PROTOCOLRESULTDATE AGREEMENTS.PROTOCOLRESULTDATE%TYPE := :NEW.PROTOCOLRESULTDATE;
  new$PROTOCOLDOCTYPE AGREEMENTS.PROTOCOLDOCTYPE%TYPE := :NEW.PROTOCOLDOCTYPE;
  new$PROTOCOLSALETYPE AGREEMENTS.PROTOCOLSALETYPE%TYPE := :NEW.PROTOCOLSALETYPE;
  new$NOTIFYDATE AGREEMENTS.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$EXECUTERACCREF AGREEMENTS.EXECUTERACCREF%TYPE := :NEW.EXECUTERACCREF;
  new$DOCBASEDATE AGREEMENTS.DOCBASEDATE%TYPE := :NEW.DOCBASEDATE;
  new$DOCBASENOTIFYDATE AGREEMENTS.DOCBASENOTIFYDATE%TYPE := :NEW.DOCBASENOTIFYDATE;
  new$DOCBASETEXT AGREEMENTS.DOCBASETEXT%TYPE := :NEW.DOCBASETEXT;
  new$DOCBASETYPE AGREEMENTS.DOCBASETYPE%TYPE := :NEW.DOCBASETYPE;
  new$DOCBASESUMMA AGREEMENTS.DOCBASESUMMA%TYPE := :NEW.DOCBASESUMMA;
  new$UNKNOWNAMOUNT AGREEMENTS.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PROTOCOLREASON AGREEMENTS.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$DOCNUMBER AGREEMENTS.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$ADJUSTMENTDOCNUMBER AGREEMENTS.ADJUSTMENTDOCNUMBER%TYPE := :NEW.ADJUSTMENTDOCNUMBER;
  new$OLDDOCNUMBER AGREEMENTS.OLDDOCNUMBER%TYPE := :NEW.OLDDOCNUMBER;
  new$LOTMAXSUM AGREEMENTS.LOTMAXSUM%TYPE := :NEW.LOTMAXSUM;
  new$CLIENT_INN AGREEMENTS.CLIENT_INN%TYPE := :NEW.CLIENT_INN;
  new$CLIENT_INN20 AGREEMENTS.CLIENT_INN20%TYPE := :NEW.CLIENT_INN20;
  new$CLIENT_NAME AGREEMENTS.CLIENT_NAME%TYPE := :NEW.CLIENT_NAME;
  new$EXECUTER_INN AGREEMENTS.EXECUTER_INN%TYPE := :NEW.EXECUTER_INN;
  new$EXECUTER_INN20 AGREEMENTS.EXECUTER_INN20%TYPE := :NEW.EXECUTER_INN20;
  new$EXECUTER_NAME AGREEMENTS.EXECUTER_NAME%TYPE := :NEW.EXECUTER_NAME;
  new$EXECUTER_STATUS AGREEMENTS.EXECUTER_STATUS%TYPE := :NEW.EXECUTER_STATUS;
  new$EXECUTER_COUNTRY AGREEMENTS.EXECUTER_COUNTRY%TYPE := :NEW.EXECUTER_COUNTRY;
  new$EXECUTER_ADDRESS AGREEMENTS.EXECUTER_ADDRESS%TYPE := :NEW.EXECUTER_ADDRESS;
  new$EXECUTER_PHONE AGREEMENTS.EXECUTER_PHONE%TYPE := :NEW.EXECUTER_PHONE;
  new$REALID AGREEMENTS.REALID%TYPE := :NEW.REALID;
  new$ADJUSTMENTNUMBER AGREEMENTS.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$INNERNUMBER AGREEMENTS.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$SENDERIDKEY AGREEMENTS.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY AGREEMENTS.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REESTRVERSION AGREEMENTS.REESTRVERSION%TYPE := :NEW.REESTRVERSION;
  new$DOCTYPE AGREEMENTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$RNCLIENTID AGREEMENTS.RNCLIENTID%TYPE := :NEW.RNCLIENTID;
  new$INFONUMBER AGREEMENTS.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$STATEORDERINNERNUMBER AGREEMENTS.STATEORDERINNERNUMBER%TYPE := :NEW.STATEORDERINNERNUMBER;
  new$PROGINDEX AGREEMENTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE AGREEMENTS.NOTE%TYPE := :NEW.NOTE;
  new$PURPORTDOC AGREEMENTS.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$REESTRRECORDNUMBER AGREEMENTS.REESTRRECORDNUMBER%TYPE := :NEW.REESTRRECORDNUMBER;
  new$EXECUTERSTOREDPROPS AGREEMENTS.EXECUTERSTOREDPROPS%TYPE := :NEW.EXECUTERSTOREDPROPS;
  new$AUTOSANCTION AGREEMENTS.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$PURCHASECODE AGREEMENTS.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$DOCUMENTNUMBER AGREEMENTS.DOCUMENTNUMBER%TYPE := :NEW.DOCUMENTNUMBER;
  new$REJECTCAUSE AGREEMENTS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  CurVal$ NUMBER (10);
  CountAcc$ NUMBER(10);
  rnClientID1$ VARCHAR2(15);
  rnYear1$ VARCHAR2(15);
  rnNumber1$ VARCHAR2(15);
  ReestrVersion1$ VARCHAR2(15);
  Tmp$ NUMBER(10);
  AdjID$ NUMBER(10);
  AdjDocNum$ VARCHAR2(150);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_AGREEMENTS_BI)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   3.1.2*/
  /*    -*/
  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$CardAdvancePercent is null) then
    new$CardAdvancePercent := 0;
  END IF;
  if (new$CardAdvance is null) then
    new$CardAdvance := 0;
  END IF;
  if (new$AgreementCardAdvance is null) then
    new$AgreementCardAdvance := 0;
  END IF;
  if (new$FinCardAdvance is null) then
    new$FinCardAdvance := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$AgreementSumma is null) then
    new$AgreementSumma := 0;
  END IF;
  if (new$AgreementFinSumma is null) then
    new$AgreementFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$Region is null) then
    new$Region := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  if (new$client_ref is null) then
    new$client_ref := 0;
  END IF;

  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    BEGIN
      select fa.BudgetRef     into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;

  /*    
         -   InnerNumber*/
  if (((new$ProgIndex = 305) or (new$ProgIndex = 304) or (new$ProgIndex = 314)) and (new$InnerNumber is null)) then
    new$InnerNumber := GEN_ID('G_AgreementNumber',1);
  END IF;
  /*   */
  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  /*    .  */

  new$stateorderinnernumber := null;
  if (new$stateorderref is not null) then
    BEGIN
      select
      innernumber
      into new$stateorderinnernumber     from agreements
      where
      id = new$stateorderref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_AGREEMENTS_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_AGREEMENTS_BI_10)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  /*   5.0*/

  /*    .*/
  if (new$InnerNumber is null) then
    RaiseException('EX_AGR_InnerNumsIsNull');
  END IF;

  /*    */
  select max(AdjustmentNumber)
  into Tmp$         from Agreements
  where (InnerNumber = new$InnerNumber)
  ;
  /*      ,   0*/
  if (Tmp$ is null) then
    new$AdjustmentNumber := 0;

  else
    new$AdjustmentNumber := Tmp$ + 1;
  END IF;
  /*        */
  if (((new$AgreementType = 0) and (new$AdjustmentNumber > 0)) or
  ((new$AgreementType = 1) and (new$AdjustmentNumber = 0))) then
    RaiseException('EX_AGR_AgrTypeViolation');
  END IF;
  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;

  else
    new$LastAdjustment := 1;
  END IF;
  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then
    new$LastAccepted := 1;

  else
    new$LastAccepted := 0;
  END IF;
  /*    */
  if (new$AdjustmentNumber > 0) then
    /*      -    */
    select count(ID), max(ID), max(DocNumber)
    into Tmp$, AdjID$, AdjDocNum$             from Agreements
    where (InnerNumber = new$InnerNumber) and (LastAccepted = 1)
    ;
    /*   ,  */
    if (Tmp$ <> 1) then
      RaiseException('EX_AGR_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID)
    into Tmp$             from Agreements
    where (InnerNumber = new$InnerNumber) and (AcceptDate is null)
    ;
    if (Tmp$ > 0) then
      RaiseException('EX_AGR_AdjustDuplicate');
    END IF;
    /* ,    ,    */
    new$AdjustmentRef := AdjID$;
    new$AdjustmentDocNumber := AdjDocNum$;

  else /*     */
    /*       (    )*/
    new$AdjustmentRef := null;
    new$AdjustmentDocNumber := null;

  END IF;

-- - - - - - - - - - - - -
-- BI_20 (TR_AGREEMENTS_BI_20)
-- Create 21.05.2009
-- - - - - - - - - - - - -

  /*    -,     */
  if ((new$Client_INN   is null) and
      (new$Client_INN20 is null) and
      (new$Client_Name  is null))then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name
      into
        new$Client_INN,
        new$Client_INN20,
        new$Client_Name
      from Organizations o
      where o.Id=new$Client_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Client_INN := NULL;
        new$Client_INN20 := NULL;
        new$Client_Name := NULL;
    END;
  END IF;

  /*    -,     */
  if ((new$Executer_INN     is null) and
      (new$Executer_INN20   is null) and
      (new$Executer_Name    is null) and
      (new$Executer_Status  is null) and
      (new$Executer_Country is null) and
      (new$Executer_Address is null) and
      (new$Executer_Phone   is null))then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name,
        o.SupplierStatus,
        o.Country,
        o.Address,
        o.Phone
      into
        new$Executer_INN,
        new$Executer_INN20,
        new$Executer_Name,
        new$Executer_Status,
        new$Executer_Country,
        new$Executer_Address,
        new$Executer_Phone
      from Organizations o
      where o.Id=new$Executer_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Executer_INN := NULL;
        new$Executer_INN20 := NULL;
        new$Executer_Name := NULL;
        new$Executer_Status := NULL;
        new$Executer_Country := NULL;
        new$Executer_Address := NULL;
        new$Executer_Phone := NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_40 (TR_AGREEMENTS_BI_40)
-- Create 06.08.2010
-- - - - - - - - - - - - -

  /*       */
  if (new$senderId is null) then
    new$senderIdKey := -1;
  else
    new$senderIdKey := new$senderId;
  end if;

  if (new$SenderRecordID is null)then
    new$SenderRecordIDKey := new$ID;
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  end if;

-- - - - - - - - - - - - -
-- BI_50 (TR_AGREEMENTS_BI_50)
-- Create 06.08.2010
-- - - - - - - - - - - - -

    if (new$InnerNumber is not null) then
        CurVal$ := gen_id('G_AgreementNumber', 0);
        if (CurVal$ < new$InnerNumber) then
          CurVal$ := gen_id('G_AgreementNumber', new$InnerNumber - CurVal$);
        end if;
    end if;

-- - - - - - - - - - - - -
-- BI_300 (tr_agreements_bi_300)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$ExecuterAccRef is not null) then
    select count(ID)
    into CountAcc$     from org_accounts oa
    where oa.id = new$ExecuterAccRef and oa.Org_ref = new$Executer_Ref
    ;
    if (CountAcc$ = 0) then
      RaiseException('EX_AGR_ACCORGCHECK');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_400 (TR_AGREEMENTS_BI_400)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if ((new$rnClientID is not null) and (new$rnYear is not null) and (new$rnNumber is not null)) then

    rnClientID1$ := new$rnClientID;
    rnYear1$ := new$rnYear;
    rnNumber1$ := new$rnNumber;
    ReestrVersion1$ := new$ReestrVersion;
    while (LENGTH(rnClientID1$) < 11) LOOP
      rnClientID1$ := '0' || rnClientID1$;
    END LOOP;
    while (LENGTH(rnNumber1$) < 6) LOOP
      rnNumber1$ := '0' || rnNumber1$;
    END LOOP;
    if (LENGTH(ReestrVersion1$) < 2) then
      ReestrVersion1$ := '0' || ReestrVersion1$;
    END IF;
    /*  ReestrRecordNumber*/
    if (new$ReestrVersion is null) then
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$;

    else
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$ || ReestrVersion1$;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_AGREEMENTS_BI_500)
-- Last update 19.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- BI_600 (agreements_realid_bi_600)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_AGREEMENTS (
    ID,
    SUMMA,
    AGREEMENTDATE,
    AGREEMENTENDDATE,
    EXECUTER_REF,
    CLIENT_REF,
    FACIALACC_CLS,
    AGREEMENTTYPE,
    ACCEPTED,
    ACCEPTDATE,
    CARDADVANCEPERCENT,
    CARDADVANCE,
    CLOSEDOC,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    LASTADJUSTMENT,
    LASTACCEPTED,
    FACT,
    REGION,
    CLOSEDATE,
    DELIVERYRULES,
    AGREEMENTSUMMA,
    AGREEMENTFINSUMMA,
    ADJUSTMENTREF,
    REESTRNUMBER,
    PAYMENTDATE,
    AGREEMENTCARDADVANCE,
    FINCARDADVANCE,
    STATEORDERREF,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    AGREEMENTBEGINDATE,
    PROTOCOLNUMBER,
    PROTOCOLDATE,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXPORTDATE,
    FSORGAN,
    FSBUDGETNAME,
    FSOFFBUDGET,
    RNYEAR,
    RNNUMBER,
    RNDATE,
    PROTOCOLNOTICE,
    PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE,
    NOTIFYDATE,
    EXECUTERACCREF,
    DOCBASEDATE,
    DOCBASENOTIFYDATE,
    DOCBASETEXT,
    DOCBASETYPE,
    DOCBASESUMMA,
    UNKNOWNAMOUNT,
    PROTOCOLREASON,
    DOCNUMBER,
    ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER,
    LOTMAXSUM,
    CLIENT_INN,
    CLIENT_INN20,
    CLIENT_NAME,
    EXECUTER_INN,
    EXECUTER_INN20,
    EXECUTER_NAME,
    EXECUTER_STATUS,
    EXECUTER_COUNTRY,
    EXECUTER_ADDRESS,
    EXECUTER_PHONE,
    REALID,
    ADJUSTMENTNUMBER,
    INNERNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REESTRVERSION,
    DOCTYPE,
    RNCLIENTID,
    INFONUMBER,
    STATEORDERINNERNUMBER,
    PROGINDEX,
    NOTE,
    PURPORTDOC,
    REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS,
    AUTOSANCTION,
    PURCHASECODE,
    DOCUMENTNUMBER,
    REJECTCAUSE
  ) VALUES (
    new$ID,
    new$SUMMA,
    new$AGREEMENTDATE,
    new$AGREEMENTENDDATE,
    new$EXECUTER_REF,
    new$CLIENT_REF,
    new$FACIALACC_CLS,
    new$AGREEMENTTYPE,
    new$ACCEPTED,
    new$ACCEPTDATE,
    new$CARDADVANCEPERCENT,
    new$CARDADVANCE,
    new$CLOSEDOC,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$LASTADJUSTMENT,
    new$LASTACCEPTED,
    new$FACT,
    new$REGION,
    new$CLOSEDATE,
    new$DELIVERYRULES,
    new$AGREEMENTSUMMA,
    new$AGREEMENTFINSUMMA,
    new$ADJUSTMENTREF,
    new$REESTRNUMBER,
    new$PAYMENTDATE,
    new$AGREEMENTCARDADVANCE,
    new$FINCARDADVANCE,
    new$STATEORDERREF,
    new$REJECTCLS,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$AGREEMENTBEGINDATE,
    new$PROTOCOLNUMBER,
    new$PROTOCOLDATE,
    new$REVIEWNOTE,
    new$DOCSTATEREF,
    new$RVERSION,
    new$EXPORTDATE,
    new$FSORGAN,
    new$FSBUDGETNAME,
    new$FSOFFBUDGET,
    new$RNYEAR,
    new$RNNUMBER,
    new$RNDATE,
    new$PROTOCOLNOTICE,
    new$PROTOCOLRESULTDATE,
    new$PROTOCOLDOCTYPE,
    new$PROTOCOLSALETYPE,
    new$NOTIFYDATE,
    new$EXECUTERACCREF,
    new$DOCBASEDATE,
    new$DOCBASENOTIFYDATE,
    new$DOCBASETEXT,
    new$DOCBASETYPE,
    new$DOCBASESUMMA,
    new$UNKNOWNAMOUNT,
    new$PROTOCOLREASON,
    new$DOCNUMBER,
    new$ADJUSTMENTDOCNUMBER,
    new$OLDDOCNUMBER,
    new$LOTMAXSUM,
    new$CLIENT_INN,
    new$CLIENT_INN20,
    new$CLIENT_NAME,
    new$EXECUTER_INN,
    new$EXECUTER_INN20,
    new$EXECUTER_NAME,
    new$EXECUTER_STATUS,
    new$EXECUTER_COUNTRY,
    new$EXECUTER_ADDRESS,
    new$EXECUTER_PHONE,
    new$REALID,
    new$ADJUSTMENTNUMBER,
    new$INNERNUMBER,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$REESTRVERSION,
    new$DOCTYPE,
    new$RNCLIENTID,
    new$INFONUMBER,
    new$STATEORDERINNERNUMBER,
    new$PROGINDEX,
    new$NOTE,
    new$PURPORTDOC,
    new$REESTRRECORDNUMBER,
    new$EXECUTERSTOREDPROPS,
    new$AUTOSANCTION,
    new$PURCHASECODE,
    new$DOCUMENTNUMBER,
    new$REJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_10 (TR_AGREEMENTS_AI_10)
-- Last update 05.02.2010
-- - - - - - - - - - - - -

/*   5.0*/
    if ((new$AdjustmentNumber > 0) and (new$LastAdjustment = 1)) then
        update Agreements set
            LastAdjustment = 0,
            RVersion = -1
        where (ID = new$AdjustmentRef);
        if (new$LastAccepted = 1) then
            update Agreements set
                LastAccepted = 0,
                RVersion = -1
            where (ID = new$AdjustmentRef);
        end if;
    end if;

-- - - - - - - - - - - - -
-- AI_500 (TR_AGREEMENTS_AI_500)
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 110) AND (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_AGREEMENTS_IU
  INSTEAD OF UPDATE
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  new$ID AGREEMENTS.ID%TYPE := :NEW.ID;
  new$SUMMA AGREEMENTS.SUMMA%TYPE := :NEW.SUMMA;
  new$AGREEMENTDATE AGREEMENTS.AGREEMENTDATE%TYPE := :NEW.AGREEMENTDATE;
  new$AGREEMENTENDDATE AGREEMENTS.AGREEMENTENDDATE%TYPE := :NEW.AGREEMENTENDDATE;
  new$EXECUTER_REF AGREEMENTS.EXECUTER_REF%TYPE := :NEW.EXECUTER_REF;
  new$CLIENT_REF AGREEMENTS.CLIENT_REF%TYPE := :NEW.CLIENT_REF;
  new$FACIALACC_CLS AGREEMENTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$AGREEMENTTYPE AGREEMENTS.AGREEMENTTYPE%TYPE := :NEW.AGREEMENTTYPE;
  new$ACCEPTED AGREEMENTS.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$ACCEPTDATE AGREEMENTS.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$CARDADVANCEPERCENT AGREEMENTS.CARDADVANCEPERCENT%TYPE := :NEW.CARDADVANCEPERCENT;
  new$CARDADVANCE AGREEMENTS.CARDADVANCE%TYPE := :NEW.CARDADVANCE;
  new$CLOSEDOC AGREEMENTS.CLOSEDOC%TYPE := :NEW.CLOSEDOC;
  new$CREATERUSER AGREEMENTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE AGREEMENTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE AGREEMENTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER AGREEMENTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF AGREEMENTS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$LASTADJUSTMENT AGREEMENTS.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED AGREEMENTS.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$FACT AGREEMENTS.FACT%TYPE := :NEW.FACT;
  new$REGION AGREEMENTS.REGION%TYPE := :NEW.REGION;
  new$CLOSEDATE AGREEMENTS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$DELIVERYRULES AGREEMENTS.DELIVERYRULES%TYPE := :NEW.DELIVERYRULES;
  new$AGREEMENTSUMMA AGREEMENTS.AGREEMENTSUMMA%TYPE := :NEW.AGREEMENTSUMMA;
  new$AGREEMENTFINSUMMA AGREEMENTS.AGREEMENTFINSUMMA%TYPE := :NEW.AGREEMENTFINSUMMA;
  new$ADJUSTMENTREF AGREEMENTS.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$REESTRNUMBER AGREEMENTS.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$PAYMENTDATE AGREEMENTS.PAYMENTDATE%TYPE := :NEW.PAYMENTDATE;
  new$AGREEMENTCARDADVANCE AGREEMENTS.AGREEMENTCARDADVANCE%TYPE := :NEW.AGREEMENTCARDADVANCE;
  new$FINCARDADVANCE AGREEMENTS.FINCARDADVANCE%TYPE := :NEW.FINCARDADVANCE;
  new$STATEORDERREF AGREEMENTS.STATEORDERREF%TYPE := :NEW.STATEORDERREF;
  new$REJECTCLS AGREEMENTS.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS AGREEMENTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID AGREEMENTS.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID AGREEMENTS.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$AGREEMENTBEGINDATE AGREEMENTS.AGREEMENTBEGINDATE%TYPE := :NEW.AGREEMENTBEGINDATE;
  new$PROTOCOLNUMBER AGREEMENTS.PROTOCOLNUMBER%TYPE := :NEW.PROTOCOLNUMBER;
  new$PROTOCOLDATE AGREEMENTS.PROTOCOLDATE%TYPE := :NEW.PROTOCOLDATE;
  new$REVIEWNOTE AGREEMENTS.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF AGREEMENTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION AGREEMENTS.RVERSION%TYPE := :NEW.RVERSION;
  new$EXPORTDATE AGREEMENTS.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$FSORGAN AGREEMENTS.FSORGAN%TYPE := :NEW.FSORGAN;
  new$FSBUDGETNAME AGREEMENTS.FSBUDGETNAME%TYPE := :NEW.FSBUDGETNAME;
  new$FSOFFBUDGET AGREEMENTS.FSOFFBUDGET%TYPE := :NEW.FSOFFBUDGET;
  new$RNYEAR AGREEMENTS.RNYEAR%TYPE := :NEW.RNYEAR;
  new$RNNUMBER AGREEMENTS.RNNUMBER%TYPE := :NEW.RNNUMBER;
  new$RNDATE AGREEMENTS.RNDATE%TYPE := :NEW.RNDATE;
  new$PROTOCOLNOTICE AGREEMENTS.PROTOCOLNOTICE%TYPE := :NEW.PROTOCOLNOTICE;
  new$PROTOCOLRESULTDATE AGREEMENTS.PROTOCOLRESULTDATE%TYPE := :NEW.PROTOCOLRESULTDATE;
  new$PROTOCOLDOCTYPE AGREEMENTS.PROTOCOLDOCTYPE%TYPE := :NEW.PROTOCOLDOCTYPE;
  new$PROTOCOLSALETYPE AGREEMENTS.PROTOCOLSALETYPE%TYPE := :NEW.PROTOCOLSALETYPE;
  new$NOTIFYDATE AGREEMENTS.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$EXECUTERACCREF AGREEMENTS.EXECUTERACCREF%TYPE := :NEW.EXECUTERACCREF;
  new$DOCBASEDATE AGREEMENTS.DOCBASEDATE%TYPE := :NEW.DOCBASEDATE;
  new$DOCBASENOTIFYDATE AGREEMENTS.DOCBASENOTIFYDATE%TYPE := :NEW.DOCBASENOTIFYDATE;
  new$DOCBASETEXT AGREEMENTS.DOCBASETEXT%TYPE := :NEW.DOCBASETEXT;
  new$DOCBASETYPE AGREEMENTS.DOCBASETYPE%TYPE := :NEW.DOCBASETYPE;
  new$DOCBASESUMMA AGREEMENTS.DOCBASESUMMA%TYPE := :NEW.DOCBASESUMMA;
  new$UNKNOWNAMOUNT AGREEMENTS.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PROTOCOLREASON AGREEMENTS.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$DOCNUMBER AGREEMENTS.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$ADJUSTMENTDOCNUMBER AGREEMENTS.ADJUSTMENTDOCNUMBER%TYPE := :NEW.ADJUSTMENTDOCNUMBER;
  new$OLDDOCNUMBER AGREEMENTS.OLDDOCNUMBER%TYPE := :NEW.OLDDOCNUMBER;
  new$LOTMAXSUM AGREEMENTS.LOTMAXSUM%TYPE := :NEW.LOTMAXSUM;
  new$CLIENT_INN AGREEMENTS.CLIENT_INN%TYPE := :NEW.CLIENT_INN;
  new$CLIENT_INN20 AGREEMENTS.CLIENT_INN20%TYPE := :NEW.CLIENT_INN20;
  new$CLIENT_NAME AGREEMENTS.CLIENT_NAME%TYPE := :NEW.CLIENT_NAME;
  new$EXECUTER_INN AGREEMENTS.EXECUTER_INN%TYPE := :NEW.EXECUTER_INN;
  new$EXECUTER_INN20 AGREEMENTS.EXECUTER_INN20%TYPE := :NEW.EXECUTER_INN20;
  new$EXECUTER_NAME AGREEMENTS.EXECUTER_NAME%TYPE := :NEW.EXECUTER_NAME;
  new$EXECUTER_STATUS AGREEMENTS.EXECUTER_STATUS%TYPE := :NEW.EXECUTER_STATUS;
  new$EXECUTER_COUNTRY AGREEMENTS.EXECUTER_COUNTRY%TYPE := :NEW.EXECUTER_COUNTRY;
  new$EXECUTER_ADDRESS AGREEMENTS.EXECUTER_ADDRESS%TYPE := :NEW.EXECUTER_ADDRESS;
  new$EXECUTER_PHONE AGREEMENTS.EXECUTER_PHONE%TYPE := :NEW.EXECUTER_PHONE;
  new$REALID AGREEMENTS.REALID%TYPE := :NEW.REALID;
  new$ADJUSTMENTNUMBER AGREEMENTS.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$INNERNUMBER AGREEMENTS.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$SENDERIDKEY AGREEMENTS.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY AGREEMENTS.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REESTRVERSION AGREEMENTS.REESTRVERSION%TYPE := :NEW.REESTRVERSION;
  new$DOCTYPE AGREEMENTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$RNCLIENTID AGREEMENTS.RNCLIENTID%TYPE := :NEW.RNCLIENTID;
  new$INFONUMBER AGREEMENTS.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$STATEORDERINNERNUMBER AGREEMENTS.STATEORDERINNERNUMBER%TYPE := :NEW.STATEORDERINNERNUMBER;
  new$PROGINDEX AGREEMENTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE AGREEMENTS.NOTE%TYPE := :NEW.NOTE;
  new$PURPORTDOC AGREEMENTS.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$REESTRRECORDNUMBER AGREEMENTS.REESTRRECORDNUMBER%TYPE := :NEW.REESTRRECORDNUMBER;
  new$EXECUTERSTOREDPROPS AGREEMENTS.EXECUTERSTOREDPROPS%TYPE := :NEW.EXECUTERSTOREDPROPS;
  new$AUTOSANCTION AGREEMENTS.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$PURCHASECODE AGREEMENTS.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$DOCUMENTNUMBER AGREEMENTS.DOCUMENTNUMBER%TYPE := :NEW.DOCUMENTNUMBER;
  new$REJECTCAUSE AGREEMENTS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  MaxNumber$ NUMBER (10);
  CurVal$ NUMBER (10);
  CNT$1 NUMBER(10);
  DetCount$ NUMBER(10);
  CountAcc$ NUMBER(10);
  rnClientID1$ VARCHAR2(15);
  rnYear1$ VARCHAR2(15);
  rnNumber1$ VARCHAR2(15);
  ReestrVersion1$ VARCHAR2(15);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_AGREEMENTS_BU)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   3.1*/
  /*    -*/
  if (new$CardAdvancePercent is null) then
    new$CardAdvancePercent := 0;
  END IF;
  if (new$CardAdvance is null) then
    new$CardAdvance := 0;
  END IF;
  if (new$AgreementCardAdvance is null) then
    new$AgreementCardAdvance := 0;
  END IF;
  if (new$FinCardAdvance is null) then
    new$FinCardAdvance := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$AgreementSumma is null) then
    new$AgreementSumma := 0;
  END IF;
  if (new$AgreementFinSumma is null) then
    new$AgreementFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$Region is null) then
    new$Region := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$client_ref is null) then
    new$client_ref := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount$ from AgreementSteps where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      select count(ID)       into DetCount$ from Estimate where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*         -   InnerNumber*/
  if (((new$ProgIndex = 305) or (new$ProgIndex = 304) or (new$ProgIndex = 314)) and (new$InnerNumber is null)) then
    new$InnerNumber := GEN_ID('G_AgreementNumber',1);
  END IF;
  /*   */
  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  /*    .  */

  new$stateorderinnernumber := null;
  if (new$stateorderref is not null) then
    BEGIN
      select
      innernumber
      into new$stateorderinnernumber     from agreements
      where
      id = new$stateorderref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_3 (TR_AGREEMENTS_BU_3)
-- Create 03.12.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*            */
   new$AdjustmentRef := :OLD.AdjustmentRef;

-- - - - - - - - - - - - -
-- BU_5 (TR_AGREEMENTS_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_AGREEMENTS_BU_10)
-- Last update 08.02.2010
-- - - - - - - - - - - - -

/*   5.0*/
    /* ,      ,   */
    if ((new$InnerNumber <> :old.InnerNumber) or
        (new$AdjustmentNumber <> :old.AdjustmentNumber) or
        (new$AgreementType <> :old.AgreementType)) then
        RaiseException('EX_AGR_ChangeInnerNums');
    end if;

    /*    !!!*/
    if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and
        ((new$Accepted = 1) or (new$AcceptDate is null))) then
        RaiseException('EX_RollbackCancel');
    end if;

    /*   ,     LastAccepted*/
    if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) or
        ((:old.Accepted = 0) and (new$Accepted = 1) and (new$AcceptDate is not null))) then
        /*  LastAccepted         */
        if (new$LastAdjustment = 1) then
            new$LastAccepted := 1;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;
    end if;

    /*    ,     LastAccepted*/
    if (((:old.AcceptDate is not null) and (:old.Accepted = 1)) and
        ((new$Accepted = 0) or (new$AcceptDate is null))) then
        /*  LastAccepted         */
        if (new$LastAdjustment = 1) then
            new$LastAccepted := 0;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;
    end if;

    /*   ,     LastAdjustment*/
    if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 0)) or
        ((:old.Accepted = 1) and (new$Accepted = 0) and (new$AcceptDate is not null))) then

        if (new$LastAdjustment = 1) then
            new$LastAdjustment := 0;
            new$LastAccepted := 0;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;

        SELECT Max(AdjustmentNumber) INTO MaxNumber$ FROm AgreementS
        WHERE (InnerNumber = new$InnerNumber);
        /*    ,     */
        if ((new$adjustmentNumber=0) and (MaxNumber$<>0)) then
          RaiseException('EX_Agr_PrimaryAgrHasNotify');
        end if;
    end if;

-- - - - - - - - - - - - -
-- BU_20 (TR_AGREEMENTS_BU_20)
-- Create 21.05.2009
-- - - - - - - - - - - - -

  /*    -,      */
  if ((new$Client_Ref <> :old.Client_Ref) and
      (((new$Client_INN is null) and
        (:old.Client_INN is null)) or
       (new$Client_INN = :old.Client_INN)) and
      (((new$Client_INN20 is null) and
        (:old.Client_INN20 is null)) or
       (new$Client_INN20 = :old.Client_INN20)) and
      (new$Client_Name = :old.Client_Name)) then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name
      into
        new$Client_INN,
        new$Client_INN20,
        new$Client_Name
      from Organizations o
      where o.Id=new$Client_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Client_INN := NULL;
        new$Client_INN20 := NULL;
        new$Client_Name := NULL;
    END;
  END IF;

  /*    -,      */
  if ((new$Executer_Ref <> :old.Executer_Ref) and
      (((new$Executer_INN is null) and
        (:old.Executer_INN is null)) or
       (new$Executer_INN = :old.Executer_INN)) and
      (((new$Executer_INN20 is null) and
        (:old.Executer_INN20 is null)) or
       (new$Executer_INN20 = :old.Executer_INN20)) and
      (new$Executer_Name = :old.Executer_Name) and
      (((new$Executer_Status is null) and
        (:old.Executer_Status is null)) or
       (new$Executer_Status = :old.Executer_Status)) and
      (((new$Executer_Country is null) and
        (:old.Executer_Country is null)) or
       (new$Executer_Country = :old.Executer_Country)) and
      (((new$Executer_Address is null) and
        (:old.Executer_Address is null)) or
       (new$Executer_Address = :old.Executer_Address)) and
      (((new$Executer_Phone is null) and
        (:old.Executer_Phone is null)) or
       (new$Executer_Phone = :old.Executer_Phone))) then
     BEGIN
      select
        o.INN,
        o.INN20,
        o.Name,
        o.SupplierStatus,
        o.Country,
        o.Address,
        o.Phone
      into
        new$Executer_INN,
        new$Executer_INN20,
        new$Executer_Name,
        new$Executer_Status,
        new$Executer_Country,
        new$Executer_Address,
        new$Executer_Phone
      from Organizations o
      where o.Id=new$Executer_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Executer_INN := NULL;
        new$Executer_INN20 := NULL;
        new$Executer_Name := NULL;
        new$Executer_Status := NULL;
        new$Executer_Country := NULL;
        new$Executer_Address := NULL;
        new$Executer_Phone := NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_50 (TR_AGREEMENTS_BU_50)
-- Create 06.08.2010
-- - - - - - - - - - - - -

    if (new$InnerNumber is not null) then
        CurVal$ := gen_id('G_AgreementNumber', 0);
        if (CurVal$ < new$InnerNumber) then
          CurVal$ := gen_id('G_AgreementNumber', new$InnerNumber - CurVal$);
        end if;
    end if;

-- - - - - - - - - - - - -
-- BU_60 (tr_agreements_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*        ,     */
  if (:old.accepted = 1 and new$accepted = 0 and new$acceptdate is not null and new$adjustmentnumber = 0) then
    SELECT COUNT(*) INTO CNT$1
    from executiondocumentscaption
    where
    (            agreementinnernumber = new$innernumber
    and (accepted <> 0 or acceptdate is null)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_Agr_CannotReject');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_AGREEMENTS_BU_200)
-- Create 04.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$id, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (tr_agreements_bu_300)
-- Version 8.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ExecuterAccRef is not null) then
--     select count(ID)
--     into CountAcc$     from org_accounts oa
--     where oa.id = new$ExecuterAccRef and oa.Org_ref = new$Executer_Ref
--     ;
--     if (CountAcc$ = 0) then
--       RaiseException('EX_AGR_ACCORGCHECK');
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_400 (TR_AGREEMENTS_BU_400)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (((new$rnClientID <> :old.rnClientID) or (new$rnYear <> :old.rnYear) or
  (new$rnNumber <> :old.rnNumber) or (new$ReestrVersion <> :old.ReestrVersion)) and
  (new$rnClientID is not null) and (new$rnYear is not null) and (new$rnNumber is not null)) then

    rnClientID1$ := new$rnClientID;
    rnYear1$ := new$rnYear;
    rnNumber1$ := new$rnNumber;
    ReestrVersion1$ := new$ReestrVersion;
    while (LENGTH(rnClientID1$) < 11) LOOP
      rnClientID1$ := '0' || rnClientID1$;
    END LOOP;
    while (LENGTH(rnNumber1$) < 6) LOOP
      rnNumber1$ := '0' || rnNumber1$;
    END LOOP;
    if (LENGTH(ReestrVersion1$) < 2) then
      ReestrVersion1$ := '0' || ReestrVersion1$;
    END IF;
    /*  ReestrRecordNumber*/
    if (new$ReestrVersion is null) then
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$;

    else
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$ || ReestrVersion1$;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_600 (agreements_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_AGREEMENTS_BU_700)
-- Create 14.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_AGREEMENTS SET
    ID = new$ID,
    SUMMA = new$SUMMA,
    AGREEMENTDATE = new$AGREEMENTDATE,
    AGREEMENTENDDATE = new$AGREEMENTENDDATE,
    EXECUTER_REF = new$EXECUTER_REF,
    CLIENT_REF = new$CLIENT_REF,
    FACIALACC_CLS = new$FACIALACC_CLS,
    AGREEMENTTYPE = new$AGREEMENTTYPE,
    ACCEPTED = new$ACCEPTED,
    ACCEPTDATE = new$ACCEPTDATE,
    CARDADVANCEPERCENT = new$CARDADVANCEPERCENT,
    CARDADVANCE = new$CARDADVANCE,
    CLOSEDOC = new$CLOSEDOC,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    FACT = new$FACT,
    REGION = new$REGION,
    CLOSEDATE = new$CLOSEDATE,
    DELIVERYRULES = new$DELIVERYRULES,
    AGREEMENTSUMMA = new$AGREEMENTSUMMA,
    AGREEMENTFINSUMMA = new$AGREEMENTFINSUMMA,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    REESTRNUMBER = new$REESTRNUMBER,
    PAYMENTDATE = new$PAYMENTDATE,
    AGREEMENTCARDADVANCE = new$AGREEMENTCARDADVANCE,
    FINCARDADVANCE = new$FINCARDADVANCE,
    STATEORDERREF = new$STATEORDERREF,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    AGREEMENTBEGINDATE = new$AGREEMENTBEGINDATE,
    PROTOCOLNUMBER = new$PROTOCOLNUMBER,
    PROTOCOLDATE = new$PROTOCOLDATE,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXPORTDATE = new$EXPORTDATE,
    FSORGAN = new$FSORGAN,
    FSBUDGETNAME = new$FSBUDGETNAME,
    FSOFFBUDGET = new$FSOFFBUDGET,
    RNYEAR = new$RNYEAR,
    RNNUMBER = new$RNNUMBER,
    RNDATE = new$RNDATE,
    PROTOCOLNOTICE = new$PROTOCOLNOTICE,
    PROTOCOLRESULTDATE = new$PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE = new$PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE = new$PROTOCOLSALETYPE,
    NOTIFYDATE = new$NOTIFYDATE,
    EXECUTERACCREF = new$EXECUTERACCREF,
    DOCBASEDATE = new$DOCBASEDATE,
    DOCBASENOTIFYDATE = new$DOCBASENOTIFYDATE,
    DOCBASETEXT = new$DOCBASETEXT,
    DOCBASETYPE = new$DOCBASETYPE,
    DOCBASESUMMA = new$DOCBASESUMMA,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PROTOCOLREASON = new$PROTOCOLREASON,
    DOCNUMBER = new$DOCNUMBER,
    ADJUSTMENTDOCNUMBER = new$ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER = new$OLDDOCNUMBER,
    LOTMAXSUM = new$LOTMAXSUM,
    CLIENT_INN = new$CLIENT_INN,
    CLIENT_INN20 = new$CLIENT_INN20,
    CLIENT_NAME = new$CLIENT_NAME,
    EXECUTER_INN = new$EXECUTER_INN,
    EXECUTER_INN20 = new$EXECUTER_INN20,
    EXECUTER_NAME = new$EXECUTER_NAME,
    EXECUTER_STATUS = new$EXECUTER_STATUS,
    EXECUTER_COUNTRY = new$EXECUTER_COUNTRY,
    EXECUTER_ADDRESS = new$EXECUTER_ADDRESS,
    EXECUTER_PHONE = new$EXECUTER_PHONE,
    REALID = new$REALID,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    INNERNUMBER = new$INNERNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REESTRVERSION = new$REESTRVERSION,
    DOCTYPE = new$DOCTYPE,
    RNCLIENTID = new$RNCLIENTID,
    INFONUMBER = new$INFONUMBER,
    STATEORDERINNERNUMBER = new$STATEORDERINNERNUMBER,
    PROGINDEX = new$PROGINDEX,
    NOTE = new$NOTE,
    PURPORTDOC = new$PURPORTDOC,
    REESTRRECORDNUMBER = new$REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS = new$EXECUTERSTOREDPROPS,
    AUTOSANCTION = new$AUTOSANCTION,
    PURCHASECODE = new$PURCHASECODE,
    DOCUMENTNUMBER = new$DOCUMENTNUMBER,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_AGREEMENTS_AU_10)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   6.0*/
  /*      */
  /*     ,       */
  if ((new$AdjustmentNumber > 0) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update Agreements set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentNumber > 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update Agreements set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*          */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 304)or(new$ProgIndex = 314)))then
    update Estimate
    set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    (RecordIndex = new$Id);
  END IF;
  /*         */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 305) or (new$ProgIndex = 314))) then
    update paymentschedule set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    AgreementRef = new$ID and
    ProgIndex in (317, 318);

  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_AGREEMENTS_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*      */
  if ((new$ProgIndex = 305) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null
    where
    StateOrder = :old.ID;
  END IF;
  /*      */
  if ((new$ProgIndex = 314) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null,
    Agreement = null
    where
    StateOrder = :old.ID;
  END IF;
  /*     */
  if ((:old.ProgIndex = 304) and (new$AdjustmentNumber = 0) and (new$Accepted = 0) and
  (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    Agreement = null
    where
    Agreement = :old.ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_AGREEMENTS_AU_30)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$ProgIndex = 304) or (new$ProgIndex = 314)) and
  ((new$Accepted <> :old.Accepted) or
  (new$AcceptDate is not null and :old.AcceptDate is null) or
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where AgreementRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_AGREEMENTS_AU_500)
-- Create 28.04.2005
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes
                  (TableID, RecordId, DeleteDate
                  )
           VALUES (110, :OLD.ID, SYSDATE
                  );

      DELETE FROM DelRecIndexes
            WHERE (TableID = 110) AND (RecordId = new$ID);
   END IF;

END;
/
ALTER TRIGGER TR_AGREEMENTS_BU_500 ENABLE
/
-- ALTER TRIGGER TR_AGREEMENTS_BU_300
CREATE OR REPLACE TRIGGER TR_AGREEMENTS_IU
  INSTEAD OF UPDATE
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  new$ID AGREEMENTS.ID%TYPE := :NEW.ID;
  new$SUMMA AGREEMENTS.SUMMA%TYPE := :NEW.SUMMA;
  new$AGREEMENTDATE AGREEMENTS.AGREEMENTDATE%TYPE := :NEW.AGREEMENTDATE;
  new$AGREEMENTENDDATE AGREEMENTS.AGREEMENTENDDATE%TYPE := :NEW.AGREEMENTENDDATE;
  new$EXECUTER_REF AGREEMENTS.EXECUTER_REF%TYPE := :NEW.EXECUTER_REF;
  new$CLIENT_REF AGREEMENTS.CLIENT_REF%TYPE := :NEW.CLIENT_REF;
  new$FACIALACC_CLS AGREEMENTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$AGREEMENTTYPE AGREEMENTS.AGREEMENTTYPE%TYPE := :NEW.AGREEMENTTYPE;
  new$ACCEPTED AGREEMENTS.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$ACCEPTDATE AGREEMENTS.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$CARDADVANCEPERCENT AGREEMENTS.CARDADVANCEPERCENT%TYPE := :NEW.CARDADVANCEPERCENT;
  new$CARDADVANCE AGREEMENTS.CARDADVANCE%TYPE := :NEW.CARDADVANCE;
  new$CLOSEDOC AGREEMENTS.CLOSEDOC%TYPE := :NEW.CLOSEDOC;
  new$CREATERUSER AGREEMENTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE AGREEMENTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE AGREEMENTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER AGREEMENTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF AGREEMENTS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$LASTADJUSTMENT AGREEMENTS.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED AGREEMENTS.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$FACT AGREEMENTS.FACT%TYPE := :NEW.FACT;
  new$REGION AGREEMENTS.REGION%TYPE := :NEW.REGION;
  new$CLOSEDATE AGREEMENTS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$DELIVERYRULES AGREEMENTS.DELIVERYRULES%TYPE := :NEW.DELIVERYRULES;
  new$AGREEMENTSUMMA AGREEMENTS.AGREEMENTSUMMA%TYPE := :NEW.AGREEMENTSUMMA;
  new$AGREEMENTFINSUMMA AGREEMENTS.AGREEMENTFINSUMMA%TYPE := :NEW.AGREEMENTFINSUMMA;
  new$ADJUSTMENTREF AGREEMENTS.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$REESTRNUMBER AGREEMENTS.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$PAYMENTDATE AGREEMENTS.PAYMENTDATE%TYPE := :NEW.PAYMENTDATE;
  new$AGREEMENTCARDADVANCE AGREEMENTS.AGREEMENTCARDADVANCE%TYPE := :NEW.AGREEMENTCARDADVANCE;
  new$FINCARDADVANCE AGREEMENTS.FINCARDADVANCE%TYPE := :NEW.FINCARDADVANCE;
  new$STATEORDERREF AGREEMENTS.STATEORDERREF%TYPE := :NEW.STATEORDERREF;
  new$REJECTCLS AGREEMENTS.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS AGREEMENTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID AGREEMENTS.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID AGREEMENTS.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$AGREEMENTBEGINDATE AGREEMENTS.AGREEMENTBEGINDATE%TYPE := :NEW.AGREEMENTBEGINDATE;
  new$PROTOCOLNUMBER AGREEMENTS.PROTOCOLNUMBER%TYPE := :NEW.PROTOCOLNUMBER;
  new$PROTOCOLDATE AGREEMENTS.PROTOCOLDATE%TYPE := :NEW.PROTOCOLDATE;
  new$REVIEWNOTE AGREEMENTS.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF AGREEMENTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION AGREEMENTS.RVERSION%TYPE := :NEW.RVERSION;
  new$EXPORTDATE AGREEMENTS.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$FSORGAN AGREEMENTS.FSORGAN%TYPE := :NEW.FSORGAN;
  new$FSBUDGETNAME AGREEMENTS.FSBUDGETNAME%TYPE := :NEW.FSBUDGETNAME;
  new$FSOFFBUDGET AGREEMENTS.FSOFFBUDGET%TYPE := :NEW.FSOFFBUDGET;
  new$RNYEAR AGREEMENTS.RNYEAR%TYPE := :NEW.RNYEAR;
  new$RNNUMBER AGREEMENTS.RNNUMBER%TYPE := :NEW.RNNUMBER;
  new$RNDATE AGREEMENTS.RNDATE%TYPE := :NEW.RNDATE;
  new$PROTOCOLNOTICE AGREEMENTS.PROTOCOLNOTICE%TYPE := :NEW.PROTOCOLNOTICE;
  new$PROTOCOLRESULTDATE AGREEMENTS.PROTOCOLRESULTDATE%TYPE := :NEW.PROTOCOLRESULTDATE;
  new$PROTOCOLDOCTYPE AGREEMENTS.PROTOCOLDOCTYPE%TYPE := :NEW.PROTOCOLDOCTYPE;
  new$PROTOCOLSALETYPE AGREEMENTS.PROTOCOLSALETYPE%TYPE := :NEW.PROTOCOLSALETYPE;
  new$NOTIFYDATE AGREEMENTS.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$EXECUTERACCREF AGREEMENTS.EXECUTERACCREF%TYPE := :NEW.EXECUTERACCREF;
  new$DOCBASEDATE AGREEMENTS.DOCBASEDATE%TYPE := :NEW.DOCBASEDATE;
  new$DOCBASENOTIFYDATE AGREEMENTS.DOCBASENOTIFYDATE%TYPE := :NEW.DOCBASENOTIFYDATE;
  new$DOCBASETEXT AGREEMENTS.DOCBASETEXT%TYPE := :NEW.DOCBASETEXT;
  new$DOCBASETYPE AGREEMENTS.DOCBASETYPE%TYPE := :NEW.DOCBASETYPE;
  new$DOCBASESUMMA AGREEMENTS.DOCBASESUMMA%TYPE := :NEW.DOCBASESUMMA;
  new$UNKNOWNAMOUNT AGREEMENTS.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PROTOCOLREASON AGREEMENTS.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$DOCNUMBER AGREEMENTS.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$ADJUSTMENTDOCNUMBER AGREEMENTS.ADJUSTMENTDOCNUMBER%TYPE := :NEW.ADJUSTMENTDOCNUMBER;
  new$OLDDOCNUMBER AGREEMENTS.OLDDOCNUMBER%TYPE := :NEW.OLDDOCNUMBER;
  new$LOTMAXSUM AGREEMENTS.LOTMAXSUM%TYPE := :NEW.LOTMAXSUM;
  new$CLIENT_INN AGREEMENTS.CLIENT_INN%TYPE := :NEW.CLIENT_INN;
  new$CLIENT_INN20 AGREEMENTS.CLIENT_INN20%TYPE := :NEW.CLIENT_INN20;
  new$CLIENT_NAME AGREEMENTS.CLIENT_NAME%TYPE := :NEW.CLIENT_NAME;
  new$EXECUTER_INN AGREEMENTS.EXECUTER_INN%TYPE := :NEW.EXECUTER_INN;
  new$EXECUTER_INN20 AGREEMENTS.EXECUTER_INN20%TYPE := :NEW.EXECUTER_INN20;
  new$EXECUTER_NAME AGREEMENTS.EXECUTER_NAME%TYPE := :NEW.EXECUTER_NAME;
  new$EXECUTER_STATUS AGREEMENTS.EXECUTER_STATUS%TYPE := :NEW.EXECUTER_STATUS;
  new$EXECUTER_COUNTRY AGREEMENTS.EXECUTER_COUNTRY%TYPE := :NEW.EXECUTER_COUNTRY;
  new$EXECUTER_ADDRESS AGREEMENTS.EXECUTER_ADDRESS%TYPE := :NEW.EXECUTER_ADDRESS;
  new$EXECUTER_PHONE AGREEMENTS.EXECUTER_PHONE%TYPE := :NEW.EXECUTER_PHONE;
  new$REALID AGREEMENTS.REALID%TYPE := :NEW.REALID;
  new$ADJUSTMENTNUMBER AGREEMENTS.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$INNERNUMBER AGREEMENTS.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$SENDERIDKEY AGREEMENTS.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY AGREEMENTS.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REESTRVERSION AGREEMENTS.REESTRVERSION%TYPE := :NEW.REESTRVERSION;
  new$DOCTYPE AGREEMENTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$RNCLIENTID AGREEMENTS.RNCLIENTID%TYPE := :NEW.RNCLIENTID;
  new$INFONUMBER AGREEMENTS.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$STATEORDERINNERNUMBER AGREEMENTS.STATEORDERINNERNUMBER%TYPE := :NEW.STATEORDERINNERNUMBER;
  new$PROGINDEX AGREEMENTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE AGREEMENTS.NOTE%TYPE := :NEW.NOTE;
  new$PURPORTDOC AGREEMENTS.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$REESTRRECORDNUMBER AGREEMENTS.REESTRRECORDNUMBER%TYPE := :NEW.REESTRRECORDNUMBER;
  new$EXECUTERSTOREDPROPS AGREEMENTS.EXECUTERSTOREDPROPS%TYPE := :NEW.EXECUTERSTOREDPROPS;
  new$AUTOSANCTION AGREEMENTS.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$PURCHASECODE AGREEMENTS.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$DOCUMENTNUMBER AGREEMENTS.DOCUMENTNUMBER%TYPE := :NEW.DOCUMENTNUMBER;
  new$REJECTCAUSE AGREEMENTS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  MaxNumber$ NUMBER (10);
  CurVal$ NUMBER (10);
  CNT$1 NUMBER(10);
  DetCount$ NUMBER(10);
  CountAcc$ NUMBER(10);
  rnClientID1$ VARCHAR2(15);
  rnYear1$ VARCHAR2(15);
  rnNumber1$ VARCHAR2(15);
  ReestrVersion1$ VARCHAR2(15);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_AGREEMENTS_BU)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   3.1*/
  /*    -*/
  if (new$CardAdvancePercent is null) then
    new$CardAdvancePercent := 0;
  END IF;
  if (new$CardAdvance is null) then
    new$CardAdvance := 0;
  END IF;
  if (new$AgreementCardAdvance is null) then
    new$AgreementCardAdvance := 0;
  END IF;
  if (new$FinCardAdvance is null) then
    new$FinCardAdvance := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$AgreementSumma is null) then
    new$AgreementSumma := 0;
  END IF;
  if (new$AgreementFinSumma is null) then
    new$AgreementFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$Region is null) then
    new$Region := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$client_ref is null) then
    new$client_ref := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount$ from AgreementSteps where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      select count(ID)       into DetCount$ from Estimate where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*         -   InnerNumber*/
  if (((new$ProgIndex = 305) or (new$ProgIndex = 304) or (new$ProgIndex = 314)) and (new$InnerNumber is null)) then
    new$InnerNumber := GEN_ID('G_AgreementNumber',1);
  END IF;
  /*   */
  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  /*    .  */

  new$stateorderinnernumber := null;
  if (new$stateorderref is not null) then
    BEGIN
      select
      innernumber
      into new$stateorderinnernumber     from agreements
      where
      id = new$stateorderref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_3 (TR_AGREEMENTS_BU_3)
-- Create 03.12.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*            */
   new$AdjustmentRef := :OLD.AdjustmentRef;

-- - - - - - - - - - - - -
-- BU_5 (TR_AGREEMENTS_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_AGREEMENTS_BU_10)
-- Last update 08.02.2010
-- - - - - - - - - - - - -

/*   5.0*/
    /* ,      ,   */
    if ((new$InnerNumber <> :old.InnerNumber) or
        (new$AdjustmentNumber <> :old.AdjustmentNumber) or
        (new$AgreementType <> :old.AgreementType)) then
        RaiseException('EX_AGR_ChangeInnerNums');
    end if;

    /*    !!!*/
    if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and
        ((new$Accepted = 1) or (new$AcceptDate is null))) then
        RaiseException('EX_RollbackCancel');
    end if;

    /*   ,     LastAccepted*/
    if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) or
        ((:old.Accepted = 0) and (new$Accepted = 1) and (new$AcceptDate is not null))) then
        /*  LastAccepted         */
        if (new$LastAdjustment = 1) then
            new$LastAccepted := 1;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;
    end if;

    /*    ,     LastAccepted*/
    if (((:old.AcceptDate is not null) and (:old.Accepted = 1)) and
        ((new$Accepted = 0) or (new$AcceptDate is null))) then
        /*  LastAccepted         */
        if (new$LastAdjustment = 1) then
            new$LastAccepted := 0;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;
    end if;

    /*   ,     LastAdjustment*/
    if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 0)) or
        ((:old.Accepted = 1) and (new$Accepted = 0) and (new$AcceptDate is not null))) then

        if (new$LastAdjustment = 1) then
            new$LastAdjustment := 0;
            new$LastAccepted := 0;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;

        SELECT Max(AdjustmentNumber) INTO MaxNumber$ FROm AgreementS
        WHERE (InnerNumber = new$InnerNumber);
        /*    ,     */
        if ((new$adjustmentNumber=0) and (MaxNumber$<>0)) then
          RaiseException('EX_Agr_PrimaryAgrHasNotify');
        end if;
    end if;

-- - - - - - - - - - - - -
-- BU_20 (TR_AGREEMENTS_BU_20)
-- Create 21.05.2009
-- - - - - - - - - - - - -

  /*    -,      */
  if ((new$Client_Ref <> :old.Client_Ref) and
      (((new$Client_INN is null) and
        (:old.Client_INN is null)) or
       (new$Client_INN = :old.Client_INN)) and
      (((new$Client_INN20 is null) and
        (:old.Client_INN20 is null)) or
       (new$Client_INN20 = :old.Client_INN20)) and
      (new$Client_Name = :old.Client_Name)) then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name
      into
        new$Client_INN,
        new$Client_INN20,
        new$Client_Name
      from Organizations o
      where o.Id=new$Client_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Client_INN := NULL;
        new$Client_INN20 := NULL;
        new$Client_Name := NULL;
    END;
  END IF;

  /*    -,      */
  if ((new$Executer_Ref <> :old.Executer_Ref) and
      (((new$Executer_INN is null) and
        (:old.Executer_INN is null)) or
       (new$Executer_INN = :old.Executer_INN)) and
      (((new$Executer_INN20 is null) and
        (:old.Executer_INN20 is null)) or
       (new$Executer_INN20 = :old.Executer_INN20)) and
      (new$Executer_Name = :old.Executer_Name) and
      (((new$Executer_Status is null) and
        (:old.Executer_Status is null)) or
       (new$Executer_Status = :old.Executer_Status)) and
      (((new$Executer_Country is null) and
        (:old.Executer_Country is null)) or
       (new$Executer_Country = :old.Executer_Country)) and
      (((new$Executer_Address is null) and
        (:old.Executer_Address is null)) or
       (new$Executer_Address = :old.Executer_Address)) and
      (((new$Executer_Phone is null) and
        (:old.Executer_Phone is null)) or
       (new$Executer_Phone = :old.Executer_Phone))) then
     BEGIN
      select
        o.INN,
        o.INN20,
        o.Name,
        o.SupplierStatus,
        o.Country,
        o.Address,
        o.Phone
      into
        new$Executer_INN,
        new$Executer_INN20,
        new$Executer_Name,
        new$Executer_Status,
        new$Executer_Country,
        new$Executer_Address,
        new$Executer_Phone
      from Organizations o
      where o.Id=new$Executer_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Executer_INN := NULL;
        new$Executer_INN20 := NULL;
        new$Executer_Name := NULL;
        new$Executer_Status := NULL;
        new$Executer_Country := NULL;
        new$Executer_Address := NULL;
        new$Executer_Phone := NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_50 (TR_AGREEMENTS_BU_50)
-- Create 06.08.2010
-- - - - - - - - - - - - -

    if (new$InnerNumber is not null) then
        CurVal$ := gen_id('G_AgreementNumber', 0);
        if (CurVal$ < new$InnerNumber) then
          CurVal$ := gen_id('G_AgreementNumber', new$InnerNumber - CurVal$);
        end if;
    end if;

-- - - - - - - - - - - - -
-- BU_60 (tr_agreements_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*        ,     */
  if (:old.accepted = 1 and new$accepted = 0 and new$acceptdate is not null and new$adjustmentnumber = 0) then
    SELECT COUNT(*) INTO CNT$1
    from executiondocumentscaption
    where
    (            agreementinnernumber = new$innernumber
    and (accepted <> 0 or acceptdate is null)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_Agr_CannotReject');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_AGREEMENTS_BU_200)
-- Create 04.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$id, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (tr_agreements_bu_300)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$ExecuterAccRef is not null) then
    select count(ID)
    into CountAcc$     from org_accounts oa
    where oa.id = new$ExecuterAccRef and oa.Org_ref = new$Executer_Ref
    ;
    if (CountAcc$ = 0) then
      RaiseException('EX_AGR_ACCORGCHECK');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (TR_AGREEMENTS_BU_400)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (((new$rnClientID <> :old.rnClientID) or (new$rnYear <> :old.rnYear) or
  (new$rnNumber <> :old.rnNumber) or (new$ReestrVersion <> :old.ReestrVersion)) and
  (new$rnClientID is not null) and (new$rnYear is not null) and (new$rnNumber is not null)) then

    rnClientID1$ := new$rnClientID;
    rnYear1$ := new$rnYear;
    rnNumber1$ := new$rnNumber;
    ReestrVersion1$ := new$ReestrVersion;
    while (LENGTH(rnClientID1$) < 11) LOOP
      rnClientID1$ := '0' || rnClientID1$;
    END LOOP;
    while (LENGTH(rnNumber1$) < 6) LOOP
      rnNumber1$ := '0' || rnNumber1$;
    END LOOP;
    if (LENGTH(ReestrVersion1$) < 2) then
      ReestrVersion1$ := '0' || ReestrVersion1$;
    END IF;
    /*  ReestrRecordNumber*/
    if (new$ReestrVersion is null) then
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$;

    else
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$ || ReestrVersion1$;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_600 (agreements_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_AGREEMENTS_BU_700)
-- Create 14.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_AGREEMENTS SET
    ID = new$ID,
    SUMMA = new$SUMMA,
    AGREEMENTDATE = new$AGREEMENTDATE,
    AGREEMENTENDDATE = new$AGREEMENTENDDATE,
    EXECUTER_REF = new$EXECUTER_REF,
    CLIENT_REF = new$CLIENT_REF,
    FACIALACC_CLS = new$FACIALACC_CLS,
    AGREEMENTTYPE = new$AGREEMENTTYPE,
    ACCEPTED = new$ACCEPTED,
    ACCEPTDATE = new$ACCEPTDATE,
    CARDADVANCEPERCENT = new$CARDADVANCEPERCENT,
    CARDADVANCE = new$CARDADVANCE,
    CLOSEDOC = new$CLOSEDOC,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    FACT = new$FACT,
    REGION = new$REGION,
    CLOSEDATE = new$CLOSEDATE,
    DELIVERYRULES = new$DELIVERYRULES,
    AGREEMENTSUMMA = new$AGREEMENTSUMMA,
    AGREEMENTFINSUMMA = new$AGREEMENTFINSUMMA,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    REESTRNUMBER = new$REESTRNUMBER,
    PAYMENTDATE = new$PAYMENTDATE,
    AGREEMENTCARDADVANCE = new$AGREEMENTCARDADVANCE,
    FINCARDADVANCE = new$FINCARDADVANCE,
    STATEORDERREF = new$STATEORDERREF,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    AGREEMENTBEGINDATE = new$AGREEMENTBEGINDATE,
    PROTOCOLNUMBER = new$PROTOCOLNUMBER,
    PROTOCOLDATE = new$PROTOCOLDATE,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXPORTDATE = new$EXPORTDATE,
    FSORGAN = new$FSORGAN,
    FSBUDGETNAME = new$FSBUDGETNAME,
    FSOFFBUDGET = new$FSOFFBUDGET,
    RNYEAR = new$RNYEAR,
    RNNUMBER = new$RNNUMBER,
    RNDATE = new$RNDATE,
    PROTOCOLNOTICE = new$PROTOCOLNOTICE,
    PROTOCOLRESULTDATE = new$PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE = new$PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE = new$PROTOCOLSALETYPE,
    NOTIFYDATE = new$NOTIFYDATE,
    EXECUTERACCREF = new$EXECUTERACCREF,
    DOCBASEDATE = new$DOCBASEDATE,
    DOCBASENOTIFYDATE = new$DOCBASENOTIFYDATE,
    DOCBASETEXT = new$DOCBASETEXT,
    DOCBASETYPE = new$DOCBASETYPE,
    DOCBASESUMMA = new$DOCBASESUMMA,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PROTOCOLREASON = new$PROTOCOLREASON,
    DOCNUMBER = new$DOCNUMBER,
    ADJUSTMENTDOCNUMBER = new$ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER = new$OLDDOCNUMBER,
    LOTMAXSUM = new$LOTMAXSUM,
    CLIENT_INN = new$CLIENT_INN,
    CLIENT_INN20 = new$CLIENT_INN20,
    CLIENT_NAME = new$CLIENT_NAME,
    EXECUTER_INN = new$EXECUTER_INN,
    EXECUTER_INN20 = new$EXECUTER_INN20,
    EXECUTER_NAME = new$EXECUTER_NAME,
    EXECUTER_STATUS = new$EXECUTER_STATUS,
    EXECUTER_COUNTRY = new$EXECUTER_COUNTRY,
    EXECUTER_ADDRESS = new$EXECUTER_ADDRESS,
    EXECUTER_PHONE = new$EXECUTER_PHONE,
    REALID = new$REALID,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    INNERNUMBER = new$INNERNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REESTRVERSION = new$REESTRVERSION,
    DOCTYPE = new$DOCTYPE,
    RNCLIENTID = new$RNCLIENTID,
    INFONUMBER = new$INFONUMBER,
    STATEORDERINNERNUMBER = new$STATEORDERINNERNUMBER,
    PROGINDEX = new$PROGINDEX,
    NOTE = new$NOTE,
    PURPORTDOC = new$PURPORTDOC,
    REESTRRECORDNUMBER = new$REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS = new$EXECUTERSTOREDPROPS,
    AUTOSANCTION = new$AUTOSANCTION,
    PURCHASECODE = new$PURCHASECODE,
    DOCUMENTNUMBER = new$DOCUMENTNUMBER,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_AGREEMENTS_AU_10)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   6.0*/
  /*      */
  /*     ,       */
  if ((new$AdjustmentNumber > 0) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update Agreements set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentNumber > 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update Agreements set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*          */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 304)or(new$ProgIndex = 314)))then
    update Estimate
    set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    (RecordIndex = new$Id);
  END IF;
  /*         */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 305) or (new$ProgIndex = 314))) then
    update paymentschedule set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    AgreementRef = new$ID and
    ProgIndex in (317, 318);

  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_AGREEMENTS_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*      */
  if ((new$ProgIndex = 305) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null
    where
    StateOrder = :old.ID;
  END IF;
  /*      */
  if ((new$ProgIndex = 314) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null,
    Agreement = null
    where
    StateOrder = :old.ID;
  END IF;
  /*     */
  if ((:old.ProgIndex = 304) and (new$AdjustmentNumber = 0) and (new$Accepted = 0) and
  (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    Agreement = null
    where
    Agreement = :old.ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_AGREEMENTS_AU_30)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$ProgIndex = 304) or (new$ProgIndex = 314)) and
  ((new$Accepted <> :old.Accepted) or
  (new$AcceptDate is not null and :old.AcceptDate is null) or
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where AgreementRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_AGREEMENTS_AU_500)
-- Create 28.04.2005
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes
                  (TableID, RecordId, DeleteDate
                  )
           VALUES (110, :OLD.ID, SYSDATE
                  );

      DELETE FROM DelRecIndexes
            WHERE (TableID = 110) AND (RecordId = new$ID);
   END IF;

END;
/
commit work 
/
ALTER TRIGGER TR_EXECDOCCAPTION_BU_500 DISABLE
/
ALTER TABLE TB_EXECUTIONDOCUMENTSCAPTION ADD (
  TempRejectCause VARCHAR2(255)
)
/

CREATE OR REPLACE VIEW EXECUTIONDOCUMENTSCAPTION (
  ID,
  DOCTYPE,
  DOCUMENTDATE,
  ACCEPTDATE,
  SUMMA,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  BUDGETREF,
  STEPNUMBER,
  FACIALACC_CLS,
  RECIPIENT_REF,
  REGISTRATIONTYPE,
  REESTRNUMBER,
  AGREEMENTINNERNUMBER,
  REJECTCLS,
  REJECTCAUSE,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  REVIEWNOTE,
  DOCSTATEREF,
  RVERSION,
  EXECDOCFINSUMMA,
  FACT,
  DOCNUMBER,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  REALID,
  INNERNUMBER,
  ADJUSTMENTREF,
  ADJUSTMENTNUMBER,
  ACCEPTED,
  LASTACCEPTED,
  LASTADJUSTMENT,
  AGREEMENTREF,
  NOTE,
  SUPPLIERSTOREDPROPS,
  SUPPLIER_REF,
  SUPPLIERACC_REF,
  TEMPREJECTCAUSE)
AS
  SELECT
    ID,
    DOCTYPE,
    DOCUMENTDATE,
    ACCEPTDATE,
    SUMMA,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    STEPNUMBER,
    FACIALACC_CLS,
    RECIPIENT_REF,
    REGISTRATIONTYPE,
    REESTRNUMBER,
    AGREEMENTINNERNUMBER,
    REJECTCLS,
    REJECTCAUSE,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXECDOCFINSUMMA,
    FACT,
    DOCNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REALID,
    INNERNUMBER,
    ADJUSTMENTREF,
    ADJUSTMENTNUMBER,
    ACCEPTED,
    LASTACCEPTED,
    LASTADJUSTMENT,
    AGREEMENTREF,
    NOTE,
    SUPPLIERSTOREDPROPS,
    SUPPLIER_REF,
    SUPPLIERACC_REF,
    TEMPREJECTCAUSE
  FROM TB_EXECUTIONDOCUMENTSCAPTION
/

CREATE OR REPLACE TRIGGER TR_EXECUTIONDOCUMENTSCAPTIO_ID
  INSTEAD OF DELETE
  ON EXECUTIONDOCUMENTSCAPTION
  FOR EACH ROW
DECLARE
  quant$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_DOCEXECCAPTION_BD)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  select count(ID)   into quant$ from executiondocumentscaption 
  where AdjustmentRef = :old.ID
  ;
  if (quant$  = 0) then
    delete from ExecutionDocumentsDetail where (RecordIndex = :old.ID);
    delete from paymentschedule where (ExecutionRef = :old.ID)and(ProgIndex=308);
      
  else
    RaiseException('ex_agr_cantdeladjustmented');
  END IF;

-- - - - - - - - - - - - -
-- BD_10 (TR_DocExecCaption_BD_10)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*   LastAdjustment     */
  if ((:old.AdjustmentRef is not null) and (:old.LastAdjustment = 1)) then
    update ExecutionDocumentsCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;
  /*   LastAccepted     */    
  if ((:old.AdjustmentRef is not null) and (:old.LastAccepted = 1)) then
    update ExecutionDocumentsCaption set
    LastAccepted = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_EXECUTIONDOCUMENTSCAPTION
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_10 (TR_ExecDocCaption_AD_10)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*   LastAdjustment     */
  if ((:old.AdjustmentRef is not null) and (:old.LastAdjustment = 1)) then
    update ExecutionDocumentsCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;
  /*   LastAccepted     */    
  if ((:old.AdjustmentRef is not null) and (:old.LastAccepted = 1)) then
    update ExecutionDocumentsCaption set
    LastAccepted = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AD_200 (TR_EXECDOCCAPTION_AD_200)
-- Create 04.10.2004
-- - - - - - - - - - - - -

  /*        */
  delete from StateJumpHistory where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_EXECDOCCAPTION_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordId, DeleteDate, SUMMA) values (114, :old.ID, SYSDATE, :old.SUMMA);

END;
/

CREATE OR REPLACE TRIGGER TR_EXECUTIONDOCUMENTSCAPTIO_II
  INSTEAD OF INSERT
  ON EXECUTIONDOCUMENTSCAPTION
  FOR EACH ROW
DECLARE
  new$ID EXECUTIONDOCUMENTSCAPTION.ID%TYPE := :NEW.ID;
  new$DOCTYPE EXECUTIONDOCUMENTSCAPTION.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$DOCUMENTDATE EXECUTIONDOCUMENTSCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE EXECUTIONDOCUMENTSCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SUMMA EXECUTIONDOCUMENTSCAPTION.SUMMA%TYPE := :NEW.SUMMA;
  new$CREATERUSER EXECUTIONDOCUMENTSCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE EXECUTIONDOCUMENTSCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE EXECUTIONDOCUMENTSCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER EXECUTIONDOCUMENTSCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF EXECUTIONDOCUMENTSCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$STEPNUMBER EXECUTIONDOCUMENTSCAPTION.STEPNUMBER%TYPE := :NEW.STEPNUMBER;
  new$FACIALACC_CLS EXECUTIONDOCUMENTSCAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$RECIPIENT_REF EXECUTIONDOCUMENTSCAPTION.RECIPIENT_REF%TYPE := :NEW.RECIPIENT_REF;
  new$REGISTRATIONTYPE EXECUTIONDOCUMENTSCAPTION.REGISTRATIONTYPE%TYPE := :NEW.REGISTRATIONTYPE;
  new$REESTRNUMBER EXECUTIONDOCUMENTSCAPTION.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$AGREEMENTINNERNUMBER EXECUTIONDOCUMENTSCAPTION.AGREEMENTINNERNUMBER%TYPE := :NEW.AGREEMENTINNERNUMBER;
  new$REJECTCLS EXECUTIONDOCUMENTSCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTCAUSE EXECUTIONDOCUMENTSCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CRYPTOSTATUS EXECUTIONDOCUMENTSCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID EXECUTIONDOCUMENTSCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID EXECUTIONDOCUMENTSCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REVIEWNOTE EXECUTIONDOCUMENTSCAPTION.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF EXECUTIONDOCUMENTSCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION EXECUTIONDOCUMENTSCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$EXECDOCFINSUMMA EXECUTIONDOCUMENTSCAPTION.EXECDOCFINSUMMA%TYPE := :NEW.EXECDOCFINSUMMA;
  new$FACT EXECUTIONDOCUMENTSCAPTION.FACT%TYPE := :NEW.FACT;
  new$DOCNUMBER EXECUTIONDOCUMENTSCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SENDERIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REALID EXECUTIONDOCUMENTSCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER EXECUTIONDOCUMENTSCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTREF EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ADJUSTMENTNUMBER EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$ACCEPTED EXECUTIONDOCUMENTSCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED EXECUTIONDOCUMENTSCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$LASTADJUSTMENT EXECUTIONDOCUMENTSCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$AGREEMENTREF EXECUTIONDOCUMENTSCAPTION.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$NOTE EXECUTIONDOCUMENTSCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$SUPPLIERSTOREDPROPS EXECUTIONDOCUMENTSCAPTION.SUPPLIERSTOREDPROPS%TYPE := :NEW.SUPPLIERSTOREDPROPS;
  new$SUPPLIER_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIER_REF%TYPE := :NEW.SUPPLIER_REF;
  new$SUPPLIERACC_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIERACC_REF%TYPE := :NEW.SUPPLIERACC_REF;
  new$TEMPREJECTCAUSE EXECUTIONDOCUMENTSCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  Tmp$ NUMBER(10);
  AdjID$ NUMBER(10);
  AdjDocNum$ VARCHAR2(50);
  agr_accepted$ NUMBER(10);
  agr_acceptdate$ NUMBER(10);
  PreviousInner$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ExecDoccaption_BI)
-- Version 11.20.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$DocType is null) then 
    new$DocType := 0;
  END IF;
  if (new$Summa is null) then 
    new$Summa := 0;
  END IF;
  if (new$ExecDocFinSumma is null) then 
    new$ExecDocFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$RegistrationType is null) then 
    new$RegistrationType := 0;
  END IF;
  if (new$Fact is null) then 
    new$Fact := 0;
  END IF;
  if (new$Accepted is null) then 
    new$Accepted := 1;
  END IF;
  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    BEGIN
      select fa.BudgetRef
      into new$BudgetRef     from FacialAcc_Cls fa
      where fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then 
    GetIntConst(-1,3,new$BudgetRef);
  END IF;
  if (new$Supplier_Ref is null and new$SupplierAcc_Ref is not null) then
    BEGIN
      select oa.Org_Ref
      into new$Supplier_Ref   from Org_Accounts oa
      where oa.id = new$SupplierAcc_Ref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,     ,      */
  if (new$AdjustmentRef is null) then
    new$InnerNumber := GEN_ID('g_ExecDocNumber',1);
      
  else
    BEGIN
      /*          */
      select
      InnerNumber 
      into PreviousInner$     from ExecutionDocumentsCaption
      where ID = new$AdjustmentRef and LastAccepted = 1 and LastAdjustment = 1
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (PreviousInner$ is null) then
      RaiseException('EX_ExecDoc_NotFindInner');
    END IF;
    new$InnerNumber := PreviousInner$;
      
  END IF;
  /*      id */  
  new$agreementinnernumber := null;
  if (new$agreementref is not null) then
    BEGIN
      select
      innernumber
      into new$agreementinnernumber     from agreements
      where
      id = new$agreementref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_EXECDOCCAPTION_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;
          
    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_EXECDOCCAPTION_BI_10)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*    .*/
  if (new$InnerNumber is null) then
    RaiseException('EX_AGR_InnerNumsIsNull');
  END IF;

  /*    */
  select max(AdjustmentNumber)
  into Tmp$     from ExecutionDocumentsCaption
  where (InnerNumber = new$InnerNumber)
  ;
  /*      ,   0*/
  if (Tmp$ is null) then
    new$AdjustmentNumber := 0;
        
  else
    new$AdjustmentNumber := Tmp$ + 1;
  END IF;
  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;
        
  else
    new$LastAdjustment := 1;
  END IF;
  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then
    new$LastAccepted := 1;
        
  else
    new$LastAccepted := 0;
  END IF;
  /*    */
  if (new$AdjustmentRef is not null) then
    /*      -    */
    select count(ID), max(ID), max(DocNumber)
    into Tmp$, AdjID$, AdjDocNum$       from ExecutionDocumentsCaption
    where (InnerNumber = new$InnerNumber) and (LastAccepted = 1)
    ;
    /*   ,  */
    if (Tmp$ <> 1) then
      RaiseException('EX_ExecDoc_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID)
    into Tmp$       from ExecutionDocumentsCaption
    where (InnerNumber = new$InnerNumber) and (AcceptDate is null)
    ;
    if (Tmp$ > 0) then
      RaiseException('EX_ExecDoc_AdjustDuplicate');
    END IF;
    /* ,    ,    */      
    new$AdjustmentRef := AdjID$;
        
  else /*     */
    /*       (    )*/      
    new$AdjustmentRef := null;
  END IF;

-- - - - - - - - - - - - -
-- BI_40 (tr_execdoccaption_bi_40)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*       */
  if (new$senderId is null) then 
    new$senderIdKey := -1;
      
  else 
    new$senderIdKey := new$senderId;
  END IF;
  if (new$SenderRecordID is null)then
    new$SenderRecordIDKey := new$ID;
      
  else 
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_60 (tr_execdoccaption_bi_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$agreementinnernumber is not null) then
    BEGIN
      /*        , .. 
             ,    ,   
            ,     */
      select accepted, acceptdate     into
      agr_accepted$, agr_acceptdate$ from agreements
      where
      innernumber = new$agreementinnernumber and adjustmentnumber = 0
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*        */
    if (new$acceptdate is null and agr_accepted$ = 0 and agr_acceptdate$ is not null) then
      RaiseException('EX_Agr_Rejected');
    END IF;
    /*        */
    if (new$accepted = 1 and new$acceptdate is not null and
    (agr_accepted$ = 0 or agr_acceptdate$ is null)) then
      RaiseException('EX_Agr_NotAccepted');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_EXECDOCCAPTION_BI_500)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_EXECUTIONDOCUMENTSCAPTION (
    ID,
    DOCTYPE,
    DOCUMENTDATE,
    ACCEPTDATE,
    SUMMA,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    STEPNUMBER,
    FACIALACC_CLS,
    RECIPIENT_REF,
    REGISTRATIONTYPE,
    REESTRNUMBER,
    AGREEMENTINNERNUMBER,
    REJECTCLS,
    REJECTCAUSE,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXECDOCFINSUMMA,
    FACT,
    DOCNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REALID,
    INNERNUMBER,
    ADJUSTMENTREF,
    ADJUSTMENTNUMBER,
    ACCEPTED,
    LASTACCEPTED,
    LASTADJUSTMENT,
    AGREEMENTREF,
    NOTE,
    SUPPLIERSTOREDPROPS,
    SUPPLIER_REF,
    SUPPLIERACC_REF,
    TEMPREJECTCAUSE
  ) VALUES (
    new$ID,
    new$DOCTYPE,
    new$DOCUMENTDATE,
    new$ACCEPTDATE,
    new$SUMMA,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$STEPNUMBER,
    new$FACIALACC_CLS,
    new$RECIPIENT_REF,
    new$REGISTRATIONTYPE,
    new$REESTRNUMBER,
    new$AGREEMENTINNERNUMBER,
    new$REJECTCLS,
    new$REJECTCAUSE,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$REVIEWNOTE,
    new$DOCSTATEREF,
    new$RVERSION,
    new$EXECDOCFINSUMMA,
    new$FACT,
    new$DOCNUMBER,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$REALID,
    new$INNERNUMBER,
    new$ADJUSTMENTREF,
    new$ADJUSTMENTNUMBER,
    new$ACCEPTED,
    new$LASTACCEPTED,
    new$LASTADJUSTMENT,
    new$AGREEMENTREF,
    new$NOTE,
    new$SUPPLIERSTOREDPROPS,
    new$SUPPLIER_REF,
    new$SUPPLIERACC_REF,
    new$TEMPREJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_0 (TR_ExecDocCaption_AI)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*       */
  /*     ,       */
  if ((new$AdjustmentRef is not null) and (new$LastAdjustment = 1)) then
    update ExecutionDocuMENTSCaption set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);        
    if (new$LastAccepted = 1) then
      update ExecutionDocuMENTSCaption set
      LastAccepted = 0,
      RVersion = -1
      where (ID = new$AdjustmentRef);
        
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_EXECDOCCAPTION_AI_500)
-- - - - - - - - - - - - -

-- 25.08.2004
  delete from DelRecIndexes where (TableID = 114) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_EXECUTIONDOCUMENTSCAPTIO_IU
  INSTEAD OF UPDATE
  ON EXECUTIONDOCUMENTSCAPTION
  FOR EACH ROW
DECLARE
  new$ID EXECUTIONDOCUMENTSCAPTION.ID%TYPE := :NEW.ID;
  new$DOCTYPE EXECUTIONDOCUMENTSCAPTION.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$DOCUMENTDATE EXECUTIONDOCUMENTSCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE EXECUTIONDOCUMENTSCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SUMMA EXECUTIONDOCUMENTSCAPTION.SUMMA%TYPE := :NEW.SUMMA;
  new$CREATERUSER EXECUTIONDOCUMENTSCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE EXECUTIONDOCUMENTSCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE EXECUTIONDOCUMENTSCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER EXECUTIONDOCUMENTSCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF EXECUTIONDOCUMENTSCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$STEPNUMBER EXECUTIONDOCUMENTSCAPTION.STEPNUMBER%TYPE := :NEW.STEPNUMBER;
  new$FACIALACC_CLS EXECUTIONDOCUMENTSCAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$RECIPIENT_REF EXECUTIONDOCUMENTSCAPTION.RECIPIENT_REF%TYPE := :NEW.RECIPIENT_REF;
  new$REGISTRATIONTYPE EXECUTIONDOCUMENTSCAPTION.REGISTRATIONTYPE%TYPE := :NEW.REGISTRATIONTYPE;
  new$REESTRNUMBER EXECUTIONDOCUMENTSCAPTION.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$AGREEMENTINNERNUMBER EXECUTIONDOCUMENTSCAPTION.AGREEMENTINNERNUMBER%TYPE := :NEW.AGREEMENTINNERNUMBER;
  new$REJECTCLS EXECUTIONDOCUMENTSCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTCAUSE EXECUTIONDOCUMENTSCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CRYPTOSTATUS EXECUTIONDOCUMENTSCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID EXECUTIONDOCUMENTSCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID EXECUTIONDOCUMENTSCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REVIEWNOTE EXECUTIONDOCUMENTSCAPTION.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF EXECUTIONDOCUMENTSCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION EXECUTIONDOCUMENTSCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$EXECDOCFINSUMMA EXECUTIONDOCUMENTSCAPTION.EXECDOCFINSUMMA%TYPE := :NEW.EXECDOCFINSUMMA;
  new$FACT EXECUTIONDOCUMENTSCAPTION.FACT%TYPE := :NEW.FACT;
  new$DOCNUMBER EXECUTIONDOCUMENTSCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SENDERIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REALID EXECUTIONDOCUMENTSCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER EXECUTIONDOCUMENTSCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTREF EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ADJUSTMENTNUMBER EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$ACCEPTED EXECUTIONDOCUMENTSCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED EXECUTIONDOCUMENTSCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$LASTADJUSTMENT EXECUTIONDOCUMENTSCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$AGREEMENTREF EXECUTIONDOCUMENTSCAPTION.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$NOTE EXECUTIONDOCUMENTSCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$SUPPLIERSTOREDPROPS EXECUTIONDOCUMENTSCAPTION.SUPPLIERSTOREDPROPS%TYPE := :NEW.SUPPLIERSTOREDPROPS;
  new$SUPPLIER_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIER_REF%TYPE := :NEW.SUPPLIER_REF;
  new$SUPPLIERACC_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIERACC_REF%TYPE := :NEW.SUPPLIERACC_REF;
  new$TEMPREJECTCAUSE EXECUTIONDOCUMENTSCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  CntAgr$ NUMBER(10);
  CntStep$ NUMBER(10);
  agr_accepted$ NUMBER(10);
  agr_acceptdate$ NUMBER(10);
  CountExecDoc$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_EXECDOCCAPTION_BU)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$DocType is null) then 
    new$DocType := 0;
  END IF;
  if (new$Summa is null) then 
    new$Summa := 0;
  END IF;
  if (new$ExecDocFinSumma is null) then 
    new$ExecDocFinSumma := 0;  
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$RegistrationType is null) then 
    new$RegistrationType := 0;
  END IF;
  if (new$Fact is null) then 
    new$Fact := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      SELECT COUNT(                   Id
      ) INTO CNT$1
      from ExecutionDocumentsDetail
      where 
      (                   RecordIndex = :old.Id
      ) AND (ROWNUM = 1)                ;
      if ((CNT$1<> 0)         ) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      SELECT COUNT(                   Id
      ) INTO CNT$2
      from PaymentSchedule
      where
      (                   ExecutionRef = :old.Id
      ) AND (ROWNUM = 1)                ;
      if ((CNT$2<> 0)         ) then
        RaiseException('Ex_CantModufyBudget');    
      END IF;
    END IF;
  END IF;
  /*     ,        */
  if (new$InnerNumber is null) then
    new$InnerNumber := :old.InnerNumber;
  END IF;
  /* c,           */
  /* ,    */
  if (new$InnerNumber <> :old.InnerNumber or
  new$AdjustmentRef <> :old.AdjustmentRef or
  new$AdjustmentNumber <> :old.AdjustmentNumber) then
    RaiseException('EX_Agr_ChangeInnerNums');
  END IF;
  /*      id */  
  new$agreementinnernumber := null;
  if (new$agreementref is not null) then
    BEGIN
      select
      innernumber
      into new$agreementinnernumber     from agreements
      where
      id = new$agreementref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_EXECDOCCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;
          
    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_EXECDOCCAPTION_BU_10)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*     */
  if (:old.AcceptDate is not null and :old.Accepted = 0 and (new$Accepted = 1 or new$AcceptDate is null)) then
    RaiseException('EX_RollbackCancel');
  END IF;
      
  /*   ,     LastAccepted*/
  if (:old.AcceptDate is null and new$AcceptDate is not null and new$Accepted = 1) then 
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 1;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    END IF;
  END IF;
      
  /*    ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 1 and new$AcceptDate is null) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 0;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');  
    END IF;
  END IF;
      
  /*   ,     LastAdjustment  LastAccepted */
  if (new$AcceptDate is not null and new$Accepted = 0 and (:old.AcceptDate is null or :old.Accepted = 1)) then
    if (:old.LastAdjustment = 1) then
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    END IF;
    SELECT COUNT(                 Id
    ) INTO CNT$1
    from ExecutionDocumentsCaption
    where
    (                 InnerNumber = new$InnerNumber and AdjustmentNumber > 0
    ) AND (ROWNUM = 1)              ;
    /*          */
    if (new$AdjustmentNumber = 0 and 
    (CNT$1<> 0)       ) then
      RaiseException('EX_ExecDoc_PrimaryAgrHasNotify');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_40 (tr_execdoccaption_bu_40)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  if ((:old.AcceptDate is not null) and (new$AcceptDate is null)) then
    select count(ID) into CntAgr$ from Agreements where (CloseDoc = :old.ID) ;
    select count(ID) into CntStep$ from AgreementSteps where (CloseDoc = :old.ID) ;
    if ((CntAgr$ > 0) or (CntStep$ > 0)) then
      RaiseException('ex_CannotUpdateCloseDoc');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_60 (tr_execdoccaption_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$agreementinnernumber is not null) then
    BEGIN
      /*        , .. 
             ,    ,   
            ,     */
      select accepted, acceptdate     into
      agr_accepted$, agr_acceptdate$ from agreements
      where
      innernumber = new$agreementinnernumber and adjustmentnumber = 0
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*        */
    if (new$acceptdate is null and agr_accepted$ = 0 and agr_acceptdate$ is not null) then
      RaiseException('EX_Agr_Rejected');
    END IF;
    /*        */
    if (new$accepted = 1 and new$acceptdate is not null and
    (agr_accepted$ = 0 or agr_acceptdate$ is null)) then
      RaiseException('EX_Agr_NotAccepted');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_EXECDOCCAPTION_BU_200)
-- Create 04.10.2004
-- - - - - - - - - - - - -

  /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_EXECDOCCAPTION_BU_210)
-- Version 11.20.00.1
-- - - - - - - - - - - - -

  /*   */
  if (new$rejectcls is not null and new$accepted = 0) then
    /*         */
    select
    count(ffd.id)
    into CountExecDoc$     from
    facialfindetail ffd
    left join facialfincaption ffc on ffc.id = ffd.recordindex
    where
    (ffc.acceptdate is not null and (ffd.sourceexecdoc = new$id or ffd.destexecdoc = new$id))
    ;
    /*       */
    if (CountExecDoc$ <> 0) then
      RaiseException('ex_exedoc_useinfacialfindetail');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_EDCAPTION_BU_700)
-- Create 14.10.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_EXECUTIONDOCUMENTSCAPTION SET
    ID = new$ID,
    DOCTYPE = new$DOCTYPE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    SUMMA = new$SUMMA,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    STEPNUMBER = new$STEPNUMBER,
    FACIALACC_CLS = new$FACIALACC_CLS,
    RECIPIENT_REF = new$RECIPIENT_REF,
    REGISTRATIONTYPE = new$REGISTRATIONTYPE,
    REESTRNUMBER = new$REESTRNUMBER,
    AGREEMENTINNERNUMBER = new$AGREEMENTINNERNUMBER,
    REJECTCLS = new$REJECTCLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXECDOCFINSUMMA = new$EXECDOCFINSUMMA,
    FACT = new$FACT,
    DOCNUMBER = new$DOCNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REALID = new$REALID,
    INNERNUMBER = new$INNERNUMBER,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    ACCEPTED = new$ACCEPTED,
    LASTACCEPTED = new$LASTACCEPTED,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    AGREEMENTREF = new$AGREEMENTREF,
    NOTE = new$NOTE,
    SUPPLIERSTOREDPROPS = new$SUPPLIERSTOREDPROPS,
    SUPPLIER_REF = new$SUPPLIER_REF,
    SUPPLIERACC_REF = new$SUPPLIERACC_REF,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_0 (TR_ExecDocCaption_AU)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*       */
  /*     ,       */
  if ((new$AdjustmentRef is not null) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update ExecutionDocuMENTSCaption set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentRef is not null) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update ExecutionDocuMENTSCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_EXECDOCCAPTION_AU_30)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$Accepted <> :old.Accepted) or 
  (new$AcceptDate is not null and :old.AcceptDate is null) or 
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where ExecutionRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_EXECDOCCAPTION_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (114, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=114) and (RecordId=new$ID);
  end if;

END;
/
update EXECUTIONDOCUMENTSCAPTION set
  TempRejectCause = REJECTCAUSE
/
commit work 
/
ALTER TABLE TB_EXECUTIONDOCUMENTSCAPTION DROP (REJECTCAUSE)
/

CREATE OR REPLACE VIEW EXECUTIONDOCUMENTSCAPTION (
  ID,
  DOCTYPE,
  DOCUMENTDATE,
  ACCEPTDATE,
  SUMMA,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  BUDGETREF,
  STEPNUMBER,
  FACIALACC_CLS,
  RECIPIENT_REF,
  REGISTRATIONTYPE,
  REESTRNUMBER,
  AGREEMENTINNERNUMBER,
  REJECTCLS,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  REVIEWNOTE,
  DOCSTATEREF,
  RVERSION,
  EXECDOCFINSUMMA,
  FACT,
  DOCNUMBER,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  REALID,
  INNERNUMBER,
  ADJUSTMENTREF,
  ADJUSTMENTNUMBER,
  ACCEPTED,
  LASTACCEPTED,
  LASTADJUSTMENT,
  AGREEMENTREF,
  NOTE,
  SUPPLIERSTOREDPROPS,
  SUPPLIER_REF,
  SUPPLIERACC_REF,
  TEMPREJECTCAUSE)
AS
  SELECT
    ID,
    DOCTYPE,
    DOCUMENTDATE,
    ACCEPTDATE,
    SUMMA,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    STEPNUMBER,
    FACIALACC_CLS,
    RECIPIENT_REF,
    REGISTRATIONTYPE,
    REESTRNUMBER,
    AGREEMENTINNERNUMBER,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXECDOCFINSUMMA,
    FACT,
    DOCNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REALID,
    INNERNUMBER,
    ADJUSTMENTREF,
    ADJUSTMENTNUMBER,
    ACCEPTED,
    LASTACCEPTED,
    LASTADJUSTMENT,
    AGREEMENTREF,
    NOTE,
    SUPPLIERSTOREDPROPS,
    SUPPLIER_REF,
    SUPPLIERACC_REF,
    TEMPREJECTCAUSE
  FROM TB_EXECUTIONDOCUMENTSCAPTION
/

CREATE OR REPLACE TRIGGER TR_EXECUTIONDOCUMENTSCAPTIO_ID
  INSTEAD OF DELETE
  ON EXECUTIONDOCUMENTSCAPTION
  FOR EACH ROW
DECLARE
  quant$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_DOCEXECCAPTION_BD)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  select count(ID)   into quant$ from executiondocumentscaption 
  where AdjustmentRef = :old.ID
  ;
  if (quant$  = 0) then
    delete from ExecutionDocumentsDetail where (RecordIndex = :old.ID);
    delete from paymentschedule where (ExecutionRef = :old.ID)and(ProgIndex=308);
      
  else
    RaiseException('ex_agr_cantdeladjustmented');
  END IF;

-- - - - - - - - - - - - -
-- BD_10 (TR_DocExecCaption_BD_10)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*   LastAdjustment     */
  if ((:old.AdjustmentRef is not null) and (:old.LastAdjustment = 1)) then
    update ExecutionDocumentsCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;
  /*   LastAccepted     */    
  if ((:old.AdjustmentRef is not null) and (:old.LastAccepted = 1)) then
    update ExecutionDocumentsCaption set
    LastAccepted = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_EXECUTIONDOCUMENTSCAPTION
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_10 (TR_ExecDocCaption_AD_10)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*   LastAdjustment     */
  if ((:old.AdjustmentRef is not null) and (:old.LastAdjustment = 1)) then
    update ExecutionDocumentsCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;
  /*   LastAccepted     */    
  if ((:old.AdjustmentRef is not null) and (:old.LastAccepted = 1)) then
    update ExecutionDocumentsCaption set
    LastAccepted = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AD_200 (TR_EXECDOCCAPTION_AD_200)
-- Create 04.10.2004
-- - - - - - - - - - - - -

  /*        */
  delete from StateJumpHistory where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_EXECDOCCAPTION_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordId, DeleteDate, SUMMA) values (114, :old.ID, SYSDATE, :old.SUMMA);

END;
/

CREATE OR REPLACE TRIGGER TR_EXECUTIONDOCUMENTSCAPTIO_II
  INSTEAD OF INSERT
  ON EXECUTIONDOCUMENTSCAPTION
  FOR EACH ROW
DECLARE
  new$ID EXECUTIONDOCUMENTSCAPTION.ID%TYPE := :NEW.ID;
  new$DOCTYPE EXECUTIONDOCUMENTSCAPTION.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$DOCUMENTDATE EXECUTIONDOCUMENTSCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE EXECUTIONDOCUMENTSCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SUMMA EXECUTIONDOCUMENTSCAPTION.SUMMA%TYPE := :NEW.SUMMA;
  new$CREATERUSER EXECUTIONDOCUMENTSCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE EXECUTIONDOCUMENTSCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE EXECUTIONDOCUMENTSCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER EXECUTIONDOCUMENTSCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF EXECUTIONDOCUMENTSCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$STEPNUMBER EXECUTIONDOCUMENTSCAPTION.STEPNUMBER%TYPE := :NEW.STEPNUMBER;
  new$FACIALACC_CLS EXECUTIONDOCUMENTSCAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$RECIPIENT_REF EXECUTIONDOCUMENTSCAPTION.RECIPIENT_REF%TYPE := :NEW.RECIPIENT_REF;
  new$REGISTRATIONTYPE EXECUTIONDOCUMENTSCAPTION.REGISTRATIONTYPE%TYPE := :NEW.REGISTRATIONTYPE;
  new$REESTRNUMBER EXECUTIONDOCUMENTSCAPTION.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$AGREEMENTINNERNUMBER EXECUTIONDOCUMENTSCAPTION.AGREEMENTINNERNUMBER%TYPE := :NEW.AGREEMENTINNERNUMBER;
  new$REJECTCLS EXECUTIONDOCUMENTSCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS EXECUTIONDOCUMENTSCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID EXECUTIONDOCUMENTSCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID EXECUTIONDOCUMENTSCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REVIEWNOTE EXECUTIONDOCUMENTSCAPTION.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF EXECUTIONDOCUMENTSCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION EXECUTIONDOCUMENTSCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$EXECDOCFINSUMMA EXECUTIONDOCUMENTSCAPTION.EXECDOCFINSUMMA%TYPE := :NEW.EXECDOCFINSUMMA;
  new$FACT EXECUTIONDOCUMENTSCAPTION.FACT%TYPE := :NEW.FACT;
  new$DOCNUMBER EXECUTIONDOCUMENTSCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SENDERIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REALID EXECUTIONDOCUMENTSCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER EXECUTIONDOCUMENTSCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTREF EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ADJUSTMENTNUMBER EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$ACCEPTED EXECUTIONDOCUMENTSCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED EXECUTIONDOCUMENTSCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$LASTADJUSTMENT EXECUTIONDOCUMENTSCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$AGREEMENTREF EXECUTIONDOCUMENTSCAPTION.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$NOTE EXECUTIONDOCUMENTSCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$SUPPLIERSTOREDPROPS EXECUTIONDOCUMENTSCAPTION.SUPPLIERSTOREDPROPS%TYPE := :NEW.SUPPLIERSTOREDPROPS;
  new$SUPPLIER_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIER_REF%TYPE := :NEW.SUPPLIER_REF;
  new$SUPPLIERACC_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIERACC_REF%TYPE := :NEW.SUPPLIERACC_REF;
  new$TEMPREJECTCAUSE EXECUTIONDOCUMENTSCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  Tmp$ NUMBER(10);
  AdjID$ NUMBER(10);
  AdjDocNum$ VARCHAR2(50);
  agr_accepted$ NUMBER(10);
  agr_acceptdate$ NUMBER(10);
  PreviousInner$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ExecDoccaption_BI)
-- Version 11.20.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$DocType is null) then 
    new$DocType := 0;
  END IF;
  if (new$Summa is null) then 
    new$Summa := 0;
  END IF;
  if (new$ExecDocFinSumma is null) then 
    new$ExecDocFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$RegistrationType is null) then 
    new$RegistrationType := 0;
  END IF;
  if (new$Fact is null) then 
    new$Fact := 0;
  END IF;
  if (new$Accepted is null) then 
    new$Accepted := 1;
  END IF;
  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    BEGIN
      select fa.BudgetRef
      into new$BudgetRef     from FacialAcc_Cls fa
      where fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then 
    GetIntConst(-1,3,new$BudgetRef);
  END IF;
  if (new$Supplier_Ref is null and new$SupplierAcc_Ref is not null) then
    BEGIN
      select oa.Org_Ref
      into new$Supplier_Ref   from Org_Accounts oa
      where oa.id = new$SupplierAcc_Ref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,     ,      */
  if (new$AdjustmentRef is null) then
    new$InnerNumber := GEN_ID('g_ExecDocNumber',1);
      
  else
    BEGIN
      /*          */
      select
      InnerNumber 
      into PreviousInner$     from ExecutionDocumentsCaption
      where ID = new$AdjustmentRef and LastAccepted = 1 and LastAdjustment = 1
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (PreviousInner$ is null) then
      RaiseException('EX_ExecDoc_NotFindInner');
    END IF;
    new$InnerNumber := PreviousInner$;
      
  END IF;
  /*      id */  
  new$agreementinnernumber := null;
  if (new$agreementref is not null) then
    BEGIN
      select
      innernumber
      into new$agreementinnernumber     from agreements
      where
      id = new$agreementref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_EXECDOCCAPTION_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;
          
    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_EXECDOCCAPTION_BI_10)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*    .*/
  if (new$InnerNumber is null) then
    RaiseException('EX_AGR_InnerNumsIsNull');
  END IF;

  /*    */
  select max(AdjustmentNumber)
  into Tmp$     from ExecutionDocumentsCaption
  where (InnerNumber = new$InnerNumber)
  ;
  /*      ,   0*/
  if (Tmp$ is null) then
    new$AdjustmentNumber := 0;
        
  else
    new$AdjustmentNumber := Tmp$ + 1;
  END IF;
  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;
        
  else
    new$LastAdjustment := 1;
  END IF;
  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then
    new$LastAccepted := 1;
        
  else
    new$LastAccepted := 0;
  END IF;
  /*    */
  if (new$AdjustmentRef is not null) then
    /*      -    */
    select count(ID), max(ID), max(DocNumber)
    into Tmp$, AdjID$, AdjDocNum$       from ExecutionDocumentsCaption
    where (InnerNumber = new$InnerNumber) and (LastAccepted = 1)
    ;
    /*   ,  */
    if (Tmp$ <> 1) then
      RaiseException('EX_ExecDoc_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID)
    into Tmp$       from ExecutionDocumentsCaption
    where (InnerNumber = new$InnerNumber) and (AcceptDate is null)
    ;
    if (Tmp$ > 0) then
      RaiseException('EX_ExecDoc_AdjustDuplicate');
    END IF;
    /* ,    ,    */      
    new$AdjustmentRef := AdjID$;
        
  else /*     */
    /*       (    )*/      
    new$AdjustmentRef := null;
  END IF;

-- - - - - - - - - - - - -
-- BI_40 (tr_execdoccaption_bi_40)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*       */
  if (new$senderId is null) then 
    new$senderIdKey := -1;
      
  else 
    new$senderIdKey := new$senderId;
  END IF;
  if (new$SenderRecordID is null)then
    new$SenderRecordIDKey := new$ID;
      
  else 
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_60 (tr_execdoccaption_bi_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$agreementinnernumber is not null) then
    BEGIN
      /*        , .. 
             ,    ,   
            ,     */
      select accepted, acceptdate     into
      agr_accepted$, agr_acceptdate$ from agreements
      where
      innernumber = new$agreementinnernumber and adjustmentnumber = 0
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*        */
    if (new$acceptdate is null and agr_accepted$ = 0 and agr_acceptdate$ is not null) then
      RaiseException('EX_Agr_Rejected');
    END IF;
    /*        */
    if (new$accepted = 1 and new$acceptdate is not null and
    (agr_accepted$ = 0 or agr_acceptdate$ is null)) then
      RaiseException('EX_Agr_NotAccepted');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_EXECDOCCAPTION_BI_500)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_EXECUTIONDOCUMENTSCAPTION (
    ID,
    DOCTYPE,
    DOCUMENTDATE,
    ACCEPTDATE,
    SUMMA,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    STEPNUMBER,
    FACIALACC_CLS,
    RECIPIENT_REF,
    REGISTRATIONTYPE,
    REESTRNUMBER,
    AGREEMENTINNERNUMBER,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXECDOCFINSUMMA,
    FACT,
    DOCNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REALID,
    INNERNUMBER,
    ADJUSTMENTREF,
    ADJUSTMENTNUMBER,
    ACCEPTED,
    LASTACCEPTED,
    LASTADJUSTMENT,
    AGREEMENTREF,
    NOTE,
    SUPPLIERSTOREDPROPS,
    SUPPLIER_REF,
    SUPPLIERACC_REF,
    TEMPREJECTCAUSE
  ) VALUES (
    new$ID,
    new$DOCTYPE,
    new$DOCUMENTDATE,
    new$ACCEPTDATE,
    new$SUMMA,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$STEPNUMBER,
    new$FACIALACC_CLS,
    new$RECIPIENT_REF,
    new$REGISTRATIONTYPE,
    new$REESTRNUMBER,
    new$AGREEMENTINNERNUMBER,
    new$REJECTCLS,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$REVIEWNOTE,
    new$DOCSTATEREF,
    new$RVERSION,
    new$EXECDOCFINSUMMA,
    new$FACT,
    new$DOCNUMBER,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$REALID,
    new$INNERNUMBER,
    new$ADJUSTMENTREF,
    new$ADJUSTMENTNUMBER,
    new$ACCEPTED,
    new$LASTACCEPTED,
    new$LASTADJUSTMENT,
    new$AGREEMENTREF,
    new$NOTE,
    new$SUPPLIERSTOREDPROPS,
    new$SUPPLIER_REF,
    new$SUPPLIERACC_REF,
    new$TEMPREJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_0 (TR_ExecDocCaption_AI)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*       */
  /*     ,       */
  if ((new$AdjustmentRef is not null) and (new$LastAdjustment = 1)) then
    update ExecutionDocuMENTSCaption set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);        
    if (new$LastAccepted = 1) then
      update ExecutionDocuMENTSCaption set
      LastAccepted = 0,
      RVersion = -1
      where (ID = new$AdjustmentRef);
        
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_EXECDOCCAPTION_AI_500)
-- - - - - - - - - - - - -

-- 25.08.2004
  delete from DelRecIndexes where (TableID = 114) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_EXECUTIONDOCUMENTSCAPTIO_IU
  INSTEAD OF UPDATE
  ON EXECUTIONDOCUMENTSCAPTION
  FOR EACH ROW
DECLARE
  new$ID EXECUTIONDOCUMENTSCAPTION.ID%TYPE := :NEW.ID;
  new$DOCTYPE EXECUTIONDOCUMENTSCAPTION.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$DOCUMENTDATE EXECUTIONDOCUMENTSCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE EXECUTIONDOCUMENTSCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SUMMA EXECUTIONDOCUMENTSCAPTION.SUMMA%TYPE := :NEW.SUMMA;
  new$CREATERUSER EXECUTIONDOCUMENTSCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE EXECUTIONDOCUMENTSCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE EXECUTIONDOCUMENTSCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER EXECUTIONDOCUMENTSCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF EXECUTIONDOCUMENTSCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$STEPNUMBER EXECUTIONDOCUMENTSCAPTION.STEPNUMBER%TYPE := :NEW.STEPNUMBER;
  new$FACIALACC_CLS EXECUTIONDOCUMENTSCAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$RECIPIENT_REF EXECUTIONDOCUMENTSCAPTION.RECIPIENT_REF%TYPE := :NEW.RECIPIENT_REF;
  new$REGISTRATIONTYPE EXECUTIONDOCUMENTSCAPTION.REGISTRATIONTYPE%TYPE := :NEW.REGISTRATIONTYPE;
  new$REESTRNUMBER EXECUTIONDOCUMENTSCAPTION.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$AGREEMENTINNERNUMBER EXECUTIONDOCUMENTSCAPTION.AGREEMENTINNERNUMBER%TYPE := :NEW.AGREEMENTINNERNUMBER;
  new$REJECTCLS EXECUTIONDOCUMENTSCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS EXECUTIONDOCUMENTSCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID EXECUTIONDOCUMENTSCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID EXECUTIONDOCUMENTSCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REVIEWNOTE EXECUTIONDOCUMENTSCAPTION.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF EXECUTIONDOCUMENTSCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION EXECUTIONDOCUMENTSCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$EXECDOCFINSUMMA EXECUTIONDOCUMENTSCAPTION.EXECDOCFINSUMMA%TYPE := :NEW.EXECDOCFINSUMMA;
  new$FACT EXECUTIONDOCUMENTSCAPTION.FACT%TYPE := :NEW.FACT;
  new$DOCNUMBER EXECUTIONDOCUMENTSCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SENDERIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REALID EXECUTIONDOCUMENTSCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER EXECUTIONDOCUMENTSCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTREF EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ADJUSTMENTNUMBER EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$ACCEPTED EXECUTIONDOCUMENTSCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED EXECUTIONDOCUMENTSCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$LASTADJUSTMENT EXECUTIONDOCUMENTSCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$AGREEMENTREF EXECUTIONDOCUMENTSCAPTION.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$NOTE EXECUTIONDOCUMENTSCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$SUPPLIERSTOREDPROPS EXECUTIONDOCUMENTSCAPTION.SUPPLIERSTOREDPROPS%TYPE := :NEW.SUPPLIERSTOREDPROPS;
  new$SUPPLIER_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIER_REF%TYPE := :NEW.SUPPLIER_REF;
  new$SUPPLIERACC_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIERACC_REF%TYPE := :NEW.SUPPLIERACC_REF;
  new$TEMPREJECTCAUSE EXECUTIONDOCUMENTSCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  CntAgr$ NUMBER(10);
  CntStep$ NUMBER(10);
  agr_accepted$ NUMBER(10);
  agr_acceptdate$ NUMBER(10);
  CountExecDoc$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_EXECDOCCAPTION_BU)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$DocType is null) then 
    new$DocType := 0;
  END IF;
  if (new$Summa is null) then 
    new$Summa := 0;
  END IF;
  if (new$ExecDocFinSumma is null) then 
    new$ExecDocFinSumma := 0;  
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$RegistrationType is null) then 
    new$RegistrationType := 0;
  END IF;
  if (new$Fact is null) then 
    new$Fact := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      SELECT COUNT(                   Id
      ) INTO CNT$1
      from ExecutionDocumentsDetail
      where 
      (                   RecordIndex = :old.Id
      ) AND (ROWNUM = 1)                ;
      if ((CNT$1<> 0)         ) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      SELECT COUNT(                   Id
      ) INTO CNT$2
      from PaymentSchedule
      where
      (                   ExecutionRef = :old.Id
      ) AND (ROWNUM = 1)                ;
      if ((CNT$2<> 0)         ) then
        RaiseException('Ex_CantModufyBudget');    
      END IF;
    END IF;
  END IF;
  /*     ,        */
  if (new$InnerNumber is null) then
    new$InnerNumber := :old.InnerNumber;
  END IF;
  /* c,           */
  /* ,    */
  if (new$InnerNumber <> :old.InnerNumber or
  new$AdjustmentRef <> :old.AdjustmentRef or
  new$AdjustmentNumber <> :old.AdjustmentNumber) then
    RaiseException('EX_Agr_ChangeInnerNums');
  END IF;
  /*      id */  
  new$agreementinnernumber := null;
  if (new$agreementref is not null) then
    BEGIN
      select
      innernumber
      into new$agreementinnernumber     from agreements
      where
      id = new$agreementref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_EXECDOCCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;
          
    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_EXECDOCCAPTION_BU_10)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*     */
  if (:old.AcceptDate is not null and :old.Accepted = 0 and (new$Accepted = 1 or new$AcceptDate is null)) then
    RaiseException('EX_RollbackCancel');
  END IF;
      
  /*   ,     LastAccepted*/
  if (:old.AcceptDate is null and new$AcceptDate is not null and new$Accepted = 1) then 
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 1;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    END IF;
  END IF;
      
  /*    ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 1 and new$AcceptDate is null) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 0;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');  
    END IF;
  END IF;
      
  /*   ,     LastAdjustment  LastAccepted */
  if (new$AcceptDate is not null and new$Accepted = 0 and (:old.AcceptDate is null or :old.Accepted = 1)) then
    if (:old.LastAdjustment = 1) then
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    END IF;
    SELECT COUNT(                 Id
    ) INTO CNT$1
    from ExecutionDocumentsCaption
    where
    (                 InnerNumber = new$InnerNumber and AdjustmentNumber > 0
    ) AND (ROWNUM = 1)              ;
    /*          */
    if (new$AdjustmentNumber = 0 and 
    (CNT$1<> 0)       ) then
      RaiseException('EX_ExecDoc_PrimaryAgrHasNotify');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_40 (tr_execdoccaption_bu_40)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  if ((:old.AcceptDate is not null) and (new$AcceptDate is null)) then
    select count(ID) into CntAgr$ from Agreements where (CloseDoc = :old.ID) ;
    select count(ID) into CntStep$ from AgreementSteps where (CloseDoc = :old.ID) ;
    if ((CntAgr$ > 0) or (CntStep$ > 0)) then
      RaiseException('ex_CannotUpdateCloseDoc');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_60 (tr_execdoccaption_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$agreementinnernumber is not null) then
    BEGIN
      /*        , .. 
             ,    ,   
            ,     */
      select accepted, acceptdate     into
      agr_accepted$, agr_acceptdate$ from agreements
      where
      innernumber = new$agreementinnernumber and adjustmentnumber = 0
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*        */
    if (new$acceptdate is null and agr_accepted$ = 0 and agr_acceptdate$ is not null) then
      RaiseException('EX_Agr_Rejected');
    END IF;
    /*        */
    if (new$accepted = 1 and new$acceptdate is not null and
    (agr_accepted$ = 0 or agr_acceptdate$ is null)) then
      RaiseException('EX_Agr_NotAccepted');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_EXECDOCCAPTION_BU_200)
-- Create 04.10.2004
-- - - - - - - - - - - - -

  /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_EXECDOCCAPTION_BU_210)
-- Version 11.20.00.1
-- - - - - - - - - - - - -

  /*   */
  if (new$rejectcls is not null and new$accepted = 0) then
    /*         */
    select
    count(ffd.id)
    into CountExecDoc$     from
    facialfindetail ffd
    left join facialfincaption ffc on ffc.id = ffd.recordindex
    where
    (ffc.acceptdate is not null and (ffd.sourceexecdoc = new$id or ffd.destexecdoc = new$id))
    ;
    /*       */
    if (CountExecDoc$ <> 0) then
      RaiseException('ex_exedoc_useinfacialfindetail');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_EDCAPTION_BU_700)
-- Create 14.10.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_EXECUTIONDOCUMENTSCAPTION SET
    ID = new$ID,
    DOCTYPE = new$DOCTYPE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    SUMMA = new$SUMMA,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    STEPNUMBER = new$STEPNUMBER,
    FACIALACC_CLS = new$FACIALACC_CLS,
    RECIPIENT_REF = new$RECIPIENT_REF,
    REGISTRATIONTYPE = new$REGISTRATIONTYPE,
    REESTRNUMBER = new$REESTRNUMBER,
    AGREEMENTINNERNUMBER = new$AGREEMENTINNERNUMBER,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXECDOCFINSUMMA = new$EXECDOCFINSUMMA,
    FACT = new$FACT,
    DOCNUMBER = new$DOCNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REALID = new$REALID,
    INNERNUMBER = new$INNERNUMBER,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    ACCEPTED = new$ACCEPTED,
    LASTACCEPTED = new$LASTACCEPTED,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    AGREEMENTREF = new$AGREEMENTREF,
    NOTE = new$NOTE,
    SUPPLIERSTOREDPROPS = new$SUPPLIERSTOREDPROPS,
    SUPPLIER_REF = new$SUPPLIER_REF,
    SUPPLIERACC_REF = new$SUPPLIERACC_REF,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_0 (TR_ExecDocCaption_AU)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*       */
  /*     ,       */
  if ((new$AdjustmentRef is not null) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update ExecutionDocuMENTSCaption set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentRef is not null) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update ExecutionDocuMENTSCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_EXECDOCCAPTION_AU_30)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$Accepted <> :old.Accepted) or 
  (new$AcceptDate is not null and :old.AcceptDate is null) or 
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where ExecutionRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_EXECDOCCAPTION_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (114, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=114) and (RecordId=new$ID);
  end if;

END;
/
ALTER TABLE TB_EXECUTIONDOCUMENTSCAPTION ADD (
  REJECTCAUSE VARCHAR2(1000)
)
/

CREATE OR REPLACE VIEW EXECUTIONDOCUMENTSCAPTION (
  ID,
  DOCTYPE,
  DOCUMENTDATE,
  ACCEPTDATE,
  SUMMA,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  BUDGETREF,
  STEPNUMBER,
  FACIALACC_CLS,
  RECIPIENT_REF,
  REGISTRATIONTYPE,
  REESTRNUMBER,
  AGREEMENTINNERNUMBER,
  REJECTCLS,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  REVIEWNOTE,
  DOCSTATEREF,
  RVERSION,
  EXECDOCFINSUMMA,
  FACT,
  DOCNUMBER,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  REALID,
  INNERNUMBER,
  ADJUSTMENTREF,
  ADJUSTMENTNUMBER,
  ACCEPTED,
  LASTACCEPTED,
  LASTADJUSTMENT,
  AGREEMENTREF,
  NOTE,
  SUPPLIERSTOREDPROPS,
  SUPPLIER_REF,
  SUPPLIERACC_REF,
  TEMPREJECTCAUSE,
  REJECTCAUSE)
AS
  SELECT
    ID,
    DOCTYPE,
    DOCUMENTDATE,
    ACCEPTDATE,
    SUMMA,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    STEPNUMBER,
    FACIALACC_CLS,
    RECIPIENT_REF,
    REGISTRATIONTYPE,
    REESTRNUMBER,
    AGREEMENTINNERNUMBER,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXECDOCFINSUMMA,
    FACT,
    DOCNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REALID,
    INNERNUMBER,
    ADJUSTMENTREF,
    ADJUSTMENTNUMBER,
    ACCEPTED,
    LASTACCEPTED,
    LASTADJUSTMENT,
    AGREEMENTREF,
    NOTE,
    SUPPLIERSTOREDPROPS,
    SUPPLIER_REF,
    SUPPLIERACC_REF,
    TEMPREJECTCAUSE,
    REJECTCAUSE
  FROM TB_EXECUTIONDOCUMENTSCAPTION
/

CREATE OR REPLACE TRIGGER TR_EXECUTIONDOCUMENTSCAPTIO_ID
  INSTEAD OF DELETE
  ON EXECUTIONDOCUMENTSCAPTION
  FOR EACH ROW
DECLARE
  quant$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_DOCEXECCAPTION_BD)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  select count(ID)   into quant$ from executiondocumentscaption 
  where AdjustmentRef = :old.ID
  ;
  if (quant$  = 0) then
    delete from ExecutionDocumentsDetail where (RecordIndex = :old.ID);
    delete from paymentschedule where (ExecutionRef = :old.ID)and(ProgIndex=308);
      
  else
    RaiseException('ex_agr_cantdeladjustmented');
  END IF;

-- - - - - - - - - - - - -
-- BD_10 (TR_DocExecCaption_BD_10)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*   LastAdjustment     */
  if ((:old.AdjustmentRef is not null) and (:old.LastAdjustment = 1)) then
    update ExecutionDocumentsCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;
  /*   LastAccepted     */    
  if ((:old.AdjustmentRef is not null) and (:old.LastAccepted = 1)) then
    update ExecutionDocumentsCaption set
    LastAccepted = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_EXECUTIONDOCUMENTSCAPTION
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_10 (TR_ExecDocCaption_AD_10)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*   LastAdjustment     */
  if ((:old.AdjustmentRef is not null) and (:old.LastAdjustment = 1)) then
    update ExecutionDocumentsCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;
  /*   LastAccepted     */    
  if ((:old.AdjustmentRef is not null) and (:old.LastAccepted = 1)) then
    update ExecutionDocumentsCaption set
    LastAccepted = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AD_200 (TR_EXECDOCCAPTION_AD_200)
-- Create 04.10.2004
-- - - - - - - - - - - - -

  /*        */
  delete from StateJumpHistory where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_EXECDOCCAPTION_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordId, DeleteDate, SUMMA) values (114, :old.ID, SYSDATE, :old.SUMMA);

END;
/

CREATE OR REPLACE TRIGGER TR_EXECUTIONDOCUMENTSCAPTIO_II
  INSTEAD OF INSERT
  ON EXECUTIONDOCUMENTSCAPTION
  FOR EACH ROW
DECLARE
  new$ID EXECUTIONDOCUMENTSCAPTION.ID%TYPE := :NEW.ID;
  new$DOCTYPE EXECUTIONDOCUMENTSCAPTION.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$DOCUMENTDATE EXECUTIONDOCUMENTSCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE EXECUTIONDOCUMENTSCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SUMMA EXECUTIONDOCUMENTSCAPTION.SUMMA%TYPE := :NEW.SUMMA;
  new$CREATERUSER EXECUTIONDOCUMENTSCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE EXECUTIONDOCUMENTSCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE EXECUTIONDOCUMENTSCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER EXECUTIONDOCUMENTSCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF EXECUTIONDOCUMENTSCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$STEPNUMBER EXECUTIONDOCUMENTSCAPTION.STEPNUMBER%TYPE := :NEW.STEPNUMBER;
  new$FACIALACC_CLS EXECUTIONDOCUMENTSCAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$RECIPIENT_REF EXECUTIONDOCUMENTSCAPTION.RECIPIENT_REF%TYPE := :NEW.RECIPIENT_REF;
  new$REGISTRATIONTYPE EXECUTIONDOCUMENTSCAPTION.REGISTRATIONTYPE%TYPE := :NEW.REGISTRATIONTYPE;
  new$REESTRNUMBER EXECUTIONDOCUMENTSCAPTION.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$AGREEMENTINNERNUMBER EXECUTIONDOCUMENTSCAPTION.AGREEMENTINNERNUMBER%TYPE := :NEW.AGREEMENTINNERNUMBER;
  new$REJECTCLS EXECUTIONDOCUMENTSCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS EXECUTIONDOCUMENTSCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID EXECUTIONDOCUMENTSCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID EXECUTIONDOCUMENTSCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REVIEWNOTE EXECUTIONDOCUMENTSCAPTION.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF EXECUTIONDOCUMENTSCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION EXECUTIONDOCUMENTSCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$EXECDOCFINSUMMA EXECUTIONDOCUMENTSCAPTION.EXECDOCFINSUMMA%TYPE := :NEW.EXECDOCFINSUMMA;
  new$FACT EXECUTIONDOCUMENTSCAPTION.FACT%TYPE := :NEW.FACT;
  new$DOCNUMBER EXECUTIONDOCUMENTSCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SENDERIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REALID EXECUTIONDOCUMENTSCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER EXECUTIONDOCUMENTSCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTREF EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ADJUSTMENTNUMBER EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$ACCEPTED EXECUTIONDOCUMENTSCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED EXECUTIONDOCUMENTSCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$LASTADJUSTMENT EXECUTIONDOCUMENTSCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$AGREEMENTREF EXECUTIONDOCUMENTSCAPTION.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$NOTE EXECUTIONDOCUMENTSCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$SUPPLIERSTOREDPROPS EXECUTIONDOCUMENTSCAPTION.SUPPLIERSTOREDPROPS%TYPE := :NEW.SUPPLIERSTOREDPROPS;
  new$SUPPLIER_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIER_REF%TYPE := :NEW.SUPPLIER_REF;
  new$SUPPLIERACC_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIERACC_REF%TYPE := :NEW.SUPPLIERACC_REF;
  new$TEMPREJECTCAUSE EXECUTIONDOCUMENTSCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
  new$REJECTCAUSE EXECUTIONDOCUMENTSCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  Tmp$ NUMBER(10);
  AdjID$ NUMBER(10);
  AdjDocNum$ VARCHAR2(50);
  agr_accepted$ NUMBER(10);
  agr_acceptdate$ NUMBER(10);
  PreviousInner$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ExecDoccaption_BI)
-- Version 11.20.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$DocType is null) then 
    new$DocType := 0;
  END IF;
  if (new$Summa is null) then 
    new$Summa := 0;
  END IF;
  if (new$ExecDocFinSumma is null) then 
    new$ExecDocFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$RegistrationType is null) then 
    new$RegistrationType := 0;
  END IF;
  if (new$Fact is null) then 
    new$Fact := 0;
  END IF;
  if (new$Accepted is null) then 
    new$Accepted := 1;
  END IF;
  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    BEGIN
      select fa.BudgetRef
      into new$BudgetRef     from FacialAcc_Cls fa
      where fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then 
    GetIntConst(-1,3,new$BudgetRef);
  END IF;
  if (new$Supplier_Ref is null and new$SupplierAcc_Ref is not null) then
    BEGIN
      select oa.Org_Ref
      into new$Supplier_Ref   from Org_Accounts oa
      where oa.id = new$SupplierAcc_Ref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,     ,      */
  if (new$AdjustmentRef is null) then
    new$InnerNumber := GEN_ID('g_ExecDocNumber',1);
      
  else
    BEGIN
      /*          */
      select
      InnerNumber 
      into PreviousInner$     from ExecutionDocumentsCaption
      where ID = new$AdjustmentRef and LastAccepted = 1 and LastAdjustment = 1
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (PreviousInner$ is null) then
      RaiseException('EX_ExecDoc_NotFindInner');
    END IF;
    new$InnerNumber := PreviousInner$;
      
  END IF;
  /*      id */  
  new$agreementinnernumber := null;
  if (new$agreementref is not null) then
    BEGIN
      select
      innernumber
      into new$agreementinnernumber     from agreements
      where
      id = new$agreementref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_EXECDOCCAPTION_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;
          
    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_EXECDOCCAPTION_BI_10)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*    .*/
  if (new$InnerNumber is null) then
    RaiseException('EX_AGR_InnerNumsIsNull');
  END IF;

  /*    */
  select max(AdjustmentNumber)
  into Tmp$     from ExecutionDocumentsCaption
  where (InnerNumber = new$InnerNumber)
  ;
  /*      ,   0*/
  if (Tmp$ is null) then
    new$AdjustmentNumber := 0;
        
  else
    new$AdjustmentNumber := Tmp$ + 1;
  END IF;
  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;
        
  else
    new$LastAdjustment := 1;
  END IF;
  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then
    new$LastAccepted := 1;
        
  else
    new$LastAccepted := 0;
  END IF;
  /*    */
  if (new$AdjustmentRef is not null) then
    /*      -    */
    select count(ID), max(ID), max(DocNumber)
    into Tmp$, AdjID$, AdjDocNum$       from ExecutionDocumentsCaption
    where (InnerNumber = new$InnerNumber) and (LastAccepted = 1)
    ;
    /*   ,  */
    if (Tmp$ <> 1) then
      RaiseException('EX_ExecDoc_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID)
    into Tmp$       from ExecutionDocumentsCaption
    where (InnerNumber = new$InnerNumber) and (AcceptDate is null)
    ;
    if (Tmp$ > 0) then
      RaiseException('EX_ExecDoc_AdjustDuplicate');
    END IF;
    /* ,    ,    */      
    new$AdjustmentRef := AdjID$;
        
  else /*     */
    /*       (    )*/      
    new$AdjustmentRef := null;
  END IF;

-- - - - - - - - - - - - -
-- BI_40 (tr_execdoccaption_bi_40)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*       */
  if (new$senderId is null) then 
    new$senderIdKey := -1;
      
  else 
    new$senderIdKey := new$senderId;
  END IF;
  if (new$SenderRecordID is null)then
    new$SenderRecordIDKey := new$ID;
      
  else 
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_60 (tr_execdoccaption_bi_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$agreementinnernumber is not null) then
    BEGIN
      /*        , .. 
             ,    ,   
            ,     */
      select accepted, acceptdate     into
      agr_accepted$, agr_acceptdate$ from agreements
      where
      innernumber = new$agreementinnernumber and adjustmentnumber = 0
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*        */
    if (new$acceptdate is null and agr_accepted$ = 0 and agr_acceptdate$ is not null) then
      RaiseException('EX_Agr_Rejected');
    END IF;
    /*        */
    if (new$accepted = 1 and new$acceptdate is not null and
    (agr_accepted$ = 0 or agr_acceptdate$ is null)) then
      RaiseException('EX_Agr_NotAccepted');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_EXECDOCCAPTION_BI_500)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_EXECUTIONDOCUMENTSCAPTION (
    ID,
    DOCTYPE,
    DOCUMENTDATE,
    ACCEPTDATE,
    SUMMA,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    STEPNUMBER,
    FACIALACC_CLS,
    RECIPIENT_REF,
    REGISTRATIONTYPE,
    REESTRNUMBER,
    AGREEMENTINNERNUMBER,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXECDOCFINSUMMA,
    FACT,
    DOCNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REALID,
    INNERNUMBER,
    ADJUSTMENTREF,
    ADJUSTMENTNUMBER,
    ACCEPTED,
    LASTACCEPTED,
    LASTADJUSTMENT,
    AGREEMENTREF,
    NOTE,
    SUPPLIERSTOREDPROPS,
    SUPPLIER_REF,
    SUPPLIERACC_REF,
    TEMPREJECTCAUSE,
    REJECTCAUSE
  ) VALUES (
    new$ID,
    new$DOCTYPE,
    new$DOCUMENTDATE,
    new$ACCEPTDATE,
    new$SUMMA,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$STEPNUMBER,
    new$FACIALACC_CLS,
    new$RECIPIENT_REF,
    new$REGISTRATIONTYPE,
    new$REESTRNUMBER,
    new$AGREEMENTINNERNUMBER,
    new$REJECTCLS,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$REVIEWNOTE,
    new$DOCSTATEREF,
    new$RVERSION,
    new$EXECDOCFINSUMMA,
    new$FACT,
    new$DOCNUMBER,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$REALID,
    new$INNERNUMBER,
    new$ADJUSTMENTREF,
    new$ADJUSTMENTNUMBER,
    new$ACCEPTED,
    new$LASTACCEPTED,
    new$LASTADJUSTMENT,
    new$AGREEMENTREF,
    new$NOTE,
    new$SUPPLIERSTOREDPROPS,
    new$SUPPLIER_REF,
    new$SUPPLIERACC_REF,
    new$TEMPREJECTCAUSE,
    new$REJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_0 (TR_ExecDocCaption_AI)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*       */
  /*     ,       */
  if ((new$AdjustmentRef is not null) and (new$LastAdjustment = 1)) then
    update ExecutionDocuMENTSCaption set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);        
    if (new$LastAccepted = 1) then
      update ExecutionDocuMENTSCaption set
      LastAccepted = 0,
      RVersion = -1
      where (ID = new$AdjustmentRef);
        
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_EXECDOCCAPTION_AI_500)
-- - - - - - - - - - - - -

-- 25.08.2004
  delete from DelRecIndexes where (TableID = 114) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_EXECUTIONDOCUMENTSCAPTIO_IU
  INSTEAD OF UPDATE
  ON EXECUTIONDOCUMENTSCAPTION
  FOR EACH ROW
DECLARE
  new$ID EXECUTIONDOCUMENTSCAPTION.ID%TYPE := :NEW.ID;
  new$DOCTYPE EXECUTIONDOCUMENTSCAPTION.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$DOCUMENTDATE EXECUTIONDOCUMENTSCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE EXECUTIONDOCUMENTSCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SUMMA EXECUTIONDOCUMENTSCAPTION.SUMMA%TYPE := :NEW.SUMMA;
  new$CREATERUSER EXECUTIONDOCUMENTSCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE EXECUTIONDOCUMENTSCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE EXECUTIONDOCUMENTSCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER EXECUTIONDOCUMENTSCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF EXECUTIONDOCUMENTSCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$STEPNUMBER EXECUTIONDOCUMENTSCAPTION.STEPNUMBER%TYPE := :NEW.STEPNUMBER;
  new$FACIALACC_CLS EXECUTIONDOCUMENTSCAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$RECIPIENT_REF EXECUTIONDOCUMENTSCAPTION.RECIPIENT_REF%TYPE := :NEW.RECIPIENT_REF;
  new$REGISTRATIONTYPE EXECUTIONDOCUMENTSCAPTION.REGISTRATIONTYPE%TYPE := :NEW.REGISTRATIONTYPE;
  new$REESTRNUMBER EXECUTIONDOCUMENTSCAPTION.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$AGREEMENTINNERNUMBER EXECUTIONDOCUMENTSCAPTION.AGREEMENTINNERNUMBER%TYPE := :NEW.AGREEMENTINNERNUMBER;
  new$REJECTCLS EXECUTIONDOCUMENTSCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS EXECUTIONDOCUMENTSCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID EXECUTIONDOCUMENTSCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID EXECUTIONDOCUMENTSCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REVIEWNOTE EXECUTIONDOCUMENTSCAPTION.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF EXECUTIONDOCUMENTSCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION EXECUTIONDOCUMENTSCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$EXECDOCFINSUMMA EXECUTIONDOCUMENTSCAPTION.EXECDOCFINSUMMA%TYPE := :NEW.EXECDOCFINSUMMA;
  new$FACT EXECUTIONDOCUMENTSCAPTION.FACT%TYPE := :NEW.FACT;
  new$DOCNUMBER EXECUTIONDOCUMENTSCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SENDERIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REALID EXECUTIONDOCUMENTSCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER EXECUTIONDOCUMENTSCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTREF EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ADJUSTMENTNUMBER EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$ACCEPTED EXECUTIONDOCUMENTSCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED EXECUTIONDOCUMENTSCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$LASTADJUSTMENT EXECUTIONDOCUMENTSCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$AGREEMENTREF EXECUTIONDOCUMENTSCAPTION.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$NOTE EXECUTIONDOCUMENTSCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$SUPPLIERSTOREDPROPS EXECUTIONDOCUMENTSCAPTION.SUPPLIERSTOREDPROPS%TYPE := :NEW.SUPPLIERSTOREDPROPS;
  new$SUPPLIER_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIER_REF%TYPE := :NEW.SUPPLIER_REF;
  new$SUPPLIERACC_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIERACC_REF%TYPE := :NEW.SUPPLIERACC_REF;
  new$TEMPREJECTCAUSE EXECUTIONDOCUMENTSCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
  new$REJECTCAUSE EXECUTIONDOCUMENTSCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  CntAgr$ NUMBER(10);
  CntStep$ NUMBER(10);
  agr_accepted$ NUMBER(10);
  agr_acceptdate$ NUMBER(10);
  CountExecDoc$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_EXECDOCCAPTION_BU)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$DocType is null) then 
    new$DocType := 0;
  END IF;
  if (new$Summa is null) then 
    new$Summa := 0;
  END IF;
  if (new$ExecDocFinSumma is null) then 
    new$ExecDocFinSumma := 0;  
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$RegistrationType is null) then 
    new$RegistrationType := 0;
  END IF;
  if (new$Fact is null) then 
    new$Fact := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      SELECT COUNT(                   Id
      ) INTO CNT$1
      from ExecutionDocumentsDetail
      where 
      (                   RecordIndex = :old.Id
      ) AND (ROWNUM = 1)                ;
      if ((CNT$1<> 0)         ) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      SELECT COUNT(                   Id
      ) INTO CNT$2
      from PaymentSchedule
      where
      (                   ExecutionRef = :old.Id
      ) AND (ROWNUM = 1)                ;
      if ((CNT$2<> 0)         ) then
        RaiseException('Ex_CantModufyBudget');    
      END IF;
    END IF;
  END IF;
  /*     ,        */
  if (new$InnerNumber is null) then
    new$InnerNumber := :old.InnerNumber;
  END IF;
  /* c,           */
  /* ,    */
  if (new$InnerNumber <> :old.InnerNumber or
  new$AdjustmentRef <> :old.AdjustmentRef or
  new$AdjustmentNumber <> :old.AdjustmentNumber) then
    RaiseException('EX_Agr_ChangeInnerNums');
  END IF;
  /*      id */  
  new$agreementinnernumber := null;
  if (new$agreementref is not null) then
    BEGIN
      select
      innernumber
      into new$agreementinnernumber     from agreements
      where
      id = new$agreementref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_EXECDOCCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;
          
    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_EXECDOCCAPTION_BU_10)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*     */
  if (:old.AcceptDate is not null and :old.Accepted = 0 and (new$Accepted = 1 or new$AcceptDate is null)) then
    RaiseException('EX_RollbackCancel');
  END IF;
      
  /*   ,     LastAccepted*/
  if (:old.AcceptDate is null and new$AcceptDate is not null and new$Accepted = 1) then 
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 1;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    END IF;
  END IF;
      
  /*    ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 1 and new$AcceptDate is null) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 0;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');  
    END IF;
  END IF;
      
  /*   ,     LastAdjustment  LastAccepted */
  if (new$AcceptDate is not null and new$Accepted = 0 and (:old.AcceptDate is null or :old.Accepted = 1)) then
    if (:old.LastAdjustment = 1) then
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    END IF;
    SELECT COUNT(                 Id
    ) INTO CNT$1
    from ExecutionDocumentsCaption
    where
    (                 InnerNumber = new$InnerNumber and AdjustmentNumber > 0
    ) AND (ROWNUM = 1)              ;
    /*          */
    if (new$AdjustmentNumber = 0 and 
    (CNT$1<> 0)       ) then
      RaiseException('EX_ExecDoc_PrimaryAgrHasNotify');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_40 (tr_execdoccaption_bu_40)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  if ((:old.AcceptDate is not null) and (new$AcceptDate is null)) then
    select count(ID) into CntAgr$ from Agreements where (CloseDoc = :old.ID) ;
    select count(ID) into CntStep$ from AgreementSteps where (CloseDoc = :old.ID) ;
    if ((CntAgr$ > 0) or (CntStep$ > 0)) then
      RaiseException('ex_CannotUpdateCloseDoc');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_60 (tr_execdoccaption_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$agreementinnernumber is not null) then
    BEGIN
      /*        , .. 
             ,    ,   
            ,     */
      select accepted, acceptdate     into
      agr_accepted$, agr_acceptdate$ from agreements
      where
      innernumber = new$agreementinnernumber and adjustmentnumber = 0
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*        */
    if (new$acceptdate is null and agr_accepted$ = 0 and agr_acceptdate$ is not null) then
      RaiseException('EX_Agr_Rejected');
    END IF;
    /*        */
    if (new$accepted = 1 and new$acceptdate is not null and
    (agr_accepted$ = 0 or agr_acceptdate$ is null)) then
      RaiseException('EX_Agr_NotAccepted');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_EXECDOCCAPTION_BU_200)
-- Create 04.10.2004
-- - - - - - - - - - - - -

  /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_EXECDOCCAPTION_BU_210)
-- Version 11.20.00.1
-- - - - - - - - - - - - -

  /*   */
  if (new$rejectcls is not null and new$accepted = 0) then
    /*         */
    select
    count(ffd.id)
    into CountExecDoc$     from
    facialfindetail ffd
    left join facialfincaption ffc on ffc.id = ffd.recordindex
    where
    (ffc.acceptdate is not null and (ffd.sourceexecdoc = new$id or ffd.destexecdoc = new$id))
    ;
    /*       */
    if (CountExecDoc$ <> 0) then
      RaiseException('ex_exedoc_useinfacialfindetail');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_EDCAPTION_BU_700)
-- Create 14.10.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_EXECUTIONDOCUMENTSCAPTION SET
    ID = new$ID,
    DOCTYPE = new$DOCTYPE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    SUMMA = new$SUMMA,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    STEPNUMBER = new$STEPNUMBER,
    FACIALACC_CLS = new$FACIALACC_CLS,
    RECIPIENT_REF = new$RECIPIENT_REF,
    REGISTRATIONTYPE = new$REGISTRATIONTYPE,
    REESTRNUMBER = new$REESTRNUMBER,
    AGREEMENTINNERNUMBER = new$AGREEMENTINNERNUMBER,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXECDOCFINSUMMA = new$EXECDOCFINSUMMA,
    FACT = new$FACT,
    DOCNUMBER = new$DOCNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REALID = new$REALID,
    INNERNUMBER = new$INNERNUMBER,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    ACCEPTED = new$ACCEPTED,
    LASTACCEPTED = new$LASTACCEPTED,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    AGREEMENTREF = new$AGREEMENTREF,
    NOTE = new$NOTE,
    SUPPLIERSTOREDPROPS = new$SUPPLIERSTOREDPROPS,
    SUPPLIER_REF = new$SUPPLIER_REF,
    SUPPLIERACC_REF = new$SUPPLIERACC_REF,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_0 (TR_ExecDocCaption_AU)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*       */
  /*     ,       */
  if ((new$AdjustmentRef is not null) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update ExecutionDocuMENTSCaption set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentRef is not null) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update ExecutionDocuMENTSCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_EXECDOCCAPTION_AU_30)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$Accepted <> :old.Accepted) or 
  (new$AcceptDate is not null and :old.AcceptDate is null) or 
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where ExecutionRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_EXECDOCCAPTION_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (114, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=114) and (RecordId=new$ID);
  end if;

END;
/
update EXECUTIONDOCUMENTSCAPTION set
  REJECTCAUSE = TempRejectCause
/
commit work 
/
ALTER TABLE TB_EXECUTIONDOCUMENTSCAPTION DROP (TempRejectCause)
/

CREATE OR REPLACE VIEW EXECUTIONDOCUMENTSCAPTION (
  ID,
  DOCTYPE,
  DOCUMENTDATE,
  ACCEPTDATE,
  SUMMA,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  BUDGETREF,
  STEPNUMBER,
  FACIALACC_CLS,
  RECIPIENT_REF,
  REGISTRATIONTYPE,
  REESTRNUMBER,
  AGREEMENTINNERNUMBER,
  REJECTCLS,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  REVIEWNOTE,
  DOCSTATEREF,
  RVERSION,
  EXECDOCFINSUMMA,
  FACT,
  DOCNUMBER,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  REALID,
  INNERNUMBER,
  ADJUSTMENTREF,
  ADJUSTMENTNUMBER,
  ACCEPTED,
  LASTACCEPTED,
  LASTADJUSTMENT,
  AGREEMENTREF,
  NOTE,
  SUPPLIERSTOREDPROPS,
  SUPPLIER_REF,
  SUPPLIERACC_REF,
  REJECTCAUSE)
AS
  SELECT
    ID,
    DOCTYPE,
    DOCUMENTDATE,
    ACCEPTDATE,
    SUMMA,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    STEPNUMBER,
    FACIALACC_CLS,
    RECIPIENT_REF,
    REGISTRATIONTYPE,
    REESTRNUMBER,
    AGREEMENTINNERNUMBER,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXECDOCFINSUMMA,
    FACT,
    DOCNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REALID,
    INNERNUMBER,
    ADJUSTMENTREF,
    ADJUSTMENTNUMBER,
    ACCEPTED,
    LASTACCEPTED,
    LASTADJUSTMENT,
    AGREEMENTREF,
    NOTE,
    SUPPLIERSTOREDPROPS,
    SUPPLIER_REF,
    SUPPLIERACC_REF,
    REJECTCAUSE
  FROM TB_EXECUTIONDOCUMENTSCAPTION
/

CREATE OR REPLACE TRIGGER TR_EXECUTIONDOCUMENTSCAPTIO_ID
  INSTEAD OF DELETE
  ON EXECUTIONDOCUMENTSCAPTION
  FOR EACH ROW
DECLARE
  quant$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_DOCEXECCAPTION_BD)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  select count(ID)   into quant$ from executiondocumentscaption 
  where AdjustmentRef = :old.ID
  ;
  if (quant$  = 0) then
    delete from ExecutionDocumentsDetail where (RecordIndex = :old.ID);
    delete from paymentschedule where (ExecutionRef = :old.ID)and(ProgIndex=308);
      
  else
    RaiseException('ex_agr_cantdeladjustmented');
  END IF;

-- - - - - - - - - - - - -
-- BD_10 (TR_DocExecCaption_BD_10)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*   LastAdjustment     */
  if ((:old.AdjustmentRef is not null) and (:old.LastAdjustment = 1)) then
    update ExecutionDocumentsCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;
  /*   LastAccepted     */    
  if ((:old.AdjustmentRef is not null) and (:old.LastAccepted = 1)) then
    update ExecutionDocumentsCaption set
    LastAccepted = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_EXECUTIONDOCUMENTSCAPTION
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_10 (TR_ExecDocCaption_AD_10)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*   LastAdjustment     */
  if ((:old.AdjustmentRef is not null) and (:old.LastAdjustment = 1)) then
    update ExecutionDocumentsCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;
  /*   LastAccepted     */    
  if ((:old.AdjustmentRef is not null) and (:old.LastAccepted = 1)) then
    update ExecutionDocumentsCaption set
    LastAccepted = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AD_200 (TR_EXECDOCCAPTION_AD_200)
-- Create 04.10.2004
-- - - - - - - - - - - - -

  /*        */
  delete from StateJumpHistory where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_EXECDOCCAPTION_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordId, DeleteDate, SUMMA) values (114, :old.ID, SYSDATE, :old.SUMMA);

END;
/

CREATE OR REPLACE TRIGGER TR_EXECUTIONDOCUMENTSCAPTIO_II
  INSTEAD OF INSERT
  ON EXECUTIONDOCUMENTSCAPTION
  FOR EACH ROW
DECLARE
  new$ID EXECUTIONDOCUMENTSCAPTION.ID%TYPE := :NEW.ID;
  new$DOCTYPE EXECUTIONDOCUMENTSCAPTION.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$DOCUMENTDATE EXECUTIONDOCUMENTSCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE EXECUTIONDOCUMENTSCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SUMMA EXECUTIONDOCUMENTSCAPTION.SUMMA%TYPE := :NEW.SUMMA;
  new$CREATERUSER EXECUTIONDOCUMENTSCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE EXECUTIONDOCUMENTSCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE EXECUTIONDOCUMENTSCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER EXECUTIONDOCUMENTSCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF EXECUTIONDOCUMENTSCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$STEPNUMBER EXECUTIONDOCUMENTSCAPTION.STEPNUMBER%TYPE := :NEW.STEPNUMBER;
  new$FACIALACC_CLS EXECUTIONDOCUMENTSCAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$RECIPIENT_REF EXECUTIONDOCUMENTSCAPTION.RECIPIENT_REF%TYPE := :NEW.RECIPIENT_REF;
  new$REGISTRATIONTYPE EXECUTIONDOCUMENTSCAPTION.REGISTRATIONTYPE%TYPE := :NEW.REGISTRATIONTYPE;
  new$REESTRNUMBER EXECUTIONDOCUMENTSCAPTION.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$AGREEMENTINNERNUMBER EXECUTIONDOCUMENTSCAPTION.AGREEMENTINNERNUMBER%TYPE := :NEW.AGREEMENTINNERNUMBER;
  new$REJECTCLS EXECUTIONDOCUMENTSCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS EXECUTIONDOCUMENTSCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID EXECUTIONDOCUMENTSCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID EXECUTIONDOCUMENTSCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REVIEWNOTE EXECUTIONDOCUMENTSCAPTION.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF EXECUTIONDOCUMENTSCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION EXECUTIONDOCUMENTSCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$EXECDOCFINSUMMA EXECUTIONDOCUMENTSCAPTION.EXECDOCFINSUMMA%TYPE := :NEW.EXECDOCFINSUMMA;
  new$FACT EXECUTIONDOCUMENTSCAPTION.FACT%TYPE := :NEW.FACT;
  new$DOCNUMBER EXECUTIONDOCUMENTSCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SENDERIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REALID EXECUTIONDOCUMENTSCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER EXECUTIONDOCUMENTSCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTREF EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ADJUSTMENTNUMBER EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$ACCEPTED EXECUTIONDOCUMENTSCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED EXECUTIONDOCUMENTSCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$LASTADJUSTMENT EXECUTIONDOCUMENTSCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$AGREEMENTREF EXECUTIONDOCUMENTSCAPTION.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$NOTE EXECUTIONDOCUMENTSCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$SUPPLIERSTOREDPROPS EXECUTIONDOCUMENTSCAPTION.SUPPLIERSTOREDPROPS%TYPE := :NEW.SUPPLIERSTOREDPROPS;
  new$SUPPLIER_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIER_REF%TYPE := :NEW.SUPPLIER_REF;
  new$SUPPLIERACC_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIERACC_REF%TYPE := :NEW.SUPPLIERACC_REF;
  new$REJECTCAUSE EXECUTIONDOCUMENTSCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  Tmp$ NUMBER(10);
  AdjID$ NUMBER(10);
  AdjDocNum$ VARCHAR2(50);
  agr_accepted$ NUMBER(10);
  agr_acceptdate$ NUMBER(10);
  PreviousInner$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ExecDoccaption_BI)
-- Version 11.20.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$DocType is null) then 
    new$DocType := 0;
  END IF;
  if (new$Summa is null) then 
    new$Summa := 0;
  END IF;
  if (new$ExecDocFinSumma is null) then 
    new$ExecDocFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$RegistrationType is null) then 
    new$RegistrationType := 0;
  END IF;
  if (new$Fact is null) then 
    new$Fact := 0;
  END IF;
  if (new$Accepted is null) then 
    new$Accepted := 1;
  END IF;
  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    BEGIN
      select fa.BudgetRef
      into new$BudgetRef     from FacialAcc_Cls fa
      where fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then 
    GetIntConst(-1,3,new$BudgetRef);
  END IF;
  if (new$Supplier_Ref is null and new$SupplierAcc_Ref is not null) then
    BEGIN
      select oa.Org_Ref
      into new$Supplier_Ref   from Org_Accounts oa
      where oa.id = new$SupplierAcc_Ref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,     ,      */
  if (new$AdjustmentRef is null) then
    new$InnerNumber := GEN_ID('g_ExecDocNumber',1);
      
  else
    BEGIN
      /*          */
      select
      InnerNumber 
      into PreviousInner$     from ExecutionDocumentsCaption
      where ID = new$AdjustmentRef and LastAccepted = 1 and LastAdjustment = 1
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (PreviousInner$ is null) then
      RaiseException('EX_ExecDoc_NotFindInner');
    END IF;
    new$InnerNumber := PreviousInner$;
      
  END IF;
  /*      id */  
  new$agreementinnernumber := null;
  if (new$agreementref is not null) then
    BEGIN
      select
      innernumber
      into new$agreementinnernumber     from agreements
      where
      id = new$agreementref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_EXECDOCCAPTION_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;
          
    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_EXECDOCCAPTION_BI_10)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*    .*/
  if (new$InnerNumber is null) then
    RaiseException('EX_AGR_InnerNumsIsNull');
  END IF;

  /*    */
  select max(AdjustmentNumber)
  into Tmp$     from ExecutionDocumentsCaption
  where (InnerNumber = new$InnerNumber)
  ;
  /*      ,   0*/
  if (Tmp$ is null) then
    new$AdjustmentNumber := 0;
        
  else
    new$AdjustmentNumber := Tmp$ + 1;
  END IF;
  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;
        
  else
    new$LastAdjustment := 1;
  END IF;
  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then
    new$LastAccepted := 1;
        
  else
    new$LastAccepted := 0;
  END IF;
  /*    */
  if (new$AdjustmentRef is not null) then
    /*      -    */
    select count(ID), max(ID), max(DocNumber)
    into Tmp$, AdjID$, AdjDocNum$       from ExecutionDocumentsCaption
    where (InnerNumber = new$InnerNumber) and (LastAccepted = 1)
    ;
    /*   ,  */
    if (Tmp$ <> 1) then
      RaiseException('EX_ExecDoc_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID)
    into Tmp$       from ExecutionDocumentsCaption
    where (InnerNumber = new$InnerNumber) and (AcceptDate is null)
    ;
    if (Tmp$ > 0) then
      RaiseException('EX_ExecDoc_AdjustDuplicate');
    END IF;
    /* ,    ,    */      
    new$AdjustmentRef := AdjID$;
        
  else /*     */
    /*       (    )*/      
    new$AdjustmentRef := null;
  END IF;

-- - - - - - - - - - - - -
-- BI_40 (tr_execdoccaption_bi_40)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*       */
  if (new$senderId is null) then 
    new$senderIdKey := -1;
      
  else 
    new$senderIdKey := new$senderId;
  END IF;
  if (new$SenderRecordID is null)then
    new$SenderRecordIDKey := new$ID;
      
  else 
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_60 (tr_execdoccaption_bi_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$agreementinnernumber is not null) then
    BEGIN
      /*        , .. 
             ,    ,   
            ,     */
      select accepted, acceptdate     into
      agr_accepted$, agr_acceptdate$ from agreements
      where
      innernumber = new$agreementinnernumber and adjustmentnumber = 0
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*        */
    if (new$acceptdate is null and agr_accepted$ = 0 and agr_acceptdate$ is not null) then
      RaiseException('EX_Agr_Rejected');
    END IF;
    /*        */
    if (new$accepted = 1 and new$acceptdate is not null and
    (agr_accepted$ = 0 or agr_acceptdate$ is null)) then
      RaiseException('EX_Agr_NotAccepted');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_EXECDOCCAPTION_BI_500)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_EXECUTIONDOCUMENTSCAPTION (
    ID,
    DOCTYPE,
    DOCUMENTDATE,
    ACCEPTDATE,
    SUMMA,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    STEPNUMBER,
    FACIALACC_CLS,
    RECIPIENT_REF,
    REGISTRATIONTYPE,
    REESTRNUMBER,
    AGREEMENTINNERNUMBER,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXECDOCFINSUMMA,
    FACT,
    DOCNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REALID,
    INNERNUMBER,
    ADJUSTMENTREF,
    ADJUSTMENTNUMBER,
    ACCEPTED,
    LASTACCEPTED,
    LASTADJUSTMENT,
    AGREEMENTREF,
    NOTE,
    SUPPLIERSTOREDPROPS,
    SUPPLIER_REF,
    SUPPLIERACC_REF,
    REJECTCAUSE
  ) VALUES (
    new$ID,
    new$DOCTYPE,
    new$DOCUMENTDATE,
    new$ACCEPTDATE,
    new$SUMMA,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$STEPNUMBER,
    new$FACIALACC_CLS,
    new$RECIPIENT_REF,
    new$REGISTRATIONTYPE,
    new$REESTRNUMBER,
    new$AGREEMENTINNERNUMBER,
    new$REJECTCLS,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$REVIEWNOTE,
    new$DOCSTATEREF,
    new$RVERSION,
    new$EXECDOCFINSUMMA,
    new$FACT,
    new$DOCNUMBER,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$REALID,
    new$INNERNUMBER,
    new$ADJUSTMENTREF,
    new$ADJUSTMENTNUMBER,
    new$ACCEPTED,
    new$LASTACCEPTED,
    new$LASTADJUSTMENT,
    new$AGREEMENTREF,
    new$NOTE,
    new$SUPPLIERSTOREDPROPS,
    new$SUPPLIER_REF,
    new$SUPPLIERACC_REF,
    new$REJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_0 (TR_ExecDocCaption_AI)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*       */
  /*     ,       */
  if ((new$AdjustmentRef is not null) and (new$LastAdjustment = 1)) then
    update ExecutionDocuMENTSCaption set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);        
    if (new$LastAccepted = 1) then
      update ExecutionDocuMENTSCaption set
      LastAccepted = 0,
      RVersion = -1
      where (ID = new$AdjustmentRef);
        
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_EXECDOCCAPTION_AI_500)
-- - - - - - - - - - - - -

-- 25.08.2004
  delete from DelRecIndexes where (TableID = 114) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_EXECUTIONDOCUMENTSCAPTIO_IU
  INSTEAD OF UPDATE
  ON EXECUTIONDOCUMENTSCAPTION
  FOR EACH ROW
DECLARE
  new$ID EXECUTIONDOCUMENTSCAPTION.ID%TYPE := :NEW.ID;
  new$DOCTYPE EXECUTIONDOCUMENTSCAPTION.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$DOCUMENTDATE EXECUTIONDOCUMENTSCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE EXECUTIONDOCUMENTSCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SUMMA EXECUTIONDOCUMENTSCAPTION.SUMMA%TYPE := :NEW.SUMMA;
  new$CREATERUSER EXECUTIONDOCUMENTSCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE EXECUTIONDOCUMENTSCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE EXECUTIONDOCUMENTSCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER EXECUTIONDOCUMENTSCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF EXECUTIONDOCUMENTSCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$STEPNUMBER EXECUTIONDOCUMENTSCAPTION.STEPNUMBER%TYPE := :NEW.STEPNUMBER;
  new$FACIALACC_CLS EXECUTIONDOCUMENTSCAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$RECIPIENT_REF EXECUTIONDOCUMENTSCAPTION.RECIPIENT_REF%TYPE := :NEW.RECIPIENT_REF;
  new$REGISTRATIONTYPE EXECUTIONDOCUMENTSCAPTION.REGISTRATIONTYPE%TYPE := :NEW.REGISTRATIONTYPE;
  new$REESTRNUMBER EXECUTIONDOCUMENTSCAPTION.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$AGREEMENTINNERNUMBER EXECUTIONDOCUMENTSCAPTION.AGREEMENTINNERNUMBER%TYPE := :NEW.AGREEMENTINNERNUMBER;
  new$REJECTCLS EXECUTIONDOCUMENTSCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS EXECUTIONDOCUMENTSCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID EXECUTIONDOCUMENTSCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID EXECUTIONDOCUMENTSCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REVIEWNOTE EXECUTIONDOCUMENTSCAPTION.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF EXECUTIONDOCUMENTSCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION EXECUTIONDOCUMENTSCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$EXECDOCFINSUMMA EXECUTIONDOCUMENTSCAPTION.EXECDOCFINSUMMA%TYPE := :NEW.EXECDOCFINSUMMA;
  new$FACT EXECUTIONDOCUMENTSCAPTION.FACT%TYPE := :NEW.FACT;
  new$DOCNUMBER EXECUTIONDOCUMENTSCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SENDERIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REALID EXECUTIONDOCUMENTSCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER EXECUTIONDOCUMENTSCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTREF EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ADJUSTMENTNUMBER EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$ACCEPTED EXECUTIONDOCUMENTSCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED EXECUTIONDOCUMENTSCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$LASTADJUSTMENT EXECUTIONDOCUMENTSCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$AGREEMENTREF EXECUTIONDOCUMENTSCAPTION.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$NOTE EXECUTIONDOCUMENTSCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$SUPPLIERSTOREDPROPS EXECUTIONDOCUMENTSCAPTION.SUPPLIERSTOREDPROPS%TYPE := :NEW.SUPPLIERSTOREDPROPS;
  new$SUPPLIER_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIER_REF%TYPE := :NEW.SUPPLIER_REF;
  new$SUPPLIERACC_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIERACC_REF%TYPE := :NEW.SUPPLIERACC_REF;
  new$REJECTCAUSE EXECUTIONDOCUMENTSCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  CntAgr$ NUMBER(10);
  CntStep$ NUMBER(10);
  agr_accepted$ NUMBER(10);
  agr_acceptdate$ NUMBER(10);
  CountExecDoc$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_EXECDOCCAPTION_BU)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$DocType is null) then 
    new$DocType := 0;
  END IF;
  if (new$Summa is null) then 
    new$Summa := 0;
  END IF;
  if (new$ExecDocFinSumma is null) then 
    new$ExecDocFinSumma := 0;  
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$RegistrationType is null) then 
    new$RegistrationType := 0;
  END IF;
  if (new$Fact is null) then 
    new$Fact := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      SELECT COUNT(                   Id
      ) INTO CNT$1
      from ExecutionDocumentsDetail
      where 
      (                   RecordIndex = :old.Id
      ) AND (ROWNUM = 1)                ;
      if ((CNT$1<> 0)         ) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      SELECT COUNT(                   Id
      ) INTO CNT$2
      from PaymentSchedule
      where
      (                   ExecutionRef = :old.Id
      ) AND (ROWNUM = 1)                ;
      if ((CNT$2<> 0)         ) then
        RaiseException('Ex_CantModufyBudget');    
      END IF;
    END IF;
  END IF;
  /*     ,        */
  if (new$InnerNumber is null) then
    new$InnerNumber := :old.InnerNumber;
  END IF;
  /* c,           */
  /* ,    */
  if (new$InnerNumber <> :old.InnerNumber or
  new$AdjustmentRef <> :old.AdjustmentRef or
  new$AdjustmentNumber <> :old.AdjustmentNumber) then
    RaiseException('EX_Agr_ChangeInnerNums');
  END IF;
  /*      id */  
  new$agreementinnernumber := null;
  if (new$agreementref is not null) then
    BEGIN
      select
      innernumber
      into new$agreementinnernumber     from agreements
      where
      id = new$agreementref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_EXECDOCCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;
          
    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_EXECDOCCAPTION_BU_10)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*     */
  if (:old.AcceptDate is not null and :old.Accepted = 0 and (new$Accepted = 1 or new$AcceptDate is null)) then
    RaiseException('EX_RollbackCancel');
  END IF;
      
  /*   ,     LastAccepted*/
  if (:old.AcceptDate is null and new$AcceptDate is not null and new$Accepted = 1) then 
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 1;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    END IF;
  END IF;
      
  /*    ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 1 and new$AcceptDate is null) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 0;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');  
    END IF;
  END IF;
      
  /*   ,     LastAdjustment  LastAccepted */
  if (new$AcceptDate is not null and new$Accepted = 0 and (:old.AcceptDate is null or :old.Accepted = 1)) then
    if (:old.LastAdjustment = 1) then
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    END IF;
    SELECT COUNT(                 Id
    ) INTO CNT$1
    from ExecutionDocumentsCaption
    where
    (                 InnerNumber = new$InnerNumber and AdjustmentNumber > 0
    ) AND (ROWNUM = 1)              ;
    /*          */
    if (new$AdjustmentNumber = 0 and 
    (CNT$1<> 0)       ) then
      RaiseException('EX_ExecDoc_PrimaryAgrHasNotify');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_40 (tr_execdoccaption_bu_40)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  if ((:old.AcceptDate is not null) and (new$AcceptDate is null)) then
    select count(ID) into CntAgr$ from Agreements where (CloseDoc = :old.ID) ;
    select count(ID) into CntStep$ from AgreementSteps where (CloseDoc = :old.ID) ;
    if ((CntAgr$ > 0) or (CntStep$ > 0)) then
      RaiseException('ex_CannotUpdateCloseDoc');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_60 (tr_execdoccaption_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$agreementinnernumber is not null) then
    BEGIN
      /*        , .. 
             ,    ,   
            ,     */
      select accepted, acceptdate     into
      agr_accepted$, agr_acceptdate$ from agreements
      where
      innernumber = new$agreementinnernumber and adjustmentnumber = 0
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*        */
    if (new$acceptdate is null and agr_accepted$ = 0 and agr_acceptdate$ is not null) then
      RaiseException('EX_Agr_Rejected');
    END IF;
    /*        */
    if (new$accepted = 1 and new$acceptdate is not null and
    (agr_accepted$ = 0 or agr_acceptdate$ is null)) then
      RaiseException('EX_Agr_NotAccepted');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_EXECDOCCAPTION_BU_200)
-- Create 04.10.2004
-- - - - - - - - - - - - -

  /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_EXECDOCCAPTION_BU_210)
-- Version 11.20.00.1
-- - - - - - - - - - - - -

  /*   */
  if (new$rejectcls is not null and new$accepted = 0) then
    /*         */
    select
    count(ffd.id)
    into CountExecDoc$     from
    facialfindetail ffd
    left join facialfincaption ffc on ffc.id = ffd.recordindex
    where
    (ffc.acceptdate is not null and (ffd.sourceexecdoc = new$id or ffd.destexecdoc = new$id))
    ;
    /*       */
    if (CountExecDoc$ <> 0) then
      RaiseException('ex_exedoc_useinfacialfindetail');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_EDCAPTION_BU_700)
-- Create 14.10.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_EXECUTIONDOCUMENTSCAPTION SET
    ID = new$ID,
    DOCTYPE = new$DOCTYPE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    SUMMA = new$SUMMA,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    STEPNUMBER = new$STEPNUMBER,
    FACIALACC_CLS = new$FACIALACC_CLS,
    RECIPIENT_REF = new$RECIPIENT_REF,
    REGISTRATIONTYPE = new$REGISTRATIONTYPE,
    REESTRNUMBER = new$REESTRNUMBER,
    AGREEMENTINNERNUMBER = new$AGREEMENTINNERNUMBER,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXECDOCFINSUMMA = new$EXECDOCFINSUMMA,
    FACT = new$FACT,
    DOCNUMBER = new$DOCNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REALID = new$REALID,
    INNERNUMBER = new$INNERNUMBER,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    ACCEPTED = new$ACCEPTED,
    LASTACCEPTED = new$LASTACCEPTED,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    AGREEMENTREF = new$AGREEMENTREF,
    NOTE = new$NOTE,
    SUPPLIERSTOREDPROPS = new$SUPPLIERSTOREDPROPS,
    SUPPLIER_REF = new$SUPPLIER_REF,
    SUPPLIERACC_REF = new$SUPPLIERACC_REF,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_0 (TR_ExecDocCaption_AU)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*       */
  /*     ,       */
  if ((new$AdjustmentRef is not null) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update ExecutionDocuMENTSCaption set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentRef is not null) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update ExecutionDocuMENTSCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_EXECDOCCAPTION_AU_30)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$Accepted <> :old.Accepted) or 
  (new$AcceptDate is not null and :old.AcceptDate is null) or 
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where ExecutionRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_EXECDOCCAPTION_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (114, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=114) and (RecordId=new$ID);
  end if;

END;
/
ALTER TRIGGER TR_EXECDOCCAPTION_BU_500 ENABLE
/
commit work 
/
ALTER TRIGGER TR_PAYDOC32_BU_500 DISABLE
/
/*        ,   */
-- drop trigger TR_PAYDOC32_AU_45
CREATE OR REPLACE TRIGGER TR_PAYDOC32_IU
  INSTEAD OF UPDATE
  ON PAYDOC32
  FOR EACH ROW
DECLARE
  new$ID PAYDOC32.ID%TYPE := :NEW.ID;
  new$INPUTDATE PAYDOC32.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$PRINTDATE PAYDOC32.PRINTDATE%TYPE := :NEW.PRINTDATE;
  new$ACCEPTDATE PAYDOC32.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PAYERATTRREF PAYDOC32.PAYERATTRREF%TYPE := :NEW.PAYERATTRREF;
  new$ACCEPTORATTRREF PAYDOC32.ACCEPTORATTRREF%TYPE := :NEW.ACCEPTORATTRREF;
  new$SENDBY PAYDOC32.SENDBY%TYPE := :NEW.SENDBY;
  new$SUMMA PAYDOC32.SUMMA%TYPE := :NEW.SUMMA;
  new$CURRENCY PAYDOC32.CURRENCY%TYPE := :NEW.CURRENCY;
  new$PAYDATE PAYDOC32.PAYDATE%TYPE := :NEW.PAYDATE;
  new$PAYQUEUE PAYDOC32.PAYQUEUE%TYPE := :NEW.PAYQUEUE;
  new$TEXTNOTE PAYDOC32.TEXTNOTE%TYPE := :NEW.TEXTNOTE;
  new$PROGINDEX PAYDOC32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX PAYDOC32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER PAYDOC32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYDOC32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER PAYDOC32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE PAYDOC32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$SOURCEDOCNUMBER PAYDOC32.SOURCEDOCNUMBER%TYPE := :NEW.SOURCEDOCNUMBER;
  new$CHILDCOUNT PAYDOC32.CHILDCOUNT%TYPE := :NEW.CHILDCOUNT;
  new$FACIALACC_CLS PAYDOC32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$ACCOUNTREF PAYDOC32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$DOCTYPE PAYDOC32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SOURCEFACIALACC_CLS PAYDOC32.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$PARENTINDEX PAYDOC32.PARENTINDEX%TYPE := :NEW.PARENTINDEX;
  new$ANUMBER PAYDOC32.ANUMBER%TYPE := :NEW.ANUMBER;
  new$TAXNOTE PAYDOC32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$REJECT_CLS PAYDOC32.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE PAYDOC32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$REALPAYERORG_REF PAYDOC32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$ISDIVIDE PAYDOC32.ISDIVIDE%TYPE := :NEW.ISDIVIDE;
  new$CURSUM PAYDOC32.CURSUM%TYPE := :NEW.CURSUM;
  new$CREDIT PAYDOC32.CREDIT%TYPE := :NEW.CREDIT;
  new$DEBIT PAYDOC32.DEBIT%TYPE := :NEW.DEBIT;
  new$RVERSION PAYDOC32.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYDOC32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MEANSTYPE PAYDOC32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$PAYMENTCONDITION PAYDOC32.PAYMENTCONDITION%TYPE := :NEW.PAYMENTCONDITION;
  new$BUDGETREF PAYDOC32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$TRANSFERTCLS PAYDOC32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
--
  parentinputdate NUMBER;
  cnt$ NUMBER (10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (T_PAYDOC32_BU_0)
-- Last update 15.09.2005
-- - - - - - - - - - - - -

   IF (new$DocType IS NULL) THEN new$DocType := 1010; END IF;
   IF (new$SourceFacialAcc_cls IS NULL) THEN new$SourceFacialAcc_cls := 0; END IF;
   IF (new$ProgIndex IS NULL) THEN new$ProgIndex := 11; END IF;
   IF (new$Currency IS NULL) THEN new$Currency := 2; END IF;
   IF (new$Summa IS NULL) THEN new$Summa := 0; END IF;
   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;
   IF (new$Debit IS NULL) THEN new$Debit := 0; END IF;
   IF (new$CurSum IS NULL) THEN new$CurSum := 0; END IF;

   IF (new$BuhOperationCLS IS NULL) THEN
      GetIntConst (60, 15, new$BuhOperationCLS);
   END IF;

   IF (new$MeansType IS NULL) THEN new$MeansType := 0; END IF;

   --  ,   ,     .
   IF (   (:OLD.AcceptDate IS NOT NULL)
       OR (:OLD.ANumber IS NOT NULL)
       OR (:OLD.ParentIndex IS NOT NULL)
      ) THEN
      IF (
             --   , , , .  
             --   ,    
             --    
             (new$AcceptorAttrRef <> :OLD.AcceptorAttrRef)
          OR (new$PayerAttrRef <> :OLD.PayerAttrRef)
          OR ((new$Summa - :OLD.Summa) > 0.001)
          OR ((new$Summa - :OLD.Summa) < -0.001)
          OR ((new$Credit - :OLD.Credit) > 0.001)
          OR ((new$Credit - :OLD.Credit) < -0.001)
          OR ((new$Debit - :OLD.Debit) > 0.001)
          OR ((new$Debit - :OLD.Debit) < -0.001)
         ) THEN
         IF (    (:OLD.ANumber IS NOT NULL)
             AND (NOT (   (new$ParentIndex <> :OLD.ParentIndex)
                       OR (    (new$ParentIndex IS NULL)
                           AND (:OLD.ParentIndex IS NOT NULL)
                          )
                       OR (    (new$ParentIndex IS NOT NULL)
                           AND (:OLD.ParentIndex IS NULL)
                          )
                      )
                 )
            ) THEN
            RaiseException ('EX_CANNOTUPDATENUMBER');
         ELSIF (:OLD.AcceptDate IS NOT NULL) THEN
            RaiseException ('EX_CANNOTUPDATEACCEPT');
         END IF;
      END IF;

      --     ,    
      --    
      IF ((new$InputDate <> :OLD.InputDate) AND (new$ParentIndex IS NOT NULL)
         ) THEN
         BEGIN
            SELECT InputDate
              INTO ParentInputDate
              FROM PayDoc32
             WHERE ID = new$parentindex;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               ParentInputDate := NULL;
         END;

         IF (ParentInputDate <> new$InputDate) THEN
            RaiseException ('EX_CANNOTUPDATECHILDDOC');
         END IF;
      END IF;
   END IF;

   --      ,
   --  ,     
   IF (    (new$ChildCount IS NOT NULL)
       AND (   (new$Reject_Cls <> :OLD.Reject_Cls)
            OR ((:OLD.Reject_Cls IS NULL) AND (new$Reject_Cls IS NOT NULL))
            OR ((:OLD.Reject_Cls IS NOT NULL) AND (new$Reject_Cls IS NULL))
           )
      ) THEN
      UPDATE PayDoc32
         SET Reject_Cls = new$Reject_Cls
       WHERE (ParentIndex = new$ID) AND (ID <> new$ID);
   END IF;

-- - - - - - - - - - - - -
-- BU_1 (TR_PAYDOC32_BU_1)
-- Last update 19.09.2005
-- - - - - - - - - - - - -

   IF ((new$acceptorattrref <> new$acceptorattrref) AND (new$progindex <> 11)
      ) THEN
      SELECT org_accdefaults.paytype, org_accdefaults.payqueue
        INTO new$sendby, new$payqueue
        FROM org_accdefaults, org_accounts
       WHERE (org_accounts.ID = new$acceptorattrref)
         AND (org_accounts.accdefault = org_accdefaults.ID);

      IF (new$sendby IS NULL) THEN
         getintconst (11, 1, new$sendby);
      END IF;

      IF (new$payqueue IS NULL) THEN
         getintconst (11, 2, new$payqueue);
      END IF;
   END IF;

   IF (new$SendBy IS NULL) THEN new$SendBy := 2; END IF;
   IF (new$PayQueue IS NULL) THEN new$PayQueue := 5; END IF;
   IF (new$accountref IS NULL) THEN new$accountref := new$acceptorattrref; END IF;
   IF (new$acceptorattrref IS NULL) THEN new$acceptorattrref := new$accountref; END IF;
   IF (new$facialacc_cls IS NULL) THEN new$facialacc_cls := 0; END IF;

-- - - - - - - - - - - - -
-- BU_2 (TR_PAYDOC32_BU_2)
-- Create 14.09.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   --     ,  ,  ,  ,
   --         
   IF ((:OLD.childcount IS NOT NULL) AND (:OLD.childcount <> 0)) THEN
      IF (   (   ((new$acceptdate IS NULL) AND (:OLD.acceptdate IS NOT NULL)
                 )
              OR ((new$acceptdate IS NOT NULL) AND (:OLD.acceptdate IS NULL)
                 )
              OR (new$acceptdate <> :OLD.acceptdate)
             )
          OR (   ((new$payqueue IS NULL) AND (:OLD.payqueue IS NOT NULL))
              OR ((new$payqueue IS NOT NULL) AND (:OLD.payqueue IS NULL))
              OR (new$payqueue <> :OLD.payqueue)
             )
          OR (   ((new$printdate IS NULL) AND (:OLD.printdate IS NOT NULL))
              OR ((new$printdate IS NOT NULL) AND (:OLD.printdate IS NULL))
              OR (new$printdate <> :OLD.printdate)
             )
          OR (   ((new$sendby IS NULL) AND (:OLD.sendby IS NOT NULL))
              OR ((new$sendby IS NOT NULL) AND (:OLD.sendby IS NULL))
              OR (new$sendby <> :OLD.sendby)
             )
          OR (   ((new$paydate IS NULL) AND (:OLD.paydate IS NOT NULL))
              OR ((new$paydate IS NOT NULL) AND (:OLD.paydate IS NULL))
              OR (new$paydate <> :OLD.paydate)
             )
          OR (   ((new$anumber IS NULL) AND (:OLD.anumber IS NOT NULL))
              OR ((new$anumber IS NOT NULL) AND (:OLD.anumber IS NULL))
              OR (new$anumber <> :OLD.anumber)
             )
         ) THEN
         UPDATE paydoc32
            SET acceptdate = new$acceptdate,
                payqueue = new$payqueue,
                printdate = new$printdate,
                sendby = new$sendby,
                paydate = new$paydate,
                anumber = new$anumber
          WHERE parentindex = :OLD.ID;
      END IF;
   END IF;

   --      ,
   --  ,     
   IF (    (new$childcount IS NOT NULL)
       AND (   (new$reject_cls <> :OLD.reject_cls)
            OR ((:OLD.reject_cls IS NULL) AND (new$reject_cls IS NOT NULL))
            OR ((:OLD.reject_cls IS NOT NULL) AND (new$reject_cls IS NULL))
           )
      ) THEN
      UPDATE paydoc32
         SET reject_cls = new$reject_cls
       WHERE (parentindex = new$ID) AND (ID <> new$ID);
   END IF;

-- - - - - - - - - - - - -
-- BU_3 (TR_PAYDOC32_BU_3)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   SELECT COUNT (ID)
     INTO cnt$
     FROM paydocexchange
    WHERE (paydocref = :OLD.ID) AND (status <> 0);

   IF (cnt$ > 0) THEN
      IF (   (new$ANUMBER <> :OLD.ANUMBER)
          OR ((new$ANUMBER IS NULL) AND (NOT :OLD.ANUMBER IS NULL))
          OR ((:OLD.ANUMBER IS NULL) AND (NOT new$ANUMBER IS NULL))
          OR (new$INPUTDATE <> :OLD.INPUTDATE)
          OR ((new$INPUTDATE IS NULL) AND (NOT :OLD.INPUTDATE IS NULL))
          OR ((:OLD.INPUTDATE IS NULL) AND (NOT new$INPUTDATE IS NULL))
          OR (new$PRINTDATE <> :OLD.PRINTDATE)
          OR ((new$PRINTDATE IS NULL) AND (NOT :OLD.PRINTDATE IS NULL))
          OR ((:OLD.PRINTDATE IS NULL) AND (NOT new$PRINTDATE IS NULL))
          OR (new$PAYERATTRREF <> :OLD.PAYERATTRREF)
          OR (new$ACCEPTORATTRREF <> :OLD.ACCEPTORATTRREF)
          OR (new$SENDBY <> :OLD.SENDBY)
          OR (new$SUMMA <> :OLD.SUMMA)
          OR (new$PAYDATE <> :OLD.PAYDATE)
          OR ((new$PAYDATE IS NULL) AND (NOT :OLD.PAYDATE IS NULL))
          OR ((:OLD.PAYDATE IS NULL) AND (NOT new$PAYDATE IS NULL))
          OR (new$PAYQUEUE <> :OLD.PAYQUEUE)
          OR ((new$PAYQUEUE IS NULL) AND (NOT :OLD.PAYQUEUE IS NULL))
          OR ((:OLD.PAYQUEUE IS NULL) AND (NOT new$PAYQUEUE IS NULL))
          OR (new$TEXTNOTE <> :OLD.TEXTNOTE)
          OR ((new$TEXTNOTE IS NULL) AND (NOT :OLD.TEXTNOTE IS NULL))
          OR ((:OLD.TEXTNOTE IS NULL) AND (NOT new$TEXTNOTE IS NULL))
          OR (new$SOURCEDOCNUMBER <> :OLD.SOURCEDOCNUMBER)
          OR (    (new$SOURCEDOCNUMBER IS NULL)
              AND (NOT :OLD.SOURCEDOCNUMBER IS NULL)
             )
          OR (    (:OLD.SOURCEDOCNUMBER IS NULL)
              AND (NOT new$SOURCEDOCNUMBER IS NULL)
             )
          OR (new$DOCTYPE <> :OLD.DOCTYPE)
          OR (new$TAXNOTE <> :OLD.TAXNOTE)
          OR ((new$TAXNOTE IS NULL) AND (NOT :OLD.TAXNOTE IS NULL))
          OR ((:OLD.TAXNOTE IS NULL) AND (NOT new$TAXNOTE IS NULL))
         ) THEN
         RaiseException ('EX_CANNOTCHANGESENDED');
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_12 (TR_PAYDOC32_BU_12)
-- Create 12.08.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   --            
   IF (new$debit * new$credit <> 0) THEN
      RaiseException ('EX_FAILDEBETCREDITVALUE');
   END IF;

   IF (new$summa = :OLD.summa) THEN
      new$summa := new$credit - new$debit;
   ELSIF (new$summa > 0) THEN
      new$credit := new$summa;
      new$debit := 0;
   ELSE
      new$credit := 0;
      new$debit := -new$summa;
   END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_PAYDOC32_BU_700)
-- Create 17.09.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_PAYDOC32 SET
    ID = new$ID,
    INPUTDATE = new$INPUTDATE,
    PRINTDATE = new$PRINTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    PAYERATTRREF = new$PAYERATTRREF,
    ACCEPTORATTRREF = new$ACCEPTORATTRREF,
    SENDBY = new$SENDBY,
    SUMMA = new$SUMMA,
    CURRENCY = new$CURRENCY,
    PAYDATE = new$PAYDATE,
    PAYQUEUE = new$PAYQUEUE,
    TEXTNOTE = new$TEXTNOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    SOURCEDOCNUMBER = new$SOURCEDOCNUMBER,
    CHILDCOUNT = new$CHILDCOUNT,
    FACIALACC_CLS = new$FACIALACC_CLS,
    ACCOUNTREF = new$ACCOUNTREF,
    DOCTYPE = new$DOCTYPE,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    PARENTINDEX = new$PARENTINDEX,
    ANUMBER = new$ANUMBER,
    TAXNOTE = new$TAXNOTE,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    ISDIVIDE = new$ISDIVIDE,
    CURSUM = new$CURSUM,
    CREDIT = new$CREDIT,
    DEBIT = new$DEBIT,
    RVERSION = new$RVERSION,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    MEANSTYPE = new$MEANSTYPE,
    PAYMENTCONDITION = new$PAYMENTCONDITION,
    BUDGETREF = new$BUDGETREF,
    TRANSFERTCLS = new$TRANSFERTCLS
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_50 (T_PAYDOC32_AU_50)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (    (new$inputdate <> :OLD.inputdate)
       AND (new$acceptdate IS NULL)
       AND (new$anumber IS NULL)
       AND (new$childcount IS NOT NULL)
      ) THEN
      --      
      UPDATE paydoc32
         SET inputdate = new$inputdate
       WHERE (parentindex = new$ID) AND (ID <> new$ID);
   END IF;

-- - - - - - - - - - - - -
-- AU_130 (TR_PAYDOC32_AU_130)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (new$progindex IN (131, 132, 383, 384, 385, 386))
                                                       --   
   THEN
      IF (   (new$acceptdate = :OLD.acceptdate)
          OR ((new$acceptdate IS NULL) AND (:OLD.acceptdate IS NULL))
         ) THEN
         NULL;
      ELSE
         --     
         UPDATE debt
            SET recorddate = new$acceptdate
          WHERE (ID = new$recordindex) AND (recorddate IS NULL);
      END IF;                                                       -- if-then
   END IF;                                                          -- if-then

   IF (new$progindex IN (121, 122, 133, 341, 411))
                                                  --  
   THEN
      IF (   (new$acceptdate = :OLD.acceptdate)
          OR ((new$acceptdate IS NULL) AND (:OLD.acceptdate IS NULL))
         ) THEN
         NULL;
      ELSE
         UPDATE findocdetail
            SET recorddate = new$acceptdate
          WHERE (ID = new$recordindex) AND (recorddate IS NULL);
      END IF;                                                       -- if-then
   END IF;

END;
/
ALTER TABLE TB_PAYDOC32 ADD (
  TempRejectCause VARCHAR2(255)
)
/

CREATE OR REPLACE VIEW PAYDOC32 (
  ID,
  INPUTDATE,
  PRINTDATE,
  ACCEPTDATE,
  PAYERATTRREF,
  ACCEPTORATTRREF,
  SENDBY,
  SUMMA,
  CURRENCY,
  PAYDATE,
  PAYQUEUE,
  TEXTNOTE,
  PROGINDEX,
  RECORDINDEX,
  CREATERUSER,
  CREATEDATE,
  UPDATERUSER,
  UPDATEDATE,
  SOURCEDOCNUMBER,
  CHILDCOUNT,
  FACIALACC_CLS,
  ACCOUNTREF,
  DOCTYPE,
  SOURCEFACIALACC_CLS,
  PARENTINDEX,
  ANUMBER,
  TAXNOTE,
  REJECT_CLS,
  REJECTCAUSE,
  REALPAYERORG_REF,
  ISDIVIDE,
  CURSUM,
  CREDIT,
  DEBIT,
  RVERSION,
  BUHOPERATIONCLS,
  MEANSTYPE,
  PAYMENTCONDITION,
  BUDGETREF,
  TRANSFERTCLS,
  TEMPREJECTCAUSE)
AS
  SELECT
    ID,
    INPUTDATE,
    PRINTDATE,
    ACCEPTDATE,
    PAYERATTRREF,
    ACCEPTORATTRREF,
    SENDBY,
    SUMMA,
    CURRENCY,
    PAYDATE,
    PAYQUEUE,
    TEXTNOTE,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    SOURCEDOCNUMBER,
    CHILDCOUNT,
    FACIALACC_CLS,
    ACCOUNTREF,
    DOCTYPE,
    SOURCEFACIALACC_CLS,
    PARENTINDEX,
    ANUMBER,
    TAXNOTE,
    REJECT_CLS,
    REJECTCAUSE,
    REALPAYERORG_REF,
    ISDIVIDE,
    CURSUM,
    CREDIT,
    DEBIT,
    RVERSION,
    BUHOPERATIONCLS,
    MEANSTYPE,
    PAYMENTCONDITION,
    BUDGETREF,
    TRANSFERTCLS,
    TEMPREJECTCAUSE
  FROM TB_PAYDOC32
/

CREATE OR REPLACE TRIGGER TR_PAYDOC32_ID
  INSTEAD OF DELETE
  ON PAYDOC32
  FOR EACH ROW
DECLARE
  cnt$ NUMBER (10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (T_PAYDOC32_BD_0)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   /*  /        */
   IF (:OLD.AcceptDate IS NOT NULL) THEN
      RaiseException ('EX_CANNOTDELETEACCEPT');
   END IF;

   IF (:OLD.ANumber IS NOT NULL) THEN
      RaiseException ('EX_CANNOTDELETENUMBER');
   END IF;

-- - - - - - - - - - - - -
-- BD_2 (TR_PAYDOC32_BD_2)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF ((:OLD.ChildCount IS NOT NULL) AND (:OLD.ChildCount <> 0)) THEN
      UPDATE PayDoc32
         SET ParentIndex = NULL
       WHERE ParentIndex = :OLD.ID;
   END IF;

-- - - - - - - - - - - - -
-- BD_3 (TR_PAYDOC32_BD_3)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   --    ,  
   SELECT COUNT (ID)
     INTO cnt$
     FROM paydocexchange
    WHERE (paydocref = :OLD.ID) AND (status <> 0);

   IF CNT$ > 0 THEN
      RaiseException ('EX_CANNOTCHANGESENDED');
   END IF;

-- - - - - - - - - - - - -
-- BD_100 (T_PAYDOC32_BD_1)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   /*       */
   IF (:OLD.ParentIndex IS NOT NULL) THEN
      RaiseException ('EX_CANNOTDELETECHILDDOC');
   END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_PAYDOC32
  WHERE ID = :OLD.ID
           AND (   RVersion = :OLD.RVersion
                OR RVersion IS NULL AND :OLD.RVersion IS NULL
               );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

END;
/

CREATE OR REPLACE TRIGGER TR_PAYDOC32_II
  INSTEAD OF INSERT
  ON PAYDOC32
  FOR EACH ROW
DECLARE
  new$ID PAYDOC32.ID%TYPE := :NEW.ID;
  new$INPUTDATE PAYDOC32.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$PRINTDATE PAYDOC32.PRINTDATE%TYPE := :NEW.PRINTDATE;
  new$ACCEPTDATE PAYDOC32.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PAYERATTRREF PAYDOC32.PAYERATTRREF%TYPE := :NEW.PAYERATTRREF;
  new$ACCEPTORATTRREF PAYDOC32.ACCEPTORATTRREF%TYPE := :NEW.ACCEPTORATTRREF;
  new$SENDBY PAYDOC32.SENDBY%TYPE := :NEW.SENDBY;
  new$SUMMA PAYDOC32.SUMMA%TYPE := :NEW.SUMMA;
  new$CURRENCY PAYDOC32.CURRENCY%TYPE := :NEW.CURRENCY;
  new$PAYDATE PAYDOC32.PAYDATE%TYPE := :NEW.PAYDATE;
  new$PAYQUEUE PAYDOC32.PAYQUEUE%TYPE := :NEW.PAYQUEUE;
  new$TEXTNOTE PAYDOC32.TEXTNOTE%TYPE := :NEW.TEXTNOTE;
  new$PROGINDEX PAYDOC32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX PAYDOC32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER PAYDOC32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYDOC32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER PAYDOC32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE PAYDOC32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$SOURCEDOCNUMBER PAYDOC32.SOURCEDOCNUMBER%TYPE := :NEW.SOURCEDOCNUMBER;
  new$CHILDCOUNT PAYDOC32.CHILDCOUNT%TYPE := :NEW.CHILDCOUNT;
  new$FACIALACC_CLS PAYDOC32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$ACCOUNTREF PAYDOC32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$DOCTYPE PAYDOC32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SOURCEFACIALACC_CLS PAYDOC32.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$PARENTINDEX PAYDOC32.PARENTINDEX%TYPE := :NEW.PARENTINDEX;
  new$ANUMBER PAYDOC32.ANUMBER%TYPE := :NEW.ANUMBER;
  new$TAXNOTE PAYDOC32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$REJECT_CLS PAYDOC32.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE PAYDOC32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$REALPAYERORG_REF PAYDOC32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$ISDIVIDE PAYDOC32.ISDIVIDE%TYPE := :NEW.ISDIVIDE;
  new$CURSUM PAYDOC32.CURSUM%TYPE := :NEW.CURSUM;
  new$CREDIT PAYDOC32.CREDIT%TYPE := :NEW.CREDIT;
  new$DEBIT PAYDOC32.DEBIT%TYPE := :NEW.DEBIT;
  new$RVERSION PAYDOC32.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYDOC32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MEANSTYPE PAYDOC32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$PAYMENTCONDITION PAYDOC32.PAYMENTCONDITION%TYPE := :NEW.PAYMENTCONDITION;
  new$BUDGETREF PAYDOC32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$TRANSFERTCLS PAYDOC32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$TEMPREJECTCAUSE PAYDOC32.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (T_PAYDOC32_BI_0)
-- Last update 17.03.2009
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   IF (new$progindex IS NULL) THEN new$progindex := 11; END IF;
   IF (new$currency IS NULL) THEN
      GetIntConst (19, 4, new$currency);
   END IF;
   IF (new$summa IS NULL) THEN new$summa := 0; END IF;
   IF (new$cursum IS NULL) THEN new$cursum := 0; END IF;
   IF (new$credit IS NULL) THEN new$credit := 0; END IF;
   IF (new$debit IS NULL) THEN new$debit := 0; END IF;

   IF (new$doctype IS NULL) THEN new$doctype := 1010; END IF;
   IF (new$sourcefacialacc_cls IS NULL) THEN new$sourcefacialacc_cls := 0; END IF;
   
   IF (new$BuhOperationCLS IS NULL) THEN
      GetIntConst (60, 15, new$BuhOperationCLS);
   END IF;
   IF (new$MeansType IS NULL) THEN new$MeansType := 0; END IF;

-- - - - - - - - - - - - -
-- BI_1 (TR_PAYDOC32_BI_1)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   --   
   IF (new$progindex <> 11) THEN
      BEGIN
         SELECT org_accdefaults.paytype, org_accdefaults.payqueue
           INTO new$sendby, new$payqueue
           FROM org_accdefaults, org_accounts
          WHERE (org_accounts.ID = new$acceptorattrref)
            AND (org_accounts.accdefault = org_accdefaults.ID);
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            new$sendby := NULL;
            new$payqueue := NULL;
      END;

      IF (new$sendby IS NULL) THEN
         getintconst (11, 1, new$sendby);
      END IF;

      IF (new$payqueue IS NULL) THEN
         getintconst (11, 2, new$payqueue);
      END IF;
   END IF;

   IF (new$SendBy IS NULL) THEN
      new$SendBy := 2;
   END IF;

   IF (new$PayQueue IS NULL) THEN
      new$PayQueue := 5;
   END IF;

   IF (new$accountref IS NULL) THEN
      new$accountref := new$acceptorattrref;
   END IF;

   IF (new$acceptorattrref IS NULL) THEN
      new$acceptorattrref := new$accountref;
   END IF;

   IF (new$facialacc_cls IS NULL) THEN
      new$facialacc_cls := 0;
   END IF;

   /*  .  ,     */
   IF ((NEW$BudgetRef IS NULL) OR (NEW$BudgetRef = 0)) THEN
      BEGIN
         SELECT fa.BudgetRef
           INTO NEW$BudgetRef
           FROM FacialAcc_Cls fa
          WHERE fa.ID = NEW$FacialAcc_Cls;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            NEW$BudgetRef := NULL;
      END;
   END IF;

   /*  ,    */
   IF ((NEW$BudgetRef IS NULL) OR (NEW$BudgetRef = 0)) THEN
      GetIntConst (-1, 3, NEW$BudgetRef);
   END IF;

-- - - - - - - - - - - - -
-- BI_12 (TR_PAYDOC32_BI_12)
-- Create 12.08.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (new$debit * new$credit <> 0) THEN
      RaiseException ('EX_FAILDEBETCREDITVALUE');
   END IF;

   IF (   (new$summa IS NULL)
       OR (new$summa = 0) AND ((new$debit <> 0) OR (new$credit <> 0))
      ) THEN
      new$summa := new$credit - new$debit;
   ELSIF (new$summa > 0) THEN
      new$credit := new$summa;
      new$debit := 0;
   ELSE
      new$credit := 0;
      new$debit := -new$summa;
   END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_PAYDOC32_BI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_PAYDOC32 (
    ID,
    INPUTDATE,
    PRINTDATE,
    ACCEPTDATE,
    PAYERATTRREF,
    ACCEPTORATTRREF,
    SENDBY,
    SUMMA,
    CURRENCY,
    PAYDATE,
    PAYQUEUE,
    TEXTNOTE,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    SOURCEDOCNUMBER,
    CHILDCOUNT,
    FACIALACC_CLS,
    ACCOUNTREF,
    DOCTYPE,
    SOURCEFACIALACC_CLS,
    PARENTINDEX,
    ANUMBER,
    TAXNOTE,
    REJECT_CLS,
    REJECTCAUSE,
    REALPAYERORG_REF,
    ISDIVIDE,
    CURSUM,
    CREDIT,
    DEBIT,
    RVERSION,
    BUHOPERATIONCLS,
    MEANSTYPE,
    PAYMENTCONDITION,
    BUDGETREF,
    TRANSFERTCLS,
    TEMPREJECTCAUSE
  ) VALUES (
    new$ID,
    new$INPUTDATE,
    new$PRINTDATE,
    new$ACCEPTDATE,
    new$PAYERATTRREF,
    new$ACCEPTORATTRREF,
    new$SENDBY,
    new$SUMMA,
    new$CURRENCY,
    new$PAYDATE,
    new$PAYQUEUE,
    new$TEXTNOTE,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$SOURCEDOCNUMBER,
    new$CHILDCOUNT,
    new$FACIALACC_CLS,
    new$ACCOUNTREF,
    new$DOCTYPE,
    new$SOURCEFACIALACC_CLS,
    new$PARENTINDEX,
    new$ANUMBER,
    new$TAXNOTE,
    new$REJECT_CLS,
    new$REJECTCAUSE,
    new$REALPAYERORG_REF,
    new$ISDIVIDE,
    new$CURSUM,
    new$CREDIT,
    new$DEBIT,
    new$RVERSION,
    new$BUHOPERATIONCLS,
    new$MEANSTYPE,
    new$PAYMENTCONDITION,
    new$BUDGETREF,
    new$TRANSFERTCLS,
    new$TEMPREJECTCAUSE);

END;
/

CREATE OR REPLACE TRIGGER TR_PAYDOC32_IU
  INSTEAD OF UPDATE
  ON PAYDOC32
  FOR EACH ROW
DECLARE
  new$ID PAYDOC32.ID%TYPE := :NEW.ID;
  new$INPUTDATE PAYDOC32.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$PRINTDATE PAYDOC32.PRINTDATE%TYPE := :NEW.PRINTDATE;
  new$ACCEPTDATE PAYDOC32.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PAYERATTRREF PAYDOC32.PAYERATTRREF%TYPE := :NEW.PAYERATTRREF;
  new$ACCEPTORATTRREF PAYDOC32.ACCEPTORATTRREF%TYPE := :NEW.ACCEPTORATTRREF;
  new$SENDBY PAYDOC32.SENDBY%TYPE := :NEW.SENDBY;
  new$SUMMA PAYDOC32.SUMMA%TYPE := :NEW.SUMMA;
  new$CURRENCY PAYDOC32.CURRENCY%TYPE := :NEW.CURRENCY;
  new$PAYDATE PAYDOC32.PAYDATE%TYPE := :NEW.PAYDATE;
  new$PAYQUEUE PAYDOC32.PAYQUEUE%TYPE := :NEW.PAYQUEUE;
  new$TEXTNOTE PAYDOC32.TEXTNOTE%TYPE := :NEW.TEXTNOTE;
  new$PROGINDEX PAYDOC32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX PAYDOC32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER PAYDOC32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYDOC32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER PAYDOC32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE PAYDOC32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$SOURCEDOCNUMBER PAYDOC32.SOURCEDOCNUMBER%TYPE := :NEW.SOURCEDOCNUMBER;
  new$CHILDCOUNT PAYDOC32.CHILDCOUNT%TYPE := :NEW.CHILDCOUNT;
  new$FACIALACC_CLS PAYDOC32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$ACCOUNTREF PAYDOC32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$DOCTYPE PAYDOC32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SOURCEFACIALACC_CLS PAYDOC32.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$PARENTINDEX PAYDOC32.PARENTINDEX%TYPE := :NEW.PARENTINDEX;
  new$ANUMBER PAYDOC32.ANUMBER%TYPE := :NEW.ANUMBER;
  new$TAXNOTE PAYDOC32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$REJECT_CLS PAYDOC32.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE PAYDOC32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$REALPAYERORG_REF PAYDOC32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$ISDIVIDE PAYDOC32.ISDIVIDE%TYPE := :NEW.ISDIVIDE;
  new$CURSUM PAYDOC32.CURSUM%TYPE := :NEW.CURSUM;
  new$CREDIT PAYDOC32.CREDIT%TYPE := :NEW.CREDIT;
  new$DEBIT PAYDOC32.DEBIT%TYPE := :NEW.DEBIT;
  new$RVERSION PAYDOC32.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYDOC32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MEANSTYPE PAYDOC32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$PAYMENTCONDITION PAYDOC32.PAYMENTCONDITION%TYPE := :NEW.PAYMENTCONDITION;
  new$BUDGETREF PAYDOC32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$TRANSFERTCLS PAYDOC32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$TEMPREJECTCAUSE PAYDOC32.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  parentinputdate NUMBER;
  cnt$ NUMBER (10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (T_PAYDOC32_BU_0)
-- Last update 15.09.2005
-- - - - - - - - - - - - -

   IF (new$DocType IS NULL) THEN new$DocType := 1010; END IF;
   IF (new$SourceFacialAcc_cls IS NULL) THEN new$SourceFacialAcc_cls := 0; END IF;
   IF (new$ProgIndex IS NULL) THEN new$ProgIndex := 11; END IF;
   IF (new$Currency IS NULL) THEN new$Currency := 2; END IF;
   IF (new$Summa IS NULL) THEN new$Summa := 0; END IF;
   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;
   IF (new$Debit IS NULL) THEN new$Debit := 0; END IF;
   IF (new$CurSum IS NULL) THEN new$CurSum := 0; END IF;

   IF (new$BuhOperationCLS IS NULL) THEN
      GetIntConst (60, 15, new$BuhOperationCLS);
   END IF;

   IF (new$MeansType IS NULL) THEN new$MeansType := 0; END IF;

   --  ,   ,     .
   IF (   (:OLD.AcceptDate IS NOT NULL)
       OR (:OLD.ANumber IS NOT NULL)
       OR (:OLD.ParentIndex IS NOT NULL)
      ) THEN
      IF (
             --   , , , .  
             --   ,    
             --    
             (new$AcceptorAttrRef <> :OLD.AcceptorAttrRef)
          OR (new$PayerAttrRef <> :OLD.PayerAttrRef)
          OR ((new$Summa - :OLD.Summa) > 0.001)
          OR ((new$Summa - :OLD.Summa) < -0.001)
          OR ((new$Credit - :OLD.Credit) > 0.001)
          OR ((new$Credit - :OLD.Credit) < -0.001)
          OR ((new$Debit - :OLD.Debit) > 0.001)
          OR ((new$Debit - :OLD.Debit) < -0.001)
         ) THEN
         IF (    (:OLD.ANumber IS NOT NULL)
             AND (NOT (   (new$ParentIndex <> :OLD.ParentIndex)
                       OR (    (new$ParentIndex IS NULL)
                           AND (:OLD.ParentIndex IS NOT NULL)
                          )
                       OR (    (new$ParentIndex IS NOT NULL)
                           AND (:OLD.ParentIndex IS NULL)
                          )
                      )
                 )
            ) THEN
            RaiseException ('EX_CANNOTUPDATENUMBER');
         ELSIF (:OLD.AcceptDate IS NOT NULL) THEN
            RaiseException ('EX_CANNOTUPDATEACCEPT');
         END IF;
      END IF;

      --     ,    
      --    
      IF ((new$InputDate <> :OLD.InputDate) AND (new$ParentIndex IS NOT NULL)
         ) THEN
         BEGIN
            SELECT InputDate
              INTO ParentInputDate
              FROM PayDoc32
             WHERE ID = new$parentindex;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               ParentInputDate := NULL;
         END;

         IF (ParentInputDate <> new$InputDate) THEN
            RaiseException ('EX_CANNOTUPDATECHILDDOC');
         END IF;
      END IF;
   END IF;

   --      ,
   --  ,     
   IF (    (new$ChildCount IS NOT NULL)
       AND (   (new$Reject_Cls <> :OLD.Reject_Cls)
            OR ((:OLD.Reject_Cls IS NULL) AND (new$Reject_Cls IS NOT NULL))
            OR ((:OLD.Reject_Cls IS NOT NULL) AND (new$Reject_Cls IS NULL))
           )
      ) THEN
      UPDATE PayDoc32
         SET Reject_Cls = new$Reject_Cls
       WHERE (ParentIndex = new$ID) AND (ID <> new$ID);
   END IF;

-- - - - - - - - - - - - -
-- BU_1 (TR_PAYDOC32_BU_1)
-- Last update 19.09.2005
-- - - - - - - - - - - - -

   IF ((new$acceptorattrref <> new$acceptorattrref) AND (new$progindex <> 11)
      ) THEN
      SELECT org_accdefaults.paytype, org_accdefaults.payqueue
        INTO new$sendby, new$payqueue
        FROM org_accdefaults, org_accounts
       WHERE (org_accounts.ID = new$acceptorattrref)
         AND (org_accounts.accdefault = org_accdefaults.ID);

      IF (new$sendby IS NULL) THEN
         getintconst (11, 1, new$sendby);
      END IF;

      IF (new$payqueue IS NULL) THEN
         getintconst (11, 2, new$payqueue);
      END IF;
   END IF;

   IF (new$SendBy IS NULL) THEN new$SendBy := 2; END IF;
   IF (new$PayQueue IS NULL) THEN new$PayQueue := 5; END IF;
   IF (new$accountref IS NULL) THEN new$accountref := new$acceptorattrref; END IF;
   IF (new$acceptorattrref IS NULL) THEN new$acceptorattrref := new$accountref; END IF;
   IF (new$facialacc_cls IS NULL) THEN new$facialacc_cls := 0; END IF;

-- - - - - - - - - - - - -
-- BU_2 (TR_PAYDOC32_BU_2)
-- Create 14.09.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   --     ,  ,  ,  ,
   --         
   IF ((:OLD.childcount IS NOT NULL) AND (:OLD.childcount <> 0)) THEN
      IF (   (   ((new$acceptdate IS NULL) AND (:OLD.acceptdate IS NOT NULL)
                 )
              OR ((new$acceptdate IS NOT NULL) AND (:OLD.acceptdate IS NULL)
                 )
              OR (new$acceptdate <> :OLD.acceptdate)
             )
          OR (   ((new$payqueue IS NULL) AND (:OLD.payqueue IS NOT NULL))
              OR ((new$payqueue IS NOT NULL) AND (:OLD.payqueue IS NULL))
              OR (new$payqueue <> :OLD.payqueue)
             )
          OR (   ((new$printdate IS NULL) AND (:OLD.printdate IS NOT NULL))
              OR ((new$printdate IS NOT NULL) AND (:OLD.printdate IS NULL))
              OR (new$printdate <> :OLD.printdate)
             )
          OR (   ((new$sendby IS NULL) AND (:OLD.sendby IS NOT NULL))
              OR ((new$sendby IS NOT NULL) AND (:OLD.sendby IS NULL))
              OR (new$sendby <> :OLD.sendby)
             )
          OR (   ((new$paydate IS NULL) AND (:OLD.paydate IS NOT NULL))
              OR ((new$paydate IS NOT NULL) AND (:OLD.paydate IS NULL))
              OR (new$paydate <> :OLD.paydate)
             )
          OR (   ((new$anumber IS NULL) AND (:OLD.anumber IS NOT NULL))
              OR ((new$anumber IS NOT NULL) AND (:OLD.anumber IS NULL))
              OR (new$anumber <> :OLD.anumber)
             )
         ) THEN
         UPDATE paydoc32
            SET acceptdate = new$acceptdate,
                payqueue = new$payqueue,
                printdate = new$printdate,
                sendby = new$sendby,
                paydate = new$paydate,
                anumber = new$anumber
          WHERE parentindex = :OLD.ID;
      END IF;
   END IF;

   --      ,
   --  ,     
   IF (    (new$childcount IS NOT NULL)
       AND (   (new$reject_cls <> :OLD.reject_cls)
            OR ((:OLD.reject_cls IS NULL) AND (new$reject_cls IS NOT NULL))
            OR ((:OLD.reject_cls IS NOT NULL) AND (new$reject_cls IS NULL))
           )
      ) THEN
      UPDATE paydoc32
         SET reject_cls = new$reject_cls
       WHERE (parentindex = new$ID) AND (ID <> new$ID);
   END IF;

-- - - - - - - - - - - - -
-- BU_3 (TR_PAYDOC32_BU_3)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   SELECT COUNT (ID)
     INTO cnt$
     FROM paydocexchange
    WHERE (paydocref = :OLD.ID) AND (status <> 0);

   IF (cnt$ > 0) THEN
      IF (   (new$ANUMBER <> :OLD.ANUMBER)
          OR ((new$ANUMBER IS NULL) AND (NOT :OLD.ANUMBER IS NULL))
          OR ((:OLD.ANUMBER IS NULL) AND (NOT new$ANUMBER IS NULL))
          OR (new$INPUTDATE <> :OLD.INPUTDATE)
          OR ((new$INPUTDATE IS NULL) AND (NOT :OLD.INPUTDATE IS NULL))
          OR ((:OLD.INPUTDATE IS NULL) AND (NOT new$INPUTDATE IS NULL))
          OR (new$PRINTDATE <> :OLD.PRINTDATE)
          OR ((new$PRINTDATE IS NULL) AND (NOT :OLD.PRINTDATE IS NULL))
          OR ((:OLD.PRINTDATE IS NULL) AND (NOT new$PRINTDATE IS NULL))
          OR (new$PAYERATTRREF <> :OLD.PAYERATTRREF)
          OR (new$ACCEPTORATTRREF <> :OLD.ACCEPTORATTRREF)
          OR (new$SENDBY <> :OLD.SENDBY)
          OR (new$SUMMA <> :OLD.SUMMA)
          OR (new$PAYDATE <> :OLD.PAYDATE)
          OR ((new$PAYDATE IS NULL) AND (NOT :OLD.PAYDATE IS NULL))
          OR ((:OLD.PAYDATE IS NULL) AND (NOT new$PAYDATE IS NULL))
          OR (new$PAYQUEUE <> :OLD.PAYQUEUE)
          OR ((new$PAYQUEUE IS NULL) AND (NOT :OLD.PAYQUEUE IS NULL))
          OR ((:OLD.PAYQUEUE IS NULL) AND (NOT new$PAYQUEUE IS NULL))
          OR (new$TEXTNOTE <> :OLD.TEXTNOTE)
          OR ((new$TEXTNOTE IS NULL) AND (NOT :OLD.TEXTNOTE IS NULL))
          OR ((:OLD.TEXTNOTE IS NULL) AND (NOT new$TEXTNOTE IS NULL))
          OR (new$SOURCEDOCNUMBER <> :OLD.SOURCEDOCNUMBER)
          OR (    (new$SOURCEDOCNUMBER IS NULL)
              AND (NOT :OLD.SOURCEDOCNUMBER IS NULL)
             )
          OR (    (:OLD.SOURCEDOCNUMBER IS NULL)
              AND (NOT new$SOURCEDOCNUMBER IS NULL)
             )
          OR (new$DOCTYPE <> :OLD.DOCTYPE)
          OR (new$TAXNOTE <> :OLD.TAXNOTE)
          OR ((new$TAXNOTE IS NULL) AND (NOT :OLD.TAXNOTE IS NULL))
          OR ((:OLD.TAXNOTE IS NULL) AND (NOT new$TAXNOTE IS NULL))
         ) THEN
         RaiseException ('EX_CANNOTCHANGESENDED');
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_12 (TR_PAYDOC32_BU_12)
-- Create 12.08.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   --            
   IF (new$debit * new$credit <> 0) THEN
      RaiseException ('EX_FAILDEBETCREDITVALUE');
   END IF;

   IF (new$summa = :OLD.summa) THEN
      new$summa := new$credit - new$debit;
   ELSIF (new$summa > 0) THEN
      new$credit := new$summa;
      new$debit := 0;
   ELSE
      new$credit := 0;
      new$debit := -new$summa;
   END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_PAYDOC32_BU_700)
-- Create 17.09.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_PAYDOC32 SET
    ID = new$ID,
    INPUTDATE = new$INPUTDATE,
    PRINTDATE = new$PRINTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    PAYERATTRREF = new$PAYERATTRREF,
    ACCEPTORATTRREF = new$ACCEPTORATTRREF,
    SENDBY = new$SENDBY,
    SUMMA = new$SUMMA,
    CURRENCY = new$CURRENCY,
    PAYDATE = new$PAYDATE,
    PAYQUEUE = new$PAYQUEUE,
    TEXTNOTE = new$TEXTNOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    SOURCEDOCNUMBER = new$SOURCEDOCNUMBER,
    CHILDCOUNT = new$CHILDCOUNT,
    FACIALACC_CLS = new$FACIALACC_CLS,
    ACCOUNTREF = new$ACCOUNTREF,
    DOCTYPE = new$DOCTYPE,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    PARENTINDEX = new$PARENTINDEX,
    ANUMBER = new$ANUMBER,
    TAXNOTE = new$TAXNOTE,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    ISDIVIDE = new$ISDIVIDE,
    CURSUM = new$CURSUM,
    CREDIT = new$CREDIT,
    DEBIT = new$DEBIT,
    RVERSION = new$RVERSION,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    MEANSTYPE = new$MEANSTYPE,
    PAYMENTCONDITION = new$PAYMENTCONDITION,
    BUDGETREF = new$BUDGETREF,
    TRANSFERTCLS = new$TRANSFERTCLS,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_50 (T_PAYDOC32_AU_50)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (    (new$inputdate <> :OLD.inputdate)
       AND (new$acceptdate IS NULL)
       AND (new$anumber IS NULL)
       AND (new$childcount IS NOT NULL)
      ) THEN
      --      
      UPDATE paydoc32
         SET inputdate = new$inputdate
       WHERE (parentindex = new$ID) AND (ID <> new$ID);
   END IF;

-- - - - - - - - - - - - -
-- AU_130 (TR_PAYDOC32_AU_130)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (new$progindex IN (131, 132, 383, 384, 385, 386))
                                                       --   
   THEN
      IF (   (new$acceptdate = :OLD.acceptdate)
          OR ((new$acceptdate IS NULL) AND (:OLD.acceptdate IS NULL))
         ) THEN
         NULL;
      ELSE
         --     
         UPDATE debt
            SET recorddate = new$acceptdate
          WHERE (ID = new$recordindex) AND (recorddate IS NULL);
      END IF;                                                       -- if-then
   END IF;                                                          -- if-then

   IF (new$progindex IN (121, 122, 133, 341, 411))
                                                  --  
   THEN
      IF (   (new$acceptdate = :OLD.acceptdate)
          OR ((new$acceptdate IS NULL) AND (:OLD.acceptdate IS NULL))
         ) THEN
         NULL;
      ELSE
         UPDATE findocdetail
            SET recorddate = new$acceptdate
          WHERE (ID = new$recordindex) AND (recorddate IS NULL);
      END IF;                                                       -- if-then
   END IF;

END;
/
update PAYDOC32 set
  TempRejectCause = REJECTCAUSE
/
commit work 
/
ALTER TABLE TB_PAYDOC32 DROP (REJECTCAUSE)
/

CREATE OR REPLACE VIEW PAYDOC32 (
  ID,
  INPUTDATE,
  PRINTDATE,
  ACCEPTDATE,
  PAYERATTRREF,
  ACCEPTORATTRREF,
  SENDBY,
  SUMMA,
  CURRENCY,
  PAYDATE,
  PAYQUEUE,
  TEXTNOTE,
  PROGINDEX,
  RECORDINDEX,
  CREATERUSER,
  CREATEDATE,
  UPDATERUSER,
  UPDATEDATE,
  SOURCEDOCNUMBER,
  CHILDCOUNT,
  FACIALACC_CLS,
  ACCOUNTREF,
  DOCTYPE,
  SOURCEFACIALACC_CLS,
  PARENTINDEX,
  ANUMBER,
  TAXNOTE,
  REJECT_CLS,
  REALPAYERORG_REF,
  ISDIVIDE,
  CURSUM,
  CREDIT,
  DEBIT,
  RVERSION,
  BUHOPERATIONCLS,
  MEANSTYPE,
  PAYMENTCONDITION,
  BUDGETREF,
  TRANSFERTCLS,
  TEMPREJECTCAUSE)
AS
  SELECT
    ID,
    INPUTDATE,
    PRINTDATE,
    ACCEPTDATE,
    PAYERATTRREF,
    ACCEPTORATTRREF,
    SENDBY,
    SUMMA,
    CURRENCY,
    PAYDATE,
    PAYQUEUE,
    TEXTNOTE,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    SOURCEDOCNUMBER,
    CHILDCOUNT,
    FACIALACC_CLS,
    ACCOUNTREF,
    DOCTYPE,
    SOURCEFACIALACC_CLS,
    PARENTINDEX,
    ANUMBER,
    TAXNOTE,
    REJECT_CLS,
    REALPAYERORG_REF,
    ISDIVIDE,
    CURSUM,
    CREDIT,
    DEBIT,
    RVERSION,
    BUHOPERATIONCLS,
    MEANSTYPE,
    PAYMENTCONDITION,
    BUDGETREF,
    TRANSFERTCLS,
    TEMPREJECTCAUSE
  FROM TB_PAYDOC32
/

CREATE OR REPLACE TRIGGER TR_PAYDOC32_ID
  INSTEAD OF DELETE
  ON PAYDOC32
  FOR EACH ROW
DECLARE
  cnt$ NUMBER (10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (T_PAYDOC32_BD_0)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   /*  /        */
   IF (:OLD.AcceptDate IS NOT NULL) THEN
      RaiseException ('EX_CANNOTDELETEACCEPT');
   END IF;

   IF (:OLD.ANumber IS NOT NULL) THEN
      RaiseException ('EX_CANNOTDELETENUMBER');
   END IF;

-- - - - - - - - - - - - -
-- BD_2 (TR_PAYDOC32_BD_2)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF ((:OLD.ChildCount IS NOT NULL) AND (:OLD.ChildCount <> 0)) THEN
      UPDATE PayDoc32
         SET ParentIndex = NULL
       WHERE ParentIndex = :OLD.ID;
   END IF;

-- - - - - - - - - - - - -
-- BD_3 (TR_PAYDOC32_BD_3)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   --    ,  
   SELECT COUNT (ID)
     INTO cnt$
     FROM paydocexchange
    WHERE (paydocref = :OLD.ID) AND (status <> 0);

   IF CNT$ > 0 THEN
      RaiseException ('EX_CANNOTCHANGESENDED');
   END IF;

-- - - - - - - - - - - - -
-- BD_100 (T_PAYDOC32_BD_1)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   /*       */
   IF (:OLD.ParentIndex IS NOT NULL) THEN
      RaiseException ('EX_CANNOTDELETECHILDDOC');
   END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_PAYDOC32
  WHERE ID = :OLD.ID
           AND (   RVersion = :OLD.RVersion
                OR RVersion IS NULL AND :OLD.RVersion IS NULL
               );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

END;
/

CREATE OR REPLACE TRIGGER TR_PAYDOC32_II
  INSTEAD OF INSERT
  ON PAYDOC32
  FOR EACH ROW
DECLARE
  new$ID PAYDOC32.ID%TYPE := :NEW.ID;
  new$INPUTDATE PAYDOC32.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$PRINTDATE PAYDOC32.PRINTDATE%TYPE := :NEW.PRINTDATE;
  new$ACCEPTDATE PAYDOC32.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PAYERATTRREF PAYDOC32.PAYERATTRREF%TYPE := :NEW.PAYERATTRREF;
  new$ACCEPTORATTRREF PAYDOC32.ACCEPTORATTRREF%TYPE := :NEW.ACCEPTORATTRREF;
  new$SENDBY PAYDOC32.SENDBY%TYPE := :NEW.SENDBY;
  new$SUMMA PAYDOC32.SUMMA%TYPE := :NEW.SUMMA;
  new$CURRENCY PAYDOC32.CURRENCY%TYPE := :NEW.CURRENCY;
  new$PAYDATE PAYDOC32.PAYDATE%TYPE := :NEW.PAYDATE;
  new$PAYQUEUE PAYDOC32.PAYQUEUE%TYPE := :NEW.PAYQUEUE;
  new$TEXTNOTE PAYDOC32.TEXTNOTE%TYPE := :NEW.TEXTNOTE;
  new$PROGINDEX PAYDOC32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX PAYDOC32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER PAYDOC32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYDOC32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER PAYDOC32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE PAYDOC32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$SOURCEDOCNUMBER PAYDOC32.SOURCEDOCNUMBER%TYPE := :NEW.SOURCEDOCNUMBER;
  new$CHILDCOUNT PAYDOC32.CHILDCOUNT%TYPE := :NEW.CHILDCOUNT;
  new$FACIALACC_CLS PAYDOC32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$ACCOUNTREF PAYDOC32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$DOCTYPE PAYDOC32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SOURCEFACIALACC_CLS PAYDOC32.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$PARENTINDEX PAYDOC32.PARENTINDEX%TYPE := :NEW.PARENTINDEX;
  new$ANUMBER PAYDOC32.ANUMBER%TYPE := :NEW.ANUMBER;
  new$TAXNOTE PAYDOC32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$REJECT_CLS PAYDOC32.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REALPAYERORG_REF PAYDOC32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$ISDIVIDE PAYDOC32.ISDIVIDE%TYPE := :NEW.ISDIVIDE;
  new$CURSUM PAYDOC32.CURSUM%TYPE := :NEW.CURSUM;
  new$CREDIT PAYDOC32.CREDIT%TYPE := :NEW.CREDIT;
  new$DEBIT PAYDOC32.DEBIT%TYPE := :NEW.DEBIT;
  new$RVERSION PAYDOC32.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYDOC32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MEANSTYPE PAYDOC32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$PAYMENTCONDITION PAYDOC32.PAYMENTCONDITION%TYPE := :NEW.PAYMENTCONDITION;
  new$BUDGETREF PAYDOC32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$TRANSFERTCLS PAYDOC32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$TEMPREJECTCAUSE PAYDOC32.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (T_PAYDOC32_BI_0)
-- Last update 17.03.2009
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   IF (new$progindex IS NULL) THEN new$progindex := 11; END IF;
   IF (new$currency IS NULL) THEN
      GetIntConst (19, 4, new$currency);
   END IF;
   IF (new$summa IS NULL) THEN new$summa := 0; END IF;
   IF (new$cursum IS NULL) THEN new$cursum := 0; END IF;
   IF (new$credit IS NULL) THEN new$credit := 0; END IF;
   IF (new$debit IS NULL) THEN new$debit := 0; END IF;

   IF (new$doctype IS NULL) THEN new$doctype := 1010; END IF;
   IF (new$sourcefacialacc_cls IS NULL) THEN new$sourcefacialacc_cls := 0; END IF;
   
   IF (new$BuhOperationCLS IS NULL) THEN
      GetIntConst (60, 15, new$BuhOperationCLS);
   END IF;
   IF (new$MeansType IS NULL) THEN new$MeansType := 0; END IF;

-- - - - - - - - - - - - -
-- BI_1 (TR_PAYDOC32_BI_1)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   --   
   IF (new$progindex <> 11) THEN
      BEGIN
         SELECT org_accdefaults.paytype, org_accdefaults.payqueue
           INTO new$sendby, new$payqueue
           FROM org_accdefaults, org_accounts
          WHERE (org_accounts.ID = new$acceptorattrref)
            AND (org_accounts.accdefault = org_accdefaults.ID);
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            new$sendby := NULL;
            new$payqueue := NULL;
      END;

      IF (new$sendby IS NULL) THEN
         getintconst (11, 1, new$sendby);
      END IF;

      IF (new$payqueue IS NULL) THEN
         getintconst (11, 2, new$payqueue);
      END IF;
   END IF;

   IF (new$SendBy IS NULL) THEN
      new$SendBy := 2;
   END IF;

   IF (new$PayQueue IS NULL) THEN
      new$PayQueue := 5;
   END IF;

   IF (new$accountref IS NULL) THEN
      new$accountref := new$acceptorattrref;
   END IF;

   IF (new$acceptorattrref IS NULL) THEN
      new$acceptorattrref := new$accountref;
   END IF;

   IF (new$facialacc_cls IS NULL) THEN
      new$facialacc_cls := 0;
   END IF;

   /*  .  ,     */
   IF ((NEW$BudgetRef IS NULL) OR (NEW$BudgetRef = 0)) THEN
      BEGIN
         SELECT fa.BudgetRef
           INTO NEW$BudgetRef
           FROM FacialAcc_Cls fa
          WHERE fa.ID = NEW$FacialAcc_Cls;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            NEW$BudgetRef := NULL;
      END;
   END IF;

   /*  ,    */
   IF ((NEW$BudgetRef IS NULL) OR (NEW$BudgetRef = 0)) THEN
      GetIntConst (-1, 3, NEW$BudgetRef);
   END IF;

-- - - - - - - - - - - - -
-- BI_12 (TR_PAYDOC32_BI_12)
-- Create 12.08.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (new$debit * new$credit <> 0) THEN
      RaiseException ('EX_FAILDEBETCREDITVALUE');
   END IF;

   IF (   (new$summa IS NULL)
       OR (new$summa = 0) AND ((new$debit <> 0) OR (new$credit <> 0))
      ) THEN
      new$summa := new$credit - new$debit;
   ELSIF (new$summa > 0) THEN
      new$credit := new$summa;
      new$debit := 0;
   ELSE
      new$credit := 0;
      new$debit := -new$summa;
   END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_PAYDOC32_BI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_PAYDOC32 (
    ID,
    INPUTDATE,
    PRINTDATE,
    ACCEPTDATE,
    PAYERATTRREF,
    ACCEPTORATTRREF,
    SENDBY,
    SUMMA,
    CURRENCY,
    PAYDATE,
    PAYQUEUE,
    TEXTNOTE,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    SOURCEDOCNUMBER,
    CHILDCOUNT,
    FACIALACC_CLS,
    ACCOUNTREF,
    DOCTYPE,
    SOURCEFACIALACC_CLS,
    PARENTINDEX,
    ANUMBER,
    TAXNOTE,
    REJECT_CLS,
    REALPAYERORG_REF,
    ISDIVIDE,
    CURSUM,
    CREDIT,
    DEBIT,
    RVERSION,
    BUHOPERATIONCLS,
    MEANSTYPE,
    PAYMENTCONDITION,
    BUDGETREF,
    TRANSFERTCLS,
    TEMPREJECTCAUSE
  ) VALUES (
    new$ID,
    new$INPUTDATE,
    new$PRINTDATE,
    new$ACCEPTDATE,
    new$PAYERATTRREF,
    new$ACCEPTORATTRREF,
    new$SENDBY,
    new$SUMMA,
    new$CURRENCY,
    new$PAYDATE,
    new$PAYQUEUE,
    new$TEXTNOTE,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$SOURCEDOCNUMBER,
    new$CHILDCOUNT,
    new$FACIALACC_CLS,
    new$ACCOUNTREF,
    new$DOCTYPE,
    new$SOURCEFACIALACC_CLS,
    new$PARENTINDEX,
    new$ANUMBER,
    new$TAXNOTE,
    new$REJECT_CLS,
    new$REALPAYERORG_REF,
    new$ISDIVIDE,
    new$CURSUM,
    new$CREDIT,
    new$DEBIT,
    new$RVERSION,
    new$BUHOPERATIONCLS,
    new$MEANSTYPE,
    new$PAYMENTCONDITION,
    new$BUDGETREF,
    new$TRANSFERTCLS,
    new$TEMPREJECTCAUSE);

END;
/

CREATE OR REPLACE TRIGGER TR_PAYDOC32_IU
  INSTEAD OF UPDATE
  ON PAYDOC32
  FOR EACH ROW
DECLARE
  new$ID PAYDOC32.ID%TYPE := :NEW.ID;
  new$INPUTDATE PAYDOC32.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$PRINTDATE PAYDOC32.PRINTDATE%TYPE := :NEW.PRINTDATE;
  new$ACCEPTDATE PAYDOC32.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PAYERATTRREF PAYDOC32.PAYERATTRREF%TYPE := :NEW.PAYERATTRREF;
  new$ACCEPTORATTRREF PAYDOC32.ACCEPTORATTRREF%TYPE := :NEW.ACCEPTORATTRREF;
  new$SENDBY PAYDOC32.SENDBY%TYPE := :NEW.SENDBY;
  new$SUMMA PAYDOC32.SUMMA%TYPE := :NEW.SUMMA;
  new$CURRENCY PAYDOC32.CURRENCY%TYPE := :NEW.CURRENCY;
  new$PAYDATE PAYDOC32.PAYDATE%TYPE := :NEW.PAYDATE;
  new$PAYQUEUE PAYDOC32.PAYQUEUE%TYPE := :NEW.PAYQUEUE;
  new$TEXTNOTE PAYDOC32.TEXTNOTE%TYPE := :NEW.TEXTNOTE;
  new$PROGINDEX PAYDOC32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX PAYDOC32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER PAYDOC32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYDOC32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER PAYDOC32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE PAYDOC32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$SOURCEDOCNUMBER PAYDOC32.SOURCEDOCNUMBER%TYPE := :NEW.SOURCEDOCNUMBER;
  new$CHILDCOUNT PAYDOC32.CHILDCOUNT%TYPE := :NEW.CHILDCOUNT;
  new$FACIALACC_CLS PAYDOC32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$ACCOUNTREF PAYDOC32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$DOCTYPE PAYDOC32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SOURCEFACIALACC_CLS PAYDOC32.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$PARENTINDEX PAYDOC32.PARENTINDEX%TYPE := :NEW.PARENTINDEX;
  new$ANUMBER PAYDOC32.ANUMBER%TYPE := :NEW.ANUMBER;
  new$TAXNOTE PAYDOC32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$REJECT_CLS PAYDOC32.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REALPAYERORG_REF PAYDOC32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$ISDIVIDE PAYDOC32.ISDIVIDE%TYPE := :NEW.ISDIVIDE;
  new$CURSUM PAYDOC32.CURSUM%TYPE := :NEW.CURSUM;
  new$CREDIT PAYDOC32.CREDIT%TYPE := :NEW.CREDIT;
  new$DEBIT PAYDOC32.DEBIT%TYPE := :NEW.DEBIT;
  new$RVERSION PAYDOC32.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYDOC32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MEANSTYPE PAYDOC32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$PAYMENTCONDITION PAYDOC32.PAYMENTCONDITION%TYPE := :NEW.PAYMENTCONDITION;
  new$BUDGETREF PAYDOC32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$TRANSFERTCLS PAYDOC32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$TEMPREJECTCAUSE PAYDOC32.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  parentinputdate NUMBER;
  cnt$ NUMBER (10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (T_PAYDOC32_BU_0)
-- Last update 15.09.2005
-- - - - - - - - - - - - -

   IF (new$DocType IS NULL) THEN new$DocType := 1010; END IF;
   IF (new$SourceFacialAcc_cls IS NULL) THEN new$SourceFacialAcc_cls := 0; END IF;
   IF (new$ProgIndex IS NULL) THEN new$ProgIndex := 11; END IF;
   IF (new$Currency IS NULL) THEN new$Currency := 2; END IF;
   IF (new$Summa IS NULL) THEN new$Summa := 0; END IF;
   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;
   IF (new$Debit IS NULL) THEN new$Debit := 0; END IF;
   IF (new$CurSum IS NULL) THEN new$CurSum := 0; END IF;

   IF (new$BuhOperationCLS IS NULL) THEN
      GetIntConst (60, 15, new$BuhOperationCLS);
   END IF;

   IF (new$MeansType IS NULL) THEN new$MeansType := 0; END IF;

   --  ,   ,     .
   IF (   (:OLD.AcceptDate IS NOT NULL)
       OR (:OLD.ANumber IS NOT NULL)
       OR (:OLD.ParentIndex IS NOT NULL)
      ) THEN
      IF (
             --   , , , .  
             --   ,    
             --    
             (new$AcceptorAttrRef <> :OLD.AcceptorAttrRef)
          OR (new$PayerAttrRef <> :OLD.PayerAttrRef)
          OR ((new$Summa - :OLD.Summa) > 0.001)
          OR ((new$Summa - :OLD.Summa) < -0.001)
          OR ((new$Credit - :OLD.Credit) > 0.001)
          OR ((new$Credit - :OLD.Credit) < -0.001)
          OR ((new$Debit - :OLD.Debit) > 0.001)
          OR ((new$Debit - :OLD.Debit) < -0.001)
         ) THEN
         IF (    (:OLD.ANumber IS NOT NULL)
             AND (NOT (   (new$ParentIndex <> :OLD.ParentIndex)
                       OR (    (new$ParentIndex IS NULL)
                           AND (:OLD.ParentIndex IS NOT NULL)
                          )
                       OR (    (new$ParentIndex IS NOT NULL)
                           AND (:OLD.ParentIndex IS NULL)
                          )
                      )
                 )
            ) THEN
            RaiseException ('EX_CANNOTUPDATENUMBER');
         ELSIF (:OLD.AcceptDate IS NOT NULL) THEN
            RaiseException ('EX_CANNOTUPDATEACCEPT');
         END IF;
      END IF;

      --     ,    
      --    
      IF ((new$InputDate <> :OLD.InputDate) AND (new$ParentIndex IS NOT NULL)
         ) THEN
         BEGIN
            SELECT InputDate
              INTO ParentInputDate
              FROM PayDoc32
             WHERE ID = new$parentindex;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               ParentInputDate := NULL;
         END;

         IF (ParentInputDate <> new$InputDate) THEN
            RaiseException ('EX_CANNOTUPDATECHILDDOC');
         END IF;
      END IF;
   END IF;

   --      ,
   --  ,     
   IF (    (new$ChildCount IS NOT NULL)
       AND (   (new$Reject_Cls <> :OLD.Reject_Cls)
            OR ((:OLD.Reject_Cls IS NULL) AND (new$Reject_Cls IS NOT NULL))
            OR ((:OLD.Reject_Cls IS NOT NULL) AND (new$Reject_Cls IS NULL))
           )
      ) THEN
      UPDATE PayDoc32
         SET Reject_Cls = new$Reject_Cls
       WHERE (ParentIndex = new$ID) AND (ID <> new$ID);
   END IF;

-- - - - - - - - - - - - -
-- BU_1 (TR_PAYDOC32_BU_1)
-- Last update 19.09.2005
-- - - - - - - - - - - - -

   IF ((new$acceptorattrref <> new$acceptorattrref) AND (new$progindex <> 11)
      ) THEN
      SELECT org_accdefaults.paytype, org_accdefaults.payqueue
        INTO new$sendby, new$payqueue
        FROM org_accdefaults, org_accounts
       WHERE (org_accounts.ID = new$acceptorattrref)
         AND (org_accounts.accdefault = org_accdefaults.ID);

      IF (new$sendby IS NULL) THEN
         getintconst (11, 1, new$sendby);
      END IF;

      IF (new$payqueue IS NULL) THEN
         getintconst (11, 2, new$payqueue);
      END IF;
   END IF;

   IF (new$SendBy IS NULL) THEN new$SendBy := 2; END IF;
   IF (new$PayQueue IS NULL) THEN new$PayQueue := 5; END IF;
   IF (new$accountref IS NULL) THEN new$accountref := new$acceptorattrref; END IF;
   IF (new$acceptorattrref IS NULL) THEN new$acceptorattrref := new$accountref; END IF;
   IF (new$facialacc_cls IS NULL) THEN new$facialacc_cls := 0; END IF;

-- - - - - - - - - - - - -
-- BU_2 (TR_PAYDOC32_BU_2)
-- Create 14.09.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   --     ,  ,  ,  ,
   --         
   IF ((:OLD.childcount IS NOT NULL) AND (:OLD.childcount <> 0)) THEN
      IF (   (   ((new$acceptdate IS NULL) AND (:OLD.acceptdate IS NOT NULL)
                 )
              OR ((new$acceptdate IS NOT NULL) AND (:OLD.acceptdate IS NULL)
                 )
              OR (new$acceptdate <> :OLD.acceptdate)
             )
          OR (   ((new$payqueue IS NULL) AND (:OLD.payqueue IS NOT NULL))
              OR ((new$payqueue IS NOT NULL) AND (:OLD.payqueue IS NULL))
              OR (new$payqueue <> :OLD.payqueue)
             )
          OR (   ((new$printdate IS NULL) AND (:OLD.printdate IS NOT NULL))
              OR ((new$printdate IS NOT NULL) AND (:OLD.printdate IS NULL))
              OR (new$printdate <> :OLD.printdate)
             )
          OR (   ((new$sendby IS NULL) AND (:OLD.sendby IS NOT NULL))
              OR ((new$sendby IS NOT NULL) AND (:OLD.sendby IS NULL))
              OR (new$sendby <> :OLD.sendby)
             )
          OR (   ((new$paydate IS NULL) AND (:OLD.paydate IS NOT NULL))
              OR ((new$paydate IS NOT NULL) AND (:OLD.paydate IS NULL))
              OR (new$paydate <> :OLD.paydate)
             )
          OR (   ((new$anumber IS NULL) AND (:OLD.anumber IS NOT NULL))
              OR ((new$anumber IS NOT NULL) AND (:OLD.anumber IS NULL))
              OR (new$anumber <> :OLD.anumber)
             )
         ) THEN
         UPDATE paydoc32
            SET acceptdate = new$acceptdate,
                payqueue = new$payqueue,
                printdate = new$printdate,
                sendby = new$sendby,
                paydate = new$paydate,
                anumber = new$anumber
          WHERE parentindex = :OLD.ID;
      END IF;
   END IF;

   --      ,
   --  ,     
   IF (    (new$childcount IS NOT NULL)
       AND (   (new$reject_cls <> :OLD.reject_cls)
            OR ((:OLD.reject_cls IS NULL) AND (new$reject_cls IS NOT NULL))
            OR ((:OLD.reject_cls IS NOT NULL) AND (new$reject_cls IS NULL))
           )
      ) THEN
      UPDATE paydoc32
         SET reject_cls = new$reject_cls
       WHERE (parentindex = new$ID) AND (ID <> new$ID);
   END IF;

-- - - - - - - - - - - - -
-- BU_3 (TR_PAYDOC32_BU_3)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   SELECT COUNT (ID)
     INTO cnt$
     FROM paydocexchange
    WHERE (paydocref = :OLD.ID) AND (status <> 0);

   IF (cnt$ > 0) THEN
      IF (   (new$ANUMBER <> :OLD.ANUMBER)
          OR ((new$ANUMBER IS NULL) AND (NOT :OLD.ANUMBER IS NULL))
          OR ((:OLD.ANUMBER IS NULL) AND (NOT new$ANUMBER IS NULL))
          OR (new$INPUTDATE <> :OLD.INPUTDATE)
          OR ((new$INPUTDATE IS NULL) AND (NOT :OLD.INPUTDATE IS NULL))
          OR ((:OLD.INPUTDATE IS NULL) AND (NOT new$INPUTDATE IS NULL))
          OR (new$PRINTDATE <> :OLD.PRINTDATE)
          OR ((new$PRINTDATE IS NULL) AND (NOT :OLD.PRINTDATE IS NULL))
          OR ((:OLD.PRINTDATE IS NULL) AND (NOT new$PRINTDATE IS NULL))
          OR (new$PAYERATTRREF <> :OLD.PAYERATTRREF)
          OR (new$ACCEPTORATTRREF <> :OLD.ACCEPTORATTRREF)
          OR (new$SENDBY <> :OLD.SENDBY)
          OR (new$SUMMA <> :OLD.SUMMA)
          OR (new$PAYDATE <> :OLD.PAYDATE)
          OR ((new$PAYDATE IS NULL) AND (NOT :OLD.PAYDATE IS NULL))
          OR ((:OLD.PAYDATE IS NULL) AND (NOT new$PAYDATE IS NULL))
          OR (new$PAYQUEUE <> :OLD.PAYQUEUE)
          OR ((new$PAYQUEUE IS NULL) AND (NOT :OLD.PAYQUEUE IS NULL))
          OR ((:OLD.PAYQUEUE IS NULL) AND (NOT new$PAYQUEUE IS NULL))
          OR (new$TEXTNOTE <> :OLD.TEXTNOTE)
          OR ((new$TEXTNOTE IS NULL) AND (NOT :OLD.TEXTNOTE IS NULL))
          OR ((:OLD.TEXTNOTE IS NULL) AND (NOT new$TEXTNOTE IS NULL))
          OR (new$SOURCEDOCNUMBER <> :OLD.SOURCEDOCNUMBER)
          OR (    (new$SOURCEDOCNUMBER IS NULL)
              AND (NOT :OLD.SOURCEDOCNUMBER IS NULL)
             )
          OR (    (:OLD.SOURCEDOCNUMBER IS NULL)
              AND (NOT new$SOURCEDOCNUMBER IS NULL)
             )
          OR (new$DOCTYPE <> :OLD.DOCTYPE)
          OR (new$TAXNOTE <> :OLD.TAXNOTE)
          OR ((new$TAXNOTE IS NULL) AND (NOT :OLD.TAXNOTE IS NULL))
          OR ((:OLD.TAXNOTE IS NULL) AND (NOT new$TAXNOTE IS NULL))
         ) THEN
         RaiseException ('EX_CANNOTCHANGESENDED');
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_12 (TR_PAYDOC32_BU_12)
-- Create 12.08.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   --            
   IF (new$debit * new$credit <> 0) THEN
      RaiseException ('EX_FAILDEBETCREDITVALUE');
   END IF;

   IF (new$summa = :OLD.summa) THEN
      new$summa := new$credit - new$debit;
   ELSIF (new$summa > 0) THEN
      new$credit := new$summa;
      new$debit := 0;
   ELSE
      new$credit := 0;
      new$debit := -new$summa;
   END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_PAYDOC32_BU_700)
-- Create 17.09.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_PAYDOC32 SET
    ID = new$ID,
    INPUTDATE = new$INPUTDATE,
    PRINTDATE = new$PRINTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    PAYERATTRREF = new$PAYERATTRREF,
    ACCEPTORATTRREF = new$ACCEPTORATTRREF,
    SENDBY = new$SENDBY,
    SUMMA = new$SUMMA,
    CURRENCY = new$CURRENCY,
    PAYDATE = new$PAYDATE,
    PAYQUEUE = new$PAYQUEUE,
    TEXTNOTE = new$TEXTNOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    SOURCEDOCNUMBER = new$SOURCEDOCNUMBER,
    CHILDCOUNT = new$CHILDCOUNT,
    FACIALACC_CLS = new$FACIALACC_CLS,
    ACCOUNTREF = new$ACCOUNTREF,
    DOCTYPE = new$DOCTYPE,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    PARENTINDEX = new$PARENTINDEX,
    ANUMBER = new$ANUMBER,
    TAXNOTE = new$TAXNOTE,
    REJECT_CLS = new$REJECT_CLS,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    ISDIVIDE = new$ISDIVIDE,
    CURSUM = new$CURSUM,
    CREDIT = new$CREDIT,
    DEBIT = new$DEBIT,
    RVERSION = new$RVERSION,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    MEANSTYPE = new$MEANSTYPE,
    PAYMENTCONDITION = new$PAYMENTCONDITION,
    BUDGETREF = new$BUDGETREF,
    TRANSFERTCLS = new$TRANSFERTCLS,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_50 (T_PAYDOC32_AU_50)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (    (new$inputdate <> :OLD.inputdate)
       AND (new$acceptdate IS NULL)
       AND (new$anumber IS NULL)
       AND (new$childcount IS NOT NULL)
      ) THEN
      --      
      UPDATE paydoc32
         SET inputdate = new$inputdate
       WHERE (parentindex = new$ID) AND (ID <> new$ID);
   END IF;

-- - - - - - - - - - - - -
-- AU_130 (TR_PAYDOC32_AU_130)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (new$progindex IN (131, 132, 383, 384, 385, 386))
                                                       --   
   THEN
      IF (   (new$acceptdate = :OLD.acceptdate)
          OR ((new$acceptdate IS NULL) AND (:OLD.acceptdate IS NULL))
         ) THEN
         NULL;
      ELSE
         --     
         UPDATE debt
            SET recorddate = new$acceptdate
          WHERE (ID = new$recordindex) AND (recorddate IS NULL);
      END IF;                                                       -- if-then
   END IF;                                                          -- if-then

   IF (new$progindex IN (121, 122, 133, 341, 411))
                                                  --  
   THEN
      IF (   (new$acceptdate = :OLD.acceptdate)
          OR ((new$acceptdate IS NULL) AND (:OLD.acceptdate IS NULL))
         ) THEN
         NULL;
      ELSE
         UPDATE findocdetail
            SET recorddate = new$acceptdate
          WHERE (ID = new$recordindex) AND (recorddate IS NULL);
      END IF;                                                       -- if-then
   END IF;

END;
/
ALTER TABLE TB_PAYDOC32 ADD (
  REJECTCAUSE VARCHAR2(1000)
)
/

CREATE OR REPLACE VIEW PAYDOC32 (
  ID,
  INPUTDATE,
  PRINTDATE,
  ACCEPTDATE,
  PAYERATTRREF,
  ACCEPTORATTRREF,
  SENDBY,
  SUMMA,
  CURRENCY,
  PAYDATE,
  PAYQUEUE,
  TEXTNOTE,
  PROGINDEX,
  RECORDINDEX,
  CREATERUSER,
  CREATEDATE,
  UPDATERUSER,
  UPDATEDATE,
  SOURCEDOCNUMBER,
  CHILDCOUNT,
  FACIALACC_CLS,
  ACCOUNTREF,
  DOCTYPE,
  SOURCEFACIALACC_CLS,
  PARENTINDEX,
  ANUMBER,
  TAXNOTE,
  REJECT_CLS,
  REALPAYERORG_REF,
  ISDIVIDE,
  CURSUM,
  CREDIT,
  DEBIT,
  RVERSION,
  BUHOPERATIONCLS,
  MEANSTYPE,
  PAYMENTCONDITION,
  BUDGETREF,
  TRANSFERTCLS,
  TEMPREJECTCAUSE,
  REJECTCAUSE)
AS
  SELECT
    ID,
    INPUTDATE,
    PRINTDATE,
    ACCEPTDATE,
    PAYERATTRREF,
    ACCEPTORATTRREF,
    SENDBY,
    SUMMA,
    CURRENCY,
    PAYDATE,
    PAYQUEUE,
    TEXTNOTE,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    SOURCEDOCNUMBER,
    CHILDCOUNT,
    FACIALACC_CLS,
    ACCOUNTREF,
    DOCTYPE,
    SOURCEFACIALACC_CLS,
    PARENTINDEX,
    ANUMBER,
    TAXNOTE,
    REJECT_CLS,
    REALPAYERORG_REF,
    ISDIVIDE,
    CURSUM,
    CREDIT,
    DEBIT,
    RVERSION,
    BUHOPERATIONCLS,
    MEANSTYPE,
    PAYMENTCONDITION,
    BUDGETREF,
    TRANSFERTCLS,
    TEMPREJECTCAUSE,
    REJECTCAUSE
  FROM TB_PAYDOC32
/

CREATE OR REPLACE TRIGGER TR_PAYDOC32_ID
  INSTEAD OF DELETE
  ON PAYDOC32
  FOR EACH ROW
DECLARE
  cnt$ NUMBER (10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (T_PAYDOC32_BD_0)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   /*  /        */
   IF (:OLD.AcceptDate IS NOT NULL) THEN
      RaiseException ('EX_CANNOTDELETEACCEPT');
   END IF;

   IF (:OLD.ANumber IS NOT NULL) THEN
      RaiseException ('EX_CANNOTDELETENUMBER');
   END IF;

-- - - - - - - - - - - - -
-- BD_2 (TR_PAYDOC32_BD_2)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF ((:OLD.ChildCount IS NOT NULL) AND (:OLD.ChildCount <> 0)) THEN
      UPDATE PayDoc32
         SET ParentIndex = NULL
       WHERE ParentIndex = :OLD.ID;
   END IF;

-- - - - - - - - - - - - -
-- BD_3 (TR_PAYDOC32_BD_3)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   --    ,  
   SELECT COUNT (ID)
     INTO cnt$
     FROM paydocexchange
    WHERE (paydocref = :OLD.ID) AND (status <> 0);

   IF CNT$ > 0 THEN
      RaiseException ('EX_CANNOTCHANGESENDED');
   END IF;

-- - - - - - - - - - - - -
-- BD_100 (T_PAYDOC32_BD_1)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   /*       */
   IF (:OLD.ParentIndex IS NOT NULL) THEN
      RaiseException ('EX_CANNOTDELETECHILDDOC');
   END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_PAYDOC32
  WHERE ID = :OLD.ID
           AND (   RVersion = :OLD.RVersion
                OR RVersion IS NULL AND :OLD.RVersion IS NULL
               );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

END;
/

CREATE OR REPLACE TRIGGER TR_PAYDOC32_II
  INSTEAD OF INSERT
  ON PAYDOC32
  FOR EACH ROW
DECLARE
  new$ID PAYDOC32.ID%TYPE := :NEW.ID;
  new$INPUTDATE PAYDOC32.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$PRINTDATE PAYDOC32.PRINTDATE%TYPE := :NEW.PRINTDATE;
  new$ACCEPTDATE PAYDOC32.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PAYERATTRREF PAYDOC32.PAYERATTRREF%TYPE := :NEW.PAYERATTRREF;
  new$ACCEPTORATTRREF PAYDOC32.ACCEPTORATTRREF%TYPE := :NEW.ACCEPTORATTRREF;
  new$SENDBY PAYDOC32.SENDBY%TYPE := :NEW.SENDBY;
  new$SUMMA PAYDOC32.SUMMA%TYPE := :NEW.SUMMA;
  new$CURRENCY PAYDOC32.CURRENCY%TYPE := :NEW.CURRENCY;
  new$PAYDATE PAYDOC32.PAYDATE%TYPE := :NEW.PAYDATE;
  new$PAYQUEUE PAYDOC32.PAYQUEUE%TYPE := :NEW.PAYQUEUE;
  new$TEXTNOTE PAYDOC32.TEXTNOTE%TYPE := :NEW.TEXTNOTE;
  new$PROGINDEX PAYDOC32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX PAYDOC32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER PAYDOC32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYDOC32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER PAYDOC32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE PAYDOC32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$SOURCEDOCNUMBER PAYDOC32.SOURCEDOCNUMBER%TYPE := :NEW.SOURCEDOCNUMBER;
  new$CHILDCOUNT PAYDOC32.CHILDCOUNT%TYPE := :NEW.CHILDCOUNT;
  new$FACIALACC_CLS PAYDOC32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$ACCOUNTREF PAYDOC32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$DOCTYPE PAYDOC32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SOURCEFACIALACC_CLS PAYDOC32.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$PARENTINDEX PAYDOC32.PARENTINDEX%TYPE := :NEW.PARENTINDEX;
  new$ANUMBER PAYDOC32.ANUMBER%TYPE := :NEW.ANUMBER;
  new$TAXNOTE PAYDOC32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$REJECT_CLS PAYDOC32.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REALPAYERORG_REF PAYDOC32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$ISDIVIDE PAYDOC32.ISDIVIDE%TYPE := :NEW.ISDIVIDE;
  new$CURSUM PAYDOC32.CURSUM%TYPE := :NEW.CURSUM;
  new$CREDIT PAYDOC32.CREDIT%TYPE := :NEW.CREDIT;
  new$DEBIT PAYDOC32.DEBIT%TYPE := :NEW.DEBIT;
  new$RVERSION PAYDOC32.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYDOC32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MEANSTYPE PAYDOC32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$PAYMENTCONDITION PAYDOC32.PAYMENTCONDITION%TYPE := :NEW.PAYMENTCONDITION;
  new$BUDGETREF PAYDOC32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$TRANSFERTCLS PAYDOC32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$TEMPREJECTCAUSE PAYDOC32.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
  new$REJECTCAUSE PAYDOC32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (T_PAYDOC32_BI_0)
-- Last update 17.03.2009
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   IF (new$progindex IS NULL) THEN new$progindex := 11; END IF;
   IF (new$currency IS NULL) THEN
      GetIntConst (19, 4, new$currency);
   END IF;
   IF (new$summa IS NULL) THEN new$summa := 0; END IF;
   IF (new$cursum IS NULL) THEN new$cursum := 0; END IF;
   IF (new$credit IS NULL) THEN new$credit := 0; END IF;
   IF (new$debit IS NULL) THEN new$debit := 0; END IF;

   IF (new$doctype IS NULL) THEN new$doctype := 1010; END IF;
   IF (new$sourcefacialacc_cls IS NULL) THEN new$sourcefacialacc_cls := 0; END IF;
   
   IF (new$BuhOperationCLS IS NULL) THEN
      GetIntConst (60, 15, new$BuhOperationCLS);
   END IF;
   IF (new$MeansType IS NULL) THEN new$MeansType := 0; END IF;

-- - - - - - - - - - - - -
-- BI_1 (TR_PAYDOC32_BI_1)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   --   
   IF (new$progindex <> 11) THEN
      BEGIN
         SELECT org_accdefaults.paytype, org_accdefaults.payqueue
           INTO new$sendby, new$payqueue
           FROM org_accdefaults, org_accounts
          WHERE (org_accounts.ID = new$acceptorattrref)
            AND (org_accounts.accdefault = org_accdefaults.ID);
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            new$sendby := NULL;
            new$payqueue := NULL;
      END;

      IF (new$sendby IS NULL) THEN
         getintconst (11, 1, new$sendby);
      END IF;

      IF (new$payqueue IS NULL) THEN
         getintconst (11, 2, new$payqueue);
      END IF;
   END IF;

   IF (new$SendBy IS NULL) THEN
      new$SendBy := 2;
   END IF;

   IF (new$PayQueue IS NULL) THEN
      new$PayQueue := 5;
   END IF;

   IF (new$accountref IS NULL) THEN
      new$accountref := new$acceptorattrref;
   END IF;

   IF (new$acceptorattrref IS NULL) THEN
      new$acceptorattrref := new$accountref;
   END IF;

   IF (new$facialacc_cls IS NULL) THEN
      new$facialacc_cls := 0;
   END IF;

   /*  .  ,     */
   IF ((NEW$BudgetRef IS NULL) OR (NEW$BudgetRef = 0)) THEN
      BEGIN
         SELECT fa.BudgetRef
           INTO NEW$BudgetRef
           FROM FacialAcc_Cls fa
          WHERE fa.ID = NEW$FacialAcc_Cls;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            NEW$BudgetRef := NULL;
      END;
   END IF;

   /*  ,    */
   IF ((NEW$BudgetRef IS NULL) OR (NEW$BudgetRef = 0)) THEN
      GetIntConst (-1, 3, NEW$BudgetRef);
   END IF;

-- - - - - - - - - - - - -
-- BI_12 (TR_PAYDOC32_BI_12)
-- Create 12.08.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (new$debit * new$credit <> 0) THEN
      RaiseException ('EX_FAILDEBETCREDITVALUE');
   END IF;

   IF (   (new$summa IS NULL)
       OR (new$summa = 0) AND ((new$debit <> 0) OR (new$credit <> 0))
      ) THEN
      new$summa := new$credit - new$debit;
   ELSIF (new$summa > 0) THEN
      new$credit := new$summa;
      new$debit := 0;
   ELSE
      new$credit := 0;
      new$debit := -new$summa;
   END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_PAYDOC32_BI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_PAYDOC32 (
    ID,
    INPUTDATE,
    PRINTDATE,
    ACCEPTDATE,
    PAYERATTRREF,
    ACCEPTORATTRREF,
    SENDBY,
    SUMMA,
    CURRENCY,
    PAYDATE,
    PAYQUEUE,
    TEXTNOTE,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    SOURCEDOCNUMBER,
    CHILDCOUNT,
    FACIALACC_CLS,
    ACCOUNTREF,
    DOCTYPE,
    SOURCEFACIALACC_CLS,
    PARENTINDEX,
    ANUMBER,
    TAXNOTE,
    REJECT_CLS,
    REALPAYERORG_REF,
    ISDIVIDE,
    CURSUM,
    CREDIT,
    DEBIT,
    RVERSION,
    BUHOPERATIONCLS,
    MEANSTYPE,
    PAYMENTCONDITION,
    BUDGETREF,
    TRANSFERTCLS,
    TEMPREJECTCAUSE,
    REJECTCAUSE
  ) VALUES (
    new$ID,
    new$INPUTDATE,
    new$PRINTDATE,
    new$ACCEPTDATE,
    new$PAYERATTRREF,
    new$ACCEPTORATTRREF,
    new$SENDBY,
    new$SUMMA,
    new$CURRENCY,
    new$PAYDATE,
    new$PAYQUEUE,
    new$TEXTNOTE,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$SOURCEDOCNUMBER,
    new$CHILDCOUNT,
    new$FACIALACC_CLS,
    new$ACCOUNTREF,
    new$DOCTYPE,
    new$SOURCEFACIALACC_CLS,
    new$PARENTINDEX,
    new$ANUMBER,
    new$TAXNOTE,
    new$REJECT_CLS,
    new$REALPAYERORG_REF,
    new$ISDIVIDE,
    new$CURSUM,
    new$CREDIT,
    new$DEBIT,
    new$RVERSION,
    new$BUHOPERATIONCLS,
    new$MEANSTYPE,
    new$PAYMENTCONDITION,
    new$BUDGETREF,
    new$TRANSFERTCLS,
    new$TEMPREJECTCAUSE,
    new$REJECTCAUSE);

END;
/

CREATE OR REPLACE TRIGGER TR_PAYDOC32_IU
  INSTEAD OF UPDATE
  ON PAYDOC32
  FOR EACH ROW
DECLARE
  new$ID PAYDOC32.ID%TYPE := :NEW.ID;
  new$INPUTDATE PAYDOC32.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$PRINTDATE PAYDOC32.PRINTDATE%TYPE := :NEW.PRINTDATE;
  new$ACCEPTDATE PAYDOC32.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PAYERATTRREF PAYDOC32.PAYERATTRREF%TYPE := :NEW.PAYERATTRREF;
  new$ACCEPTORATTRREF PAYDOC32.ACCEPTORATTRREF%TYPE := :NEW.ACCEPTORATTRREF;
  new$SENDBY PAYDOC32.SENDBY%TYPE := :NEW.SENDBY;
  new$SUMMA PAYDOC32.SUMMA%TYPE := :NEW.SUMMA;
  new$CURRENCY PAYDOC32.CURRENCY%TYPE := :NEW.CURRENCY;
  new$PAYDATE PAYDOC32.PAYDATE%TYPE := :NEW.PAYDATE;
  new$PAYQUEUE PAYDOC32.PAYQUEUE%TYPE := :NEW.PAYQUEUE;
  new$TEXTNOTE PAYDOC32.TEXTNOTE%TYPE := :NEW.TEXTNOTE;
  new$PROGINDEX PAYDOC32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX PAYDOC32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER PAYDOC32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYDOC32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER PAYDOC32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE PAYDOC32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$SOURCEDOCNUMBER PAYDOC32.SOURCEDOCNUMBER%TYPE := :NEW.SOURCEDOCNUMBER;
  new$CHILDCOUNT PAYDOC32.CHILDCOUNT%TYPE := :NEW.CHILDCOUNT;
  new$FACIALACC_CLS PAYDOC32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$ACCOUNTREF PAYDOC32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$DOCTYPE PAYDOC32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SOURCEFACIALACC_CLS PAYDOC32.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$PARENTINDEX PAYDOC32.PARENTINDEX%TYPE := :NEW.PARENTINDEX;
  new$ANUMBER PAYDOC32.ANUMBER%TYPE := :NEW.ANUMBER;
  new$TAXNOTE PAYDOC32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$REJECT_CLS PAYDOC32.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REALPAYERORG_REF PAYDOC32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$ISDIVIDE PAYDOC32.ISDIVIDE%TYPE := :NEW.ISDIVIDE;
  new$CURSUM PAYDOC32.CURSUM%TYPE := :NEW.CURSUM;
  new$CREDIT PAYDOC32.CREDIT%TYPE := :NEW.CREDIT;
  new$DEBIT PAYDOC32.DEBIT%TYPE := :NEW.DEBIT;
  new$RVERSION PAYDOC32.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYDOC32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MEANSTYPE PAYDOC32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$PAYMENTCONDITION PAYDOC32.PAYMENTCONDITION%TYPE := :NEW.PAYMENTCONDITION;
  new$BUDGETREF PAYDOC32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$TRANSFERTCLS PAYDOC32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$TEMPREJECTCAUSE PAYDOC32.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
  new$REJECTCAUSE PAYDOC32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  parentinputdate NUMBER;
  cnt$ NUMBER (10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (T_PAYDOC32_BU_0)
-- Last update 15.09.2005
-- - - - - - - - - - - - -

   IF (new$DocType IS NULL) THEN new$DocType := 1010; END IF;
   IF (new$SourceFacialAcc_cls IS NULL) THEN new$SourceFacialAcc_cls := 0; END IF;
   IF (new$ProgIndex IS NULL) THEN new$ProgIndex := 11; END IF;
   IF (new$Currency IS NULL) THEN new$Currency := 2; END IF;
   IF (new$Summa IS NULL) THEN new$Summa := 0; END IF;
   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;
   IF (new$Debit IS NULL) THEN new$Debit := 0; END IF;
   IF (new$CurSum IS NULL) THEN new$CurSum := 0; END IF;

   IF (new$BuhOperationCLS IS NULL) THEN
      GetIntConst (60, 15, new$BuhOperationCLS);
   END IF;

   IF (new$MeansType IS NULL) THEN new$MeansType := 0; END IF;

   --  ,   ,     .
   IF (   (:OLD.AcceptDate IS NOT NULL)
       OR (:OLD.ANumber IS NOT NULL)
       OR (:OLD.ParentIndex IS NOT NULL)
      ) THEN
      IF (
             --   , , , .  
             --   ,    
             --    
             (new$AcceptorAttrRef <> :OLD.AcceptorAttrRef)
          OR (new$PayerAttrRef <> :OLD.PayerAttrRef)
          OR ((new$Summa - :OLD.Summa) > 0.001)
          OR ((new$Summa - :OLD.Summa) < -0.001)
          OR ((new$Credit - :OLD.Credit) > 0.001)
          OR ((new$Credit - :OLD.Credit) < -0.001)
          OR ((new$Debit - :OLD.Debit) > 0.001)
          OR ((new$Debit - :OLD.Debit) < -0.001)
         ) THEN
         IF (    (:OLD.ANumber IS NOT NULL)
             AND (NOT (   (new$ParentIndex <> :OLD.ParentIndex)
                       OR (    (new$ParentIndex IS NULL)
                           AND (:OLD.ParentIndex IS NOT NULL)
                          )
                       OR (    (new$ParentIndex IS NOT NULL)
                           AND (:OLD.ParentIndex IS NULL)
                          )
                      )
                 )
            ) THEN
            RaiseException ('EX_CANNOTUPDATENUMBER');
         ELSIF (:OLD.AcceptDate IS NOT NULL) THEN
            RaiseException ('EX_CANNOTUPDATEACCEPT');
         END IF;
      END IF;

      --     ,    
      --    
      IF ((new$InputDate <> :OLD.InputDate) AND (new$ParentIndex IS NOT NULL)
         ) THEN
         BEGIN
            SELECT InputDate
              INTO ParentInputDate
              FROM PayDoc32
             WHERE ID = new$parentindex;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               ParentInputDate := NULL;
         END;

         IF (ParentInputDate <> new$InputDate) THEN
            RaiseException ('EX_CANNOTUPDATECHILDDOC');
         END IF;
      END IF;
   END IF;

   --      ,
   --  ,     
   IF (    (new$ChildCount IS NOT NULL)
       AND (   (new$Reject_Cls <> :OLD.Reject_Cls)
            OR ((:OLD.Reject_Cls IS NULL) AND (new$Reject_Cls IS NOT NULL))
            OR ((:OLD.Reject_Cls IS NOT NULL) AND (new$Reject_Cls IS NULL))
           )
      ) THEN
      UPDATE PayDoc32
         SET Reject_Cls = new$Reject_Cls
       WHERE (ParentIndex = new$ID) AND (ID <> new$ID);
   END IF;

-- - - - - - - - - - - - -
-- BU_1 (TR_PAYDOC32_BU_1)
-- Last update 19.09.2005
-- - - - - - - - - - - - -

   IF ((new$acceptorattrref <> new$acceptorattrref) AND (new$progindex <> 11)
      ) THEN
      SELECT org_accdefaults.paytype, org_accdefaults.payqueue
        INTO new$sendby, new$payqueue
        FROM org_accdefaults, org_accounts
       WHERE (org_accounts.ID = new$acceptorattrref)
         AND (org_accounts.accdefault = org_accdefaults.ID);

      IF (new$sendby IS NULL) THEN
         getintconst (11, 1, new$sendby);
      END IF;

      IF (new$payqueue IS NULL) THEN
         getintconst (11, 2, new$payqueue);
      END IF;
   END IF;

   IF (new$SendBy IS NULL) THEN new$SendBy := 2; END IF;
   IF (new$PayQueue IS NULL) THEN new$PayQueue := 5; END IF;
   IF (new$accountref IS NULL) THEN new$accountref := new$acceptorattrref; END IF;
   IF (new$acceptorattrref IS NULL) THEN new$acceptorattrref := new$accountref; END IF;
   IF (new$facialacc_cls IS NULL) THEN new$facialacc_cls := 0; END IF;

-- - - - - - - - - - - - -
-- BU_2 (TR_PAYDOC32_BU_2)
-- Create 14.09.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   --     ,  ,  ,  ,
   --         
   IF ((:OLD.childcount IS NOT NULL) AND (:OLD.childcount <> 0)) THEN
      IF (   (   ((new$acceptdate IS NULL) AND (:OLD.acceptdate IS NOT NULL)
                 )
              OR ((new$acceptdate IS NOT NULL) AND (:OLD.acceptdate IS NULL)
                 )
              OR (new$acceptdate <> :OLD.acceptdate)
             )
          OR (   ((new$payqueue IS NULL) AND (:OLD.payqueue IS NOT NULL))
              OR ((new$payqueue IS NOT NULL) AND (:OLD.payqueue IS NULL))
              OR (new$payqueue <> :OLD.payqueue)
             )
          OR (   ((new$printdate IS NULL) AND (:OLD.printdate IS NOT NULL))
              OR ((new$printdate IS NOT NULL) AND (:OLD.printdate IS NULL))
              OR (new$printdate <> :OLD.printdate)
             )
          OR (   ((new$sendby IS NULL) AND (:OLD.sendby IS NOT NULL))
              OR ((new$sendby IS NOT NULL) AND (:OLD.sendby IS NULL))
              OR (new$sendby <> :OLD.sendby)
             )
          OR (   ((new$paydate IS NULL) AND (:OLD.paydate IS NOT NULL))
              OR ((new$paydate IS NOT NULL) AND (:OLD.paydate IS NULL))
              OR (new$paydate <> :OLD.paydate)
             )
          OR (   ((new$anumber IS NULL) AND (:OLD.anumber IS NOT NULL))
              OR ((new$anumber IS NOT NULL) AND (:OLD.anumber IS NULL))
              OR (new$anumber <> :OLD.anumber)
             )
         ) THEN
         UPDATE paydoc32
            SET acceptdate = new$acceptdate,
                payqueue = new$payqueue,
                printdate = new$printdate,
                sendby = new$sendby,
                paydate = new$paydate,
                anumber = new$anumber
          WHERE parentindex = :OLD.ID;
      END IF;
   END IF;

   --      ,
   --  ,     
   IF (    (new$childcount IS NOT NULL)
       AND (   (new$reject_cls <> :OLD.reject_cls)
            OR ((:OLD.reject_cls IS NULL) AND (new$reject_cls IS NOT NULL))
            OR ((:OLD.reject_cls IS NOT NULL) AND (new$reject_cls IS NULL))
           )
      ) THEN
      UPDATE paydoc32
         SET reject_cls = new$reject_cls
       WHERE (parentindex = new$ID) AND (ID <> new$ID);
   END IF;

-- - - - - - - - - - - - -
-- BU_3 (TR_PAYDOC32_BU_3)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   SELECT COUNT (ID)
     INTO cnt$
     FROM paydocexchange
    WHERE (paydocref = :OLD.ID) AND (status <> 0);

   IF (cnt$ > 0) THEN
      IF (   (new$ANUMBER <> :OLD.ANUMBER)
          OR ((new$ANUMBER IS NULL) AND (NOT :OLD.ANUMBER IS NULL))
          OR ((:OLD.ANUMBER IS NULL) AND (NOT new$ANUMBER IS NULL))
          OR (new$INPUTDATE <> :OLD.INPUTDATE)
          OR ((new$INPUTDATE IS NULL) AND (NOT :OLD.INPUTDATE IS NULL))
          OR ((:OLD.INPUTDATE IS NULL) AND (NOT new$INPUTDATE IS NULL))
          OR (new$PRINTDATE <> :OLD.PRINTDATE)
          OR ((new$PRINTDATE IS NULL) AND (NOT :OLD.PRINTDATE IS NULL))
          OR ((:OLD.PRINTDATE IS NULL) AND (NOT new$PRINTDATE IS NULL))
          OR (new$PAYERATTRREF <> :OLD.PAYERATTRREF)
          OR (new$ACCEPTORATTRREF <> :OLD.ACCEPTORATTRREF)
          OR (new$SENDBY <> :OLD.SENDBY)
          OR (new$SUMMA <> :OLD.SUMMA)
          OR (new$PAYDATE <> :OLD.PAYDATE)
          OR ((new$PAYDATE IS NULL) AND (NOT :OLD.PAYDATE IS NULL))
          OR ((:OLD.PAYDATE IS NULL) AND (NOT new$PAYDATE IS NULL))
          OR (new$PAYQUEUE <> :OLD.PAYQUEUE)
          OR ((new$PAYQUEUE IS NULL) AND (NOT :OLD.PAYQUEUE IS NULL))
          OR ((:OLD.PAYQUEUE IS NULL) AND (NOT new$PAYQUEUE IS NULL))
          OR (new$TEXTNOTE <> :OLD.TEXTNOTE)
          OR ((new$TEXTNOTE IS NULL) AND (NOT :OLD.TEXTNOTE IS NULL))
          OR ((:OLD.TEXTNOTE IS NULL) AND (NOT new$TEXTNOTE IS NULL))
          OR (new$SOURCEDOCNUMBER <> :OLD.SOURCEDOCNUMBER)
          OR (    (new$SOURCEDOCNUMBER IS NULL)
              AND (NOT :OLD.SOURCEDOCNUMBER IS NULL)
             )
          OR (    (:OLD.SOURCEDOCNUMBER IS NULL)
              AND (NOT new$SOURCEDOCNUMBER IS NULL)
             )
          OR (new$DOCTYPE <> :OLD.DOCTYPE)
          OR (new$TAXNOTE <> :OLD.TAXNOTE)
          OR ((new$TAXNOTE IS NULL) AND (NOT :OLD.TAXNOTE IS NULL))
          OR ((:OLD.TAXNOTE IS NULL) AND (NOT new$TAXNOTE IS NULL))
         ) THEN
         RaiseException ('EX_CANNOTCHANGESENDED');
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_12 (TR_PAYDOC32_BU_12)
-- Create 12.08.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   --            
   IF (new$debit * new$credit <> 0) THEN
      RaiseException ('EX_FAILDEBETCREDITVALUE');
   END IF;

   IF (new$summa = :OLD.summa) THEN
      new$summa := new$credit - new$debit;
   ELSIF (new$summa > 0) THEN
      new$credit := new$summa;
      new$debit := 0;
   ELSE
      new$credit := 0;
      new$debit := -new$summa;
   END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_PAYDOC32_BU_700)
-- Create 17.09.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_PAYDOC32 SET
    ID = new$ID,
    INPUTDATE = new$INPUTDATE,
    PRINTDATE = new$PRINTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    PAYERATTRREF = new$PAYERATTRREF,
    ACCEPTORATTRREF = new$ACCEPTORATTRREF,
    SENDBY = new$SENDBY,
    SUMMA = new$SUMMA,
    CURRENCY = new$CURRENCY,
    PAYDATE = new$PAYDATE,
    PAYQUEUE = new$PAYQUEUE,
    TEXTNOTE = new$TEXTNOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    SOURCEDOCNUMBER = new$SOURCEDOCNUMBER,
    CHILDCOUNT = new$CHILDCOUNT,
    FACIALACC_CLS = new$FACIALACC_CLS,
    ACCOUNTREF = new$ACCOUNTREF,
    DOCTYPE = new$DOCTYPE,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    PARENTINDEX = new$PARENTINDEX,
    ANUMBER = new$ANUMBER,
    TAXNOTE = new$TAXNOTE,
    REJECT_CLS = new$REJECT_CLS,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    ISDIVIDE = new$ISDIVIDE,
    CURSUM = new$CURSUM,
    CREDIT = new$CREDIT,
    DEBIT = new$DEBIT,
    RVERSION = new$RVERSION,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    MEANSTYPE = new$MEANSTYPE,
    PAYMENTCONDITION = new$PAYMENTCONDITION,
    BUDGETREF = new$BUDGETREF,
    TRANSFERTCLS = new$TRANSFERTCLS,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_50 (T_PAYDOC32_AU_50)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (    (new$inputdate <> :OLD.inputdate)
       AND (new$acceptdate IS NULL)
       AND (new$anumber IS NULL)
       AND (new$childcount IS NOT NULL)
      ) THEN
      --      
      UPDATE paydoc32
         SET inputdate = new$inputdate
       WHERE (parentindex = new$ID) AND (ID <> new$ID);
   END IF;

-- - - - - - - - - - - - -
-- AU_130 (TR_PAYDOC32_AU_130)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (new$progindex IN (131, 132, 383, 384, 385, 386))
                                                       --   
   THEN
      IF (   (new$acceptdate = :OLD.acceptdate)
          OR ((new$acceptdate IS NULL) AND (:OLD.acceptdate IS NULL))
         ) THEN
         NULL;
      ELSE
         --     
         UPDATE debt
            SET recorddate = new$acceptdate
          WHERE (ID = new$recordindex) AND (recorddate IS NULL);
      END IF;                                                       -- if-then
   END IF;                                                          -- if-then

   IF (new$progindex IN (121, 122, 133, 341, 411))
                                                  --  
   THEN
      IF (   (new$acceptdate = :OLD.acceptdate)
          OR ((new$acceptdate IS NULL) AND (:OLD.acceptdate IS NULL))
         ) THEN
         NULL;
      ELSE
         UPDATE findocdetail
            SET recorddate = new$acceptdate
          WHERE (ID = new$recordindex) AND (recorddate IS NULL);
      END IF;                                                       -- if-then
   END IF;

END;
/
update PAYDOC32 set
  REJECTCAUSE = TempRejectCause
/
commit work 
/
ALTER TABLE TB_PAYDOC32 DROP (TempRejectCause)
/

CREATE OR REPLACE VIEW PAYDOC32 (
  ID,
  INPUTDATE,
  PRINTDATE,
  ACCEPTDATE,
  PAYERATTRREF,
  ACCEPTORATTRREF,
  SENDBY,
  SUMMA,
  CURRENCY,
  PAYDATE,
  PAYQUEUE,
  TEXTNOTE,
  PROGINDEX,
  RECORDINDEX,
  CREATERUSER,
  CREATEDATE,
  UPDATERUSER,
  UPDATEDATE,
  SOURCEDOCNUMBER,
  CHILDCOUNT,
  FACIALACC_CLS,
  ACCOUNTREF,
  DOCTYPE,
  SOURCEFACIALACC_CLS,
  PARENTINDEX,
  ANUMBER,
  TAXNOTE,
  REJECT_CLS,
  REALPAYERORG_REF,
  ISDIVIDE,
  CURSUM,
  CREDIT,
  DEBIT,
  RVERSION,
  BUHOPERATIONCLS,
  MEANSTYPE,
  PAYMENTCONDITION,
  BUDGETREF,
  TRANSFERTCLS,
  REJECTCAUSE)
AS
  SELECT
    ID,
    INPUTDATE,
    PRINTDATE,
    ACCEPTDATE,
    PAYERATTRREF,
    ACCEPTORATTRREF,
    SENDBY,
    SUMMA,
    CURRENCY,
    PAYDATE,
    PAYQUEUE,
    TEXTNOTE,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    SOURCEDOCNUMBER,
    CHILDCOUNT,
    FACIALACC_CLS,
    ACCOUNTREF,
    DOCTYPE,
    SOURCEFACIALACC_CLS,
    PARENTINDEX,
    ANUMBER,
    TAXNOTE,
    REJECT_CLS,
    REALPAYERORG_REF,
    ISDIVIDE,
    CURSUM,
    CREDIT,
    DEBIT,
    RVERSION,
    BUHOPERATIONCLS,
    MEANSTYPE,
    PAYMENTCONDITION,
    BUDGETREF,
    TRANSFERTCLS,
    REJECTCAUSE
  FROM TB_PAYDOC32
/

CREATE OR REPLACE TRIGGER TR_PAYDOC32_ID
  INSTEAD OF DELETE
  ON PAYDOC32
  FOR EACH ROW
DECLARE
  cnt$ NUMBER (10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (T_PAYDOC32_BD_0)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   /*  /        */
   IF (:OLD.AcceptDate IS NOT NULL) THEN
      RaiseException ('EX_CANNOTDELETEACCEPT');
   END IF;

   IF (:OLD.ANumber IS NOT NULL) THEN
      RaiseException ('EX_CANNOTDELETENUMBER');
   END IF;

-- - - - - - - - - - - - -
-- BD_2 (TR_PAYDOC32_BD_2)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF ((:OLD.ChildCount IS NOT NULL) AND (:OLD.ChildCount <> 0)) THEN
      UPDATE PayDoc32
         SET ParentIndex = NULL
       WHERE ParentIndex = :OLD.ID;
   END IF;

-- - - - - - - - - - - - -
-- BD_3 (TR_PAYDOC32_BD_3)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   --    ,  
   SELECT COUNT (ID)
     INTO cnt$
     FROM paydocexchange
    WHERE (paydocref = :OLD.ID) AND (status <> 0);

   IF CNT$ > 0 THEN
      RaiseException ('EX_CANNOTCHANGESENDED');
   END IF;

-- - - - - - - - - - - - -
-- BD_100 (T_PAYDOC32_BD_1)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   /*       */
   IF (:OLD.ParentIndex IS NOT NULL) THEN
      RaiseException ('EX_CANNOTDELETECHILDDOC');
   END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_PAYDOC32
  WHERE ID = :OLD.ID
           AND (   RVersion = :OLD.RVersion
                OR RVersion IS NULL AND :OLD.RVersion IS NULL
               );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

END;
/

CREATE OR REPLACE TRIGGER TR_PAYDOC32_II
  INSTEAD OF INSERT
  ON PAYDOC32
  FOR EACH ROW
DECLARE
  new$ID PAYDOC32.ID%TYPE := :NEW.ID;
  new$INPUTDATE PAYDOC32.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$PRINTDATE PAYDOC32.PRINTDATE%TYPE := :NEW.PRINTDATE;
  new$ACCEPTDATE PAYDOC32.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PAYERATTRREF PAYDOC32.PAYERATTRREF%TYPE := :NEW.PAYERATTRREF;
  new$ACCEPTORATTRREF PAYDOC32.ACCEPTORATTRREF%TYPE := :NEW.ACCEPTORATTRREF;
  new$SENDBY PAYDOC32.SENDBY%TYPE := :NEW.SENDBY;
  new$SUMMA PAYDOC32.SUMMA%TYPE := :NEW.SUMMA;
  new$CURRENCY PAYDOC32.CURRENCY%TYPE := :NEW.CURRENCY;
  new$PAYDATE PAYDOC32.PAYDATE%TYPE := :NEW.PAYDATE;
  new$PAYQUEUE PAYDOC32.PAYQUEUE%TYPE := :NEW.PAYQUEUE;
  new$TEXTNOTE PAYDOC32.TEXTNOTE%TYPE := :NEW.TEXTNOTE;
  new$PROGINDEX PAYDOC32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX PAYDOC32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER PAYDOC32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYDOC32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER PAYDOC32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE PAYDOC32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$SOURCEDOCNUMBER PAYDOC32.SOURCEDOCNUMBER%TYPE := :NEW.SOURCEDOCNUMBER;
  new$CHILDCOUNT PAYDOC32.CHILDCOUNT%TYPE := :NEW.CHILDCOUNT;
  new$FACIALACC_CLS PAYDOC32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$ACCOUNTREF PAYDOC32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$DOCTYPE PAYDOC32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SOURCEFACIALACC_CLS PAYDOC32.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$PARENTINDEX PAYDOC32.PARENTINDEX%TYPE := :NEW.PARENTINDEX;
  new$ANUMBER PAYDOC32.ANUMBER%TYPE := :NEW.ANUMBER;
  new$TAXNOTE PAYDOC32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$REJECT_CLS PAYDOC32.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REALPAYERORG_REF PAYDOC32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$ISDIVIDE PAYDOC32.ISDIVIDE%TYPE := :NEW.ISDIVIDE;
  new$CURSUM PAYDOC32.CURSUM%TYPE := :NEW.CURSUM;
  new$CREDIT PAYDOC32.CREDIT%TYPE := :NEW.CREDIT;
  new$DEBIT PAYDOC32.DEBIT%TYPE := :NEW.DEBIT;
  new$RVERSION PAYDOC32.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYDOC32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MEANSTYPE PAYDOC32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$PAYMENTCONDITION PAYDOC32.PAYMENTCONDITION%TYPE := :NEW.PAYMENTCONDITION;
  new$BUDGETREF PAYDOC32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$TRANSFERTCLS PAYDOC32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$REJECTCAUSE PAYDOC32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (T_PAYDOC32_BI_0)
-- Last update 17.03.2009
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   IF (new$progindex IS NULL) THEN new$progindex := 11; END IF;
   IF (new$currency IS NULL) THEN
      GetIntConst (19, 4, new$currency);
   END IF;
   IF (new$summa IS NULL) THEN new$summa := 0; END IF;
   IF (new$cursum IS NULL) THEN new$cursum := 0; END IF;
   IF (new$credit IS NULL) THEN new$credit := 0; END IF;
   IF (new$debit IS NULL) THEN new$debit := 0; END IF;

   IF (new$doctype IS NULL) THEN new$doctype := 1010; END IF;
   IF (new$sourcefacialacc_cls IS NULL) THEN new$sourcefacialacc_cls := 0; END IF;
   
   IF (new$BuhOperationCLS IS NULL) THEN
      GetIntConst (60, 15, new$BuhOperationCLS);
   END IF;
   IF (new$MeansType IS NULL) THEN new$MeansType := 0; END IF;

-- - - - - - - - - - - - -
-- BI_1 (TR_PAYDOC32_BI_1)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   --   
   IF (new$progindex <> 11) THEN
      BEGIN
         SELECT org_accdefaults.paytype, org_accdefaults.payqueue
           INTO new$sendby, new$payqueue
           FROM org_accdefaults, org_accounts
          WHERE (org_accounts.ID = new$acceptorattrref)
            AND (org_accounts.accdefault = org_accdefaults.ID);
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            new$sendby := NULL;
            new$payqueue := NULL;
      END;

      IF (new$sendby IS NULL) THEN
         getintconst (11, 1, new$sendby);
      END IF;

      IF (new$payqueue IS NULL) THEN
         getintconst (11, 2, new$payqueue);
      END IF;
   END IF;

   IF (new$SendBy IS NULL) THEN
      new$SendBy := 2;
   END IF;

   IF (new$PayQueue IS NULL) THEN
      new$PayQueue := 5;
   END IF;

   IF (new$accountref IS NULL) THEN
      new$accountref := new$acceptorattrref;
   END IF;

   IF (new$acceptorattrref IS NULL) THEN
      new$acceptorattrref := new$accountref;
   END IF;

   IF (new$facialacc_cls IS NULL) THEN
      new$facialacc_cls := 0;
   END IF;

   /*  .  ,     */
   IF ((NEW$BudgetRef IS NULL) OR (NEW$BudgetRef = 0)) THEN
      BEGIN
         SELECT fa.BudgetRef
           INTO NEW$BudgetRef
           FROM FacialAcc_Cls fa
          WHERE fa.ID = NEW$FacialAcc_Cls;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            NEW$BudgetRef := NULL;
      END;
   END IF;

   /*  ,    */
   IF ((NEW$BudgetRef IS NULL) OR (NEW$BudgetRef = 0)) THEN
      GetIntConst (-1, 3, NEW$BudgetRef);
   END IF;

-- - - - - - - - - - - - -
-- BI_12 (TR_PAYDOC32_BI_12)
-- Create 12.08.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (new$debit * new$credit <> 0) THEN
      RaiseException ('EX_FAILDEBETCREDITVALUE');
   END IF;

   IF (   (new$summa IS NULL)
       OR (new$summa = 0) AND ((new$debit <> 0) OR (new$credit <> 0))
      ) THEN
      new$summa := new$credit - new$debit;
   ELSIF (new$summa > 0) THEN
      new$credit := new$summa;
      new$debit := 0;
   ELSE
      new$credit := 0;
      new$debit := -new$summa;
   END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_PAYDOC32_BI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_PAYDOC32 (
    ID,
    INPUTDATE,
    PRINTDATE,
    ACCEPTDATE,
    PAYERATTRREF,
    ACCEPTORATTRREF,
    SENDBY,
    SUMMA,
    CURRENCY,
    PAYDATE,
    PAYQUEUE,
    TEXTNOTE,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    SOURCEDOCNUMBER,
    CHILDCOUNT,
    FACIALACC_CLS,
    ACCOUNTREF,
    DOCTYPE,
    SOURCEFACIALACC_CLS,
    PARENTINDEX,
    ANUMBER,
    TAXNOTE,
    REJECT_CLS,
    REALPAYERORG_REF,
    ISDIVIDE,
    CURSUM,
    CREDIT,
    DEBIT,
    RVERSION,
    BUHOPERATIONCLS,
    MEANSTYPE,
    PAYMENTCONDITION,
    BUDGETREF,
    TRANSFERTCLS,
    REJECTCAUSE
  ) VALUES (
    new$ID,
    new$INPUTDATE,
    new$PRINTDATE,
    new$ACCEPTDATE,
    new$PAYERATTRREF,
    new$ACCEPTORATTRREF,
    new$SENDBY,
    new$SUMMA,
    new$CURRENCY,
    new$PAYDATE,
    new$PAYQUEUE,
    new$TEXTNOTE,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$SOURCEDOCNUMBER,
    new$CHILDCOUNT,
    new$FACIALACC_CLS,
    new$ACCOUNTREF,
    new$DOCTYPE,
    new$SOURCEFACIALACC_CLS,
    new$PARENTINDEX,
    new$ANUMBER,
    new$TAXNOTE,
    new$REJECT_CLS,
    new$REALPAYERORG_REF,
    new$ISDIVIDE,
    new$CURSUM,
    new$CREDIT,
    new$DEBIT,
    new$RVERSION,
    new$BUHOPERATIONCLS,
    new$MEANSTYPE,
    new$PAYMENTCONDITION,
    new$BUDGETREF,
    new$TRANSFERTCLS,
    new$REJECTCAUSE);

END;
/

CREATE OR REPLACE TRIGGER TR_PAYDOC32_IU
  INSTEAD OF UPDATE
  ON PAYDOC32
  FOR EACH ROW
DECLARE
  new$ID PAYDOC32.ID%TYPE := :NEW.ID;
  new$INPUTDATE PAYDOC32.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$PRINTDATE PAYDOC32.PRINTDATE%TYPE := :NEW.PRINTDATE;
  new$ACCEPTDATE PAYDOC32.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PAYERATTRREF PAYDOC32.PAYERATTRREF%TYPE := :NEW.PAYERATTRREF;
  new$ACCEPTORATTRREF PAYDOC32.ACCEPTORATTRREF%TYPE := :NEW.ACCEPTORATTRREF;
  new$SENDBY PAYDOC32.SENDBY%TYPE := :NEW.SENDBY;
  new$SUMMA PAYDOC32.SUMMA%TYPE := :NEW.SUMMA;
  new$CURRENCY PAYDOC32.CURRENCY%TYPE := :NEW.CURRENCY;
  new$PAYDATE PAYDOC32.PAYDATE%TYPE := :NEW.PAYDATE;
  new$PAYQUEUE PAYDOC32.PAYQUEUE%TYPE := :NEW.PAYQUEUE;
  new$TEXTNOTE PAYDOC32.TEXTNOTE%TYPE := :NEW.TEXTNOTE;
  new$PROGINDEX PAYDOC32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX PAYDOC32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER PAYDOC32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYDOC32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER PAYDOC32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE PAYDOC32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$SOURCEDOCNUMBER PAYDOC32.SOURCEDOCNUMBER%TYPE := :NEW.SOURCEDOCNUMBER;
  new$CHILDCOUNT PAYDOC32.CHILDCOUNT%TYPE := :NEW.CHILDCOUNT;
  new$FACIALACC_CLS PAYDOC32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$ACCOUNTREF PAYDOC32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$DOCTYPE PAYDOC32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SOURCEFACIALACC_CLS PAYDOC32.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$PARENTINDEX PAYDOC32.PARENTINDEX%TYPE := :NEW.PARENTINDEX;
  new$ANUMBER PAYDOC32.ANUMBER%TYPE := :NEW.ANUMBER;
  new$TAXNOTE PAYDOC32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$REJECT_CLS PAYDOC32.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REALPAYERORG_REF PAYDOC32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$ISDIVIDE PAYDOC32.ISDIVIDE%TYPE := :NEW.ISDIVIDE;
  new$CURSUM PAYDOC32.CURSUM%TYPE := :NEW.CURSUM;
  new$CREDIT PAYDOC32.CREDIT%TYPE := :NEW.CREDIT;
  new$DEBIT PAYDOC32.DEBIT%TYPE := :NEW.DEBIT;
  new$RVERSION PAYDOC32.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYDOC32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MEANSTYPE PAYDOC32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$PAYMENTCONDITION PAYDOC32.PAYMENTCONDITION%TYPE := :NEW.PAYMENTCONDITION;
  new$BUDGETREF PAYDOC32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$TRANSFERTCLS PAYDOC32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$REJECTCAUSE PAYDOC32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  parentinputdate NUMBER;
  cnt$ NUMBER (10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (T_PAYDOC32_BU_0)
-- Last update 15.09.2005
-- - - - - - - - - - - - -

   IF (new$DocType IS NULL) THEN new$DocType := 1010; END IF;
   IF (new$SourceFacialAcc_cls IS NULL) THEN new$SourceFacialAcc_cls := 0; END IF;
   IF (new$ProgIndex IS NULL) THEN new$ProgIndex := 11; END IF;
   IF (new$Currency IS NULL) THEN new$Currency := 2; END IF;
   IF (new$Summa IS NULL) THEN new$Summa := 0; END IF;
   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;
   IF (new$Debit IS NULL) THEN new$Debit := 0; END IF;
   IF (new$CurSum IS NULL) THEN new$CurSum := 0; END IF;

   IF (new$BuhOperationCLS IS NULL) THEN
      GetIntConst (60, 15, new$BuhOperationCLS);
   END IF;

   IF (new$MeansType IS NULL) THEN new$MeansType := 0; END IF;

   --  ,   ,     .
   IF (   (:OLD.AcceptDate IS NOT NULL)
       OR (:OLD.ANumber IS NOT NULL)
       OR (:OLD.ParentIndex IS NOT NULL)
      ) THEN
      IF (
             --   , , , .  
             --   ,    
             --    
             (new$AcceptorAttrRef <> :OLD.AcceptorAttrRef)
          OR (new$PayerAttrRef <> :OLD.PayerAttrRef)
          OR ((new$Summa - :OLD.Summa) > 0.001)
          OR ((new$Summa - :OLD.Summa) < -0.001)
          OR ((new$Credit - :OLD.Credit) > 0.001)
          OR ((new$Credit - :OLD.Credit) < -0.001)
          OR ((new$Debit - :OLD.Debit) > 0.001)
          OR ((new$Debit - :OLD.Debit) < -0.001)
         ) THEN
         IF (    (:OLD.ANumber IS NOT NULL)
             AND (NOT (   (new$ParentIndex <> :OLD.ParentIndex)
                       OR (    (new$ParentIndex IS NULL)
                           AND (:OLD.ParentIndex IS NOT NULL)
                          )
                       OR (    (new$ParentIndex IS NOT NULL)
                           AND (:OLD.ParentIndex IS NULL)
                          )
                      )
                 )
            ) THEN
            RaiseException ('EX_CANNOTUPDATENUMBER');
         ELSIF (:OLD.AcceptDate IS NOT NULL) THEN
            RaiseException ('EX_CANNOTUPDATEACCEPT');
         END IF;
      END IF;

      --     ,    
      --    
      IF ((new$InputDate <> :OLD.InputDate) AND (new$ParentIndex IS NOT NULL)
         ) THEN
         BEGIN
            SELECT InputDate
              INTO ParentInputDate
              FROM PayDoc32
             WHERE ID = new$parentindex;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               ParentInputDate := NULL;
         END;

         IF (ParentInputDate <> new$InputDate) THEN
            RaiseException ('EX_CANNOTUPDATECHILDDOC');
         END IF;
      END IF;
   END IF;

   --      ,
   --  ,     
   IF (    (new$ChildCount IS NOT NULL)
       AND (   (new$Reject_Cls <> :OLD.Reject_Cls)
            OR ((:OLD.Reject_Cls IS NULL) AND (new$Reject_Cls IS NOT NULL))
            OR ((:OLD.Reject_Cls IS NOT NULL) AND (new$Reject_Cls IS NULL))
           )
      ) THEN
      UPDATE PayDoc32
         SET Reject_Cls = new$Reject_Cls
       WHERE (ParentIndex = new$ID) AND (ID <> new$ID);
   END IF;

-- - - - - - - - - - - - -
-- BU_1 (TR_PAYDOC32_BU_1)
-- Last update 19.09.2005
-- - - - - - - - - - - - -

   IF ((new$acceptorattrref <> new$acceptorattrref) AND (new$progindex <> 11)
      ) THEN
      SELECT org_accdefaults.paytype, org_accdefaults.payqueue
        INTO new$sendby, new$payqueue
        FROM org_accdefaults, org_accounts
       WHERE (org_accounts.ID = new$acceptorattrref)
         AND (org_accounts.accdefault = org_accdefaults.ID);

      IF (new$sendby IS NULL) THEN
         getintconst (11, 1, new$sendby);
      END IF;

      IF (new$payqueue IS NULL) THEN
         getintconst (11, 2, new$payqueue);
      END IF;
   END IF;

   IF (new$SendBy IS NULL) THEN new$SendBy := 2; END IF;
   IF (new$PayQueue IS NULL) THEN new$PayQueue := 5; END IF;
   IF (new$accountref IS NULL) THEN new$accountref := new$acceptorattrref; END IF;
   IF (new$acceptorattrref IS NULL) THEN new$acceptorattrref := new$accountref; END IF;
   IF (new$facialacc_cls IS NULL) THEN new$facialacc_cls := 0; END IF;

-- - - - - - - - - - - - -
-- BU_2 (TR_PAYDOC32_BU_2)
-- Create 14.09.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   --     ,  ,  ,  ,
   --         
   IF ((:OLD.childcount IS NOT NULL) AND (:OLD.childcount <> 0)) THEN
      IF (   (   ((new$acceptdate IS NULL) AND (:OLD.acceptdate IS NOT NULL)
                 )
              OR ((new$acceptdate IS NOT NULL) AND (:OLD.acceptdate IS NULL)
                 )
              OR (new$acceptdate <> :OLD.acceptdate)
             )
          OR (   ((new$payqueue IS NULL) AND (:OLD.payqueue IS NOT NULL))
              OR ((new$payqueue IS NOT NULL) AND (:OLD.payqueue IS NULL))
              OR (new$payqueue <> :OLD.payqueue)
             )
          OR (   ((new$printdate IS NULL) AND (:OLD.printdate IS NOT NULL))
              OR ((new$printdate IS NOT NULL) AND (:OLD.printdate IS NULL))
              OR (new$printdate <> :OLD.printdate)
             )
          OR (   ((new$sendby IS NULL) AND (:OLD.sendby IS NOT NULL))
              OR ((new$sendby IS NOT NULL) AND (:OLD.sendby IS NULL))
              OR (new$sendby <> :OLD.sendby)
             )
          OR (   ((new$paydate IS NULL) AND (:OLD.paydate IS NOT NULL))
              OR ((new$paydate IS NOT NULL) AND (:OLD.paydate IS NULL))
              OR (new$paydate <> :OLD.paydate)
             )
          OR (   ((new$anumber IS NULL) AND (:OLD.anumber IS NOT NULL))
              OR ((new$anumber IS NOT NULL) AND (:OLD.anumber IS NULL))
              OR (new$anumber <> :OLD.anumber)
             )
         ) THEN
         UPDATE paydoc32
            SET acceptdate = new$acceptdate,
                payqueue = new$payqueue,
                printdate = new$printdate,
                sendby = new$sendby,
                paydate = new$paydate,
                anumber = new$anumber
          WHERE parentindex = :OLD.ID;
      END IF;
   END IF;

   --      ,
   --  ,     
   IF (    (new$childcount IS NOT NULL)
       AND (   (new$reject_cls <> :OLD.reject_cls)
            OR ((:OLD.reject_cls IS NULL) AND (new$reject_cls IS NOT NULL))
            OR ((:OLD.reject_cls IS NOT NULL) AND (new$reject_cls IS NULL))
           )
      ) THEN
      UPDATE paydoc32
         SET reject_cls = new$reject_cls
       WHERE (parentindex = new$ID) AND (ID <> new$ID);
   END IF;

-- - - - - - - - - - - - -
-- BU_3 (TR_PAYDOC32_BU_3)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   SELECT COUNT (ID)
     INTO cnt$
     FROM paydocexchange
    WHERE (paydocref = :OLD.ID) AND (status <> 0);

   IF (cnt$ > 0) THEN
      IF (   (new$ANUMBER <> :OLD.ANUMBER)
          OR ((new$ANUMBER IS NULL) AND (NOT :OLD.ANUMBER IS NULL))
          OR ((:OLD.ANUMBER IS NULL) AND (NOT new$ANUMBER IS NULL))
          OR (new$INPUTDATE <> :OLD.INPUTDATE)
          OR ((new$INPUTDATE IS NULL) AND (NOT :OLD.INPUTDATE IS NULL))
          OR ((:OLD.INPUTDATE IS NULL) AND (NOT new$INPUTDATE IS NULL))
          OR (new$PRINTDATE <> :OLD.PRINTDATE)
          OR ((new$PRINTDATE IS NULL) AND (NOT :OLD.PRINTDATE IS NULL))
          OR ((:OLD.PRINTDATE IS NULL) AND (NOT new$PRINTDATE IS NULL))
          OR (new$PAYERATTRREF <> :OLD.PAYERATTRREF)
          OR (new$ACCEPTORATTRREF <> :OLD.ACCEPTORATTRREF)
          OR (new$SENDBY <> :OLD.SENDBY)
          OR (new$SUMMA <> :OLD.SUMMA)
          OR (new$PAYDATE <> :OLD.PAYDATE)
          OR ((new$PAYDATE IS NULL) AND (NOT :OLD.PAYDATE IS NULL))
          OR ((:OLD.PAYDATE IS NULL) AND (NOT new$PAYDATE IS NULL))
          OR (new$PAYQUEUE <> :OLD.PAYQUEUE)
          OR ((new$PAYQUEUE IS NULL) AND (NOT :OLD.PAYQUEUE IS NULL))
          OR ((:OLD.PAYQUEUE IS NULL) AND (NOT new$PAYQUEUE IS NULL))
          OR (new$TEXTNOTE <> :OLD.TEXTNOTE)
          OR ((new$TEXTNOTE IS NULL) AND (NOT :OLD.TEXTNOTE IS NULL))
          OR ((:OLD.TEXTNOTE IS NULL) AND (NOT new$TEXTNOTE IS NULL))
          OR (new$SOURCEDOCNUMBER <> :OLD.SOURCEDOCNUMBER)
          OR (    (new$SOURCEDOCNUMBER IS NULL)
              AND (NOT :OLD.SOURCEDOCNUMBER IS NULL)
             )
          OR (    (:OLD.SOURCEDOCNUMBER IS NULL)
              AND (NOT new$SOURCEDOCNUMBER IS NULL)
             )
          OR (new$DOCTYPE <> :OLD.DOCTYPE)
          OR (new$TAXNOTE <> :OLD.TAXNOTE)
          OR ((new$TAXNOTE IS NULL) AND (NOT :OLD.TAXNOTE IS NULL))
          OR ((:OLD.TAXNOTE IS NULL) AND (NOT new$TAXNOTE IS NULL))
         ) THEN
         RaiseException ('EX_CANNOTCHANGESENDED');
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_12 (TR_PAYDOC32_BU_12)
-- Create 12.08.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   --            
   IF (new$debit * new$credit <> 0) THEN
      RaiseException ('EX_FAILDEBETCREDITVALUE');
   END IF;

   IF (new$summa = :OLD.summa) THEN
      new$summa := new$credit - new$debit;
   ELSIF (new$summa > 0) THEN
      new$credit := new$summa;
      new$debit := 0;
   ELSE
      new$credit := 0;
      new$debit := -new$summa;
   END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_PAYDOC32_BU_700)
-- Create 17.09.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_PAYDOC32 SET
    ID = new$ID,
    INPUTDATE = new$INPUTDATE,
    PRINTDATE = new$PRINTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    PAYERATTRREF = new$PAYERATTRREF,
    ACCEPTORATTRREF = new$ACCEPTORATTRREF,
    SENDBY = new$SENDBY,
    SUMMA = new$SUMMA,
    CURRENCY = new$CURRENCY,
    PAYDATE = new$PAYDATE,
    PAYQUEUE = new$PAYQUEUE,
    TEXTNOTE = new$TEXTNOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    SOURCEDOCNUMBER = new$SOURCEDOCNUMBER,
    CHILDCOUNT = new$CHILDCOUNT,
    FACIALACC_CLS = new$FACIALACC_CLS,
    ACCOUNTREF = new$ACCOUNTREF,
    DOCTYPE = new$DOCTYPE,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    PARENTINDEX = new$PARENTINDEX,
    ANUMBER = new$ANUMBER,
    TAXNOTE = new$TAXNOTE,
    REJECT_CLS = new$REJECT_CLS,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    ISDIVIDE = new$ISDIVIDE,
    CURSUM = new$CURSUM,
    CREDIT = new$CREDIT,
    DEBIT = new$DEBIT,
    RVERSION = new$RVERSION,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    MEANSTYPE = new$MEANSTYPE,
    PAYMENTCONDITION = new$PAYMENTCONDITION,
    BUDGETREF = new$BUDGETREF,
    TRANSFERTCLS = new$TRANSFERTCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_50 (T_PAYDOC32_AU_50)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (    (new$inputdate <> :OLD.inputdate)
       AND (new$acceptdate IS NULL)
       AND (new$anumber IS NULL)
       AND (new$childcount IS NOT NULL)
      ) THEN
      --      
      UPDATE paydoc32
         SET inputdate = new$inputdate
       WHERE (parentindex = new$ID) AND (ID <> new$ID);
   END IF;

-- - - - - - - - - - - - -
-- AU_130 (TR_PAYDOC32_AU_130)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (new$progindex IN (131, 132, 383, 384, 385, 386))
                                                       --   
   THEN
      IF (   (new$acceptdate = :OLD.acceptdate)
          OR ((new$acceptdate IS NULL) AND (:OLD.acceptdate IS NULL))
         ) THEN
         NULL;
      ELSE
         --     
         UPDATE debt
            SET recorddate = new$acceptdate
          WHERE (ID = new$recordindex) AND (recorddate IS NULL);
      END IF;                                                       -- if-then
   END IF;                                                          -- if-then

   IF (new$progindex IN (121, 122, 133, 341, 411))
                                                  --  
   THEN
      IF (   (new$acceptdate = :OLD.acceptdate)
          OR ((new$acceptdate IS NULL) AND (:OLD.acceptdate IS NULL))
         ) THEN
         NULL;
      ELSE
         UPDATE findocdetail
            SET recorddate = new$acceptdate
          WHERE (ID = new$recordindex) AND (recorddate IS NULL);
      END IF;                                                       -- if-then
   END IF;

END;
/
ALTER TRIGGER TR_PAYDOC32_BU_500 ENABLE
/
commit work 
/
ALTER TRIGGER TR_INCOMES32_BU_500 DISABLE
/
ALTER TABLE TB_INCOMES32 ADD (
  TempRejectCause VARCHAR2(255)
)
/

CREATE OR REPLACE VIEW INCOMES32 (
  ID,
  DOCNUMBER,
  DOCCOUNT,
  IDATE,
  DEBIT,
  CREDIT,
  DOCTYPE,
  INN,
  ORG_REF,
  ACCOUNTINDEX,
  KD,
  SUBKD,
  REGIONCLS,
  GOSNI,
  INCACCOUNT,
  PROGINDEX,
  RECORDINDEX,
  BUDGETREF,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  NOTE,
  RECORDINDEX2,
  ELNUM,
  NOTEEX,
  BUHPAYMENTCLS,
  ACCOUNTREF,
  ELPACKETNUM,
  FACIALACC_CLS,
  NDS,
  MEANSTYPE,
  RECORDDATE,
  TOTALREF,
  REQUESTSINDEX,
  KVSR,
  TAXNOTE,
  DOCNUM,
  REALPAYERORG_REF,
  DOCDATE,
  DOCBASE,
  FACT,
  RVERSION,
  KFSR,
  KESR,
  KVR,
  KCSR,
  SUMCOMPLETE,
  ELDOCREF,
  REQUESTSINDEX2,
  FEDERALFUNDSREF,
  BUHOPERATIONCLS,
  IFS,
  IFS_CORR,
  CLSTYPE,
  NDSNOTE,
  DOGNUM,
  SENDERID,
  SENDERRECORDID,
  OKATO,
  ADDOKATO,
  REJECTCLS,
  REJECTCAUSE,
  FUNDSSOURCE,
  DIRECTIONCLS,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  STIMATEID,
  TRANSFERTCLS,
  SUBSIDYCLS,
  FAORGTYPE,
  OKTMO,
  UINCODE,
  FINTYPE,
  INVESTOBJECT,
  CONTRACTCOSTSCLS,
  TARGETCLS,
  TEMPREJECTCAUSE)
AS
  SELECT
    ID,
    DOCNUMBER,
    DOCCOUNT,
    IDATE,
    DEBIT,
    CREDIT,
    DOCTYPE,
    INN,
    ORG_REF,
    ACCOUNTINDEX,
    KD,
    SUBKD,
    REGIONCLS,
    GOSNI,
    INCACCOUNT,
    PROGINDEX,
    RECORDINDEX,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    NOTE,
    RECORDINDEX2,
    ELNUM,
    NOTEEX,
    BUHPAYMENTCLS,
    ACCOUNTREF,
    ELPACKETNUM,
    FACIALACC_CLS,
    NDS,
    MEANSTYPE,
    RECORDDATE,
    TOTALREF,
    REQUESTSINDEX,
    KVSR,
    TAXNOTE,
    DOCNUM,
    REALPAYERORG_REF,
    DOCDATE,
    DOCBASE,
    FACT,
    RVERSION,
    KFSR,
    KESR,
    KVR,
    KCSR,
    SUMCOMPLETE,
    ELDOCREF,
    REQUESTSINDEX2,
    FEDERALFUNDSREF,
    BUHOPERATIONCLS,
    IFS,
    IFS_CORR,
    CLSTYPE,
    NDSNOTE,
    DOGNUM,
    SENDERID,
    SENDERRECORDID,
    OKATO,
    ADDOKATO,
    REJECTCLS,
    REJECTCAUSE,
    FUNDSSOURCE,
    DIRECTIONCLS,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    STIMATEID,
    TRANSFERTCLS,
    SUBSIDYCLS,
    FAORGTYPE,
    OKTMO,
    UINCODE,
    FINTYPE,
    INVESTOBJECT,
    CONTRACTCOSTSCLS,
    TARGETCLS,
    TEMPREJECTCAUSE
  FROM TB_INCOMES32
/

CREATE OR REPLACE TRIGGER TR_INCOMES32_ID
  INSTEAD OF DELETE
  ON INCOMES32
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_10 (TR_INCOMES32_BD10)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

  delete
  from CurrencyIncomes
  where (id = :old.id);

-- - - - - - - - - - - - -
-- BD_20 (T_INCOMES32_BD_20)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

  /*    */
  if (:old.DocType between 1010 and 1019) then
    delete from PayDoc32
    where 
      (ProgIndex = :old.ProgIndex) 
    and 
     (RecordIndex = :old.id);
  end if;

-- - - - - - - - - - - - -
-- BD_500 (TR_INCOMES32_BD_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  Update QuotesTitle set
  DocChangeDate = SYSDATE,
  RVersion = -1
  where id = :old.recordindex;

-- - - - - - - - - - - - -
-- BD_600 (TR_INCOMES32_BD_600)
-- Last update 14.10.2009
-- - - - - - - - - - - - -

    --    
    if (:old.ProgIndex = 41) then
        delete
            from Incomes32
        where
           (ProgIndex=42)and
           (RecordIndex=:old.id);
    end if;

    --  (  )
    if (:old.ProgIndex = 42) then
        delete
            from Incomes32
        where
            (ProgIndex=43)and
            (RecordIndex=:old.id);
    end if;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_INCOMES32
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);
   
  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_500 (TR_INCOMES32_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordID, DeleteDate, ProgIndex, SUMMA) values (161, :old.ID, SYSDATE, :old.ProgIndex, :old.DEBIT + :old.CREDIT);

END;
/

CREATE OR REPLACE TRIGGER TR_INCOMES32_II
  INSTEAD OF INSERT
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$TEMPREJECTCAUSE INCOMES32.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  CapDocNumber VARCHAR2(20);
  unkKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  Kd_Master NUMBER(10);
  idKD$ NUMBER(10);
  unkVKD$ VARCHAR2(20);
  val_DocCount$ NUMBER(10);
  val_DocType$ NUMBER(10);
  val_Org_Ref$ NUMBER(10);
  val_AccountIndex$ NUMBER(10);
  val_SubKD$ NUMBER(10);
  val_RegionCLS$ NUMBER(10);
  val_GosNI$ NUMBER(10);
  val_IncAccount$ NUMBER(10);
  val_BudgetRef$ NUMBER(10);
  val_MEANSTYPE$ NUMBER(10);
  val_FACIALACC_CLS$ NUMBER(10);
  val_TransfertCls$ NUMBER(10);
  CapAcceptDate$ NUMBER;
  CapReestrNumber$ VARCHAR2(20);
  CapProgIndex$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_INCOMES32_BI)
-- Version 10.00.00.2
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN 
    select g_shared.nextval into new$id from dual;
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN 
    new$FACIALACC_CLS := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN 
    new$Gosni := 0;
  END IF;
  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN 
    new$DocBase := 0;
  END IF;
  /* 3 -    */
  IF (new$KD IS NULL) THEN 
    new$KD := 0;
  END IF;
  IF (new$ProgIndex IS NULL) THEN 
    new$ProgIndex := 3;
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN 
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN 
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN 
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN 
    new$AccountIndex := 0;
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN 
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN 
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN 
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN 
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN 
    new$DirectionCLS := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  IF (new$FinType IS NULL) THEN  
    new$FinType := 0;
  END IF;
  /*   .        */
  IF (new$IFS IS NULL) THEN 
    new$IFS := 0;
  END IF;
  IF (new$IFS_CORR IS NULL) THEN 
    new$Ifs_Corr := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
   
  /*  ,    */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0)) THEN
    BEGIN
      SELECT qt.BudgetRef      INTO new$BudgetRef FROM QuotesTitle qt
      WHERE qt.Id = new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    0,     */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0)) THEN
    BEGIN
      SELECT fa.BudgetRef      INTO new$BudgetRef FROM FacialAcc_Cls fa
      WHERE fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    0,    */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0))
  THEN 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
   
  IF (new$ProgIndex = 45) 
  THEN 
    IF (new$IncAccount IS NULL) THEN
      GetDefDFAccRefForBudget(new$BudgetRef,new$IncAccount);
    END IF;
    BEGIN

      /*     */
      SELECT qt.ProgIndex, qt.AcceptDate, qt.IncAccount, qt.ReestrNumber 
      INTO CapProgIndex$, CapAcceptDate$, new$IncAccount, CapReestrNumber$       FROM QuotesTitle qt
      WHERE 
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*           / */
    /*  /   after insert */
    IF (CapProgIndex$ <> 145) THEN 
      new$iDate := CapAcceptDate$;
    END IF;
    IF ((CapProgIndex$ = 145)AND (NOT ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0)OR (new$Credit<0)))) )
    THEN 
      new$Idate := CapAcceptDate$;      
    END IF;
    /*   -    () */
    IF ((CapProgIndex$ = 45) AND (CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN 
      /*        , *//*    */            
                  
      new$FederalFundsRef := new$ID;
      /* if-then */  
    END IF;/* if-then*/
  END IF;
  BEGIN
    /*     \*/
    SELECT org.Org_Type   INTO new$FAOrgType FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$FacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BI_5 (TR_INCOMES_BI_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BI_9 (TR_INCOMES32_BI_VZ)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   IF (new$ProgIndex = 9) THEN
      /*   */
      GetIntConst (9, 1, new$IncAccount);

      BEGIN
        /*      */
        SELECT ACCEPTDATE, BUDGETREF
          INTO new$IDate, new$BudgetRef
          FROM VZ_OFFSET
         WHERE ID = new$RecordIndex;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_INCOMES32_BI_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   BEGIN
      SELECT Inn
        INTO new$Inn
        FROM Organizations o
       WHERE (o.ID = new$Org_Ref);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

/*  .    ,    */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      BEGIN
         SELECT c.BudgetRef
           INTO new$budgetref
           FROM QuotesTitle c
          WHERE c.ID = NEW$RecordIndex;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

   /*  .  ,     */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      BEGIN
         SELECT fa.BudgetRef
           INTO new$budgetref
           FROM FacialAcc_Cls fa
          WHERE fa.ID = NEW$FacialAcc_Cls;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

   /*  ,    */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      GetIntConst (-1, 3, new$budgetref);
   END IF;

-- - - - - - - - - - - - -
-- BI_30 (TR_INCOMES32_BI_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then 
    BEGIN
      select q.BuildDate 
      into 
      new$DocDate        from QuotesTitle q 
      where q.id = new$RecordIndex 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_70 (TR_INCOMES32_BI_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
               */
         new$FederalFundsRef := new$ID;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_INCOMES32_BI_100)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if ((not (newKD$  like unkKD$)) and
    (not (newKD$  like unkVKD$))) then
      /*   (    
            ) ,  
         ,   */

      /*       */
      if (new$Debit <> 0) then 
        RaiseException('ex_UnknownRedirect');
      END IF;
      BEGIN

        /*      */
        select KD,DocCount,DocType,
        Org_Ref,AccountIndex,SubKD,RegionCLS,GosNI,
        IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,
        TransfertCls
        into
        idKD$,
        val_DocCount$,
        val_DocType$,
        val_Org_Ref$,
        val_AccountIndex$,
        val_SubKD$,
        val_RegionCLS$,
        val_GosNI$,
        val_IncAccount$,
        val_BudgetRef$,
        val_MEANSTYPE$  ,
        val_FACIALACC_CLS$,
        val_TransfertCls$         from incomes32 where id=new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
         
      if (not idKD$ is null) then
        insert into
        /* KD=   (      )
              Debit=0
              redit=-new.credit
              ProgIndex=43
              RecordIndex=new.id
              id    Incomes32*/
        Incomes32(CreaterUser, DocNum,DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS, TransfertCls)
        Values(new$CreaterUser, new$DocNum, val_DocCount$, new$iDate, new$DOCDATE, 0, -new$Credit, val_DocType$,
        val_Org_Ref$, val_AccountIndex$, idKD$, val_SubKD$, val_RegionCLS$, val_GosNI$,
        43,new$Id, val_IncAccount$, val_BudgetRef$, new$Note,val_MEANSTYPE$,val_FACIALACC_CLS$,val_TransfertCls$);
        
      END IF; 
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_110 (TR_INCOMES32_BI_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       /*       ClsType */
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                /*  -  */
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_INCOMES32_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update QuotesTitle set
  DocChangeDate = new$UpdateDate,
  RVersion = -1
  where id = new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_INCOMES32 (
    ID,
    DOCNUMBER,
    DOCCOUNT,
    IDATE,
    DEBIT,
    CREDIT,
    DOCTYPE,
    INN,
    ORG_REF,
    ACCOUNTINDEX,
    KD,
    SUBKD,
    REGIONCLS,
    GOSNI,
    INCACCOUNT,
    PROGINDEX,
    RECORDINDEX,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    NOTE,
    RECORDINDEX2,
    ELNUM,
    NOTEEX,
    BUHPAYMENTCLS,
    ACCOUNTREF,
    ELPACKETNUM,
    FACIALACC_CLS,
    NDS,
    MEANSTYPE,
    RECORDDATE,
    TOTALREF,
    REQUESTSINDEX,
    KVSR,
    TAXNOTE,
    DOCNUM,
    REALPAYERORG_REF,
    DOCDATE,
    DOCBASE,
    FACT,
    RVERSION,
    KFSR,
    KESR,
    KVR,
    KCSR,
    SUMCOMPLETE,
    ELDOCREF,
    REQUESTSINDEX2,
    FEDERALFUNDSREF,
    BUHOPERATIONCLS,
    IFS,
    IFS_CORR,
    CLSTYPE,
    NDSNOTE,
    DOGNUM,
    SENDERID,
    SENDERRECORDID,
    OKATO,
    ADDOKATO,
    REJECTCLS,
    REJECTCAUSE,
    FUNDSSOURCE,
    DIRECTIONCLS,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    STIMATEID,
    TRANSFERTCLS,
    SUBSIDYCLS,
    FAORGTYPE,
    OKTMO,
    UINCODE,
    FINTYPE,
    INVESTOBJECT,
    CONTRACTCOSTSCLS,
    TARGETCLS,
    TEMPREJECTCAUSE
  ) VALUES (
    new$ID,
    new$DOCNUMBER,
    new$DOCCOUNT,
    new$IDATE,
    new$DEBIT,
    new$CREDIT,
    new$DOCTYPE,
    new$INN,
    new$ORG_REF,
    new$ACCOUNTINDEX,
    new$KD,
    new$SUBKD,
    new$REGIONCLS,
    new$GOSNI,
    new$INCACCOUNT,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$BUDGETREF,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$NOTE,
    new$RECORDINDEX2,
    new$ELNUM,
    new$NOTEEX,
    new$BUHPAYMENTCLS,
    new$ACCOUNTREF,
    new$ELPACKETNUM,
    new$FACIALACC_CLS,
    new$NDS,
    new$MEANSTYPE,
    new$RECORDDATE,
    new$TOTALREF,
    new$REQUESTSINDEX,
    new$KVSR,
    new$TAXNOTE,
    new$DOCNUM,
    new$REALPAYERORG_REF,
    new$DOCDATE,
    new$DOCBASE,
    new$FACT,
    new$RVERSION,
    new$KFSR,
    new$KESR,
    new$KVR,
    new$KCSR,
    new$SUMCOMPLETE,
    new$ELDOCREF,
    new$REQUESTSINDEX2,
    new$FEDERALFUNDSREF,
    new$BUHOPERATIONCLS,
    new$IFS,
    new$IFS_CORR,
    new$CLSTYPE,
    new$NDSNOTE,
    new$DOGNUM,
    new$SENDERID,
    new$SENDERRECORDID,
    new$OKATO,
    new$ADDOKATO,
    new$REJECTCLS,
    new$REJECTCAUSE,
    new$FUNDSSOURCE,
    new$DIRECTIONCLS,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$STIMATEID,
    new$TRANSFERTCLS,
    new$SUBSIDYCLS,
    new$FAORGTYPE,
    new$OKTMO,
    new$UINCODE,
    new$FINTYPE,
    new$INVESTOBJECT,
    new$CONTRACTCOSTSCLS,
    new$TARGETCLS,
    new$TEMPREJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_20 (T_INCOMES32_AI_20)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   --     
   if (new$ProgIndex <> 42) then
     BEGIN
       SELECT ProgIndex, DocNumber, AcceptDate
        INTO CapProgIndex, CapDocNumber, CapAcceptDate
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
     EXCEPTION
       WHEN NO_DATA_FOUND THEN NULL;
     END;
   end if;

   --   - ,  
   IF ((CapProgIndex = 145) or (new$ProgIndex=42)) THEN

      If ((new$ProgIndex=42) and (new$DocType between 1010 and 1019) and
         (new$Debit>0) and (new$DOCDATE is not null))
      then
        BEGIN
          select kd into Kd_Master
    From Incomes32 inc
          where inc.id = new$RecordIndex;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;

        if (Kd_Master = new$Kd) then
          CapAcceptDate := new$DOCDATE;
          CapProgIndex  := new$ProgIndex;
          CapDocNumber  := new$DocNum;
        end if;
      end if; --       (         )

      --             
      IF ((CapAcceptDate IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit > 0) OR (new$Credit < 0))) THEN
         --    ( RealPayerOrg_Ref(PayDoc32)=new$RealPayerOrg_Ref(Incomes32))
         INSERT INTO PayDoc32
            (BudgetRef, AccountRef, PayerAttrRef, InputDate,
             Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref, FACIALACC_CLS)
         VALUES (new$BudgetRef, new$AccountRef, new$IncAccount, CapAcceptDate,
             (new$Debit - new$Credit), new$Note, new$ProgIndex, new$id, CapDocNumber, new$TaxNote,
             new$RealPayerOrg_Ref,new$FACIALACC_CLS);
      -- (new$Debit - new$Credit) --- ..      ,    ,
      --             
      END IF;

   END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_INCOMES32_AI_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 161) AND (RecordID = NEW$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$TEMPREJECTCAUSE INCOMES32.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 10.00.00.2
-- - - - - - - - - - - - -

  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN 
    new$DocBase := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN 
    new$Gosni := 0;
  END IF;
  /* 3 -    */
  IF (new$ProgIndex IS NULL) THEN 
    new$ProgIndex := 3; 
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0; 
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN 
    new$FACIALACC_CLS := 0; 
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN 
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN 
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN 
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN 
    new$AccountIndex := 0; 
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN 
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN 
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN 
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN 
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN 
    new$DirectionCLS := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  IF (new$FinType IS NULL) THEN  
    new$FinType := 0;
  END IF;
  /*   .        */
  IF (new$IFS_CORR IS NULL) THEN 
    new$Ifs_Corr := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$Ifs := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  BEGIN

    /*     */
    /*   after   ,*/ 
    /*      */
    SELECT ProgIndex, AcceptDate, ReestrNumber
    INTO CapProgIndex1$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
    WHERE
    (qt.ID = new$RecordIndex)
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*              
           (  , , ) */
  /*   -    () */
  IF (CapProgIndex1$ = 45)
  THEN 
    IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN 
      /*        ,
                     */            
      new$FederalFundsRef := new$ID;
      /* if-then*/
    ELSE 
      new$FederalFundsRef := NULL;
      /* if-else*/  
    END IF;/* if (CapProgIndex=45) */
  END IF;
  /*     */
  IF (new$BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
      IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
        RaiseException('Ex_CantModufyBudget');
      END IF;
      IF (new$Progindex = 41) THEN
        SELECT COUNT(inc.id ) INTO CNT$1
        FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
        IF ((CNT$1<> 0)) THEN
          RaiseException('Ex_CantModufyBudget');
        END IF;   
      END IF;
    END IF;
  END IF;
  /*     \*/
  IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
  ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

  BEGIN
    SELECT Inn
     INTO new$Inn
     FROM Organizations o
    WHERE (o.ID = new$Org_Ref);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*      */
  IF (new$ProgIndex <> 42) THEN
    BEGIN
      SELECT ProgIndex, DocNumber, AcceptDate
      INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
      WHERE
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*   -  ,   */
  IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
  THEN 
    IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
    (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
    THEN 
      BEGIN
        SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
        WHERE inc.id = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (Kd_Master$ = new$Kd) THEN 
        CapAcceptDate$ := new$DOCDATE;
        CapProgIndex$  := new$ProgIndex;
        CapDocNumber$  := new$DocNum;
        /*  */        
      END IF;/*       (         )*/
    END IF;
    IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
    THEN 

      /*      */
      /* /      Incomes32, ..      ,     */

      /*     /   */
      SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
      INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
      ;
      /*            ,  .*/
      /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
                      ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
                     ) THEN
                    EXCEPTION EX_CANNOTUPDATENUMBER;*/
                 
                
      IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
      then
        if ((new$DocType <> :old.DocType )
        or (new$Debit <> :old.Debit )
        or (new$Credit <> :old.Credit)
        or (new$org_ref <> :old.org_ref)
        or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
        or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
        )
        then
          RaiseException('EX_CANNOTUPDATENUMBER');
        END IF;
      END IF;
                


      /*           */
      IF (PayDocCount$ = 0)
      THEN 
        /*       */
        GetIntConst(11, 2,ConstPayQueue$);
        /*       */
        GetIntConst(11, 1,ConstSendBy$);

        /*    */
        INSERT INTO PayDoc32
        (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
        Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
        VALUES
        (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
        new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
        /* (new.Debit - new.Credit) --- ..      ,    ,
                                     */

        /* if-then */
      ELSE 
        /*     */
        IF (((new$AccountRef = :old.AccountRef) OR
        ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
        AND (new$IncAccount = :old.IncAccount)
        AND (new$BudgetRef = :old.BudgetRef)
        AND ((new$Note = :old.Note) OR
        ((new$Note IS NULL) AND (:old.Note IS NULL)))
        AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
        ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
        AND ((new$TaxNote = :old.TaxNote) OR
        ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
        )  THEN
          new$AccountRef := new$AccountRef;
                          
        ELSE

          UPDATE PayDoc32 pd
          SET
          pd.AccountRef = new$AccountRef,
          pd.PayerAttrRef = new$IncAccount,
          pd.AcceptorAttrRef = new$AccountRef,
          pd.TextNote = new$Note,
          pd.TaxNote = new$TaxNote,
          pd.BudgetRef = new$BudgetRef,
          pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
          pd.InputDate = CapAcceptDate$,
          pd.SourceDocNumber = CapDocNumber$,
          pd.FACIALACC_CLS = new$FACIALACC_CLS
          WHERE
          (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
        END IF;
        IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
        OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
        THEN  
          IF (Divided$ > 0)
          THEN
            /*  ,      */
            RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
          ELSE
            UPDATE PayDoc32 pd
            SET
            pd.Credit = new$Debit - new$Credit
            WHERE
            (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
          END IF;/* if-then*/            
        END IF;/* if-else*/
      END IF;
      /*     / */
      /*   :     ,     */
      /*  ,     */
      SELECT MAX(pd.AcceptDate)
      INTO Date_Pd$           FROM PayDoc32 pd
      WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
      ;
      new$Idate := Date_Pd$;
      /* if-then*/
    ELSE 
      /*       
                          -
                    . */
      DELETE FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex = new$ProgIndex)
      AND (pd.RecordIndex = new$id);
      /* if-else*/  
    END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then 
    BEGIN
      select q.BuildDate 
      into 
      new$DocDate        from QuotesTitle q 
      where q.id = new$RecordIndex 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
            */
         new$FederalFundsRef := new$ID;
      ELSE
         new$FederalFundsRef := NULL;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN
      select KDValue   into oldKD$ from kd where Id=:old.kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN

      /*     */
      select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
      IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
      into
      idKD1$,
      val_DocCount1$,
      val_DocType1$,
      val_Org_Ref1$,
      val_AccountIndex1$,
      val_SubKD1$,
      val_RegionCLS1$,
      val_GosNI1$,
      val_IncAccount1$,
      val_BudgetRef1$,
      val_MEANSTYPE1$  , 
      val_FACIALACC_CLS1$,
      val_TransfertCls1$         from incomes32 where id=new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not idKD1$ is null) then
      if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
      (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
        /*   ,    */
        delete
        from Incomes32
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      (new$Debit<>0))
      /*       */
      then 
        RaiseException('ex_UnknownRedirect');
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
        /*   ,   ,   */
        insert into
        Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
        Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
        val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
        val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
        new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
      END IF;
      if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
      and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
        /*      ,   */
        update Incomes32
        set
        DocNum = new$DocNum,
        DocCount = val_DocCount1$,
        iDate = new$iDate,
        DOCDATE = new$DOCDATE,
        Debit = 0,
        Credit = -new$Credit,
        DocType = val_DocType1$,
        Org_Ref = val_Org_Ref1$,
        AccountIndex = val_AccountIndex1$,
        KD = idKD1$,
        SubKD = val_SubKD1$,
        RegionCLS = val_RegionCLS1$,
        GosNI = val_GosNI1$,
        ProgIndex = 43,
        RecordIndex = new$Id,
        IncAccount = val_IncAccount1$,
        BudgetRef = val_BudgetRef1$,
        Note = new$Note,
        MEANSTYPE = val_MEANSTYPE1$,
        FACIALACC_CLS = val_FACIALACC_CLS1$,
        TransfertCls = val_TransfertCls1$,
        RVersion = -1
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
         
      END IF; 
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 41)    /*   () */
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    /*       */
    FOR REC$1 IN (SELECT inc.id
     AS val_ID42    FROM Incomes32 inc
    LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
    WHERE (inc.ProgIndex =  42) and
    (inc.RecordIndex =  new$id) and
    (inc.debit = 0) and
    (not(kd.kdvalue like unkKD$)) and
    (not(kd.kdvalue like unkVKD$))
    )
    LOOP
      BEGIN
        /*       */
        select inc.id
        into val_ID431$         FROM Incomes32 inc
        WHERE (inc.ProgIndex =  43) and
        (inc.RecordIndex =  REC$1.val_ID42)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      /*     ,   Credit, ProgIndex, RecordIndex */
      update Incomes32
      set
      DocNum = new$DocNum,
      DocCount = new$DocCount,       
      DOCDATE = new$DOCDATE,
      Debit = 0,
      DocType = new$DocType,
      Org_Ref = new$Org_Ref,
      AccountIndex = new$AccountIndex,
      KD = new$Kd,
      SubKD = new$SubKD,
      RegionCLS = new$RegionCLS,
      GosNI = new$GosNI,
      IncAccount = new$IncAccount,
      BudgetRef = new$BudgetRef,
      Note = new$Note,
      MEANSTYPE = new$MEANSTYPE,
      FACIALACC_CLS = new$FACIALACC_CLS,
      FACT = new$FACT,
      TransfertCls = new$TransfertCls,
      DirectionCls = new$DirectionCls,
      rversion = -1
      where id = val_ID431$;

        
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       --       ClsType
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                --  - 
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      --   
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    REJECTCAUSE = new$REJECTCAUSE,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   IF (NEW$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (161, :OLD.ID, SYSDATE);
      DELETE FROM DelRecIndexes
        WHERE (TableID = 161) AND (RecordId = NEW$ID);
   END IF;

END;
/
update INCOMES32 set
  TempRejectCause = REJECTCAUSE
/
commit work 
/
ALTER TABLE TB_INCOMES32 DROP (REJECTCAUSE)
/

CREATE OR REPLACE VIEW INCOMES32 (
  ID,
  DOCNUMBER,
  DOCCOUNT,
  IDATE,
  DEBIT,
  CREDIT,
  DOCTYPE,
  INN,
  ORG_REF,
  ACCOUNTINDEX,
  KD,
  SUBKD,
  REGIONCLS,
  GOSNI,
  INCACCOUNT,
  PROGINDEX,
  RECORDINDEX,
  BUDGETREF,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  NOTE,
  RECORDINDEX2,
  ELNUM,
  NOTEEX,
  BUHPAYMENTCLS,
  ACCOUNTREF,
  ELPACKETNUM,
  FACIALACC_CLS,
  NDS,
  MEANSTYPE,
  RECORDDATE,
  TOTALREF,
  REQUESTSINDEX,
  KVSR,
  TAXNOTE,
  DOCNUM,
  REALPAYERORG_REF,
  DOCDATE,
  DOCBASE,
  FACT,
  RVERSION,
  KFSR,
  KESR,
  KVR,
  KCSR,
  SUMCOMPLETE,
  ELDOCREF,
  REQUESTSINDEX2,
  FEDERALFUNDSREF,
  BUHOPERATIONCLS,
  IFS,
  IFS_CORR,
  CLSTYPE,
  NDSNOTE,
  DOGNUM,
  SENDERID,
  SENDERRECORDID,
  OKATO,
  ADDOKATO,
  REJECTCLS,
  FUNDSSOURCE,
  DIRECTIONCLS,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  STIMATEID,
  TRANSFERTCLS,
  SUBSIDYCLS,
  FAORGTYPE,
  OKTMO,
  UINCODE,
  FINTYPE,
  INVESTOBJECT,
  CONTRACTCOSTSCLS,
  TARGETCLS,
  TEMPREJECTCAUSE)
AS
  SELECT
    ID,
    DOCNUMBER,
    DOCCOUNT,
    IDATE,
    DEBIT,
    CREDIT,
    DOCTYPE,
    INN,
    ORG_REF,
    ACCOUNTINDEX,
    KD,
    SUBKD,
    REGIONCLS,
    GOSNI,
    INCACCOUNT,
    PROGINDEX,
    RECORDINDEX,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    NOTE,
    RECORDINDEX2,
    ELNUM,
    NOTEEX,
    BUHPAYMENTCLS,
    ACCOUNTREF,
    ELPACKETNUM,
    FACIALACC_CLS,
    NDS,
    MEANSTYPE,
    RECORDDATE,
    TOTALREF,
    REQUESTSINDEX,
    KVSR,
    TAXNOTE,
    DOCNUM,
    REALPAYERORG_REF,
    DOCDATE,
    DOCBASE,
    FACT,
    RVERSION,
    KFSR,
    KESR,
    KVR,
    KCSR,
    SUMCOMPLETE,
    ELDOCREF,
    REQUESTSINDEX2,
    FEDERALFUNDSREF,
    BUHOPERATIONCLS,
    IFS,
    IFS_CORR,
    CLSTYPE,
    NDSNOTE,
    DOGNUM,
    SENDERID,
    SENDERRECORDID,
    OKATO,
    ADDOKATO,
    REJECTCLS,
    FUNDSSOURCE,
    DIRECTIONCLS,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    STIMATEID,
    TRANSFERTCLS,
    SUBSIDYCLS,
    FAORGTYPE,
    OKTMO,
    UINCODE,
    FINTYPE,
    INVESTOBJECT,
    CONTRACTCOSTSCLS,
    TARGETCLS,
    TEMPREJECTCAUSE
  FROM TB_INCOMES32
/

CREATE OR REPLACE TRIGGER TR_INCOMES32_ID
  INSTEAD OF DELETE
  ON INCOMES32
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_10 (TR_INCOMES32_BD10)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

  delete
  from CurrencyIncomes
  where (id = :old.id);

-- - - - - - - - - - - - -
-- BD_20 (T_INCOMES32_BD_20)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

  /*    */
  if (:old.DocType between 1010 and 1019) then
    delete from PayDoc32
    where 
      (ProgIndex = :old.ProgIndex) 
    and 
     (RecordIndex = :old.id);
  end if;

-- - - - - - - - - - - - -
-- BD_500 (TR_INCOMES32_BD_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  Update QuotesTitle set
  DocChangeDate = SYSDATE,
  RVersion = -1
  where id = :old.recordindex;

-- - - - - - - - - - - - -
-- BD_600 (TR_INCOMES32_BD_600)
-- Last update 14.10.2009
-- - - - - - - - - - - - -

    --    
    if (:old.ProgIndex = 41) then
        delete
            from Incomes32
        where
           (ProgIndex=42)and
           (RecordIndex=:old.id);
    end if;

    --  (  )
    if (:old.ProgIndex = 42) then
        delete
            from Incomes32
        where
            (ProgIndex=43)and
            (RecordIndex=:old.id);
    end if;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_INCOMES32
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);
   
  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_500 (TR_INCOMES32_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordID, DeleteDate, ProgIndex, SUMMA) values (161, :old.ID, SYSDATE, :old.ProgIndex, :old.DEBIT + :old.CREDIT);

END;
/

CREATE OR REPLACE TRIGGER TR_INCOMES32_II
  INSTEAD OF INSERT
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$TEMPREJECTCAUSE INCOMES32.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  CapDocNumber VARCHAR2(20);
  unkKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  Kd_Master NUMBER(10);
  idKD$ NUMBER(10);
  unkVKD$ VARCHAR2(20);
  val_DocCount$ NUMBER(10);
  val_DocType$ NUMBER(10);
  val_Org_Ref$ NUMBER(10);
  val_AccountIndex$ NUMBER(10);
  val_SubKD$ NUMBER(10);
  val_RegionCLS$ NUMBER(10);
  val_GosNI$ NUMBER(10);
  val_IncAccount$ NUMBER(10);
  val_BudgetRef$ NUMBER(10);
  val_MEANSTYPE$ NUMBER(10);
  val_FACIALACC_CLS$ NUMBER(10);
  val_TransfertCls$ NUMBER(10);
  CapAcceptDate$ NUMBER;
  CapReestrNumber$ VARCHAR2(20);
  CapProgIndex$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_INCOMES32_BI)
-- Version 10.00.00.2
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN 
    select g_shared.nextval into new$id from dual;
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN 
    new$FACIALACC_CLS := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN 
    new$Gosni := 0;
  END IF;
  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN 
    new$DocBase := 0;
  END IF;
  /* 3 -    */
  IF (new$KD IS NULL) THEN 
    new$KD := 0;
  END IF;
  IF (new$ProgIndex IS NULL) THEN 
    new$ProgIndex := 3;
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN 
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN 
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN 
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN 
    new$AccountIndex := 0;
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN 
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN 
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN 
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN 
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN 
    new$DirectionCLS := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  IF (new$FinType IS NULL) THEN  
    new$FinType := 0;
  END IF;
  /*   .        */
  IF (new$IFS IS NULL) THEN 
    new$IFS := 0;
  END IF;
  IF (new$IFS_CORR IS NULL) THEN 
    new$Ifs_Corr := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
   
  /*  ,    */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0)) THEN
    BEGIN
      SELECT qt.BudgetRef      INTO new$BudgetRef FROM QuotesTitle qt
      WHERE qt.Id = new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    0,     */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0)) THEN
    BEGIN
      SELECT fa.BudgetRef      INTO new$BudgetRef FROM FacialAcc_Cls fa
      WHERE fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    0,    */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0))
  THEN 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
   
  IF (new$ProgIndex = 45) 
  THEN 
    IF (new$IncAccount IS NULL) THEN
      GetDefDFAccRefForBudget(new$BudgetRef,new$IncAccount);
    END IF;
    BEGIN

      /*     */
      SELECT qt.ProgIndex, qt.AcceptDate, qt.IncAccount, qt.ReestrNumber 
      INTO CapProgIndex$, CapAcceptDate$, new$IncAccount, CapReestrNumber$       FROM QuotesTitle qt
      WHERE 
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*           / */
    /*  /   after insert */
    IF (CapProgIndex$ <> 145) THEN 
      new$iDate := CapAcceptDate$;
    END IF;
    IF ((CapProgIndex$ = 145)AND (NOT ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0)OR (new$Credit<0)))) )
    THEN 
      new$Idate := CapAcceptDate$;      
    END IF;
    /*   -    () */
    IF ((CapProgIndex$ = 45) AND (CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN 
      /*        , *//*    */            
                  
      new$FederalFundsRef := new$ID;
      /* if-then */  
    END IF;/* if-then*/
  END IF;
  BEGIN
    /*     \*/
    SELECT org.Org_Type   INTO new$FAOrgType FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$FacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BI_5 (TR_INCOMES_BI_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BI_9 (TR_INCOMES32_BI_VZ)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   IF (new$ProgIndex = 9) THEN
      /*   */
      GetIntConst (9, 1, new$IncAccount);

      BEGIN
        /*      */
        SELECT ACCEPTDATE, BUDGETREF
          INTO new$IDate, new$BudgetRef
          FROM VZ_OFFSET
         WHERE ID = new$RecordIndex;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_INCOMES32_BI_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   BEGIN
      SELECT Inn
        INTO new$Inn
        FROM Organizations o
       WHERE (o.ID = new$Org_Ref);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

/*  .    ,    */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      BEGIN
         SELECT c.BudgetRef
           INTO new$budgetref
           FROM QuotesTitle c
          WHERE c.ID = NEW$RecordIndex;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

   /*  .  ,     */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      BEGIN
         SELECT fa.BudgetRef
           INTO new$budgetref
           FROM FacialAcc_Cls fa
          WHERE fa.ID = NEW$FacialAcc_Cls;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

   /*  ,    */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      GetIntConst (-1, 3, new$budgetref);
   END IF;

-- - - - - - - - - - - - -
-- BI_30 (TR_INCOMES32_BI_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then 
    BEGIN
      select q.BuildDate 
      into 
      new$DocDate        from QuotesTitle q 
      where q.id = new$RecordIndex 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_70 (TR_INCOMES32_BI_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
               */
         new$FederalFundsRef := new$ID;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_INCOMES32_BI_100)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if ((not (newKD$  like unkKD$)) and
    (not (newKD$  like unkVKD$))) then
      /*   (    
            ) ,  
         ,   */

      /*       */
      if (new$Debit <> 0) then 
        RaiseException('ex_UnknownRedirect');
      END IF;
      BEGIN

        /*      */
        select KD,DocCount,DocType,
        Org_Ref,AccountIndex,SubKD,RegionCLS,GosNI,
        IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,
        TransfertCls
        into
        idKD$,
        val_DocCount$,
        val_DocType$,
        val_Org_Ref$,
        val_AccountIndex$,
        val_SubKD$,
        val_RegionCLS$,
        val_GosNI$,
        val_IncAccount$,
        val_BudgetRef$,
        val_MEANSTYPE$  ,
        val_FACIALACC_CLS$,
        val_TransfertCls$         from incomes32 where id=new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
         
      if (not idKD$ is null) then
        insert into
        /* KD=   (      )
              Debit=0
              redit=-new.credit
              ProgIndex=43
              RecordIndex=new.id
              id    Incomes32*/
        Incomes32(CreaterUser, DocNum,DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS, TransfertCls)
        Values(new$CreaterUser, new$DocNum, val_DocCount$, new$iDate, new$DOCDATE, 0, -new$Credit, val_DocType$,
        val_Org_Ref$, val_AccountIndex$, idKD$, val_SubKD$, val_RegionCLS$, val_GosNI$,
        43,new$Id, val_IncAccount$, val_BudgetRef$, new$Note,val_MEANSTYPE$,val_FACIALACC_CLS$,val_TransfertCls$);
        
      END IF; 
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_110 (TR_INCOMES32_BI_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       /*       ClsType */
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                /*  -  */
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_INCOMES32_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update QuotesTitle set
  DocChangeDate = new$UpdateDate,
  RVersion = -1
  where id = new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_INCOMES32 (
    ID,
    DOCNUMBER,
    DOCCOUNT,
    IDATE,
    DEBIT,
    CREDIT,
    DOCTYPE,
    INN,
    ORG_REF,
    ACCOUNTINDEX,
    KD,
    SUBKD,
    REGIONCLS,
    GOSNI,
    INCACCOUNT,
    PROGINDEX,
    RECORDINDEX,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    NOTE,
    RECORDINDEX2,
    ELNUM,
    NOTEEX,
    BUHPAYMENTCLS,
    ACCOUNTREF,
    ELPACKETNUM,
    FACIALACC_CLS,
    NDS,
    MEANSTYPE,
    RECORDDATE,
    TOTALREF,
    REQUESTSINDEX,
    KVSR,
    TAXNOTE,
    DOCNUM,
    REALPAYERORG_REF,
    DOCDATE,
    DOCBASE,
    FACT,
    RVERSION,
    KFSR,
    KESR,
    KVR,
    KCSR,
    SUMCOMPLETE,
    ELDOCREF,
    REQUESTSINDEX2,
    FEDERALFUNDSREF,
    BUHOPERATIONCLS,
    IFS,
    IFS_CORR,
    CLSTYPE,
    NDSNOTE,
    DOGNUM,
    SENDERID,
    SENDERRECORDID,
    OKATO,
    ADDOKATO,
    REJECTCLS,
    FUNDSSOURCE,
    DIRECTIONCLS,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    STIMATEID,
    TRANSFERTCLS,
    SUBSIDYCLS,
    FAORGTYPE,
    OKTMO,
    UINCODE,
    FINTYPE,
    INVESTOBJECT,
    CONTRACTCOSTSCLS,
    TARGETCLS,
    TEMPREJECTCAUSE
  ) VALUES (
    new$ID,
    new$DOCNUMBER,
    new$DOCCOUNT,
    new$IDATE,
    new$DEBIT,
    new$CREDIT,
    new$DOCTYPE,
    new$INN,
    new$ORG_REF,
    new$ACCOUNTINDEX,
    new$KD,
    new$SUBKD,
    new$REGIONCLS,
    new$GOSNI,
    new$INCACCOUNT,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$BUDGETREF,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$NOTE,
    new$RECORDINDEX2,
    new$ELNUM,
    new$NOTEEX,
    new$BUHPAYMENTCLS,
    new$ACCOUNTREF,
    new$ELPACKETNUM,
    new$FACIALACC_CLS,
    new$NDS,
    new$MEANSTYPE,
    new$RECORDDATE,
    new$TOTALREF,
    new$REQUESTSINDEX,
    new$KVSR,
    new$TAXNOTE,
    new$DOCNUM,
    new$REALPAYERORG_REF,
    new$DOCDATE,
    new$DOCBASE,
    new$FACT,
    new$RVERSION,
    new$KFSR,
    new$KESR,
    new$KVR,
    new$KCSR,
    new$SUMCOMPLETE,
    new$ELDOCREF,
    new$REQUESTSINDEX2,
    new$FEDERALFUNDSREF,
    new$BUHOPERATIONCLS,
    new$IFS,
    new$IFS_CORR,
    new$CLSTYPE,
    new$NDSNOTE,
    new$DOGNUM,
    new$SENDERID,
    new$SENDERRECORDID,
    new$OKATO,
    new$ADDOKATO,
    new$REJECTCLS,
    new$FUNDSSOURCE,
    new$DIRECTIONCLS,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$STIMATEID,
    new$TRANSFERTCLS,
    new$SUBSIDYCLS,
    new$FAORGTYPE,
    new$OKTMO,
    new$UINCODE,
    new$FINTYPE,
    new$INVESTOBJECT,
    new$CONTRACTCOSTSCLS,
    new$TARGETCLS,
    new$TEMPREJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_20 (T_INCOMES32_AI_20)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   --     
   if (new$ProgIndex <> 42) then
     BEGIN
       SELECT ProgIndex, DocNumber, AcceptDate
        INTO CapProgIndex, CapDocNumber, CapAcceptDate
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
     EXCEPTION
       WHEN NO_DATA_FOUND THEN NULL;
     END;
   end if;

   --   - ,  
   IF ((CapProgIndex = 145) or (new$ProgIndex=42)) THEN

      If ((new$ProgIndex=42) and (new$DocType between 1010 and 1019) and
         (new$Debit>0) and (new$DOCDATE is not null))
      then
        BEGIN
          select kd into Kd_Master
    From Incomes32 inc
          where inc.id = new$RecordIndex;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;

        if (Kd_Master = new$Kd) then
          CapAcceptDate := new$DOCDATE;
          CapProgIndex  := new$ProgIndex;
          CapDocNumber  := new$DocNum;
        end if;
      end if; --       (         )

      --             
      IF ((CapAcceptDate IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit > 0) OR (new$Credit < 0))) THEN
         --    ( RealPayerOrg_Ref(PayDoc32)=new$RealPayerOrg_Ref(Incomes32))
         INSERT INTO PayDoc32
            (BudgetRef, AccountRef, PayerAttrRef, InputDate,
             Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref, FACIALACC_CLS)
         VALUES (new$BudgetRef, new$AccountRef, new$IncAccount, CapAcceptDate,
             (new$Debit - new$Credit), new$Note, new$ProgIndex, new$id, CapDocNumber, new$TaxNote,
             new$RealPayerOrg_Ref,new$FACIALACC_CLS);
      -- (new$Debit - new$Credit) --- ..      ,    ,
      --             
      END IF;

   END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_INCOMES32_AI_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 161) AND (RecordID = NEW$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$TEMPREJECTCAUSE INCOMES32.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 10.00.00.2
-- - - - - - - - - - - - -

  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN 
    new$DocBase := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN 
    new$Gosni := 0;
  END IF;
  /* 3 -    */
  IF (new$ProgIndex IS NULL) THEN 
    new$ProgIndex := 3; 
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0; 
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN 
    new$FACIALACC_CLS := 0; 
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN 
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN 
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN 
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN 
    new$AccountIndex := 0; 
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN 
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN 
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN 
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN 
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN 
    new$DirectionCLS := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  IF (new$FinType IS NULL) THEN  
    new$FinType := 0;
  END IF;
  /*   .        */
  IF (new$IFS_CORR IS NULL) THEN 
    new$Ifs_Corr := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$Ifs := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  BEGIN

    /*     */
    /*   after   ,*/ 
    /*      */
    SELECT ProgIndex, AcceptDate, ReestrNumber
    INTO CapProgIndex1$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
    WHERE
    (qt.ID = new$RecordIndex)
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*              
           (  , , ) */
  /*   -    () */
  IF (CapProgIndex1$ = 45)
  THEN 
    IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN 
      /*        ,
                     */            
      new$FederalFundsRef := new$ID;
      /* if-then*/
    ELSE 
      new$FederalFundsRef := NULL;
      /* if-else*/  
    END IF;/* if (CapProgIndex=45) */
  END IF;
  /*     */
  IF (new$BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
      IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
        RaiseException('Ex_CantModufyBudget');
      END IF;
      IF (new$Progindex = 41) THEN
        SELECT COUNT(inc.id ) INTO CNT$1
        FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
        IF ((CNT$1<> 0)) THEN
          RaiseException('Ex_CantModufyBudget');
        END IF;   
      END IF;
    END IF;
  END IF;
  /*     \*/
  IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
  ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

  BEGIN
    SELECT Inn
     INTO new$Inn
     FROM Organizations o
    WHERE (o.ID = new$Org_Ref);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*      */
  IF (new$ProgIndex <> 42) THEN
    BEGIN
      SELECT ProgIndex, DocNumber, AcceptDate
      INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
      WHERE
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*   -  ,   */
  IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
  THEN 
    IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
    (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
    THEN 
      BEGIN
        SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
        WHERE inc.id = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (Kd_Master$ = new$Kd) THEN 
        CapAcceptDate$ := new$DOCDATE;
        CapProgIndex$  := new$ProgIndex;
        CapDocNumber$  := new$DocNum;
        /*  */        
      END IF;/*       (         )*/
    END IF;
    IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
    THEN 

      /*      */
      /* /      Incomes32, ..      ,     */

      /*     /   */
      SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
      INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
      ;
      /*            ,  .*/
      /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
                      ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
                     ) THEN
                    EXCEPTION EX_CANNOTUPDATENUMBER;*/
                 
                
      IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
      then
        if ((new$DocType <> :old.DocType )
        or (new$Debit <> :old.Debit )
        or (new$Credit <> :old.Credit)
        or (new$org_ref <> :old.org_ref)
        or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
        or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
        )
        then
          RaiseException('EX_CANNOTUPDATENUMBER');
        END IF;
      END IF;
                


      /*           */
      IF (PayDocCount$ = 0)
      THEN 
        /*       */
        GetIntConst(11, 2,ConstPayQueue$);
        /*       */
        GetIntConst(11, 1,ConstSendBy$);

        /*    */
        INSERT INTO PayDoc32
        (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
        Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
        VALUES
        (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
        new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
        /* (new.Debit - new.Credit) --- ..      ,    ,
                                     */

        /* if-then */
      ELSE 
        /*     */
        IF (((new$AccountRef = :old.AccountRef) OR
        ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
        AND (new$IncAccount = :old.IncAccount)
        AND (new$BudgetRef = :old.BudgetRef)
        AND ((new$Note = :old.Note) OR
        ((new$Note IS NULL) AND (:old.Note IS NULL)))
        AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
        ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
        AND ((new$TaxNote = :old.TaxNote) OR
        ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
        )  THEN
          new$AccountRef := new$AccountRef;
                          
        ELSE

          UPDATE PayDoc32 pd
          SET
          pd.AccountRef = new$AccountRef,
          pd.PayerAttrRef = new$IncAccount,
          pd.AcceptorAttrRef = new$AccountRef,
          pd.TextNote = new$Note,
          pd.TaxNote = new$TaxNote,
          pd.BudgetRef = new$BudgetRef,
          pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
          pd.InputDate = CapAcceptDate$,
          pd.SourceDocNumber = CapDocNumber$,
          pd.FACIALACC_CLS = new$FACIALACC_CLS
          WHERE
          (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
        END IF;
        IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
        OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
        THEN  
          IF (Divided$ > 0)
          THEN
            /*  ,      */
            RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
          ELSE
            UPDATE PayDoc32 pd
            SET
            pd.Credit = new$Debit - new$Credit
            WHERE
            (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
          END IF;/* if-then*/            
        END IF;/* if-else*/
      END IF;
      /*     / */
      /*   :     ,     */
      /*  ,     */
      SELECT MAX(pd.AcceptDate)
      INTO Date_Pd$           FROM PayDoc32 pd
      WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
      ;
      new$Idate := Date_Pd$;
      /* if-then*/
    ELSE 
      /*       
                          -
                    . */
      DELETE FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex = new$ProgIndex)
      AND (pd.RecordIndex = new$id);
      /* if-else*/  
    END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then 
    BEGIN
      select q.BuildDate 
      into 
      new$DocDate        from QuotesTitle q 
      where q.id = new$RecordIndex 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
            */
         new$FederalFundsRef := new$ID;
      ELSE
         new$FederalFundsRef := NULL;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN
      select KDValue   into oldKD$ from kd where Id=:old.kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN

      /*     */
      select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
      IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
      into
      idKD1$,
      val_DocCount1$,
      val_DocType1$,
      val_Org_Ref1$,
      val_AccountIndex1$,
      val_SubKD1$,
      val_RegionCLS1$,
      val_GosNI1$,
      val_IncAccount1$,
      val_BudgetRef1$,
      val_MEANSTYPE1$  , 
      val_FACIALACC_CLS1$,
      val_TransfertCls1$         from incomes32 where id=new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not idKD1$ is null) then
      if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
      (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
        /*   ,    */
        delete
        from Incomes32
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      (new$Debit<>0))
      /*       */
      then 
        RaiseException('ex_UnknownRedirect');
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
        /*   ,   ,   */
        insert into
        Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
        Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
        val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
        val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
        new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
      END IF;
      if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
      and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
        /*      ,   */
        update Incomes32
        set
        DocNum = new$DocNum,
        DocCount = val_DocCount1$,
        iDate = new$iDate,
        DOCDATE = new$DOCDATE,
        Debit = 0,
        Credit = -new$Credit,
        DocType = val_DocType1$,
        Org_Ref = val_Org_Ref1$,
        AccountIndex = val_AccountIndex1$,
        KD = idKD1$,
        SubKD = val_SubKD1$,
        RegionCLS = val_RegionCLS1$,
        GosNI = val_GosNI1$,
        ProgIndex = 43,
        RecordIndex = new$Id,
        IncAccount = val_IncAccount1$,
        BudgetRef = val_BudgetRef1$,
        Note = new$Note,
        MEANSTYPE = val_MEANSTYPE1$,
        FACIALACC_CLS = val_FACIALACC_CLS1$,
        TransfertCls = val_TransfertCls1$,
        RVersion = -1
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
         
      END IF; 
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 41)    /*   () */
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    /*       */
    FOR REC$1 IN (SELECT inc.id
     AS val_ID42    FROM Incomes32 inc
    LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
    WHERE (inc.ProgIndex =  42) and
    (inc.RecordIndex =  new$id) and
    (inc.debit = 0) and
    (not(kd.kdvalue like unkKD$)) and
    (not(kd.kdvalue like unkVKD$))
    )
    LOOP
      BEGIN
        /*       */
        select inc.id
        into val_ID431$         FROM Incomes32 inc
        WHERE (inc.ProgIndex =  43) and
        (inc.RecordIndex =  REC$1.val_ID42)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      /*     ,   Credit, ProgIndex, RecordIndex */
      update Incomes32
      set
      DocNum = new$DocNum,
      DocCount = new$DocCount,       
      DOCDATE = new$DOCDATE,
      Debit = 0,
      DocType = new$DocType,
      Org_Ref = new$Org_Ref,
      AccountIndex = new$AccountIndex,
      KD = new$Kd,
      SubKD = new$SubKD,
      RegionCLS = new$RegionCLS,
      GosNI = new$GosNI,
      IncAccount = new$IncAccount,
      BudgetRef = new$BudgetRef,
      Note = new$Note,
      MEANSTYPE = new$MEANSTYPE,
      FACIALACC_CLS = new$FACIALACC_CLS,
      FACT = new$FACT,
      TransfertCls = new$TransfertCls,
      DirectionCls = new$DirectionCls,
      rversion = -1
      where id = val_ID431$;

        
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       --       ClsType
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                --  - 
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      --   
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   IF (NEW$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (161, :OLD.ID, SYSDATE);
      DELETE FROM DelRecIndexes
        WHERE (TableID = 161) AND (RecordId = NEW$ID);
   END IF;

END;
/
ALTER TABLE TB_INCOMES32 ADD (
  REJECTCAUSE VARCHAR2(1000)
)
/

CREATE OR REPLACE VIEW INCOMES32 (
  ID,
  DOCNUMBER,
  DOCCOUNT,
  IDATE,
  DEBIT,
  CREDIT,
  DOCTYPE,
  INN,
  ORG_REF,
  ACCOUNTINDEX,
  KD,
  SUBKD,
  REGIONCLS,
  GOSNI,
  INCACCOUNT,
  PROGINDEX,
  RECORDINDEX,
  BUDGETREF,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  NOTE,
  RECORDINDEX2,
  ELNUM,
  NOTEEX,
  BUHPAYMENTCLS,
  ACCOUNTREF,
  ELPACKETNUM,
  FACIALACC_CLS,
  NDS,
  MEANSTYPE,
  RECORDDATE,
  TOTALREF,
  REQUESTSINDEX,
  KVSR,
  TAXNOTE,
  DOCNUM,
  REALPAYERORG_REF,
  DOCDATE,
  DOCBASE,
  FACT,
  RVERSION,
  KFSR,
  KESR,
  KVR,
  KCSR,
  SUMCOMPLETE,
  ELDOCREF,
  REQUESTSINDEX2,
  FEDERALFUNDSREF,
  BUHOPERATIONCLS,
  IFS,
  IFS_CORR,
  CLSTYPE,
  NDSNOTE,
  DOGNUM,
  SENDERID,
  SENDERRECORDID,
  OKATO,
  ADDOKATO,
  REJECTCLS,
  FUNDSSOURCE,
  DIRECTIONCLS,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  STIMATEID,
  TRANSFERTCLS,
  SUBSIDYCLS,
  FAORGTYPE,
  OKTMO,
  UINCODE,
  FINTYPE,
  INVESTOBJECT,
  CONTRACTCOSTSCLS,
  TARGETCLS,
  TEMPREJECTCAUSE,
  REJECTCAUSE)
AS
  SELECT
    ID,
    DOCNUMBER,
    DOCCOUNT,
    IDATE,
    DEBIT,
    CREDIT,
    DOCTYPE,
    INN,
    ORG_REF,
    ACCOUNTINDEX,
    KD,
    SUBKD,
    REGIONCLS,
    GOSNI,
    INCACCOUNT,
    PROGINDEX,
    RECORDINDEX,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    NOTE,
    RECORDINDEX2,
    ELNUM,
    NOTEEX,
    BUHPAYMENTCLS,
    ACCOUNTREF,
    ELPACKETNUM,
    FACIALACC_CLS,
    NDS,
    MEANSTYPE,
    RECORDDATE,
    TOTALREF,
    REQUESTSINDEX,
    KVSR,
    TAXNOTE,
    DOCNUM,
    REALPAYERORG_REF,
    DOCDATE,
    DOCBASE,
    FACT,
    RVERSION,
    KFSR,
    KESR,
    KVR,
    KCSR,
    SUMCOMPLETE,
    ELDOCREF,
    REQUESTSINDEX2,
    FEDERALFUNDSREF,
    BUHOPERATIONCLS,
    IFS,
    IFS_CORR,
    CLSTYPE,
    NDSNOTE,
    DOGNUM,
    SENDERID,
    SENDERRECORDID,
    OKATO,
    ADDOKATO,
    REJECTCLS,
    FUNDSSOURCE,
    DIRECTIONCLS,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    STIMATEID,
    TRANSFERTCLS,
    SUBSIDYCLS,
    FAORGTYPE,
    OKTMO,
    UINCODE,
    FINTYPE,
    INVESTOBJECT,
    CONTRACTCOSTSCLS,
    TARGETCLS,
    TEMPREJECTCAUSE,
    REJECTCAUSE
  FROM TB_INCOMES32
/

CREATE OR REPLACE TRIGGER TR_INCOMES32_ID
  INSTEAD OF DELETE
  ON INCOMES32
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_10 (TR_INCOMES32_BD10)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

  delete
  from CurrencyIncomes
  where (id = :old.id);

-- - - - - - - - - - - - -
-- BD_20 (T_INCOMES32_BD_20)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

  /*    */
  if (:old.DocType between 1010 and 1019) then
    delete from PayDoc32
    where 
      (ProgIndex = :old.ProgIndex) 
    and 
     (RecordIndex = :old.id);
  end if;

-- - - - - - - - - - - - -
-- BD_500 (TR_INCOMES32_BD_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  Update QuotesTitle set
  DocChangeDate = SYSDATE,
  RVersion = -1
  where id = :old.recordindex;

-- - - - - - - - - - - - -
-- BD_600 (TR_INCOMES32_BD_600)
-- Last update 14.10.2009
-- - - - - - - - - - - - -

    --    
    if (:old.ProgIndex = 41) then
        delete
            from Incomes32
        where
           (ProgIndex=42)and
           (RecordIndex=:old.id);
    end if;

    --  (  )
    if (:old.ProgIndex = 42) then
        delete
            from Incomes32
        where
            (ProgIndex=43)and
            (RecordIndex=:old.id);
    end if;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_INCOMES32
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);
   
  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_500 (TR_INCOMES32_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordID, DeleteDate, ProgIndex, SUMMA) values (161, :old.ID, SYSDATE, :old.ProgIndex, :old.DEBIT + :old.CREDIT);

END;
/

CREATE OR REPLACE TRIGGER TR_INCOMES32_II
  INSTEAD OF INSERT
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$TEMPREJECTCAUSE INCOMES32.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  CapDocNumber VARCHAR2(20);
  unkKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  Kd_Master NUMBER(10);
  idKD$ NUMBER(10);
  unkVKD$ VARCHAR2(20);
  val_DocCount$ NUMBER(10);
  val_DocType$ NUMBER(10);
  val_Org_Ref$ NUMBER(10);
  val_AccountIndex$ NUMBER(10);
  val_SubKD$ NUMBER(10);
  val_RegionCLS$ NUMBER(10);
  val_GosNI$ NUMBER(10);
  val_IncAccount$ NUMBER(10);
  val_BudgetRef$ NUMBER(10);
  val_MEANSTYPE$ NUMBER(10);
  val_FACIALACC_CLS$ NUMBER(10);
  val_TransfertCls$ NUMBER(10);
  CapAcceptDate$ NUMBER;
  CapReestrNumber$ VARCHAR2(20);
  CapProgIndex$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_INCOMES32_BI)
-- Version 10.00.00.2
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN 
    select g_shared.nextval into new$id from dual;
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN 
    new$FACIALACC_CLS := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN 
    new$Gosni := 0;
  END IF;
  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN 
    new$DocBase := 0;
  END IF;
  /* 3 -    */
  IF (new$KD IS NULL) THEN 
    new$KD := 0;
  END IF;
  IF (new$ProgIndex IS NULL) THEN 
    new$ProgIndex := 3;
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN 
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN 
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN 
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN 
    new$AccountIndex := 0;
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN 
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN 
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN 
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN 
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN 
    new$DirectionCLS := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  IF (new$FinType IS NULL) THEN  
    new$FinType := 0;
  END IF;
  /*   .        */
  IF (new$IFS IS NULL) THEN 
    new$IFS := 0;
  END IF;
  IF (new$IFS_CORR IS NULL) THEN 
    new$Ifs_Corr := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
   
  /*  ,    */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0)) THEN
    BEGIN
      SELECT qt.BudgetRef      INTO new$BudgetRef FROM QuotesTitle qt
      WHERE qt.Id = new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    0,     */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0)) THEN
    BEGIN
      SELECT fa.BudgetRef      INTO new$BudgetRef FROM FacialAcc_Cls fa
      WHERE fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    0,    */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0))
  THEN 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
   
  IF (new$ProgIndex = 45) 
  THEN 
    IF (new$IncAccount IS NULL) THEN
      GetDefDFAccRefForBudget(new$BudgetRef,new$IncAccount);
    END IF;
    BEGIN

      /*     */
      SELECT qt.ProgIndex, qt.AcceptDate, qt.IncAccount, qt.ReestrNumber 
      INTO CapProgIndex$, CapAcceptDate$, new$IncAccount, CapReestrNumber$       FROM QuotesTitle qt
      WHERE 
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*           / */
    /*  /   after insert */
    IF (CapProgIndex$ <> 145) THEN 
      new$iDate := CapAcceptDate$;
    END IF;
    IF ((CapProgIndex$ = 145)AND (NOT ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0)OR (new$Credit<0)))) )
    THEN 
      new$Idate := CapAcceptDate$;      
    END IF;
    /*   -    () */
    IF ((CapProgIndex$ = 45) AND (CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN 
      /*        , *//*    */            
                  
      new$FederalFundsRef := new$ID;
      /* if-then */  
    END IF;/* if-then*/
  END IF;
  BEGIN
    /*     \*/
    SELECT org.Org_Type   INTO new$FAOrgType FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$FacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BI_5 (TR_INCOMES_BI_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BI_9 (TR_INCOMES32_BI_VZ)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   IF (new$ProgIndex = 9) THEN
      /*   */
      GetIntConst (9, 1, new$IncAccount);

      BEGIN
        /*      */
        SELECT ACCEPTDATE, BUDGETREF
          INTO new$IDate, new$BudgetRef
          FROM VZ_OFFSET
         WHERE ID = new$RecordIndex;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_INCOMES32_BI_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   BEGIN
      SELECT Inn
        INTO new$Inn
        FROM Organizations o
       WHERE (o.ID = new$Org_Ref);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

/*  .    ,    */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      BEGIN
         SELECT c.BudgetRef
           INTO new$budgetref
           FROM QuotesTitle c
          WHERE c.ID = NEW$RecordIndex;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

   /*  .  ,     */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      BEGIN
         SELECT fa.BudgetRef
           INTO new$budgetref
           FROM FacialAcc_Cls fa
          WHERE fa.ID = NEW$FacialAcc_Cls;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

   /*  ,    */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      GetIntConst (-1, 3, new$budgetref);
   END IF;

-- - - - - - - - - - - - -
-- BI_30 (TR_INCOMES32_BI_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then 
    BEGIN
      select q.BuildDate 
      into 
      new$DocDate        from QuotesTitle q 
      where q.id = new$RecordIndex 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_70 (TR_INCOMES32_BI_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
               */
         new$FederalFundsRef := new$ID;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_INCOMES32_BI_100)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if ((not (newKD$  like unkKD$)) and
    (not (newKD$  like unkVKD$))) then
      /*   (    
            ) ,  
         ,   */

      /*       */
      if (new$Debit <> 0) then 
        RaiseException('ex_UnknownRedirect');
      END IF;
      BEGIN

        /*      */
        select KD,DocCount,DocType,
        Org_Ref,AccountIndex,SubKD,RegionCLS,GosNI,
        IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,
        TransfertCls
        into
        idKD$,
        val_DocCount$,
        val_DocType$,
        val_Org_Ref$,
        val_AccountIndex$,
        val_SubKD$,
        val_RegionCLS$,
        val_GosNI$,
        val_IncAccount$,
        val_BudgetRef$,
        val_MEANSTYPE$  ,
        val_FACIALACC_CLS$,
        val_TransfertCls$         from incomes32 where id=new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
         
      if (not idKD$ is null) then
        insert into
        /* KD=   (      )
              Debit=0
              redit=-new.credit
              ProgIndex=43
              RecordIndex=new.id
              id    Incomes32*/
        Incomes32(CreaterUser, DocNum,DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS, TransfertCls)
        Values(new$CreaterUser, new$DocNum, val_DocCount$, new$iDate, new$DOCDATE, 0, -new$Credit, val_DocType$,
        val_Org_Ref$, val_AccountIndex$, idKD$, val_SubKD$, val_RegionCLS$, val_GosNI$,
        43,new$Id, val_IncAccount$, val_BudgetRef$, new$Note,val_MEANSTYPE$,val_FACIALACC_CLS$,val_TransfertCls$);
        
      END IF; 
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_110 (TR_INCOMES32_BI_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       /*       ClsType */
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                /*  -  */
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_INCOMES32_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update QuotesTitle set
  DocChangeDate = new$UpdateDate,
  RVersion = -1
  where id = new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_INCOMES32 (
    ID,
    DOCNUMBER,
    DOCCOUNT,
    IDATE,
    DEBIT,
    CREDIT,
    DOCTYPE,
    INN,
    ORG_REF,
    ACCOUNTINDEX,
    KD,
    SUBKD,
    REGIONCLS,
    GOSNI,
    INCACCOUNT,
    PROGINDEX,
    RECORDINDEX,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    NOTE,
    RECORDINDEX2,
    ELNUM,
    NOTEEX,
    BUHPAYMENTCLS,
    ACCOUNTREF,
    ELPACKETNUM,
    FACIALACC_CLS,
    NDS,
    MEANSTYPE,
    RECORDDATE,
    TOTALREF,
    REQUESTSINDEX,
    KVSR,
    TAXNOTE,
    DOCNUM,
    REALPAYERORG_REF,
    DOCDATE,
    DOCBASE,
    FACT,
    RVERSION,
    KFSR,
    KESR,
    KVR,
    KCSR,
    SUMCOMPLETE,
    ELDOCREF,
    REQUESTSINDEX2,
    FEDERALFUNDSREF,
    BUHOPERATIONCLS,
    IFS,
    IFS_CORR,
    CLSTYPE,
    NDSNOTE,
    DOGNUM,
    SENDERID,
    SENDERRECORDID,
    OKATO,
    ADDOKATO,
    REJECTCLS,
    FUNDSSOURCE,
    DIRECTIONCLS,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    STIMATEID,
    TRANSFERTCLS,
    SUBSIDYCLS,
    FAORGTYPE,
    OKTMO,
    UINCODE,
    FINTYPE,
    INVESTOBJECT,
    CONTRACTCOSTSCLS,
    TARGETCLS,
    TEMPREJECTCAUSE,
    REJECTCAUSE
  ) VALUES (
    new$ID,
    new$DOCNUMBER,
    new$DOCCOUNT,
    new$IDATE,
    new$DEBIT,
    new$CREDIT,
    new$DOCTYPE,
    new$INN,
    new$ORG_REF,
    new$ACCOUNTINDEX,
    new$KD,
    new$SUBKD,
    new$REGIONCLS,
    new$GOSNI,
    new$INCACCOUNT,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$BUDGETREF,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$NOTE,
    new$RECORDINDEX2,
    new$ELNUM,
    new$NOTEEX,
    new$BUHPAYMENTCLS,
    new$ACCOUNTREF,
    new$ELPACKETNUM,
    new$FACIALACC_CLS,
    new$NDS,
    new$MEANSTYPE,
    new$RECORDDATE,
    new$TOTALREF,
    new$REQUESTSINDEX,
    new$KVSR,
    new$TAXNOTE,
    new$DOCNUM,
    new$REALPAYERORG_REF,
    new$DOCDATE,
    new$DOCBASE,
    new$FACT,
    new$RVERSION,
    new$KFSR,
    new$KESR,
    new$KVR,
    new$KCSR,
    new$SUMCOMPLETE,
    new$ELDOCREF,
    new$REQUESTSINDEX2,
    new$FEDERALFUNDSREF,
    new$BUHOPERATIONCLS,
    new$IFS,
    new$IFS_CORR,
    new$CLSTYPE,
    new$NDSNOTE,
    new$DOGNUM,
    new$SENDERID,
    new$SENDERRECORDID,
    new$OKATO,
    new$ADDOKATO,
    new$REJECTCLS,
    new$FUNDSSOURCE,
    new$DIRECTIONCLS,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$STIMATEID,
    new$TRANSFERTCLS,
    new$SUBSIDYCLS,
    new$FAORGTYPE,
    new$OKTMO,
    new$UINCODE,
    new$FINTYPE,
    new$INVESTOBJECT,
    new$CONTRACTCOSTSCLS,
    new$TARGETCLS,
    new$TEMPREJECTCAUSE,
    new$REJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_20 (T_INCOMES32_AI_20)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   --     
   if (new$ProgIndex <> 42) then
     BEGIN
       SELECT ProgIndex, DocNumber, AcceptDate
        INTO CapProgIndex, CapDocNumber, CapAcceptDate
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
     EXCEPTION
       WHEN NO_DATA_FOUND THEN NULL;
     END;
   end if;

   --   - ,  
   IF ((CapProgIndex = 145) or (new$ProgIndex=42)) THEN

      If ((new$ProgIndex=42) and (new$DocType between 1010 and 1019) and
         (new$Debit>0) and (new$DOCDATE is not null))
      then
        BEGIN
          select kd into Kd_Master
    From Incomes32 inc
          where inc.id = new$RecordIndex;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;

        if (Kd_Master = new$Kd) then
          CapAcceptDate := new$DOCDATE;
          CapProgIndex  := new$ProgIndex;
          CapDocNumber  := new$DocNum;
        end if;
      end if; --       (         )

      --             
      IF ((CapAcceptDate IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit > 0) OR (new$Credit < 0))) THEN
         --    ( RealPayerOrg_Ref(PayDoc32)=new$RealPayerOrg_Ref(Incomes32))
         INSERT INTO PayDoc32
            (BudgetRef, AccountRef, PayerAttrRef, InputDate,
             Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref, FACIALACC_CLS)
         VALUES (new$BudgetRef, new$AccountRef, new$IncAccount, CapAcceptDate,
             (new$Debit - new$Credit), new$Note, new$ProgIndex, new$id, CapDocNumber, new$TaxNote,
             new$RealPayerOrg_Ref,new$FACIALACC_CLS);
      -- (new$Debit - new$Credit) --- ..      ,    ,
      --             
      END IF;

   END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_INCOMES32_AI_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 161) AND (RecordID = NEW$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$TEMPREJECTCAUSE INCOMES32.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 10.00.00.2
-- - - - - - - - - - - - -

  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN 
    new$DocBase := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN 
    new$Gosni := 0;
  END IF;
  /* 3 -    */
  IF (new$ProgIndex IS NULL) THEN 
    new$ProgIndex := 3; 
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0; 
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN 
    new$FACIALACC_CLS := 0; 
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN 
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN 
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN 
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN 
    new$AccountIndex := 0; 
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN 
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN 
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN 
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN 
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN 
    new$DirectionCLS := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  IF (new$FinType IS NULL) THEN  
    new$FinType := 0;
  END IF;
  /*   .        */
  IF (new$IFS_CORR IS NULL) THEN 
    new$Ifs_Corr := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$Ifs := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  BEGIN

    /*     */
    /*   after   ,*/ 
    /*      */
    SELECT ProgIndex, AcceptDate, ReestrNumber
    INTO CapProgIndex1$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
    WHERE
    (qt.ID = new$RecordIndex)
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*              
           (  , , ) */
  /*   -    () */
  IF (CapProgIndex1$ = 45)
  THEN 
    IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN 
      /*        ,
                     */            
      new$FederalFundsRef := new$ID;
      /* if-then*/
    ELSE 
      new$FederalFundsRef := NULL;
      /* if-else*/  
    END IF;/* if (CapProgIndex=45) */
  END IF;
  /*     */
  IF (new$BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
      IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
        RaiseException('Ex_CantModufyBudget');
      END IF;
      IF (new$Progindex = 41) THEN
        SELECT COUNT(inc.id ) INTO CNT$1
        FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
        IF ((CNT$1<> 0)) THEN
          RaiseException('Ex_CantModufyBudget');
        END IF;   
      END IF;
    END IF;
  END IF;
  /*     \*/
  IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
  ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

  BEGIN
    SELECT Inn
     INTO new$Inn
     FROM Organizations o
    WHERE (o.ID = new$Org_Ref);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*      */
  IF (new$ProgIndex <> 42) THEN
    BEGIN
      SELECT ProgIndex, DocNumber, AcceptDate
      INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
      WHERE
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*   -  ,   */
  IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
  THEN 
    IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
    (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
    THEN 
      BEGIN
        SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
        WHERE inc.id = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (Kd_Master$ = new$Kd) THEN 
        CapAcceptDate$ := new$DOCDATE;
        CapProgIndex$  := new$ProgIndex;
        CapDocNumber$  := new$DocNum;
        /*  */        
      END IF;/*       (         )*/
    END IF;
    IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
    THEN 

      /*      */
      /* /      Incomes32, ..      ,     */

      /*     /   */
      SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
      INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
      ;
      /*            ,  .*/
      /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
                      ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
                     ) THEN
                    EXCEPTION EX_CANNOTUPDATENUMBER;*/
                 
                
      IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
      then
        if ((new$DocType <> :old.DocType )
        or (new$Debit <> :old.Debit )
        or (new$Credit <> :old.Credit)
        or (new$org_ref <> :old.org_ref)
        or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
        or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
        )
        then
          RaiseException('EX_CANNOTUPDATENUMBER');
        END IF;
      END IF;
                


      /*           */
      IF (PayDocCount$ = 0)
      THEN 
        /*       */
        GetIntConst(11, 2,ConstPayQueue$);
        /*       */
        GetIntConst(11, 1,ConstSendBy$);

        /*    */
        INSERT INTO PayDoc32
        (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
        Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
        VALUES
        (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
        new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
        /* (new.Debit - new.Credit) --- ..      ,    ,
                                     */

        /* if-then */
      ELSE 
        /*     */
        IF (((new$AccountRef = :old.AccountRef) OR
        ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
        AND (new$IncAccount = :old.IncAccount)
        AND (new$BudgetRef = :old.BudgetRef)
        AND ((new$Note = :old.Note) OR
        ((new$Note IS NULL) AND (:old.Note IS NULL)))
        AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
        ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
        AND ((new$TaxNote = :old.TaxNote) OR
        ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
        )  THEN
          new$AccountRef := new$AccountRef;
                          
        ELSE

          UPDATE PayDoc32 pd
          SET
          pd.AccountRef = new$AccountRef,
          pd.PayerAttrRef = new$IncAccount,
          pd.AcceptorAttrRef = new$AccountRef,
          pd.TextNote = new$Note,
          pd.TaxNote = new$TaxNote,
          pd.BudgetRef = new$BudgetRef,
          pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
          pd.InputDate = CapAcceptDate$,
          pd.SourceDocNumber = CapDocNumber$,
          pd.FACIALACC_CLS = new$FACIALACC_CLS
          WHERE
          (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
        END IF;
        IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
        OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
        THEN  
          IF (Divided$ > 0)
          THEN
            /*  ,      */
            RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
          ELSE
            UPDATE PayDoc32 pd
            SET
            pd.Credit = new$Debit - new$Credit
            WHERE
            (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
          END IF;/* if-then*/            
        END IF;/* if-else*/
      END IF;
      /*     / */
      /*   :     ,     */
      /*  ,     */
      SELECT MAX(pd.AcceptDate)
      INTO Date_Pd$           FROM PayDoc32 pd
      WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
      ;
      new$Idate := Date_Pd$;
      /* if-then*/
    ELSE 
      /*       
                          -
                    . */
      DELETE FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex = new$ProgIndex)
      AND (pd.RecordIndex = new$id);
      /* if-else*/  
    END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then 
    BEGIN
      select q.BuildDate 
      into 
      new$DocDate        from QuotesTitle q 
      where q.id = new$RecordIndex 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
            */
         new$FederalFundsRef := new$ID;
      ELSE
         new$FederalFundsRef := NULL;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN
      select KDValue   into oldKD$ from kd where Id=:old.kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN

      /*     */
      select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
      IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
      into
      idKD1$,
      val_DocCount1$,
      val_DocType1$,
      val_Org_Ref1$,
      val_AccountIndex1$,
      val_SubKD1$,
      val_RegionCLS1$,
      val_GosNI1$,
      val_IncAccount1$,
      val_BudgetRef1$,
      val_MEANSTYPE1$  , 
      val_FACIALACC_CLS1$,
      val_TransfertCls1$         from incomes32 where id=new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not idKD1$ is null) then
      if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
      (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
        /*   ,    */
        delete
        from Incomes32
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      (new$Debit<>0))
      /*       */
      then 
        RaiseException('ex_UnknownRedirect');
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
        /*   ,   ,   */
        insert into
        Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
        Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
        val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
        val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
        new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
      END IF;
      if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
      and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
        /*      ,   */
        update Incomes32
        set
        DocNum = new$DocNum,
        DocCount = val_DocCount1$,
        iDate = new$iDate,
        DOCDATE = new$DOCDATE,
        Debit = 0,
        Credit = -new$Credit,
        DocType = val_DocType1$,
        Org_Ref = val_Org_Ref1$,
        AccountIndex = val_AccountIndex1$,
        KD = idKD1$,
        SubKD = val_SubKD1$,
        RegionCLS = val_RegionCLS1$,
        GosNI = val_GosNI1$,
        ProgIndex = 43,
        RecordIndex = new$Id,
        IncAccount = val_IncAccount1$,
        BudgetRef = val_BudgetRef1$,
        Note = new$Note,
        MEANSTYPE = val_MEANSTYPE1$,
        FACIALACC_CLS = val_FACIALACC_CLS1$,
        TransfertCls = val_TransfertCls1$,
        RVersion = -1
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
         
      END IF; 
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 41)    /*   () */
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    /*       */
    FOR REC$1 IN (SELECT inc.id
     AS val_ID42    FROM Incomes32 inc
    LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
    WHERE (inc.ProgIndex =  42) and
    (inc.RecordIndex =  new$id) and
    (inc.debit = 0) and
    (not(kd.kdvalue like unkKD$)) and
    (not(kd.kdvalue like unkVKD$))
    )
    LOOP
      BEGIN
        /*       */
        select inc.id
        into val_ID431$         FROM Incomes32 inc
        WHERE (inc.ProgIndex =  43) and
        (inc.RecordIndex =  REC$1.val_ID42)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      /*     ,   Credit, ProgIndex, RecordIndex */
      update Incomes32
      set
      DocNum = new$DocNum,
      DocCount = new$DocCount,       
      DOCDATE = new$DOCDATE,
      Debit = 0,
      DocType = new$DocType,
      Org_Ref = new$Org_Ref,
      AccountIndex = new$AccountIndex,
      KD = new$Kd,
      SubKD = new$SubKD,
      RegionCLS = new$RegionCLS,
      GosNI = new$GosNI,
      IncAccount = new$IncAccount,
      BudgetRef = new$BudgetRef,
      Note = new$Note,
      MEANSTYPE = new$MEANSTYPE,
      FACIALACC_CLS = new$FACIALACC_CLS,
      FACT = new$FACT,
      TransfertCls = new$TransfertCls,
      DirectionCls = new$DirectionCls,
      rversion = -1
      where id = val_ID431$;

        
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       --       ClsType
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                --  - 
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      --   
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   IF (NEW$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (161, :OLD.ID, SYSDATE);
      DELETE FROM DelRecIndexes
        WHERE (TableID = 161) AND (RecordId = NEW$ID);
   END IF;

END;
/
update INCOMES32 set
  REJECTCAUSE = TempRejectCause
/
commit work 
/
ALTER TABLE TB_INCOMES32 DROP (TempRejectCause)
/

CREATE OR REPLACE VIEW INCOMES32 (
  ID,
  DOCNUMBER,
  DOCCOUNT,
  IDATE,
  DEBIT,
  CREDIT,
  DOCTYPE,
  INN,
  ORG_REF,
  ACCOUNTINDEX,
  KD,
  SUBKD,
  REGIONCLS,
  GOSNI,
  INCACCOUNT,
  PROGINDEX,
  RECORDINDEX,
  BUDGETREF,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  NOTE,
  RECORDINDEX2,
  ELNUM,
  NOTEEX,
  BUHPAYMENTCLS,
  ACCOUNTREF,
  ELPACKETNUM,
  FACIALACC_CLS,
  NDS,
  MEANSTYPE,
  RECORDDATE,
  TOTALREF,
  REQUESTSINDEX,
  KVSR,
  TAXNOTE,
  DOCNUM,
  REALPAYERORG_REF,
  DOCDATE,
  DOCBASE,
  FACT,
  RVERSION,
  KFSR,
  KESR,
  KVR,
  KCSR,
  SUMCOMPLETE,
  ELDOCREF,
  REQUESTSINDEX2,
  FEDERALFUNDSREF,
  BUHOPERATIONCLS,
  IFS,
  IFS_CORR,
  CLSTYPE,
  NDSNOTE,
  DOGNUM,
  SENDERID,
  SENDERRECORDID,
  OKATO,
  ADDOKATO,
  REJECTCLS,
  FUNDSSOURCE,
  DIRECTIONCLS,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  STIMATEID,
  TRANSFERTCLS,
  SUBSIDYCLS,
  FAORGTYPE,
  OKTMO,
  UINCODE,
  FINTYPE,
  INVESTOBJECT,
  CONTRACTCOSTSCLS,
  TARGETCLS,
  REJECTCAUSE)
AS
  SELECT
    ID,
    DOCNUMBER,
    DOCCOUNT,
    IDATE,
    DEBIT,
    CREDIT,
    DOCTYPE,
    INN,
    ORG_REF,
    ACCOUNTINDEX,
    KD,
    SUBKD,
    REGIONCLS,
    GOSNI,
    INCACCOUNT,
    PROGINDEX,
    RECORDINDEX,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    NOTE,
    RECORDINDEX2,
    ELNUM,
    NOTEEX,
    BUHPAYMENTCLS,
    ACCOUNTREF,
    ELPACKETNUM,
    FACIALACC_CLS,
    NDS,
    MEANSTYPE,
    RECORDDATE,
    TOTALREF,
    REQUESTSINDEX,
    KVSR,
    TAXNOTE,
    DOCNUM,
    REALPAYERORG_REF,
    DOCDATE,
    DOCBASE,
    FACT,
    RVERSION,
    KFSR,
    KESR,
    KVR,
    KCSR,
    SUMCOMPLETE,
    ELDOCREF,
    REQUESTSINDEX2,
    FEDERALFUNDSREF,
    BUHOPERATIONCLS,
    IFS,
    IFS_CORR,
    CLSTYPE,
    NDSNOTE,
    DOGNUM,
    SENDERID,
    SENDERRECORDID,
    OKATO,
    ADDOKATO,
    REJECTCLS,
    FUNDSSOURCE,
    DIRECTIONCLS,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    STIMATEID,
    TRANSFERTCLS,
    SUBSIDYCLS,
    FAORGTYPE,
    OKTMO,
    UINCODE,
    FINTYPE,
    INVESTOBJECT,
    CONTRACTCOSTSCLS,
    TARGETCLS,
    REJECTCAUSE
  FROM TB_INCOMES32
/

CREATE OR REPLACE TRIGGER TR_INCOMES32_ID
  INSTEAD OF DELETE
  ON INCOMES32
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_10 (TR_INCOMES32_BD10)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

  delete
  from CurrencyIncomes
  where (id = :old.id);

-- - - - - - - - - - - - -
-- BD_20 (T_INCOMES32_BD_20)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

  /*    */
  if (:old.DocType between 1010 and 1019) then
    delete from PayDoc32
    where 
      (ProgIndex = :old.ProgIndex) 
    and 
     (RecordIndex = :old.id);
  end if;

-- - - - - - - - - - - - -
-- BD_500 (TR_INCOMES32_BD_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  Update QuotesTitle set
  DocChangeDate = SYSDATE,
  RVersion = -1
  where id = :old.recordindex;

-- - - - - - - - - - - - -
-- BD_600 (TR_INCOMES32_BD_600)
-- Last update 14.10.2009
-- - - - - - - - - - - - -

    --    
    if (:old.ProgIndex = 41) then
        delete
            from Incomes32
        where
           (ProgIndex=42)and
           (RecordIndex=:old.id);
    end if;

    --  (  )
    if (:old.ProgIndex = 42) then
        delete
            from Incomes32
        where
            (ProgIndex=43)and
            (RecordIndex=:old.id);
    end if;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_INCOMES32
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);
   
  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_500 (TR_INCOMES32_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordID, DeleteDate, ProgIndex, SUMMA) values (161, :old.ID, SYSDATE, :old.ProgIndex, :old.DEBIT + :old.CREDIT);

END;
/

CREATE OR REPLACE TRIGGER TR_INCOMES32_II
  INSTEAD OF INSERT
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  CapDocNumber VARCHAR2(20);
  unkKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  Kd_Master NUMBER(10);
  idKD$ NUMBER(10);
  unkVKD$ VARCHAR2(20);
  val_DocCount$ NUMBER(10);
  val_DocType$ NUMBER(10);
  val_Org_Ref$ NUMBER(10);
  val_AccountIndex$ NUMBER(10);
  val_SubKD$ NUMBER(10);
  val_RegionCLS$ NUMBER(10);
  val_GosNI$ NUMBER(10);
  val_IncAccount$ NUMBER(10);
  val_BudgetRef$ NUMBER(10);
  val_MEANSTYPE$ NUMBER(10);
  val_FACIALACC_CLS$ NUMBER(10);
  val_TransfertCls$ NUMBER(10);
  CapAcceptDate$ NUMBER;
  CapReestrNumber$ VARCHAR2(20);
  CapProgIndex$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_INCOMES32_BI)
-- Version 10.00.00.2
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN 
    select g_shared.nextval into new$id from dual;
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN 
    new$FACIALACC_CLS := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN 
    new$Gosni := 0;
  END IF;
  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN 
    new$DocBase := 0;
  END IF;
  /* 3 -    */
  IF (new$KD IS NULL) THEN 
    new$KD := 0;
  END IF;
  IF (new$ProgIndex IS NULL) THEN 
    new$ProgIndex := 3;
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN 
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN 
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN 
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN 
    new$AccountIndex := 0;
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN 
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN 
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN 
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN 
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN 
    new$DirectionCLS := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  IF (new$FinType IS NULL) THEN  
    new$FinType := 0;
  END IF;
  /*   .        */
  IF (new$IFS IS NULL) THEN 
    new$IFS := 0;
  END IF;
  IF (new$IFS_CORR IS NULL) THEN 
    new$Ifs_Corr := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
   
  /*  ,    */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0)) THEN
    BEGIN
      SELECT qt.BudgetRef      INTO new$BudgetRef FROM QuotesTitle qt
      WHERE qt.Id = new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    0,     */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0)) THEN
    BEGIN
      SELECT fa.BudgetRef      INTO new$BudgetRef FROM FacialAcc_Cls fa
      WHERE fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    0,    */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0))
  THEN 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
   
  IF (new$ProgIndex = 45) 
  THEN 
    IF (new$IncAccount IS NULL) THEN
      GetDefDFAccRefForBudget(new$BudgetRef,new$IncAccount);
    END IF;
    BEGIN

      /*     */
      SELECT qt.ProgIndex, qt.AcceptDate, qt.IncAccount, qt.ReestrNumber 
      INTO CapProgIndex$, CapAcceptDate$, new$IncAccount, CapReestrNumber$       FROM QuotesTitle qt
      WHERE 
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*           / */
    /*  /   after insert */
    IF (CapProgIndex$ <> 145) THEN 
      new$iDate := CapAcceptDate$;
    END IF;
    IF ((CapProgIndex$ = 145)AND (NOT ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0)OR (new$Credit<0)))) )
    THEN 
      new$Idate := CapAcceptDate$;      
    END IF;
    /*   -    () */
    IF ((CapProgIndex$ = 45) AND (CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN 
      /*        , *//*    */            
                  
      new$FederalFundsRef := new$ID;
      /* if-then */  
    END IF;/* if-then*/
  END IF;
  BEGIN
    /*     \*/
    SELECT org.Org_Type   INTO new$FAOrgType FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$FacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BI_5 (TR_INCOMES_BI_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BI_9 (TR_INCOMES32_BI_VZ)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   IF (new$ProgIndex = 9) THEN
      /*   */
      GetIntConst (9, 1, new$IncAccount);

      BEGIN
        /*      */
        SELECT ACCEPTDATE, BUDGETREF
          INTO new$IDate, new$BudgetRef
          FROM VZ_OFFSET
         WHERE ID = new$RecordIndex;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_INCOMES32_BI_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   BEGIN
      SELECT Inn
        INTO new$Inn
        FROM Organizations o
       WHERE (o.ID = new$Org_Ref);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

/*  .    ,    */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      BEGIN
         SELECT c.BudgetRef
           INTO new$budgetref
           FROM QuotesTitle c
          WHERE c.ID = NEW$RecordIndex;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

   /*  .  ,     */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      BEGIN
         SELECT fa.BudgetRef
           INTO new$budgetref
           FROM FacialAcc_Cls fa
          WHERE fa.ID = NEW$FacialAcc_Cls;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

   /*  ,    */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      GetIntConst (-1, 3, new$budgetref);
   END IF;

-- - - - - - - - - - - - -
-- BI_30 (TR_INCOMES32_BI_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then 
    BEGIN
      select q.BuildDate 
      into 
      new$DocDate        from QuotesTitle q 
      where q.id = new$RecordIndex 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_70 (TR_INCOMES32_BI_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
               */
         new$FederalFundsRef := new$ID;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_INCOMES32_BI_100)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if ((not (newKD$  like unkKD$)) and
    (not (newKD$  like unkVKD$))) then
      /*   (    
            ) ,  
         ,   */

      /*       */
      if (new$Debit <> 0) then 
        RaiseException('ex_UnknownRedirect');
      END IF;
      BEGIN

        /*      */
        select KD,DocCount,DocType,
        Org_Ref,AccountIndex,SubKD,RegionCLS,GosNI,
        IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,
        TransfertCls
        into
        idKD$,
        val_DocCount$,
        val_DocType$,
        val_Org_Ref$,
        val_AccountIndex$,
        val_SubKD$,
        val_RegionCLS$,
        val_GosNI$,
        val_IncAccount$,
        val_BudgetRef$,
        val_MEANSTYPE$  ,
        val_FACIALACC_CLS$,
        val_TransfertCls$         from incomes32 where id=new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
         
      if (not idKD$ is null) then
        insert into
        /* KD=   (      )
              Debit=0
              redit=-new.credit
              ProgIndex=43
              RecordIndex=new.id
              id    Incomes32*/
        Incomes32(CreaterUser, DocNum,DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS, TransfertCls)
        Values(new$CreaterUser, new$DocNum, val_DocCount$, new$iDate, new$DOCDATE, 0, -new$Credit, val_DocType$,
        val_Org_Ref$, val_AccountIndex$, idKD$, val_SubKD$, val_RegionCLS$, val_GosNI$,
        43,new$Id, val_IncAccount$, val_BudgetRef$, new$Note,val_MEANSTYPE$,val_FACIALACC_CLS$,val_TransfertCls$);
        
      END IF; 
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_110 (TR_INCOMES32_BI_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       /*       ClsType */
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                /*  -  */
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_INCOMES32_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update QuotesTitle set
  DocChangeDate = new$UpdateDate,
  RVersion = -1
  where id = new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_INCOMES32 (
    ID,
    DOCNUMBER,
    DOCCOUNT,
    IDATE,
    DEBIT,
    CREDIT,
    DOCTYPE,
    INN,
    ORG_REF,
    ACCOUNTINDEX,
    KD,
    SUBKD,
    REGIONCLS,
    GOSNI,
    INCACCOUNT,
    PROGINDEX,
    RECORDINDEX,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    NOTE,
    RECORDINDEX2,
    ELNUM,
    NOTEEX,
    BUHPAYMENTCLS,
    ACCOUNTREF,
    ELPACKETNUM,
    FACIALACC_CLS,
    NDS,
    MEANSTYPE,
    RECORDDATE,
    TOTALREF,
    REQUESTSINDEX,
    KVSR,
    TAXNOTE,
    DOCNUM,
    REALPAYERORG_REF,
    DOCDATE,
    DOCBASE,
    FACT,
    RVERSION,
    KFSR,
    KESR,
    KVR,
    KCSR,
    SUMCOMPLETE,
    ELDOCREF,
    REQUESTSINDEX2,
    FEDERALFUNDSREF,
    BUHOPERATIONCLS,
    IFS,
    IFS_CORR,
    CLSTYPE,
    NDSNOTE,
    DOGNUM,
    SENDERID,
    SENDERRECORDID,
    OKATO,
    ADDOKATO,
    REJECTCLS,
    FUNDSSOURCE,
    DIRECTIONCLS,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    STIMATEID,
    TRANSFERTCLS,
    SUBSIDYCLS,
    FAORGTYPE,
    OKTMO,
    UINCODE,
    FINTYPE,
    INVESTOBJECT,
    CONTRACTCOSTSCLS,
    TARGETCLS,
    REJECTCAUSE
  ) VALUES (
    new$ID,
    new$DOCNUMBER,
    new$DOCCOUNT,
    new$IDATE,
    new$DEBIT,
    new$CREDIT,
    new$DOCTYPE,
    new$INN,
    new$ORG_REF,
    new$ACCOUNTINDEX,
    new$KD,
    new$SUBKD,
    new$REGIONCLS,
    new$GOSNI,
    new$INCACCOUNT,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$BUDGETREF,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$NOTE,
    new$RECORDINDEX2,
    new$ELNUM,
    new$NOTEEX,
    new$BUHPAYMENTCLS,
    new$ACCOUNTREF,
    new$ELPACKETNUM,
    new$FACIALACC_CLS,
    new$NDS,
    new$MEANSTYPE,
    new$RECORDDATE,
    new$TOTALREF,
    new$REQUESTSINDEX,
    new$KVSR,
    new$TAXNOTE,
    new$DOCNUM,
    new$REALPAYERORG_REF,
    new$DOCDATE,
    new$DOCBASE,
    new$FACT,
    new$RVERSION,
    new$KFSR,
    new$KESR,
    new$KVR,
    new$KCSR,
    new$SUMCOMPLETE,
    new$ELDOCREF,
    new$REQUESTSINDEX2,
    new$FEDERALFUNDSREF,
    new$BUHOPERATIONCLS,
    new$IFS,
    new$IFS_CORR,
    new$CLSTYPE,
    new$NDSNOTE,
    new$DOGNUM,
    new$SENDERID,
    new$SENDERRECORDID,
    new$OKATO,
    new$ADDOKATO,
    new$REJECTCLS,
    new$FUNDSSOURCE,
    new$DIRECTIONCLS,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$STIMATEID,
    new$TRANSFERTCLS,
    new$SUBSIDYCLS,
    new$FAORGTYPE,
    new$OKTMO,
    new$UINCODE,
    new$FINTYPE,
    new$INVESTOBJECT,
    new$CONTRACTCOSTSCLS,
    new$TARGETCLS,
    new$REJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_20 (T_INCOMES32_AI_20)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   --     
   if (new$ProgIndex <> 42) then
     BEGIN
       SELECT ProgIndex, DocNumber, AcceptDate
        INTO CapProgIndex, CapDocNumber, CapAcceptDate
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
     EXCEPTION
       WHEN NO_DATA_FOUND THEN NULL;
     END;
   end if;

   --   - ,  
   IF ((CapProgIndex = 145) or (new$ProgIndex=42)) THEN

      If ((new$ProgIndex=42) and (new$DocType between 1010 and 1019) and
         (new$Debit>0) and (new$DOCDATE is not null))
      then
        BEGIN
          select kd into Kd_Master
    From Incomes32 inc
          where inc.id = new$RecordIndex;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;

        if (Kd_Master = new$Kd) then
          CapAcceptDate := new$DOCDATE;
          CapProgIndex  := new$ProgIndex;
          CapDocNumber  := new$DocNum;
        end if;
      end if; --       (         )

      --             
      IF ((CapAcceptDate IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit > 0) OR (new$Credit < 0))) THEN
         --    ( RealPayerOrg_Ref(PayDoc32)=new$RealPayerOrg_Ref(Incomes32))
         INSERT INTO PayDoc32
            (BudgetRef, AccountRef, PayerAttrRef, InputDate,
             Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref, FACIALACC_CLS)
         VALUES (new$BudgetRef, new$AccountRef, new$IncAccount, CapAcceptDate,
             (new$Debit - new$Credit), new$Note, new$ProgIndex, new$id, CapDocNumber, new$TaxNote,
             new$RealPayerOrg_Ref,new$FACIALACC_CLS);
      -- (new$Debit - new$Credit) --- ..      ,    ,
      --             
      END IF;

   END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_INCOMES32_AI_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 161) AND (RecordID = NEW$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 10.00.00.2
-- - - - - - - - - - - - -

  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN 
    new$DocBase := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN 
    new$Gosni := 0;
  END IF;
  /* 3 -    */
  IF (new$ProgIndex IS NULL) THEN 
    new$ProgIndex := 3; 
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0; 
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN 
    new$FACIALACC_CLS := 0; 
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN 
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN 
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN 
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN 
    new$AccountIndex := 0; 
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN 
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN 
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN 
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN 
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN 
    new$DirectionCLS := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  IF (new$FinType IS NULL) THEN  
    new$FinType := 0;
  END IF;
  /*   .        */
  IF (new$IFS_CORR IS NULL) THEN 
    new$Ifs_Corr := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$Ifs := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  BEGIN

    /*     */
    /*   after   ,*/ 
    /*      */
    SELECT ProgIndex, AcceptDate, ReestrNumber
    INTO CapProgIndex1$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
    WHERE
    (qt.ID = new$RecordIndex)
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*              
           (  , , ) */
  /*   -    () */
  IF (CapProgIndex1$ = 45)
  THEN 
    IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN 
      /*        ,
                     */            
      new$FederalFundsRef := new$ID;
      /* if-then*/
    ELSE 
      new$FederalFundsRef := NULL;
      /* if-else*/  
    END IF;/* if (CapProgIndex=45) */
  END IF;
  /*     */
  IF (new$BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
      IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
        RaiseException('Ex_CantModufyBudget');
      END IF;
      IF (new$Progindex = 41) THEN
        SELECT COUNT(inc.id ) INTO CNT$1
        FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
        IF ((CNT$1<> 0)) THEN
          RaiseException('Ex_CantModufyBudget');
        END IF;   
      END IF;
    END IF;
  END IF;
  /*     \*/
  IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
  ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

  BEGIN
    SELECT Inn
     INTO new$Inn
     FROM Organizations o
    WHERE (o.ID = new$Org_Ref);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*      */
  IF (new$ProgIndex <> 42) THEN
    BEGIN
      SELECT ProgIndex, DocNumber, AcceptDate
      INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
      WHERE
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*   -  ,   */
  IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
  THEN 
    IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
    (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
    THEN 
      BEGIN
        SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
        WHERE inc.id = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (Kd_Master$ = new$Kd) THEN 
        CapAcceptDate$ := new$DOCDATE;
        CapProgIndex$  := new$ProgIndex;
        CapDocNumber$  := new$DocNum;
        /*  */        
      END IF;/*       (         )*/
    END IF;
    IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
    THEN 

      /*      */
      /* /      Incomes32, ..      ,     */

      /*     /   */
      SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
      INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
      ;
      /*            ,  .*/
      /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
                      ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
                     ) THEN
                    EXCEPTION EX_CANNOTUPDATENUMBER;*/
                 
                
      IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
      then
        if ((new$DocType <> :old.DocType )
        or (new$Debit <> :old.Debit )
        or (new$Credit <> :old.Credit)
        or (new$org_ref <> :old.org_ref)
        or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
        or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
        )
        then
          RaiseException('EX_CANNOTUPDATENUMBER');
        END IF;
      END IF;
                


      /*           */
      IF (PayDocCount$ = 0)
      THEN 
        /*       */
        GetIntConst(11, 2,ConstPayQueue$);
        /*       */
        GetIntConst(11, 1,ConstSendBy$);

        /*    */
        INSERT INTO PayDoc32
        (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
        Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
        VALUES
        (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
        new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
        /* (new.Debit - new.Credit) --- ..      ,    ,
                                     */

        /* if-then */
      ELSE 
        /*     */
        IF (((new$AccountRef = :old.AccountRef) OR
        ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
        AND (new$IncAccount = :old.IncAccount)
        AND (new$BudgetRef = :old.BudgetRef)
        AND ((new$Note = :old.Note) OR
        ((new$Note IS NULL) AND (:old.Note IS NULL)))
        AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
        ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
        AND ((new$TaxNote = :old.TaxNote) OR
        ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
        )  THEN
          new$AccountRef := new$AccountRef;
                          
        ELSE

          UPDATE PayDoc32 pd
          SET
          pd.AccountRef = new$AccountRef,
          pd.PayerAttrRef = new$IncAccount,
          pd.AcceptorAttrRef = new$AccountRef,
          pd.TextNote = new$Note,
          pd.TaxNote = new$TaxNote,
          pd.BudgetRef = new$BudgetRef,
          pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
          pd.InputDate = CapAcceptDate$,
          pd.SourceDocNumber = CapDocNumber$,
          pd.FACIALACC_CLS = new$FACIALACC_CLS
          WHERE
          (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
        END IF;
        IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
        OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
        THEN  
          IF (Divided$ > 0)
          THEN
            /*  ,      */
            RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
          ELSE
            UPDATE PayDoc32 pd
            SET
            pd.Credit = new$Debit - new$Credit
            WHERE
            (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
          END IF;/* if-then*/            
        END IF;/* if-else*/
      END IF;
      /*     / */
      /*   :     ,     */
      /*  ,     */
      SELECT MAX(pd.AcceptDate)
      INTO Date_Pd$           FROM PayDoc32 pd
      WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
      ;
      new$Idate := Date_Pd$;
      /* if-then*/
    ELSE 
      /*       
                          -
                    . */
      DELETE FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex = new$ProgIndex)
      AND (pd.RecordIndex = new$id);
      /* if-else*/  
    END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then 
    BEGIN
      select q.BuildDate 
      into 
      new$DocDate        from QuotesTitle q 
      where q.id = new$RecordIndex 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
            */
         new$FederalFundsRef := new$ID;
      ELSE
         new$FederalFundsRef := NULL;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN
      select KDValue   into oldKD$ from kd where Id=:old.kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN

      /*     */
      select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
      IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
      into
      idKD1$,
      val_DocCount1$,
      val_DocType1$,
      val_Org_Ref1$,
      val_AccountIndex1$,
      val_SubKD1$,
      val_RegionCLS1$,
      val_GosNI1$,
      val_IncAccount1$,
      val_BudgetRef1$,
      val_MEANSTYPE1$  , 
      val_FACIALACC_CLS1$,
      val_TransfertCls1$         from incomes32 where id=new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not idKD1$ is null) then
      if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
      (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
        /*   ,    */
        delete
        from Incomes32
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      (new$Debit<>0))
      /*       */
      then 
        RaiseException('ex_UnknownRedirect');
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
        /*   ,   ,   */
        insert into
        Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
        Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
        val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
        val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
        new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
      END IF;
      if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
      and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
        /*      ,   */
        update Incomes32
        set
        DocNum = new$DocNum,
        DocCount = val_DocCount1$,
        iDate = new$iDate,
        DOCDATE = new$DOCDATE,
        Debit = 0,
        Credit = -new$Credit,
        DocType = val_DocType1$,
        Org_Ref = val_Org_Ref1$,
        AccountIndex = val_AccountIndex1$,
        KD = idKD1$,
        SubKD = val_SubKD1$,
        RegionCLS = val_RegionCLS1$,
        GosNI = val_GosNI1$,
        ProgIndex = 43,
        RecordIndex = new$Id,
        IncAccount = val_IncAccount1$,
        BudgetRef = val_BudgetRef1$,
        Note = new$Note,
        MEANSTYPE = val_MEANSTYPE1$,
        FACIALACC_CLS = val_FACIALACC_CLS1$,
        TransfertCls = val_TransfertCls1$,
        RVersion = -1
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
         
      END IF; 
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 41)    /*   () */
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    /*       */
    FOR REC$1 IN (SELECT inc.id
     AS val_ID42    FROM Incomes32 inc
    LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
    WHERE (inc.ProgIndex =  42) and
    (inc.RecordIndex =  new$id) and
    (inc.debit = 0) and
    (not(kd.kdvalue like unkKD$)) and
    (not(kd.kdvalue like unkVKD$))
    )
    LOOP
      BEGIN
        /*       */
        select inc.id
        into val_ID431$         FROM Incomes32 inc
        WHERE (inc.ProgIndex =  43) and
        (inc.RecordIndex =  REC$1.val_ID42)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      /*     ,   Credit, ProgIndex, RecordIndex */
      update Incomes32
      set
      DocNum = new$DocNum,
      DocCount = new$DocCount,       
      DOCDATE = new$DOCDATE,
      Debit = 0,
      DocType = new$DocType,
      Org_Ref = new$Org_Ref,
      AccountIndex = new$AccountIndex,
      KD = new$Kd,
      SubKD = new$SubKD,
      RegionCLS = new$RegionCLS,
      GosNI = new$GosNI,
      IncAccount = new$IncAccount,
      BudgetRef = new$BudgetRef,
      Note = new$Note,
      MEANSTYPE = new$MEANSTYPE,
      FACIALACC_CLS = new$FACIALACC_CLS,
      FACT = new$FACT,
      TransfertCls = new$TransfertCls,
      DirectionCls = new$DirectionCls,
      rversion = -1
      where id = val_ID431$;

        
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       --       ClsType
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                --  - 
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      --   
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   IF (NEW$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (161, :OLD.ID, SYSDATE);
      DELETE FROM DelRecIndexes
        WHERE (TableID = 161) AND (RecordId = NEW$ID);
   END IF;

END;
/
-- CREATE TRIGGER tr_paydoc32_au_45
CREATE OR REPLACE TRIGGER TR_PAYDOC32_IU
  INSTEAD OF UPDATE
  ON PAYDOC32
  FOR EACH ROW
DECLARE
  new$ID PAYDOC32.ID%TYPE := :NEW.ID;
  new$INPUTDATE PAYDOC32.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$PRINTDATE PAYDOC32.PRINTDATE%TYPE := :NEW.PRINTDATE;
  new$ACCEPTDATE PAYDOC32.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PAYERATTRREF PAYDOC32.PAYERATTRREF%TYPE := :NEW.PAYERATTRREF;
  new$ACCEPTORATTRREF PAYDOC32.ACCEPTORATTRREF%TYPE := :NEW.ACCEPTORATTRREF;
  new$SENDBY PAYDOC32.SENDBY%TYPE := :NEW.SENDBY;
  new$SUMMA PAYDOC32.SUMMA%TYPE := :NEW.SUMMA;
  new$CURRENCY PAYDOC32.CURRENCY%TYPE := :NEW.CURRENCY;
  new$PAYDATE PAYDOC32.PAYDATE%TYPE := :NEW.PAYDATE;
  new$PAYQUEUE PAYDOC32.PAYQUEUE%TYPE := :NEW.PAYQUEUE;
  new$TEXTNOTE PAYDOC32.TEXTNOTE%TYPE := :NEW.TEXTNOTE;
  new$PROGINDEX PAYDOC32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX PAYDOC32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER PAYDOC32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYDOC32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER PAYDOC32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE PAYDOC32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$SOURCEDOCNUMBER PAYDOC32.SOURCEDOCNUMBER%TYPE := :NEW.SOURCEDOCNUMBER;
  new$CHILDCOUNT PAYDOC32.CHILDCOUNT%TYPE := :NEW.CHILDCOUNT;
  new$FACIALACC_CLS PAYDOC32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$ACCOUNTREF PAYDOC32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$DOCTYPE PAYDOC32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SOURCEFACIALACC_CLS PAYDOC32.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$PARENTINDEX PAYDOC32.PARENTINDEX%TYPE := :NEW.PARENTINDEX;
  new$ANUMBER PAYDOC32.ANUMBER%TYPE := :NEW.ANUMBER;
  new$TAXNOTE PAYDOC32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$REJECT_CLS PAYDOC32.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REALPAYERORG_REF PAYDOC32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$ISDIVIDE PAYDOC32.ISDIVIDE%TYPE := :NEW.ISDIVIDE;
  new$CURSUM PAYDOC32.CURSUM%TYPE := :NEW.CURSUM;
  new$CREDIT PAYDOC32.CREDIT%TYPE := :NEW.CREDIT;
  new$DEBIT PAYDOC32.DEBIT%TYPE := :NEW.DEBIT;
  new$RVERSION PAYDOC32.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYDOC32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MEANSTYPE PAYDOC32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$PAYMENTCONDITION PAYDOC32.PAYMENTCONDITION%TYPE := :NEW.PAYMENTCONDITION;
  new$BUDGETREF PAYDOC32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$TRANSFERTCLS PAYDOC32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$REJECTCAUSE PAYDOC32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  parentinputdate NUMBER;
  cnt$ NUMBER (10);
  Dummy$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (T_PAYDOC32_BU_0)
-- Last update 15.09.2005
-- - - - - - - - - - - - -

   IF (new$DocType IS NULL) THEN new$DocType := 1010; END IF;
   IF (new$SourceFacialAcc_cls IS NULL) THEN new$SourceFacialAcc_cls := 0; END IF;
   IF (new$ProgIndex IS NULL) THEN new$ProgIndex := 11; END IF;
   IF (new$Currency IS NULL) THEN new$Currency := 2; END IF;
   IF (new$Summa IS NULL) THEN new$Summa := 0; END IF;
   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;
   IF (new$Debit IS NULL) THEN new$Debit := 0; END IF;
   IF (new$CurSum IS NULL) THEN new$CurSum := 0; END IF;

   IF (new$BuhOperationCLS IS NULL) THEN
      GetIntConst (60, 15, new$BuhOperationCLS);
   END IF;

   IF (new$MeansType IS NULL) THEN new$MeansType := 0; END IF;

   --  ,   ,     .
   IF (   (:OLD.AcceptDate IS NOT NULL)
       OR (:OLD.ANumber IS NOT NULL)
       OR (:OLD.ParentIndex IS NOT NULL)
      ) THEN
      IF (
             --   , , , .  
             --   ,    
             --    
             (new$AcceptorAttrRef <> :OLD.AcceptorAttrRef)
          OR (new$PayerAttrRef <> :OLD.PayerAttrRef)
          OR ((new$Summa - :OLD.Summa) > 0.001)
          OR ((new$Summa - :OLD.Summa) < -0.001)
          OR ((new$Credit - :OLD.Credit) > 0.001)
          OR ((new$Credit - :OLD.Credit) < -0.001)
          OR ((new$Debit - :OLD.Debit) > 0.001)
          OR ((new$Debit - :OLD.Debit) < -0.001)
         ) THEN
         IF (    (:OLD.ANumber IS NOT NULL)
             AND (NOT (   (new$ParentIndex <> :OLD.ParentIndex)
                       OR (    (new$ParentIndex IS NULL)
                           AND (:OLD.ParentIndex IS NOT NULL)
                          )
                       OR (    (new$ParentIndex IS NOT NULL)
                           AND (:OLD.ParentIndex IS NULL)
                          )
                      )
                 )
            ) THEN
            RaiseException ('EX_CANNOTUPDATENUMBER');
         ELSIF (:OLD.AcceptDate IS NOT NULL) THEN
            RaiseException ('EX_CANNOTUPDATEACCEPT');
         END IF;
      END IF;

      --     ,    
      --    
      IF ((new$InputDate <> :OLD.InputDate) AND (new$ParentIndex IS NOT NULL)
         ) THEN
         BEGIN
            SELECT InputDate
              INTO ParentInputDate
              FROM PayDoc32
             WHERE ID = new$parentindex;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               ParentInputDate := NULL;
         END;

         IF (ParentInputDate <> new$InputDate) THEN
            RaiseException ('EX_CANNOTUPDATECHILDDOC');
         END IF;
      END IF;
   END IF;

   --      ,
   --  ,     
   IF (    (new$ChildCount IS NOT NULL)
       AND (   (new$Reject_Cls <> :OLD.Reject_Cls)
            OR ((:OLD.Reject_Cls IS NULL) AND (new$Reject_Cls IS NOT NULL))
            OR ((:OLD.Reject_Cls IS NOT NULL) AND (new$Reject_Cls IS NULL))
           )
      ) THEN
      UPDATE PayDoc32
         SET Reject_Cls = new$Reject_Cls
       WHERE (ParentIndex = new$ID) AND (ID <> new$ID);
   END IF;

-- - - - - - - - - - - - -
-- BU_1 (TR_PAYDOC32_BU_1)
-- Last update 19.09.2005
-- - - - - - - - - - - - -

   IF ((new$acceptorattrref <> new$acceptorattrref) AND (new$progindex <> 11)
      ) THEN
      SELECT org_accdefaults.paytype, org_accdefaults.payqueue
        INTO new$sendby, new$payqueue
        FROM org_accdefaults, org_accounts
       WHERE (org_accounts.ID = new$acceptorattrref)
         AND (org_accounts.accdefault = org_accdefaults.ID);

      IF (new$sendby IS NULL) THEN
         getintconst (11, 1, new$sendby);
      END IF;

      IF (new$payqueue IS NULL) THEN
         getintconst (11, 2, new$payqueue);
      END IF;
   END IF;

   IF (new$SendBy IS NULL) THEN new$SendBy := 2; END IF;
   IF (new$PayQueue IS NULL) THEN new$PayQueue := 5; END IF;
   IF (new$accountref IS NULL) THEN new$accountref := new$acceptorattrref; END IF;
   IF (new$acceptorattrref IS NULL) THEN new$acceptorattrref := new$accountref; END IF;
   IF (new$facialacc_cls IS NULL) THEN new$facialacc_cls := 0; END IF;

-- - - - - - - - - - - - -
-- BU_2 (TR_PAYDOC32_BU_2)
-- Create 14.09.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   --     ,  ,  ,  ,
   --         
   IF ((:OLD.childcount IS NOT NULL) AND (:OLD.childcount <> 0)) THEN
      IF (   (   ((new$acceptdate IS NULL) AND (:OLD.acceptdate IS NOT NULL)
                 )
              OR ((new$acceptdate IS NOT NULL) AND (:OLD.acceptdate IS NULL)
                 )
              OR (new$acceptdate <> :OLD.acceptdate)
             )
          OR (   ((new$payqueue IS NULL) AND (:OLD.payqueue IS NOT NULL))
              OR ((new$payqueue IS NOT NULL) AND (:OLD.payqueue IS NULL))
              OR (new$payqueue <> :OLD.payqueue)
             )
          OR (   ((new$printdate IS NULL) AND (:OLD.printdate IS NOT NULL))
              OR ((new$printdate IS NOT NULL) AND (:OLD.printdate IS NULL))
              OR (new$printdate <> :OLD.printdate)
             )
          OR (   ((new$sendby IS NULL) AND (:OLD.sendby IS NOT NULL))
              OR ((new$sendby IS NOT NULL) AND (:OLD.sendby IS NULL))
              OR (new$sendby <> :OLD.sendby)
             )
          OR (   ((new$paydate IS NULL) AND (:OLD.paydate IS NOT NULL))
              OR ((new$paydate IS NOT NULL) AND (:OLD.paydate IS NULL))
              OR (new$paydate <> :OLD.paydate)
             )
          OR (   ((new$anumber IS NULL) AND (:OLD.anumber IS NOT NULL))
              OR ((new$anumber IS NOT NULL) AND (:OLD.anumber IS NULL))
              OR (new$anumber <> :OLD.anumber)
             )
         ) THEN
         UPDATE paydoc32
            SET acceptdate = new$acceptdate,
                payqueue = new$payqueue,
                printdate = new$printdate,
                sendby = new$sendby,
                paydate = new$paydate,
                anumber = new$anumber
          WHERE parentindex = :OLD.ID;
      END IF;
   END IF;

   --      ,
   --  ,     
   IF (    (new$childcount IS NOT NULL)
       AND (   (new$reject_cls <> :OLD.reject_cls)
            OR ((:OLD.reject_cls IS NULL) AND (new$reject_cls IS NOT NULL))
            OR ((:OLD.reject_cls IS NOT NULL) AND (new$reject_cls IS NULL))
           )
      ) THEN
      UPDATE paydoc32
         SET reject_cls = new$reject_cls
       WHERE (parentindex = new$ID) AND (ID <> new$ID);
   END IF;

-- - - - - - - - - - - - -
-- BU_3 (TR_PAYDOC32_BU_3)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   SELECT COUNT (ID)
     INTO cnt$
     FROM paydocexchange
    WHERE (paydocref = :OLD.ID) AND (status <> 0);

   IF (cnt$ > 0) THEN
      IF (   (new$ANUMBER <> :OLD.ANUMBER)
          OR ((new$ANUMBER IS NULL) AND (NOT :OLD.ANUMBER IS NULL))
          OR ((:OLD.ANUMBER IS NULL) AND (NOT new$ANUMBER IS NULL))
          OR (new$INPUTDATE <> :OLD.INPUTDATE)
          OR ((new$INPUTDATE IS NULL) AND (NOT :OLD.INPUTDATE IS NULL))
          OR ((:OLD.INPUTDATE IS NULL) AND (NOT new$INPUTDATE IS NULL))
          OR (new$PRINTDATE <> :OLD.PRINTDATE)
          OR ((new$PRINTDATE IS NULL) AND (NOT :OLD.PRINTDATE IS NULL))
          OR ((:OLD.PRINTDATE IS NULL) AND (NOT new$PRINTDATE IS NULL))
          OR (new$PAYERATTRREF <> :OLD.PAYERATTRREF)
          OR (new$ACCEPTORATTRREF <> :OLD.ACCEPTORATTRREF)
          OR (new$SENDBY <> :OLD.SENDBY)
          OR (new$SUMMA <> :OLD.SUMMA)
          OR (new$PAYDATE <> :OLD.PAYDATE)
          OR ((new$PAYDATE IS NULL) AND (NOT :OLD.PAYDATE IS NULL))
          OR ((:OLD.PAYDATE IS NULL) AND (NOT new$PAYDATE IS NULL))
          OR (new$PAYQUEUE <> :OLD.PAYQUEUE)
          OR ((new$PAYQUEUE IS NULL) AND (NOT :OLD.PAYQUEUE IS NULL))
          OR ((:OLD.PAYQUEUE IS NULL) AND (NOT new$PAYQUEUE IS NULL))
          OR (new$TEXTNOTE <> :OLD.TEXTNOTE)
          OR ((new$TEXTNOTE IS NULL) AND (NOT :OLD.TEXTNOTE IS NULL))
          OR ((:OLD.TEXTNOTE IS NULL) AND (NOT new$TEXTNOTE IS NULL))
          OR (new$SOURCEDOCNUMBER <> :OLD.SOURCEDOCNUMBER)
          OR (    (new$SOURCEDOCNUMBER IS NULL)
              AND (NOT :OLD.SOURCEDOCNUMBER IS NULL)
             )
          OR (    (:OLD.SOURCEDOCNUMBER IS NULL)
              AND (NOT new$SOURCEDOCNUMBER IS NULL)
             )
          OR (new$DOCTYPE <> :OLD.DOCTYPE)
          OR (new$TAXNOTE <> :OLD.TAXNOTE)
          OR ((new$TAXNOTE IS NULL) AND (NOT :OLD.TAXNOTE IS NULL))
          OR ((:OLD.TAXNOTE IS NULL) AND (NOT new$TAXNOTE IS NULL))
         ) THEN
         RaiseException ('EX_CANNOTCHANGESENDED');
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_12 (TR_PAYDOC32_BU_12)
-- Create 12.08.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   --            
   IF (new$debit * new$credit <> 0) THEN
      RaiseException ('EX_FAILDEBETCREDITVALUE');
   END IF;

   IF (new$summa = :OLD.summa) THEN
      new$summa := new$credit - new$debit;
   ELSIF (new$summa > 0) THEN
      new$credit := new$summa;
      new$debit := 0;
   ELSE
      new$credit := 0;
      new$debit := -new$summa;
   END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_PAYDOC32_BU_700)
-- Create 17.09.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_PAYDOC32 SET
    ID = new$ID,
    INPUTDATE = new$INPUTDATE,
    PRINTDATE = new$PRINTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    PAYERATTRREF = new$PAYERATTRREF,
    ACCEPTORATTRREF = new$ACCEPTORATTRREF,
    SENDBY = new$SENDBY,
    SUMMA = new$SUMMA,
    CURRENCY = new$CURRENCY,
    PAYDATE = new$PAYDATE,
    PAYQUEUE = new$PAYQUEUE,
    TEXTNOTE = new$TEXTNOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    SOURCEDOCNUMBER = new$SOURCEDOCNUMBER,
    CHILDCOUNT = new$CHILDCOUNT,
    FACIALACC_CLS = new$FACIALACC_CLS,
    ACCOUNTREF = new$ACCOUNTREF,
    DOCTYPE = new$DOCTYPE,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    PARENTINDEX = new$PARENTINDEX,
    ANUMBER = new$ANUMBER,
    TAXNOTE = new$TAXNOTE,
    REJECT_CLS = new$REJECT_CLS,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    ISDIVIDE = new$ISDIVIDE,
    CURSUM = new$CURSUM,
    CREDIT = new$CREDIT,
    DEBIT = new$DEBIT,
    RVERSION = new$RVERSION,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    MEANSTYPE = new$MEANSTYPE,
    PAYMENTCONDITION = new$PAYMENTCONDITION,
    BUDGETREF = new$BUDGETREF,
    TRANSFERTCLS = new$TRANSFERTCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_45 (tr_paydoc32_au_45)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF ((new$ProgIndex = 45) OR (new$ProgIndex = 42))
  THEN 
    /*    else, ..    null  UNKNOWN  then   */
    IF (  (new$AcceptDate = :old.AcceptDate) 
    OR
    ( (new$AcceptDate IS NULL) AND (:old.AcceptDate IS NULL) ) 
    ) 
    THEN 
      Dummy$ := 0;
         
    ELSE
      UPDATE Incomes32 i
      SET
      i.IDate = new$AcceptDate
      WHERE
      i.ID = new$RecordIndex;
    END IF;
    /*    ,       incomes32*/
    if ( (new$reject_cls = :old.reject_cls)
    OR
    ((new$reject_cls IS NULL) AND (:old.reject_cls IS NULL))
    )  THEN
      Dummy$ := 0;
       
    ELSE
      UPDATE incomes32 inc
      SET inc.rejectcls = new$reject_cls
      WHERE (inc.id = new$recordindex);
    END IF;
    if ( (new$rejectcause = :old.rejectcause)
    OR
    ((new$rejectcause IS NULL) AND (:old.rejectcause IS NULL))
    ) THEN
      Dummy$ := 0;
       
    ELSE
      UPDATE incomes32 inc
      SET inc.rejectcause = new$rejectcause
      WHERE (inc.id = new$recordindex);

       
    END IF;/* if-then */
  END IF;

-- - - - - - - - - - - - -
-- AU_50 (T_PAYDOC32_AU_50)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (    (new$inputdate <> :OLD.inputdate)
       AND (new$acceptdate IS NULL)
       AND (new$anumber IS NULL)
       AND (new$childcount IS NOT NULL)
      ) THEN
      --      
      UPDATE paydoc32
         SET inputdate = new$inputdate
       WHERE (parentindex = new$ID) AND (ID <> new$ID);
   END IF;

-- - - - - - - - - - - - -
-- AU_130 (TR_PAYDOC32_AU_130)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

   IF (new$progindex IN (131, 132, 383, 384, 385, 386))
                                                       --   
   THEN
      IF (   (new$acceptdate = :OLD.acceptdate)
          OR ((new$acceptdate IS NULL) AND (:OLD.acceptdate IS NULL))
         ) THEN
         NULL;
      ELSE
         --     
         UPDATE debt
            SET recorddate = new$acceptdate
          WHERE (ID = new$recordindex) AND (recorddate IS NULL);
      END IF;                                                       -- if-then
   END IF;                                                          -- if-then

   IF (new$progindex IN (121, 122, 133, 341, 411))
                                                  --  
   THEN
      IF (   (new$acceptdate = :OLD.acceptdate)
          OR ((new$acceptdate IS NULL) AND (:OLD.acceptdate IS NULL))
         ) THEN
         NULL;
      ELSE
         UPDATE findocdetail
            SET recorddate = new$acceptdate
          WHERE (ID = new$recordindex) AND (recorddate IS NULL);
      END IF;                                                       -- if-then
   END IF;

END;
/
ALTER TRIGGER TR_INCOMES32_BU_500 ENABLE
/
commit work 
/
ALTER TRIGGER TR_TENDERCAPTION_BU_500 DISABLE
/
ALTER TABLE TB_TENDERCAPTION ADD (
  TempRejectCause VARCHAR2(255)
)
/

CREATE OR REPLACE VIEW TENDERCAPTION (
  ID,
  BUDGETREF,
  FACIALACCCLS,
  MULTIPURPOSE,
  DOCUMENTDATE,
  ACCEPTDATE,
  PERIOD,
  ACCEPTSUMMA,
  SALETYPE,
  REJECTCLS,
  REJECTCAUSE,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  DOCSTATEREF,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  LASTADJUSTMENT,
  LASTACCEPTED,
  ADJUSTMENTREF,
  ACCEPTED,
  EXPORTDATE,
  YEARACCEPTSUMMA,
  TENDEROPTION,
  TENDERTARGET,
  RVERSION,
  ALLOWANCE,
  REFINEMENTCAUSE,
  PREFERENCE,
  PREFERENCESIZE,
  SECURITY,
  UNKNOWNAMOUNT,
  PERIODYEAR,
  SUPPORTUNDERTAKER,
  AYEAR,
  REWORKCAUSE,
  NOTE,
  REALID,
  INNERNUMBER,
  ADJUSTMENTNUMBER,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  PROTOCOLREASON,
  PROGINDEX,
  DOCNUMBER,
  SECURITYTSIZE,
  SECURITYASIZE,
  AVANSSIZE,
  PREFERENCECRIPPLE,
  PREFERENCERUSPRODUCT,
  PREFERENCEPRISON,
  AGREEMENTEXECUTIONDATE,
  PURCHASECODE,
  PURCHASESOCIALNKO,
  AVERSION,
  PARENTREF,
  TEMPREJECTCAUSE)
AS
  SELECT
    ID,
    BUDGETREF,
    FACIALACCCLS,
    MULTIPURPOSE,
    DOCUMENTDATE,
    ACCEPTDATE,
    PERIOD,
    ACCEPTSUMMA,
    SALETYPE,
    REJECTCLS,
    REJECTCAUSE,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DOCSTATEREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    LASTADJUSTMENT,
    LASTACCEPTED,
    ADJUSTMENTREF,
    ACCEPTED,
    EXPORTDATE,
    YEARACCEPTSUMMA,
    TENDEROPTION,
    TENDERTARGET,
    RVERSION,
    ALLOWANCE,
    REFINEMENTCAUSE,
    PREFERENCE,
    PREFERENCESIZE,
    SECURITY,
    UNKNOWNAMOUNT,
    PERIODYEAR,
    SUPPORTUNDERTAKER,
    AYEAR,
    REWORKCAUSE,
    NOTE,
    REALID,
    INNERNUMBER,
    ADJUSTMENTNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    PROTOCOLREASON,
    PROGINDEX,
    DOCNUMBER,
    SECURITYTSIZE,
    SECURITYASIZE,
    AVANSSIZE,
    PREFERENCECRIPPLE,
    PREFERENCERUSPRODUCT,
    PREFERENCEPRISON,
    AGREEMENTEXECUTIONDATE,
    PURCHASECODE,
    PURCHASESOCIALNKO,
    AVERSION,
    PARENTREF,
    TEMPREJECTCAUSE
  FROM TB_TENDERCAPTION
/

CREATE OR REPLACE TRIGGER TR_TENDERCAPTION_ID
  INSTEAD OF DELETE
  ON TENDERCAPTION
  FOR EACH ROW
DECLARE
  cnt$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_TENDERCAPTION_BD)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   5.1 */
  select count(ID) into cnt$ from TenderCaption where (AdjustmentRef = :old.ID) ;
  /*    ,    */
  if (cnt$ = 0) then
    delete from TenderSupDocument where (RecordIndex = :old.ID);
    delete from TenderYardsticks where (RecordIndex = :old.ID);
    delete from TenderSourceOrg where (RecordIndex = :old.ID);
    delete from TenderContacts where (RecordIndex = :old.ID);
    delete from TenderSupplements where (RecordIndex = :old.ID);
    delete from TenderProduct where (RecordIndex = :old.ID);
    delete from TenderLot where (RecordIndex = :old.ID);

  else
    RaiseException('EX_Ten_CantDelAdjustmented');
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_TENDERCAPTION
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_0 (TR_TenderCaption_AD)
-- Last update 06.08.2010
-- - - - - - - - - - - - -

  delete from TENDERPRODUCT where (RecordIndex = :old.ID);
  delete from TenderSourceOrg where (RecordIndex = :old.ID);

-- - - - - - - - - - - - -
-- AD_10 (TR_TENDERCAPTION_AD_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/
  /*   LastAdjustment     */
  if ((:old.AdjustmentNumber > 0) and (:old.LastAdjustment = 1)) then
    update TenderCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;
  /*   LastAccepted     */
  if ((:old.AdjustmentNumber > 0) and (:old.LastAccepted = 1)) then
    update TenderCaption set
    LastAccepted = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AD_200 (TR_TENDERCAPTION_AD_200)
-- Create 03.12.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  /*         */
  delete from StateJumpHistory where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_TENDERCAPTION_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordId, DeleteDate, ProgIndex) values (139, :old.ID, SYSDATE, :old.ProgIndex);

END;
/

CREATE OR REPLACE TRIGGER TR_TENDERCAPTION_II
  INSTEAD OF INSERT
  ON TENDERCAPTION
  FOR EACH ROW
DECLARE
  new$ID TENDERCAPTION.ID%TYPE := :NEW.ID;
  new$BUDGETREF TENDERCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FACIALACCCLS TENDERCAPTION.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$MULTIPURPOSE TENDERCAPTION.MULTIPURPOSE%TYPE := :NEW.MULTIPURPOSE;
  new$DOCUMENTDATE TENDERCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE TENDERCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PERIOD TENDERCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$ACCEPTSUMMA TENDERCAPTION.ACCEPTSUMMA%TYPE := :NEW.ACCEPTSUMMA;
  new$SALETYPE TENDERCAPTION.SALETYPE%TYPE := :NEW.SALETYPE;
  new$REJECTCLS TENDERCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTCAUSE TENDERCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CRYPTOSTATUS TENDERCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID TENDERCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID TENDERCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCSTATEREF TENDERCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CREATERUSER TENDERCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TENDERCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE TENDERCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER TENDERCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$LASTADJUSTMENT TENDERCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED TENDERCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$ADJUSTMENTREF TENDERCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ACCEPTED TENDERCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$EXPORTDATE TENDERCAPTION.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$YEARACCEPTSUMMA TENDERCAPTION.YEARACCEPTSUMMA%TYPE := :NEW.YEARACCEPTSUMMA;
  new$TENDEROPTION TENDERCAPTION.TENDEROPTION%TYPE := :NEW.TENDEROPTION;
  new$TENDERTARGET TENDERCAPTION.TENDERTARGET%TYPE := :NEW.TENDERTARGET;
  new$RVERSION TENDERCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$ALLOWANCE TENDERCAPTION.ALLOWANCE%TYPE := :NEW.ALLOWANCE;
  new$REFINEMENTCAUSE TENDERCAPTION.REFINEMENTCAUSE%TYPE := :NEW.REFINEMENTCAUSE;
  new$PREFERENCE TENDERCAPTION.PREFERENCE%TYPE := :NEW.PREFERENCE;
  new$PREFERENCESIZE TENDERCAPTION.PREFERENCESIZE%TYPE := :NEW.PREFERENCESIZE;
  new$SECURITY TENDERCAPTION.SECURITY%TYPE := :NEW.SECURITY;
  new$UNKNOWNAMOUNT TENDERCAPTION.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PERIODYEAR TENDERCAPTION.PERIODYEAR%TYPE := :NEW.PERIODYEAR;
  new$SUPPORTUNDERTAKER TENDERCAPTION.SUPPORTUNDERTAKER%TYPE := :NEW.SUPPORTUNDERTAKER;
  new$AYEAR TENDERCAPTION.AYEAR%TYPE := :NEW.AYEAR;
  new$REWORKCAUSE TENDERCAPTION.REWORKCAUSE%TYPE := :NEW.REWORKCAUSE;
  new$NOTE TENDERCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$REALID TENDERCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER TENDERCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTNUMBER TENDERCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$SENDERIDKEY TENDERCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY TENDERCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$PROTOCOLREASON TENDERCAPTION.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$PROGINDEX TENDERCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$DOCNUMBER TENDERCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SECURITYTSIZE TENDERCAPTION.SECURITYTSIZE%TYPE := :NEW.SECURITYTSIZE;
  new$SECURITYASIZE TENDERCAPTION.SECURITYASIZE%TYPE := :NEW.SECURITYASIZE;
  new$AVANSSIZE TENDERCAPTION.AVANSSIZE%TYPE := :NEW.AVANSSIZE;
  new$PREFERENCECRIPPLE TENDERCAPTION.PREFERENCECRIPPLE%TYPE := :NEW.PREFERENCECRIPPLE;
  new$PREFERENCERUSPRODUCT TENDERCAPTION.PREFERENCERUSPRODUCT%TYPE := :NEW.PREFERENCERUSPRODUCT;
  new$PREFERENCEPRISON TENDERCAPTION.PREFERENCEPRISON%TYPE := :NEW.PREFERENCEPRISON;
  new$AGREEMENTEXECUTIONDATE TENDERCAPTION.AGREEMENTEXECUTIONDATE%TYPE := :NEW.AGREEMENTEXECUTIONDATE;
  new$PURCHASECODE TENDERCAPTION.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$PURCHASESOCIALNKO TENDERCAPTION.PURCHASESOCIALNKO%TYPE := :NEW.PURCHASESOCIALNKO;
  new$AVERSION TENDERCAPTION.AVERSION%TYPE := :NEW.AVERSION;
  new$PARENTREF TENDERCAPTION.PARENTREF%TYPE := :NEW.PARENTREF;
  new$TEMPREJECTCAUSE TENDERCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  Tmp$ NUMBER(10);
  AdjID$ NUMBER(10);
  CurVal$ NUMBER(10);
  ParentProgIndex$ NUMBER(10);
  ParentInnerNumber$ NUMBER(10);
  AdjParentRef$ NUMBER(10);
  AdjParentInnerNumber$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_TENDERCAPTION_BI)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  /*         ( ) */
  if (new$ProgIndex = 230 and new$Multipurpose is null) then
    new$Multipurpose := 0;
  END IF;
  if (new$AcceptSumma is null) then
    new$AcceptSumma := 0;
  END IF;
  if (new$YearAcceptSumma is null) then
    new$YearAcceptSumma := 0;
  END IF;
  if (new$Allowance is null) then
    new$Allowance := 0;
  END IF;

  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    BEGIN
      select fa.BudgetRef       into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = new$FacialAccCls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    GetIntConst(-1,3,new$BudgetRef);
  END IF;

  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  if (new$SaleType is null) then
    new$SaleType := 0;
  END IF;
  if (new$TenderOption is null) then
    new$TenderOption := 0;
  END IF;
  if (new$InnerNumber is Null) then
    new$InnerNumber := GEN_ID('G_TenderInnerNumber',1);
  END IF;
  if (new$RefinementCause is Null) then
    new$RefinementCause := 0;
  END IF;
  if (new$Preference is Null) then
    new$Preference := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$SupportUndertaker is null) then
    new$SupportUndertaker := 0;
  END IF;
  if (new$PurchaseSocialNKO is null) then
    new$PurchaseSocialNKO := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_TENDERCAPTION_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_TENDERCAPTION_BI_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/

  /*    .*/
  if (new$InnerNumber is null) then
    RaiseException('EX_Ten_InnerNumsIsNull');
  END IF;

  /*    */
  select max(AdjustmentNumber)
  into Tmp$         from TenderCaption
  where (InnerNumber = new$InnerNumber)
  ;
  /*      ,   0*/
  if (Tmp$ is null) then
    new$AdjustmentNumber := 0;

  else
    new$AdjustmentNumber := Tmp$ + 1;
  END IF;

  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;

  else
    new$LastAdjustment := 1;
  END IF;

  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then
    new$LastAccepted := 1;

  else
    new$LastAccepted := 0;
  END IF;

  /*    */
  if (new$AdjustmentNumber > 0) then
    /*      -    */
    select count(ID), max(ID)
    into Tmp$, AdjID$             from TenderCaption
    where (InnerNumber = new$InnerNumber) and (LastAccepted = 1)
    ;
    /*   ,  */
    if (Tmp$ <> 1) then
      RaiseException('EX_Ten_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID)
    into Tmp$             from TenderCaption
    where (InnerNumber = new$InnerNumber) and (AcceptDate is null)
    ;
    if (Tmp$ > 0) then
      RaiseException('EX_Ten_AdjustDuplicate');
    END IF;
    /* ,    ,    */
    new$AdjustmentRef := AdjID$;

  else /*     */
    /*       (    )*/
    new$AdjustmentRef := null;

  END IF;

-- - - - - - - - - - - - -
-- BI_30 (TR_TENDERCAPTION_BI_30)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (new$ParentRef is not null) then
    BEGIN
      select ProgIndex, InnerNumber
      into ParentProgIndex$, ParentInnerNumber$     from TenderCaption
      where ID=new$ParentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /* :  /    / */
    if  ((new$ProgIndex=243 and ParentProgIndex$ <> 242)
    or (new$ProgIndex=241 and ParentProgIndex$ <> 240))
    then
      RaiseException('EX_IncorrectTenderParentRef');
    END IF;
    /* :       /     ( ,    ) */
    if (new$AdjustmentRef is not null) then
      BEGIN
        select ParentRef
        into AdjParentRef$       from TenderCaption
        where ID=new$AdjustmentRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (AdjParentRef$ is not null) then
        BEGIN
          select InnerNumber
          into AdjParentInnerNumber$         from TenderCaption
          where ID=AdjParentRef$

          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        if (AdjParentInnerNumber$ <> ParentInnerNumber$) then
          RaiseException('EX_IncorrectAdjTenderParentRef');
        END IF;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_40 (TR_TENDERCAPTION_BI_40)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$senderId is null) then
    new$senderIdKey := -1;

  else
    new$senderIdKey := new$senderId;
  END IF;
  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;

  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_50 (TR_TENDERCAPTION_BI_50)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  if (new$InnerNumber is not null) then
    CurVal$ := GEN_ID('G_TENDERINNERNUMBER',0);
    if (CurVal$ < new$InnerNumber) then
      CurVal$ := GEN_ID('G_TENDERINNERNUMBER',new$InnerNumber - CurVal$);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_TENDERCAPTION_BI_500)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- BI_600 (tendercaption_realid_bi_600)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_TENDERCAPTION (
    ID,
    BUDGETREF,
    FACIALACCCLS,
    MULTIPURPOSE,
    DOCUMENTDATE,
    ACCEPTDATE,
    PERIOD,
    ACCEPTSUMMA,
    SALETYPE,
    REJECTCLS,
    REJECTCAUSE,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DOCSTATEREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    LASTADJUSTMENT,
    LASTACCEPTED,
    ADJUSTMENTREF,
    ACCEPTED,
    EXPORTDATE,
    YEARACCEPTSUMMA,
    TENDEROPTION,
    TENDERTARGET,
    RVERSION,
    ALLOWANCE,
    REFINEMENTCAUSE,
    PREFERENCE,
    PREFERENCESIZE,
    SECURITY,
    UNKNOWNAMOUNT,
    PERIODYEAR,
    SUPPORTUNDERTAKER,
    AYEAR,
    REWORKCAUSE,
    NOTE,
    REALID,
    INNERNUMBER,
    ADJUSTMENTNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    PROTOCOLREASON,
    PROGINDEX,
    DOCNUMBER,
    SECURITYTSIZE,
    SECURITYASIZE,
    AVANSSIZE,
    PREFERENCECRIPPLE,
    PREFERENCERUSPRODUCT,
    PREFERENCEPRISON,
    AGREEMENTEXECUTIONDATE,
    PURCHASECODE,
    PURCHASESOCIALNKO,
    AVERSION,
    PARENTREF,
    TEMPREJECTCAUSE
  ) VALUES (
    new$ID,
    new$BUDGETREF,
    new$FACIALACCCLS,
    new$MULTIPURPOSE,
    new$DOCUMENTDATE,
    new$ACCEPTDATE,
    new$PERIOD,
    new$ACCEPTSUMMA,
    new$SALETYPE,
    new$REJECTCLS,
    new$REJECTCAUSE,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$DOCSTATEREF,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$LASTADJUSTMENT,
    new$LASTACCEPTED,
    new$ADJUSTMENTREF,
    new$ACCEPTED,
    new$EXPORTDATE,
    new$YEARACCEPTSUMMA,
    new$TENDEROPTION,
    new$TENDERTARGET,
    new$RVERSION,
    new$ALLOWANCE,
    new$REFINEMENTCAUSE,
    new$PREFERENCE,
    new$PREFERENCESIZE,
    new$SECURITY,
    new$UNKNOWNAMOUNT,
    new$PERIODYEAR,
    new$SUPPORTUNDERTAKER,
    new$AYEAR,
    new$REWORKCAUSE,
    new$NOTE,
    new$REALID,
    new$INNERNUMBER,
    new$ADJUSTMENTNUMBER,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$PROTOCOLREASON,
    new$PROGINDEX,
    new$DOCNUMBER,
    new$SECURITYTSIZE,
    new$SECURITYASIZE,
    new$AVANSSIZE,
    new$PREFERENCECRIPPLE,
    new$PREFERENCERUSPRODUCT,
    new$PREFERENCEPRISON,
    new$AGREEMENTEXECUTIONDATE,
    new$PURCHASECODE,
    new$PURCHASESOCIALNKO,
    new$AVERSION,
    new$PARENTREF,
    new$TEMPREJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_10 (TR_TENDERCAPTION_AI_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/
  /*      */
  if ((new$AdjustmentNumber > 0) and (new$LastAdjustment = 1)) then
    update TenderCaption set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);
    if (new$LastAccepted = 1) then
      update TenderCaption set
      LastAccepted = 0,
      RVersion = -1
      where (ID = new$AdjustmentRef);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_TENDERCAPTION_AI_500)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   DELETE FROM delrecindexes
         WHERE (tableid = 139) AND (recordid = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_TENDERCAPTION_IU
  INSTEAD OF UPDATE
  ON TENDERCAPTION
  FOR EACH ROW
DECLARE
  new$ID TENDERCAPTION.ID%TYPE := :NEW.ID;
  new$BUDGETREF TENDERCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FACIALACCCLS TENDERCAPTION.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$MULTIPURPOSE TENDERCAPTION.MULTIPURPOSE%TYPE := :NEW.MULTIPURPOSE;
  new$DOCUMENTDATE TENDERCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE TENDERCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PERIOD TENDERCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$ACCEPTSUMMA TENDERCAPTION.ACCEPTSUMMA%TYPE := :NEW.ACCEPTSUMMA;
  new$SALETYPE TENDERCAPTION.SALETYPE%TYPE := :NEW.SALETYPE;
  new$REJECTCLS TENDERCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTCAUSE TENDERCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CRYPTOSTATUS TENDERCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID TENDERCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID TENDERCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCSTATEREF TENDERCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CREATERUSER TENDERCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TENDERCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE TENDERCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER TENDERCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$LASTADJUSTMENT TENDERCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED TENDERCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$ADJUSTMENTREF TENDERCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ACCEPTED TENDERCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$EXPORTDATE TENDERCAPTION.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$YEARACCEPTSUMMA TENDERCAPTION.YEARACCEPTSUMMA%TYPE := :NEW.YEARACCEPTSUMMA;
  new$TENDEROPTION TENDERCAPTION.TENDEROPTION%TYPE := :NEW.TENDEROPTION;
  new$TENDERTARGET TENDERCAPTION.TENDERTARGET%TYPE := :NEW.TENDERTARGET;
  new$RVERSION TENDERCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$ALLOWANCE TENDERCAPTION.ALLOWANCE%TYPE := :NEW.ALLOWANCE;
  new$REFINEMENTCAUSE TENDERCAPTION.REFINEMENTCAUSE%TYPE := :NEW.REFINEMENTCAUSE;
  new$PREFERENCE TENDERCAPTION.PREFERENCE%TYPE := :NEW.PREFERENCE;
  new$PREFERENCESIZE TENDERCAPTION.PREFERENCESIZE%TYPE := :NEW.PREFERENCESIZE;
  new$SECURITY TENDERCAPTION.SECURITY%TYPE := :NEW.SECURITY;
  new$UNKNOWNAMOUNT TENDERCAPTION.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PERIODYEAR TENDERCAPTION.PERIODYEAR%TYPE := :NEW.PERIODYEAR;
  new$SUPPORTUNDERTAKER TENDERCAPTION.SUPPORTUNDERTAKER%TYPE := :NEW.SUPPORTUNDERTAKER;
  new$AYEAR TENDERCAPTION.AYEAR%TYPE := :NEW.AYEAR;
  new$REWORKCAUSE TENDERCAPTION.REWORKCAUSE%TYPE := :NEW.REWORKCAUSE;
  new$NOTE TENDERCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$REALID TENDERCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER TENDERCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTNUMBER TENDERCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$SENDERIDKEY TENDERCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY TENDERCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$PROTOCOLREASON TENDERCAPTION.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$PROGINDEX TENDERCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$DOCNUMBER TENDERCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SECURITYTSIZE TENDERCAPTION.SECURITYTSIZE%TYPE := :NEW.SECURITYTSIZE;
  new$SECURITYASIZE TENDERCAPTION.SECURITYASIZE%TYPE := :NEW.SECURITYASIZE;
  new$AVANSSIZE TENDERCAPTION.AVANSSIZE%TYPE := :NEW.AVANSSIZE;
  new$PREFERENCECRIPPLE TENDERCAPTION.PREFERENCECRIPPLE%TYPE := :NEW.PREFERENCECRIPPLE;
  new$PREFERENCERUSPRODUCT TENDERCAPTION.PREFERENCERUSPRODUCT%TYPE := :NEW.PREFERENCERUSPRODUCT;
  new$PREFERENCEPRISON TENDERCAPTION.PREFERENCEPRISON%TYPE := :NEW.PREFERENCEPRISON;
  new$AGREEMENTEXECUTIONDATE TENDERCAPTION.AGREEMENTEXECUTIONDATE%TYPE := :NEW.AGREEMENTEXECUTIONDATE;
  new$PURCHASECODE TENDERCAPTION.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$PURCHASESOCIALNKO TENDERCAPTION.PURCHASESOCIALNKO%TYPE := :NEW.PURCHASESOCIALNKO;
  new$AVERSION TENDERCAPTION.AVERSION%TYPE := :NEW.AVERSION;
  new$PARENTREF TENDERCAPTION.PARENTREF%TYPE := :NEW.PARENTREF;
  new$TEMPREJECTCAUSE TENDERCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  CurVal$ NUMBER(10);
  DetCount$ NUMBER(10);
  ParentProgIndex$ NUMBER(10);
  ParentInnerNumber$ NUMBER(10);
  AdjParentRef$ NUMBER(10);
  AdjParentInnerNumber$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_TENDERCAPTION_BU_0)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  /*         ( ) */
  if (new$ProgIndex = 230 and new$Multipurpose is null) then
    new$Multipurpose := 0;
  END IF;
  if (new$AcceptSumma is null) then
    new$AcceptSumma := 0;
  END IF;
  if (new$YearAcceptSumma is null) then
    new$YearAcceptSumma := 0;
  END IF;
  if (new$Allowance is null) then
    new$Allowance := 0;
  END IF;
  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if (not((new$BudgetRef is null) and (:old.BudgetRef is null))) then
      select count(ID)         into DetCount$ from TENDERSOURCEORG where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERCONTACTS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERSUPDOCUMENT where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERSUPPLEMENTS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERYARDSTICKS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TenderLot where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  if (new$SaleType is null) then
    new$SaleType := 0;
  END IF;
  if (new$TenderOption is null) then
    new$TenderOption := 0;
  END IF;
  if (new$InnerNumber is Null) then
    new$InnerNumber := GEN_ID('G_TenderInnerNumber',1);
  END IF;
  if (new$RefinementCause is Null) then
    new$RefinementCause := 0;
  END IF;
  if (new$Preference is Null) then
    new$Preference := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$SupportUndertaker is null) then
    new$SupportUndertaker := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_3 (TR_TENDERCAPTION_BU_3)
-- Create 03.12.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   /*             */
   new$AdjustmentRef := :OLD.AdjustmentRef;

-- - - - - - - - - - - - -
-- BU_5 (TR_TENDERCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_TENDERCAPTION_BU_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/
  if ((new$InnerNumber <> :old.InnerNumber) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber)) then
    RaiseException('EX_AGR_CHANGEINNERNUMS');
  END IF;

  /*   !!!*/
  if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and
  ((new$Accepted = 1) or (new$AcceptDate is null))) then
    RaiseException('EX_RollbackCancel');
  END IF;

  /*  ,     LastAccepted*/
  if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) or
  ((:old.Accepted = 0) and (new$Accepted = 1) and (new$AcceptDate is not null))) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;

    else
      RaiseException('EX_Ten_ChangeStateAdjust');
    END IF;
  END IF;

  /*    ,     LastAccepted*/
  if (((:old.AcceptDate is not null) and (:old.Accepted = 1)) and
  ((new$Accepted = 0) or (new$AcceptDate is null))) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 0;

    else
      RaiseException('EX_Ten_ChangeStateAdjust');
    END IF;
  END IF;

  /*   ,     LastAdjustment*/
  if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 0)) or
  ((:old.Accepted = 1) and (new$Accepted = 0) and (new$AcceptDate is not null))) then
    if (new$LastAdjustment = 1) then
      new$LastAdjustment := 0;
      new$LastAccepted := 0;

    else
      RaiseException('EX_Ten_ChangeStateAdjust');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_TENDERCAPTION_BU_30)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  /* :  /    / */
  if (new$ParentRef is not null
  /*  ,   */
  and  (:old.ParentRef is null
  or (:old.ParentRef is not null and :old.ParentRef <> new$ParentRef)))
  then
    /* :     ParentRef  */
    if (new$LastAdjustment = 0) then
      RaiseException('EX_ChangeAdjTenderParentRef');
    END IF;
    BEGIN
      select ProgIndex, InnerNumber
      into ParentProgIndex$, ParentInnerNumber$     from TenderCaption
      where ID=new$ParentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /* :  /    / */
    if  ((new$ProgIndex=243 and ParentProgIndex$ <> 242)
    or (new$ProgIndex=241 and ParentProgIndex$ <> 240))
    then
      RaiseException('EX_IncorrectTenderParentRef');
    END IF;
    /* :       /     ( ,    ) */
    if (new$AdjustmentRef is not null) then
      BEGIN
        select ParentRef
        into AdjParentRef$       from TenderCaption
        where ID=new$AdjustmentRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (AdjParentRef$ is not null) then
        BEGIN
          select InnerNumber
          into AdjParentInnerNumber$         from TenderCaption
          where ID=AdjParentRef$

          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        if (AdjParentInnerNumber$ <> ParentInnerNumber$) then
          RaiseException('EX_IncorrectAdjTenderParentRef');
        END IF;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_50 (TR_TENDERCAPTION_BU_50)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  if (new$InnerNumber is not null) then
    CurVal$ := GEN_ID('G_TENDERINNERNUMBER',0);
    if (CurVal$ < new$InnerNumber) then
      CurVal$ := GEN_ID('G_TENDERINNERNUMBER',new$InnerNumber - CurVal$);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_TENDERCAPTION_BU_200)
-- Create 03.12.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   /*        */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
        VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef);
   END IF;

-- - - - - - - - - - - - -
-- BU_600 (tendercaption_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_TENDERCAPTION_BU_700)
-- Create 14.10.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_TENDERCAPTION SET
    ID = new$ID,
    BUDGETREF = new$BUDGETREF,
    FACIALACCCLS = new$FACIALACCCLS,
    MULTIPURPOSE = new$MULTIPURPOSE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    PERIOD = new$PERIOD,
    ACCEPTSUMMA = new$ACCEPTSUMMA,
    SALETYPE = new$SALETYPE,
    REJECTCLS = new$REJECTCLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DOCSTATEREF = new$DOCSTATEREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    ACCEPTED = new$ACCEPTED,
    EXPORTDATE = new$EXPORTDATE,
    YEARACCEPTSUMMA = new$YEARACCEPTSUMMA,
    TENDEROPTION = new$TENDEROPTION,
    TENDERTARGET = new$TENDERTARGET,
    RVERSION = new$RVERSION,
    ALLOWANCE = new$ALLOWANCE,
    REFINEMENTCAUSE = new$REFINEMENTCAUSE,
    PREFERENCE = new$PREFERENCE,
    PREFERENCESIZE = new$PREFERENCESIZE,
    SECURITY = new$SECURITY,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PERIODYEAR = new$PERIODYEAR,
    SUPPORTUNDERTAKER = new$SUPPORTUNDERTAKER,
    AYEAR = new$AYEAR,
    REWORKCAUSE = new$REWORKCAUSE,
    NOTE = new$NOTE,
    REALID = new$REALID,
    INNERNUMBER = new$INNERNUMBER,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    PROTOCOLREASON = new$PROTOCOLREASON,
    PROGINDEX = new$PROGINDEX,
    DOCNUMBER = new$DOCNUMBER,
    SECURITYTSIZE = new$SECURITYTSIZE,
    SECURITYASIZE = new$SECURITYASIZE,
    AVANSSIZE = new$AVANSSIZE,
    PREFERENCECRIPPLE = new$PREFERENCECRIPPLE,
    PREFERENCERUSPRODUCT = new$PREFERENCERUSPRODUCT,
    PREFERENCEPRISON = new$PREFERENCEPRISON,
    AGREEMENTEXECUTIONDATE = new$AGREEMENTEXECUTIONDATE,
    PURCHASECODE = new$PURCHASECODE,
    PURCHASESOCIALNKO = new$PURCHASESOCIALNKO,
    AVERSION = new$AVERSION,
    PARENTREF = new$PARENTREF,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_TENDERCAPTION_AU_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.1*/
  /*      */
  /*     ,       */
  if ((new$AdjustmentNumber > 0) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update TenderCaption set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

  /*       LastAdjustment    */
  if ((new$AdjustmentNumber > 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update TenderCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_TENDERCAPTION_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   2.0*/
  /*       ,      */
  if (:old.FacialAccCls <> new$FacialAccCls) then
    update TenderProduct set
    RVersion = -1,
    FacialAccCls = new$FacialAccCls
    where
    (RecordIndex = new$ID) and (ProgIndex = 230);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_TENDERCAPTION_AU_500)
-- Create 28.04.2005
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
           VALUES (139, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
            WHERE (TableID = 139) AND (RecordId = new$ID);
   END IF;

END;
/
update TENDERCAPTION set
  TempRejectCause = REJECTCAUSE
/
commit work 
/
ALTER TABLE TB_TENDERCAPTION DROP (REJECTCAUSE)
/

CREATE OR REPLACE VIEW TENDERCAPTION (
  ID,
  BUDGETREF,
  FACIALACCCLS,
  MULTIPURPOSE,
  DOCUMENTDATE,
  ACCEPTDATE,
  PERIOD,
  ACCEPTSUMMA,
  SALETYPE,
  REJECTCLS,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  DOCSTATEREF,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  LASTADJUSTMENT,
  LASTACCEPTED,
  ADJUSTMENTREF,
  ACCEPTED,
  EXPORTDATE,
  YEARACCEPTSUMMA,
  TENDEROPTION,
  TENDERTARGET,
  RVERSION,
  ALLOWANCE,
  REFINEMENTCAUSE,
  PREFERENCE,
  PREFERENCESIZE,
  SECURITY,
  UNKNOWNAMOUNT,
  PERIODYEAR,
  SUPPORTUNDERTAKER,
  AYEAR,
  REWORKCAUSE,
  NOTE,
  REALID,
  INNERNUMBER,
  ADJUSTMENTNUMBER,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  PROTOCOLREASON,
  PROGINDEX,
  DOCNUMBER,
  SECURITYTSIZE,
  SECURITYASIZE,
  AVANSSIZE,
  PREFERENCECRIPPLE,
  PREFERENCERUSPRODUCT,
  PREFERENCEPRISON,
  AGREEMENTEXECUTIONDATE,
  PURCHASECODE,
  PURCHASESOCIALNKO,
  AVERSION,
  PARENTREF,
  TEMPREJECTCAUSE)
AS
  SELECT
    ID,
    BUDGETREF,
    FACIALACCCLS,
    MULTIPURPOSE,
    DOCUMENTDATE,
    ACCEPTDATE,
    PERIOD,
    ACCEPTSUMMA,
    SALETYPE,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DOCSTATEREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    LASTADJUSTMENT,
    LASTACCEPTED,
    ADJUSTMENTREF,
    ACCEPTED,
    EXPORTDATE,
    YEARACCEPTSUMMA,
    TENDEROPTION,
    TENDERTARGET,
    RVERSION,
    ALLOWANCE,
    REFINEMENTCAUSE,
    PREFERENCE,
    PREFERENCESIZE,
    SECURITY,
    UNKNOWNAMOUNT,
    PERIODYEAR,
    SUPPORTUNDERTAKER,
    AYEAR,
    REWORKCAUSE,
    NOTE,
    REALID,
    INNERNUMBER,
    ADJUSTMENTNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    PROTOCOLREASON,
    PROGINDEX,
    DOCNUMBER,
    SECURITYTSIZE,
    SECURITYASIZE,
    AVANSSIZE,
    PREFERENCECRIPPLE,
    PREFERENCERUSPRODUCT,
    PREFERENCEPRISON,
    AGREEMENTEXECUTIONDATE,
    PURCHASECODE,
    PURCHASESOCIALNKO,
    AVERSION,
    PARENTREF,
    TEMPREJECTCAUSE
  FROM TB_TENDERCAPTION
/

CREATE OR REPLACE TRIGGER TR_TENDERCAPTION_ID
  INSTEAD OF DELETE
  ON TENDERCAPTION
  FOR EACH ROW
DECLARE
  cnt$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_TENDERCAPTION_BD)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   5.1 */
  select count(ID) into cnt$ from TenderCaption where (AdjustmentRef = :old.ID) ;
  /*    ,    */
  if (cnt$ = 0) then
    delete from TenderSupDocument where (RecordIndex = :old.ID);
    delete from TenderYardsticks where (RecordIndex = :old.ID);
    delete from TenderSourceOrg where (RecordIndex = :old.ID);
    delete from TenderContacts where (RecordIndex = :old.ID);
    delete from TenderSupplements where (RecordIndex = :old.ID);
    delete from TenderProduct where (RecordIndex = :old.ID);
    delete from TenderLot where (RecordIndex = :old.ID);

  else
    RaiseException('EX_Ten_CantDelAdjustmented');
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_TENDERCAPTION
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_0 (TR_TenderCaption_AD)
-- Last update 06.08.2010
-- - - - - - - - - - - - -

  delete from TENDERPRODUCT where (RecordIndex = :old.ID);
  delete from TenderSourceOrg where (RecordIndex = :old.ID);

-- - - - - - - - - - - - -
-- AD_10 (TR_TENDERCAPTION_AD_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/
  /*   LastAdjustment     */
  if ((:old.AdjustmentNumber > 0) and (:old.LastAdjustment = 1)) then
    update TenderCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;
  /*   LastAccepted     */
  if ((:old.AdjustmentNumber > 0) and (:old.LastAccepted = 1)) then
    update TenderCaption set
    LastAccepted = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AD_200 (TR_TENDERCAPTION_AD_200)
-- Create 03.12.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  /*         */
  delete from StateJumpHistory where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_TENDERCAPTION_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordId, DeleteDate, ProgIndex) values (139, :old.ID, SYSDATE, :old.ProgIndex);

END;
/

CREATE OR REPLACE TRIGGER TR_TENDERCAPTION_II
  INSTEAD OF INSERT
  ON TENDERCAPTION
  FOR EACH ROW
DECLARE
  new$ID TENDERCAPTION.ID%TYPE := :NEW.ID;
  new$BUDGETREF TENDERCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FACIALACCCLS TENDERCAPTION.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$MULTIPURPOSE TENDERCAPTION.MULTIPURPOSE%TYPE := :NEW.MULTIPURPOSE;
  new$DOCUMENTDATE TENDERCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE TENDERCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PERIOD TENDERCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$ACCEPTSUMMA TENDERCAPTION.ACCEPTSUMMA%TYPE := :NEW.ACCEPTSUMMA;
  new$SALETYPE TENDERCAPTION.SALETYPE%TYPE := :NEW.SALETYPE;
  new$REJECTCLS TENDERCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS TENDERCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID TENDERCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID TENDERCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCSTATEREF TENDERCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CREATERUSER TENDERCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TENDERCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE TENDERCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER TENDERCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$LASTADJUSTMENT TENDERCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED TENDERCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$ADJUSTMENTREF TENDERCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ACCEPTED TENDERCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$EXPORTDATE TENDERCAPTION.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$YEARACCEPTSUMMA TENDERCAPTION.YEARACCEPTSUMMA%TYPE := :NEW.YEARACCEPTSUMMA;
  new$TENDEROPTION TENDERCAPTION.TENDEROPTION%TYPE := :NEW.TENDEROPTION;
  new$TENDERTARGET TENDERCAPTION.TENDERTARGET%TYPE := :NEW.TENDERTARGET;
  new$RVERSION TENDERCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$ALLOWANCE TENDERCAPTION.ALLOWANCE%TYPE := :NEW.ALLOWANCE;
  new$REFINEMENTCAUSE TENDERCAPTION.REFINEMENTCAUSE%TYPE := :NEW.REFINEMENTCAUSE;
  new$PREFERENCE TENDERCAPTION.PREFERENCE%TYPE := :NEW.PREFERENCE;
  new$PREFERENCESIZE TENDERCAPTION.PREFERENCESIZE%TYPE := :NEW.PREFERENCESIZE;
  new$SECURITY TENDERCAPTION.SECURITY%TYPE := :NEW.SECURITY;
  new$UNKNOWNAMOUNT TENDERCAPTION.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PERIODYEAR TENDERCAPTION.PERIODYEAR%TYPE := :NEW.PERIODYEAR;
  new$SUPPORTUNDERTAKER TENDERCAPTION.SUPPORTUNDERTAKER%TYPE := :NEW.SUPPORTUNDERTAKER;
  new$AYEAR TENDERCAPTION.AYEAR%TYPE := :NEW.AYEAR;
  new$REWORKCAUSE TENDERCAPTION.REWORKCAUSE%TYPE := :NEW.REWORKCAUSE;
  new$NOTE TENDERCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$REALID TENDERCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER TENDERCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTNUMBER TENDERCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$SENDERIDKEY TENDERCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY TENDERCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$PROTOCOLREASON TENDERCAPTION.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$PROGINDEX TENDERCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$DOCNUMBER TENDERCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SECURITYTSIZE TENDERCAPTION.SECURITYTSIZE%TYPE := :NEW.SECURITYTSIZE;
  new$SECURITYASIZE TENDERCAPTION.SECURITYASIZE%TYPE := :NEW.SECURITYASIZE;
  new$AVANSSIZE TENDERCAPTION.AVANSSIZE%TYPE := :NEW.AVANSSIZE;
  new$PREFERENCECRIPPLE TENDERCAPTION.PREFERENCECRIPPLE%TYPE := :NEW.PREFERENCECRIPPLE;
  new$PREFERENCERUSPRODUCT TENDERCAPTION.PREFERENCERUSPRODUCT%TYPE := :NEW.PREFERENCERUSPRODUCT;
  new$PREFERENCEPRISON TENDERCAPTION.PREFERENCEPRISON%TYPE := :NEW.PREFERENCEPRISON;
  new$AGREEMENTEXECUTIONDATE TENDERCAPTION.AGREEMENTEXECUTIONDATE%TYPE := :NEW.AGREEMENTEXECUTIONDATE;
  new$PURCHASECODE TENDERCAPTION.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$PURCHASESOCIALNKO TENDERCAPTION.PURCHASESOCIALNKO%TYPE := :NEW.PURCHASESOCIALNKO;
  new$AVERSION TENDERCAPTION.AVERSION%TYPE := :NEW.AVERSION;
  new$PARENTREF TENDERCAPTION.PARENTREF%TYPE := :NEW.PARENTREF;
  new$TEMPREJECTCAUSE TENDERCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  Tmp$ NUMBER(10);
  AdjID$ NUMBER(10);
  CurVal$ NUMBER(10);
  ParentProgIndex$ NUMBER(10);
  ParentInnerNumber$ NUMBER(10);
  AdjParentRef$ NUMBER(10);
  AdjParentInnerNumber$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_TENDERCAPTION_BI)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  /*         ( ) */
  if (new$ProgIndex = 230 and new$Multipurpose is null) then
    new$Multipurpose := 0;
  END IF;
  if (new$AcceptSumma is null) then
    new$AcceptSumma := 0;
  END IF;
  if (new$YearAcceptSumma is null) then
    new$YearAcceptSumma := 0;
  END IF;
  if (new$Allowance is null) then
    new$Allowance := 0;
  END IF;

  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    BEGIN
      select fa.BudgetRef       into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = new$FacialAccCls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    GetIntConst(-1,3,new$BudgetRef);
  END IF;

  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  if (new$SaleType is null) then
    new$SaleType := 0;
  END IF;
  if (new$TenderOption is null) then
    new$TenderOption := 0;
  END IF;
  if (new$InnerNumber is Null) then
    new$InnerNumber := GEN_ID('G_TenderInnerNumber',1);
  END IF;
  if (new$RefinementCause is Null) then
    new$RefinementCause := 0;
  END IF;
  if (new$Preference is Null) then
    new$Preference := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$SupportUndertaker is null) then
    new$SupportUndertaker := 0;
  END IF;
  if (new$PurchaseSocialNKO is null) then
    new$PurchaseSocialNKO := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_TENDERCAPTION_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_TENDERCAPTION_BI_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/

  /*    .*/
  if (new$InnerNumber is null) then
    RaiseException('EX_Ten_InnerNumsIsNull');
  END IF;

  /*    */
  select max(AdjustmentNumber)
  into Tmp$         from TenderCaption
  where (InnerNumber = new$InnerNumber)
  ;
  /*      ,   0*/
  if (Tmp$ is null) then
    new$AdjustmentNumber := 0;

  else
    new$AdjustmentNumber := Tmp$ + 1;
  END IF;

  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;

  else
    new$LastAdjustment := 1;
  END IF;

  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then
    new$LastAccepted := 1;

  else
    new$LastAccepted := 0;
  END IF;

  /*    */
  if (new$AdjustmentNumber > 0) then
    /*      -    */
    select count(ID), max(ID)
    into Tmp$, AdjID$             from TenderCaption
    where (InnerNumber = new$InnerNumber) and (LastAccepted = 1)
    ;
    /*   ,  */
    if (Tmp$ <> 1) then
      RaiseException('EX_Ten_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID)
    into Tmp$             from TenderCaption
    where (InnerNumber = new$InnerNumber) and (AcceptDate is null)
    ;
    if (Tmp$ > 0) then
      RaiseException('EX_Ten_AdjustDuplicate');
    END IF;
    /* ,    ,    */
    new$AdjustmentRef := AdjID$;

  else /*     */
    /*       (    )*/
    new$AdjustmentRef := null;

  END IF;

-- - - - - - - - - - - - -
-- BI_30 (TR_TENDERCAPTION_BI_30)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (new$ParentRef is not null) then
    BEGIN
      select ProgIndex, InnerNumber
      into ParentProgIndex$, ParentInnerNumber$     from TenderCaption
      where ID=new$ParentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /* :  /    / */
    if  ((new$ProgIndex=243 and ParentProgIndex$ <> 242)
    or (new$ProgIndex=241 and ParentProgIndex$ <> 240))
    then
      RaiseException('EX_IncorrectTenderParentRef');
    END IF;
    /* :       /     ( ,    ) */
    if (new$AdjustmentRef is not null) then
      BEGIN
        select ParentRef
        into AdjParentRef$       from TenderCaption
        where ID=new$AdjustmentRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (AdjParentRef$ is not null) then
        BEGIN
          select InnerNumber
          into AdjParentInnerNumber$         from TenderCaption
          where ID=AdjParentRef$

          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        if (AdjParentInnerNumber$ <> ParentInnerNumber$) then
          RaiseException('EX_IncorrectAdjTenderParentRef');
        END IF;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_40 (TR_TENDERCAPTION_BI_40)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$senderId is null) then
    new$senderIdKey := -1;

  else
    new$senderIdKey := new$senderId;
  END IF;
  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;

  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_50 (TR_TENDERCAPTION_BI_50)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  if (new$InnerNumber is not null) then
    CurVal$ := GEN_ID('G_TENDERINNERNUMBER',0);
    if (CurVal$ < new$InnerNumber) then
      CurVal$ := GEN_ID('G_TENDERINNERNUMBER',new$InnerNumber - CurVal$);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_TENDERCAPTION_BI_500)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- BI_600 (tendercaption_realid_bi_600)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_TENDERCAPTION (
    ID,
    BUDGETREF,
    FACIALACCCLS,
    MULTIPURPOSE,
    DOCUMENTDATE,
    ACCEPTDATE,
    PERIOD,
    ACCEPTSUMMA,
    SALETYPE,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DOCSTATEREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    LASTADJUSTMENT,
    LASTACCEPTED,
    ADJUSTMENTREF,
    ACCEPTED,
    EXPORTDATE,
    YEARACCEPTSUMMA,
    TENDEROPTION,
    TENDERTARGET,
    RVERSION,
    ALLOWANCE,
    REFINEMENTCAUSE,
    PREFERENCE,
    PREFERENCESIZE,
    SECURITY,
    UNKNOWNAMOUNT,
    PERIODYEAR,
    SUPPORTUNDERTAKER,
    AYEAR,
    REWORKCAUSE,
    NOTE,
    REALID,
    INNERNUMBER,
    ADJUSTMENTNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    PROTOCOLREASON,
    PROGINDEX,
    DOCNUMBER,
    SECURITYTSIZE,
    SECURITYASIZE,
    AVANSSIZE,
    PREFERENCECRIPPLE,
    PREFERENCERUSPRODUCT,
    PREFERENCEPRISON,
    AGREEMENTEXECUTIONDATE,
    PURCHASECODE,
    PURCHASESOCIALNKO,
    AVERSION,
    PARENTREF,
    TEMPREJECTCAUSE
  ) VALUES (
    new$ID,
    new$BUDGETREF,
    new$FACIALACCCLS,
    new$MULTIPURPOSE,
    new$DOCUMENTDATE,
    new$ACCEPTDATE,
    new$PERIOD,
    new$ACCEPTSUMMA,
    new$SALETYPE,
    new$REJECTCLS,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$DOCSTATEREF,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$LASTADJUSTMENT,
    new$LASTACCEPTED,
    new$ADJUSTMENTREF,
    new$ACCEPTED,
    new$EXPORTDATE,
    new$YEARACCEPTSUMMA,
    new$TENDEROPTION,
    new$TENDERTARGET,
    new$RVERSION,
    new$ALLOWANCE,
    new$REFINEMENTCAUSE,
    new$PREFERENCE,
    new$PREFERENCESIZE,
    new$SECURITY,
    new$UNKNOWNAMOUNT,
    new$PERIODYEAR,
    new$SUPPORTUNDERTAKER,
    new$AYEAR,
    new$REWORKCAUSE,
    new$NOTE,
    new$REALID,
    new$INNERNUMBER,
    new$ADJUSTMENTNUMBER,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$PROTOCOLREASON,
    new$PROGINDEX,
    new$DOCNUMBER,
    new$SECURITYTSIZE,
    new$SECURITYASIZE,
    new$AVANSSIZE,
    new$PREFERENCECRIPPLE,
    new$PREFERENCERUSPRODUCT,
    new$PREFERENCEPRISON,
    new$AGREEMENTEXECUTIONDATE,
    new$PURCHASECODE,
    new$PURCHASESOCIALNKO,
    new$AVERSION,
    new$PARENTREF,
    new$TEMPREJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_10 (TR_TENDERCAPTION_AI_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/
  /*      */
  if ((new$AdjustmentNumber > 0) and (new$LastAdjustment = 1)) then
    update TenderCaption set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);
    if (new$LastAccepted = 1) then
      update TenderCaption set
      LastAccepted = 0,
      RVersion = -1
      where (ID = new$AdjustmentRef);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_TENDERCAPTION_AI_500)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   DELETE FROM delrecindexes
         WHERE (tableid = 139) AND (recordid = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_TENDERCAPTION_IU
  INSTEAD OF UPDATE
  ON TENDERCAPTION
  FOR EACH ROW
DECLARE
  new$ID TENDERCAPTION.ID%TYPE := :NEW.ID;
  new$BUDGETREF TENDERCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FACIALACCCLS TENDERCAPTION.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$MULTIPURPOSE TENDERCAPTION.MULTIPURPOSE%TYPE := :NEW.MULTIPURPOSE;
  new$DOCUMENTDATE TENDERCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE TENDERCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PERIOD TENDERCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$ACCEPTSUMMA TENDERCAPTION.ACCEPTSUMMA%TYPE := :NEW.ACCEPTSUMMA;
  new$SALETYPE TENDERCAPTION.SALETYPE%TYPE := :NEW.SALETYPE;
  new$REJECTCLS TENDERCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS TENDERCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID TENDERCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID TENDERCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCSTATEREF TENDERCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CREATERUSER TENDERCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TENDERCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE TENDERCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER TENDERCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$LASTADJUSTMENT TENDERCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED TENDERCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$ADJUSTMENTREF TENDERCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ACCEPTED TENDERCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$EXPORTDATE TENDERCAPTION.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$YEARACCEPTSUMMA TENDERCAPTION.YEARACCEPTSUMMA%TYPE := :NEW.YEARACCEPTSUMMA;
  new$TENDEROPTION TENDERCAPTION.TENDEROPTION%TYPE := :NEW.TENDEROPTION;
  new$TENDERTARGET TENDERCAPTION.TENDERTARGET%TYPE := :NEW.TENDERTARGET;
  new$RVERSION TENDERCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$ALLOWANCE TENDERCAPTION.ALLOWANCE%TYPE := :NEW.ALLOWANCE;
  new$REFINEMENTCAUSE TENDERCAPTION.REFINEMENTCAUSE%TYPE := :NEW.REFINEMENTCAUSE;
  new$PREFERENCE TENDERCAPTION.PREFERENCE%TYPE := :NEW.PREFERENCE;
  new$PREFERENCESIZE TENDERCAPTION.PREFERENCESIZE%TYPE := :NEW.PREFERENCESIZE;
  new$SECURITY TENDERCAPTION.SECURITY%TYPE := :NEW.SECURITY;
  new$UNKNOWNAMOUNT TENDERCAPTION.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PERIODYEAR TENDERCAPTION.PERIODYEAR%TYPE := :NEW.PERIODYEAR;
  new$SUPPORTUNDERTAKER TENDERCAPTION.SUPPORTUNDERTAKER%TYPE := :NEW.SUPPORTUNDERTAKER;
  new$AYEAR TENDERCAPTION.AYEAR%TYPE := :NEW.AYEAR;
  new$REWORKCAUSE TENDERCAPTION.REWORKCAUSE%TYPE := :NEW.REWORKCAUSE;
  new$NOTE TENDERCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$REALID TENDERCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER TENDERCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTNUMBER TENDERCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$SENDERIDKEY TENDERCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY TENDERCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$PROTOCOLREASON TENDERCAPTION.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$PROGINDEX TENDERCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$DOCNUMBER TENDERCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SECURITYTSIZE TENDERCAPTION.SECURITYTSIZE%TYPE := :NEW.SECURITYTSIZE;
  new$SECURITYASIZE TENDERCAPTION.SECURITYASIZE%TYPE := :NEW.SECURITYASIZE;
  new$AVANSSIZE TENDERCAPTION.AVANSSIZE%TYPE := :NEW.AVANSSIZE;
  new$PREFERENCECRIPPLE TENDERCAPTION.PREFERENCECRIPPLE%TYPE := :NEW.PREFERENCECRIPPLE;
  new$PREFERENCERUSPRODUCT TENDERCAPTION.PREFERENCERUSPRODUCT%TYPE := :NEW.PREFERENCERUSPRODUCT;
  new$PREFERENCEPRISON TENDERCAPTION.PREFERENCEPRISON%TYPE := :NEW.PREFERENCEPRISON;
  new$AGREEMENTEXECUTIONDATE TENDERCAPTION.AGREEMENTEXECUTIONDATE%TYPE := :NEW.AGREEMENTEXECUTIONDATE;
  new$PURCHASECODE TENDERCAPTION.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$PURCHASESOCIALNKO TENDERCAPTION.PURCHASESOCIALNKO%TYPE := :NEW.PURCHASESOCIALNKO;
  new$AVERSION TENDERCAPTION.AVERSION%TYPE := :NEW.AVERSION;
  new$PARENTREF TENDERCAPTION.PARENTREF%TYPE := :NEW.PARENTREF;
  new$TEMPREJECTCAUSE TENDERCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  CurVal$ NUMBER(10);
  DetCount$ NUMBER(10);
  ParentProgIndex$ NUMBER(10);
  ParentInnerNumber$ NUMBER(10);
  AdjParentRef$ NUMBER(10);
  AdjParentInnerNumber$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_TENDERCAPTION_BU_0)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  /*         ( ) */
  if (new$ProgIndex = 230 and new$Multipurpose is null) then
    new$Multipurpose := 0;
  END IF;
  if (new$AcceptSumma is null) then
    new$AcceptSumma := 0;
  END IF;
  if (new$YearAcceptSumma is null) then
    new$YearAcceptSumma := 0;
  END IF;
  if (new$Allowance is null) then
    new$Allowance := 0;
  END IF;
  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if (not((new$BudgetRef is null) and (:old.BudgetRef is null))) then
      select count(ID)         into DetCount$ from TENDERSOURCEORG where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERCONTACTS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERSUPDOCUMENT where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERSUPPLEMENTS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERYARDSTICKS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TenderLot where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  if (new$SaleType is null) then
    new$SaleType := 0;
  END IF;
  if (new$TenderOption is null) then
    new$TenderOption := 0;
  END IF;
  if (new$InnerNumber is Null) then
    new$InnerNumber := GEN_ID('G_TenderInnerNumber',1);
  END IF;
  if (new$RefinementCause is Null) then
    new$RefinementCause := 0;
  END IF;
  if (new$Preference is Null) then
    new$Preference := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$SupportUndertaker is null) then
    new$SupportUndertaker := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_3 (TR_TENDERCAPTION_BU_3)
-- Create 03.12.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   /*             */
   new$AdjustmentRef := :OLD.AdjustmentRef;

-- - - - - - - - - - - - -
-- BU_5 (TR_TENDERCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_TENDERCAPTION_BU_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/
  if ((new$InnerNumber <> :old.InnerNumber) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber)) then
    RaiseException('EX_AGR_CHANGEINNERNUMS');
  END IF;

  /*   !!!*/
  if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and
  ((new$Accepted = 1) or (new$AcceptDate is null))) then
    RaiseException('EX_RollbackCancel');
  END IF;

  /*  ,     LastAccepted*/
  if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) or
  ((:old.Accepted = 0) and (new$Accepted = 1) and (new$AcceptDate is not null))) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;

    else
      RaiseException('EX_Ten_ChangeStateAdjust');
    END IF;
  END IF;

  /*    ,     LastAccepted*/
  if (((:old.AcceptDate is not null) and (:old.Accepted = 1)) and
  ((new$Accepted = 0) or (new$AcceptDate is null))) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 0;

    else
      RaiseException('EX_Ten_ChangeStateAdjust');
    END IF;
  END IF;

  /*   ,     LastAdjustment*/
  if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 0)) or
  ((:old.Accepted = 1) and (new$Accepted = 0) and (new$AcceptDate is not null))) then
    if (new$LastAdjustment = 1) then
      new$LastAdjustment := 0;
      new$LastAccepted := 0;

    else
      RaiseException('EX_Ten_ChangeStateAdjust');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_TENDERCAPTION_BU_30)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  /* :  /    / */
  if (new$ParentRef is not null
  /*  ,   */
  and  (:old.ParentRef is null
  or (:old.ParentRef is not null and :old.ParentRef <> new$ParentRef)))
  then
    /* :     ParentRef  */
    if (new$LastAdjustment = 0) then
      RaiseException('EX_ChangeAdjTenderParentRef');
    END IF;
    BEGIN
      select ProgIndex, InnerNumber
      into ParentProgIndex$, ParentInnerNumber$     from TenderCaption
      where ID=new$ParentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /* :  /    / */
    if  ((new$ProgIndex=243 and ParentProgIndex$ <> 242)
    or (new$ProgIndex=241 and ParentProgIndex$ <> 240))
    then
      RaiseException('EX_IncorrectTenderParentRef');
    END IF;
    /* :       /     ( ,    ) */
    if (new$AdjustmentRef is not null) then
      BEGIN
        select ParentRef
        into AdjParentRef$       from TenderCaption
        where ID=new$AdjustmentRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (AdjParentRef$ is not null) then
        BEGIN
          select InnerNumber
          into AdjParentInnerNumber$         from TenderCaption
          where ID=AdjParentRef$

          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        if (AdjParentInnerNumber$ <> ParentInnerNumber$) then
          RaiseException('EX_IncorrectAdjTenderParentRef');
        END IF;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_50 (TR_TENDERCAPTION_BU_50)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  if (new$InnerNumber is not null) then
    CurVal$ := GEN_ID('G_TENDERINNERNUMBER',0);
    if (CurVal$ < new$InnerNumber) then
      CurVal$ := GEN_ID('G_TENDERINNERNUMBER',new$InnerNumber - CurVal$);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_TENDERCAPTION_BU_200)
-- Create 03.12.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   /*        */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
        VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef);
   END IF;

-- - - - - - - - - - - - -
-- BU_600 (tendercaption_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_TENDERCAPTION_BU_700)
-- Create 14.10.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_TENDERCAPTION SET
    ID = new$ID,
    BUDGETREF = new$BUDGETREF,
    FACIALACCCLS = new$FACIALACCCLS,
    MULTIPURPOSE = new$MULTIPURPOSE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    PERIOD = new$PERIOD,
    ACCEPTSUMMA = new$ACCEPTSUMMA,
    SALETYPE = new$SALETYPE,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DOCSTATEREF = new$DOCSTATEREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    ACCEPTED = new$ACCEPTED,
    EXPORTDATE = new$EXPORTDATE,
    YEARACCEPTSUMMA = new$YEARACCEPTSUMMA,
    TENDEROPTION = new$TENDEROPTION,
    TENDERTARGET = new$TENDERTARGET,
    RVERSION = new$RVERSION,
    ALLOWANCE = new$ALLOWANCE,
    REFINEMENTCAUSE = new$REFINEMENTCAUSE,
    PREFERENCE = new$PREFERENCE,
    PREFERENCESIZE = new$PREFERENCESIZE,
    SECURITY = new$SECURITY,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PERIODYEAR = new$PERIODYEAR,
    SUPPORTUNDERTAKER = new$SUPPORTUNDERTAKER,
    AYEAR = new$AYEAR,
    REWORKCAUSE = new$REWORKCAUSE,
    NOTE = new$NOTE,
    REALID = new$REALID,
    INNERNUMBER = new$INNERNUMBER,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    PROTOCOLREASON = new$PROTOCOLREASON,
    PROGINDEX = new$PROGINDEX,
    DOCNUMBER = new$DOCNUMBER,
    SECURITYTSIZE = new$SECURITYTSIZE,
    SECURITYASIZE = new$SECURITYASIZE,
    AVANSSIZE = new$AVANSSIZE,
    PREFERENCECRIPPLE = new$PREFERENCECRIPPLE,
    PREFERENCERUSPRODUCT = new$PREFERENCERUSPRODUCT,
    PREFERENCEPRISON = new$PREFERENCEPRISON,
    AGREEMENTEXECUTIONDATE = new$AGREEMENTEXECUTIONDATE,
    PURCHASECODE = new$PURCHASECODE,
    PURCHASESOCIALNKO = new$PURCHASESOCIALNKO,
    AVERSION = new$AVERSION,
    PARENTREF = new$PARENTREF,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_TENDERCAPTION_AU_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.1*/
  /*      */
  /*     ,       */
  if ((new$AdjustmentNumber > 0) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update TenderCaption set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

  /*       LastAdjustment    */
  if ((new$AdjustmentNumber > 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update TenderCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_TENDERCAPTION_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   2.0*/
  /*       ,      */
  if (:old.FacialAccCls <> new$FacialAccCls) then
    update TenderProduct set
    RVersion = -1,
    FacialAccCls = new$FacialAccCls
    where
    (RecordIndex = new$ID) and (ProgIndex = 230);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_TENDERCAPTION_AU_500)
-- Create 28.04.2005
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
           VALUES (139, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
            WHERE (TableID = 139) AND (RecordId = new$ID);
   END IF;

END;
/
ALTER TABLE TB_TENDERCAPTION ADD (
  REJECTCAUSE VARCHAR2(1000)
)
/

CREATE OR REPLACE VIEW TENDERCAPTION (
  ID,
  BUDGETREF,
  FACIALACCCLS,
  MULTIPURPOSE,
  DOCUMENTDATE,
  ACCEPTDATE,
  PERIOD,
  ACCEPTSUMMA,
  SALETYPE,
  REJECTCLS,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  DOCSTATEREF,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  LASTADJUSTMENT,
  LASTACCEPTED,
  ADJUSTMENTREF,
  ACCEPTED,
  EXPORTDATE,
  YEARACCEPTSUMMA,
  TENDEROPTION,
  TENDERTARGET,
  RVERSION,
  ALLOWANCE,
  REFINEMENTCAUSE,
  PREFERENCE,
  PREFERENCESIZE,
  SECURITY,
  UNKNOWNAMOUNT,
  PERIODYEAR,
  SUPPORTUNDERTAKER,
  AYEAR,
  REWORKCAUSE,
  NOTE,
  REALID,
  INNERNUMBER,
  ADJUSTMENTNUMBER,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  PROTOCOLREASON,
  PROGINDEX,
  DOCNUMBER,
  SECURITYTSIZE,
  SECURITYASIZE,
  AVANSSIZE,
  PREFERENCECRIPPLE,
  PREFERENCERUSPRODUCT,
  PREFERENCEPRISON,
  AGREEMENTEXECUTIONDATE,
  PURCHASECODE,
  PURCHASESOCIALNKO,
  AVERSION,
  PARENTREF,
  TEMPREJECTCAUSE,
  REJECTCAUSE)
AS
  SELECT
    ID,
    BUDGETREF,
    FACIALACCCLS,
    MULTIPURPOSE,
    DOCUMENTDATE,
    ACCEPTDATE,
    PERIOD,
    ACCEPTSUMMA,
    SALETYPE,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DOCSTATEREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    LASTADJUSTMENT,
    LASTACCEPTED,
    ADJUSTMENTREF,
    ACCEPTED,
    EXPORTDATE,
    YEARACCEPTSUMMA,
    TENDEROPTION,
    TENDERTARGET,
    RVERSION,
    ALLOWANCE,
    REFINEMENTCAUSE,
    PREFERENCE,
    PREFERENCESIZE,
    SECURITY,
    UNKNOWNAMOUNT,
    PERIODYEAR,
    SUPPORTUNDERTAKER,
    AYEAR,
    REWORKCAUSE,
    NOTE,
    REALID,
    INNERNUMBER,
    ADJUSTMENTNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    PROTOCOLREASON,
    PROGINDEX,
    DOCNUMBER,
    SECURITYTSIZE,
    SECURITYASIZE,
    AVANSSIZE,
    PREFERENCECRIPPLE,
    PREFERENCERUSPRODUCT,
    PREFERENCEPRISON,
    AGREEMENTEXECUTIONDATE,
    PURCHASECODE,
    PURCHASESOCIALNKO,
    AVERSION,
    PARENTREF,
    TEMPREJECTCAUSE,
    REJECTCAUSE
  FROM TB_TENDERCAPTION
/

CREATE OR REPLACE TRIGGER TR_TENDERCAPTION_ID
  INSTEAD OF DELETE
  ON TENDERCAPTION
  FOR EACH ROW
DECLARE
  cnt$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_TENDERCAPTION_BD)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   5.1 */
  select count(ID) into cnt$ from TenderCaption where (AdjustmentRef = :old.ID) ;
  /*    ,    */
  if (cnt$ = 0) then
    delete from TenderSupDocument where (RecordIndex = :old.ID);
    delete from TenderYardsticks where (RecordIndex = :old.ID);
    delete from TenderSourceOrg where (RecordIndex = :old.ID);
    delete from TenderContacts where (RecordIndex = :old.ID);
    delete from TenderSupplements where (RecordIndex = :old.ID);
    delete from TenderProduct where (RecordIndex = :old.ID);
    delete from TenderLot where (RecordIndex = :old.ID);

  else
    RaiseException('EX_Ten_CantDelAdjustmented');
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_TENDERCAPTION
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_0 (TR_TenderCaption_AD)
-- Last update 06.08.2010
-- - - - - - - - - - - - -

  delete from TENDERPRODUCT where (RecordIndex = :old.ID);
  delete from TenderSourceOrg where (RecordIndex = :old.ID);

-- - - - - - - - - - - - -
-- AD_10 (TR_TENDERCAPTION_AD_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/
  /*   LastAdjustment     */
  if ((:old.AdjustmentNumber > 0) and (:old.LastAdjustment = 1)) then
    update TenderCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;
  /*   LastAccepted     */
  if ((:old.AdjustmentNumber > 0) and (:old.LastAccepted = 1)) then
    update TenderCaption set
    LastAccepted = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AD_200 (TR_TENDERCAPTION_AD_200)
-- Create 03.12.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  /*         */
  delete from StateJumpHistory where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_TENDERCAPTION_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordId, DeleteDate, ProgIndex) values (139, :old.ID, SYSDATE, :old.ProgIndex);

END;
/

CREATE OR REPLACE TRIGGER TR_TENDERCAPTION_II
  INSTEAD OF INSERT
  ON TENDERCAPTION
  FOR EACH ROW
DECLARE
  new$ID TENDERCAPTION.ID%TYPE := :NEW.ID;
  new$BUDGETREF TENDERCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FACIALACCCLS TENDERCAPTION.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$MULTIPURPOSE TENDERCAPTION.MULTIPURPOSE%TYPE := :NEW.MULTIPURPOSE;
  new$DOCUMENTDATE TENDERCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE TENDERCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PERIOD TENDERCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$ACCEPTSUMMA TENDERCAPTION.ACCEPTSUMMA%TYPE := :NEW.ACCEPTSUMMA;
  new$SALETYPE TENDERCAPTION.SALETYPE%TYPE := :NEW.SALETYPE;
  new$REJECTCLS TENDERCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS TENDERCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID TENDERCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID TENDERCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCSTATEREF TENDERCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CREATERUSER TENDERCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TENDERCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE TENDERCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER TENDERCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$LASTADJUSTMENT TENDERCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED TENDERCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$ADJUSTMENTREF TENDERCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ACCEPTED TENDERCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$EXPORTDATE TENDERCAPTION.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$YEARACCEPTSUMMA TENDERCAPTION.YEARACCEPTSUMMA%TYPE := :NEW.YEARACCEPTSUMMA;
  new$TENDEROPTION TENDERCAPTION.TENDEROPTION%TYPE := :NEW.TENDEROPTION;
  new$TENDERTARGET TENDERCAPTION.TENDERTARGET%TYPE := :NEW.TENDERTARGET;
  new$RVERSION TENDERCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$ALLOWANCE TENDERCAPTION.ALLOWANCE%TYPE := :NEW.ALLOWANCE;
  new$REFINEMENTCAUSE TENDERCAPTION.REFINEMENTCAUSE%TYPE := :NEW.REFINEMENTCAUSE;
  new$PREFERENCE TENDERCAPTION.PREFERENCE%TYPE := :NEW.PREFERENCE;
  new$PREFERENCESIZE TENDERCAPTION.PREFERENCESIZE%TYPE := :NEW.PREFERENCESIZE;
  new$SECURITY TENDERCAPTION.SECURITY%TYPE := :NEW.SECURITY;
  new$UNKNOWNAMOUNT TENDERCAPTION.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PERIODYEAR TENDERCAPTION.PERIODYEAR%TYPE := :NEW.PERIODYEAR;
  new$SUPPORTUNDERTAKER TENDERCAPTION.SUPPORTUNDERTAKER%TYPE := :NEW.SUPPORTUNDERTAKER;
  new$AYEAR TENDERCAPTION.AYEAR%TYPE := :NEW.AYEAR;
  new$REWORKCAUSE TENDERCAPTION.REWORKCAUSE%TYPE := :NEW.REWORKCAUSE;
  new$NOTE TENDERCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$REALID TENDERCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER TENDERCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTNUMBER TENDERCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$SENDERIDKEY TENDERCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY TENDERCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$PROTOCOLREASON TENDERCAPTION.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$PROGINDEX TENDERCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$DOCNUMBER TENDERCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SECURITYTSIZE TENDERCAPTION.SECURITYTSIZE%TYPE := :NEW.SECURITYTSIZE;
  new$SECURITYASIZE TENDERCAPTION.SECURITYASIZE%TYPE := :NEW.SECURITYASIZE;
  new$AVANSSIZE TENDERCAPTION.AVANSSIZE%TYPE := :NEW.AVANSSIZE;
  new$PREFERENCECRIPPLE TENDERCAPTION.PREFERENCECRIPPLE%TYPE := :NEW.PREFERENCECRIPPLE;
  new$PREFERENCERUSPRODUCT TENDERCAPTION.PREFERENCERUSPRODUCT%TYPE := :NEW.PREFERENCERUSPRODUCT;
  new$PREFERENCEPRISON TENDERCAPTION.PREFERENCEPRISON%TYPE := :NEW.PREFERENCEPRISON;
  new$AGREEMENTEXECUTIONDATE TENDERCAPTION.AGREEMENTEXECUTIONDATE%TYPE := :NEW.AGREEMENTEXECUTIONDATE;
  new$PURCHASECODE TENDERCAPTION.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$PURCHASESOCIALNKO TENDERCAPTION.PURCHASESOCIALNKO%TYPE := :NEW.PURCHASESOCIALNKO;
  new$AVERSION TENDERCAPTION.AVERSION%TYPE := :NEW.AVERSION;
  new$PARENTREF TENDERCAPTION.PARENTREF%TYPE := :NEW.PARENTREF;
  new$TEMPREJECTCAUSE TENDERCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
  new$REJECTCAUSE TENDERCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  Tmp$ NUMBER(10);
  AdjID$ NUMBER(10);
  CurVal$ NUMBER(10);
  ParentProgIndex$ NUMBER(10);
  ParentInnerNumber$ NUMBER(10);
  AdjParentRef$ NUMBER(10);
  AdjParentInnerNumber$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_TENDERCAPTION_BI)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  /*         ( ) */
  if (new$ProgIndex = 230 and new$Multipurpose is null) then
    new$Multipurpose := 0;
  END IF;
  if (new$AcceptSumma is null) then
    new$AcceptSumma := 0;
  END IF;
  if (new$YearAcceptSumma is null) then
    new$YearAcceptSumma := 0;
  END IF;
  if (new$Allowance is null) then
    new$Allowance := 0;
  END IF;

  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    BEGIN
      select fa.BudgetRef       into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = new$FacialAccCls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    GetIntConst(-1,3,new$BudgetRef);
  END IF;

  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  if (new$SaleType is null) then
    new$SaleType := 0;
  END IF;
  if (new$TenderOption is null) then
    new$TenderOption := 0;
  END IF;
  if (new$InnerNumber is Null) then
    new$InnerNumber := GEN_ID('G_TenderInnerNumber',1);
  END IF;
  if (new$RefinementCause is Null) then
    new$RefinementCause := 0;
  END IF;
  if (new$Preference is Null) then
    new$Preference := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$SupportUndertaker is null) then
    new$SupportUndertaker := 0;
  END IF;
  if (new$PurchaseSocialNKO is null) then
    new$PurchaseSocialNKO := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_TENDERCAPTION_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_TENDERCAPTION_BI_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/

  /*    .*/
  if (new$InnerNumber is null) then
    RaiseException('EX_Ten_InnerNumsIsNull');
  END IF;

  /*    */
  select max(AdjustmentNumber)
  into Tmp$         from TenderCaption
  where (InnerNumber = new$InnerNumber)
  ;
  /*      ,   0*/
  if (Tmp$ is null) then
    new$AdjustmentNumber := 0;

  else
    new$AdjustmentNumber := Tmp$ + 1;
  END IF;

  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;

  else
    new$LastAdjustment := 1;
  END IF;

  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then
    new$LastAccepted := 1;

  else
    new$LastAccepted := 0;
  END IF;

  /*    */
  if (new$AdjustmentNumber > 0) then
    /*      -    */
    select count(ID), max(ID)
    into Tmp$, AdjID$             from TenderCaption
    where (InnerNumber = new$InnerNumber) and (LastAccepted = 1)
    ;
    /*   ,  */
    if (Tmp$ <> 1) then
      RaiseException('EX_Ten_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID)
    into Tmp$             from TenderCaption
    where (InnerNumber = new$InnerNumber) and (AcceptDate is null)
    ;
    if (Tmp$ > 0) then
      RaiseException('EX_Ten_AdjustDuplicate');
    END IF;
    /* ,    ,    */
    new$AdjustmentRef := AdjID$;

  else /*     */
    /*       (    )*/
    new$AdjustmentRef := null;

  END IF;

-- - - - - - - - - - - - -
-- BI_30 (TR_TENDERCAPTION_BI_30)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (new$ParentRef is not null) then
    BEGIN
      select ProgIndex, InnerNumber
      into ParentProgIndex$, ParentInnerNumber$     from TenderCaption
      where ID=new$ParentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /* :  /    / */
    if  ((new$ProgIndex=243 and ParentProgIndex$ <> 242)
    or (new$ProgIndex=241 and ParentProgIndex$ <> 240))
    then
      RaiseException('EX_IncorrectTenderParentRef');
    END IF;
    /* :       /     ( ,    ) */
    if (new$AdjustmentRef is not null) then
      BEGIN
        select ParentRef
        into AdjParentRef$       from TenderCaption
        where ID=new$AdjustmentRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (AdjParentRef$ is not null) then
        BEGIN
          select InnerNumber
          into AdjParentInnerNumber$         from TenderCaption
          where ID=AdjParentRef$

          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        if (AdjParentInnerNumber$ <> ParentInnerNumber$) then
          RaiseException('EX_IncorrectAdjTenderParentRef');
        END IF;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_40 (TR_TENDERCAPTION_BI_40)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$senderId is null) then
    new$senderIdKey := -1;

  else
    new$senderIdKey := new$senderId;
  END IF;
  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;

  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_50 (TR_TENDERCAPTION_BI_50)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  if (new$InnerNumber is not null) then
    CurVal$ := GEN_ID('G_TENDERINNERNUMBER',0);
    if (CurVal$ < new$InnerNumber) then
      CurVal$ := GEN_ID('G_TENDERINNERNUMBER',new$InnerNumber - CurVal$);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_TENDERCAPTION_BI_500)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- BI_600 (tendercaption_realid_bi_600)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_TENDERCAPTION (
    ID,
    BUDGETREF,
    FACIALACCCLS,
    MULTIPURPOSE,
    DOCUMENTDATE,
    ACCEPTDATE,
    PERIOD,
    ACCEPTSUMMA,
    SALETYPE,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DOCSTATEREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    LASTADJUSTMENT,
    LASTACCEPTED,
    ADJUSTMENTREF,
    ACCEPTED,
    EXPORTDATE,
    YEARACCEPTSUMMA,
    TENDEROPTION,
    TENDERTARGET,
    RVERSION,
    ALLOWANCE,
    REFINEMENTCAUSE,
    PREFERENCE,
    PREFERENCESIZE,
    SECURITY,
    UNKNOWNAMOUNT,
    PERIODYEAR,
    SUPPORTUNDERTAKER,
    AYEAR,
    REWORKCAUSE,
    NOTE,
    REALID,
    INNERNUMBER,
    ADJUSTMENTNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    PROTOCOLREASON,
    PROGINDEX,
    DOCNUMBER,
    SECURITYTSIZE,
    SECURITYASIZE,
    AVANSSIZE,
    PREFERENCECRIPPLE,
    PREFERENCERUSPRODUCT,
    PREFERENCEPRISON,
    AGREEMENTEXECUTIONDATE,
    PURCHASECODE,
    PURCHASESOCIALNKO,
    AVERSION,
    PARENTREF,
    TEMPREJECTCAUSE,
    REJECTCAUSE
  ) VALUES (
    new$ID,
    new$BUDGETREF,
    new$FACIALACCCLS,
    new$MULTIPURPOSE,
    new$DOCUMENTDATE,
    new$ACCEPTDATE,
    new$PERIOD,
    new$ACCEPTSUMMA,
    new$SALETYPE,
    new$REJECTCLS,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$DOCSTATEREF,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$LASTADJUSTMENT,
    new$LASTACCEPTED,
    new$ADJUSTMENTREF,
    new$ACCEPTED,
    new$EXPORTDATE,
    new$YEARACCEPTSUMMA,
    new$TENDEROPTION,
    new$TENDERTARGET,
    new$RVERSION,
    new$ALLOWANCE,
    new$REFINEMENTCAUSE,
    new$PREFERENCE,
    new$PREFERENCESIZE,
    new$SECURITY,
    new$UNKNOWNAMOUNT,
    new$PERIODYEAR,
    new$SUPPORTUNDERTAKER,
    new$AYEAR,
    new$REWORKCAUSE,
    new$NOTE,
    new$REALID,
    new$INNERNUMBER,
    new$ADJUSTMENTNUMBER,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$PROTOCOLREASON,
    new$PROGINDEX,
    new$DOCNUMBER,
    new$SECURITYTSIZE,
    new$SECURITYASIZE,
    new$AVANSSIZE,
    new$PREFERENCECRIPPLE,
    new$PREFERENCERUSPRODUCT,
    new$PREFERENCEPRISON,
    new$AGREEMENTEXECUTIONDATE,
    new$PURCHASECODE,
    new$PURCHASESOCIALNKO,
    new$AVERSION,
    new$PARENTREF,
    new$TEMPREJECTCAUSE,
    new$REJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_10 (TR_TENDERCAPTION_AI_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/
  /*      */
  if ((new$AdjustmentNumber > 0) and (new$LastAdjustment = 1)) then
    update TenderCaption set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);
    if (new$LastAccepted = 1) then
      update TenderCaption set
      LastAccepted = 0,
      RVersion = -1
      where (ID = new$AdjustmentRef);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_TENDERCAPTION_AI_500)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   DELETE FROM delrecindexes
         WHERE (tableid = 139) AND (recordid = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_TENDERCAPTION_IU
  INSTEAD OF UPDATE
  ON TENDERCAPTION
  FOR EACH ROW
DECLARE
  new$ID TENDERCAPTION.ID%TYPE := :NEW.ID;
  new$BUDGETREF TENDERCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FACIALACCCLS TENDERCAPTION.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$MULTIPURPOSE TENDERCAPTION.MULTIPURPOSE%TYPE := :NEW.MULTIPURPOSE;
  new$DOCUMENTDATE TENDERCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE TENDERCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PERIOD TENDERCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$ACCEPTSUMMA TENDERCAPTION.ACCEPTSUMMA%TYPE := :NEW.ACCEPTSUMMA;
  new$SALETYPE TENDERCAPTION.SALETYPE%TYPE := :NEW.SALETYPE;
  new$REJECTCLS TENDERCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS TENDERCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID TENDERCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID TENDERCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCSTATEREF TENDERCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CREATERUSER TENDERCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TENDERCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE TENDERCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER TENDERCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$LASTADJUSTMENT TENDERCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED TENDERCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$ADJUSTMENTREF TENDERCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ACCEPTED TENDERCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$EXPORTDATE TENDERCAPTION.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$YEARACCEPTSUMMA TENDERCAPTION.YEARACCEPTSUMMA%TYPE := :NEW.YEARACCEPTSUMMA;
  new$TENDEROPTION TENDERCAPTION.TENDEROPTION%TYPE := :NEW.TENDEROPTION;
  new$TENDERTARGET TENDERCAPTION.TENDERTARGET%TYPE := :NEW.TENDERTARGET;
  new$RVERSION TENDERCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$ALLOWANCE TENDERCAPTION.ALLOWANCE%TYPE := :NEW.ALLOWANCE;
  new$REFINEMENTCAUSE TENDERCAPTION.REFINEMENTCAUSE%TYPE := :NEW.REFINEMENTCAUSE;
  new$PREFERENCE TENDERCAPTION.PREFERENCE%TYPE := :NEW.PREFERENCE;
  new$PREFERENCESIZE TENDERCAPTION.PREFERENCESIZE%TYPE := :NEW.PREFERENCESIZE;
  new$SECURITY TENDERCAPTION.SECURITY%TYPE := :NEW.SECURITY;
  new$UNKNOWNAMOUNT TENDERCAPTION.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PERIODYEAR TENDERCAPTION.PERIODYEAR%TYPE := :NEW.PERIODYEAR;
  new$SUPPORTUNDERTAKER TENDERCAPTION.SUPPORTUNDERTAKER%TYPE := :NEW.SUPPORTUNDERTAKER;
  new$AYEAR TENDERCAPTION.AYEAR%TYPE := :NEW.AYEAR;
  new$REWORKCAUSE TENDERCAPTION.REWORKCAUSE%TYPE := :NEW.REWORKCAUSE;
  new$NOTE TENDERCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$REALID TENDERCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER TENDERCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTNUMBER TENDERCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$SENDERIDKEY TENDERCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY TENDERCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$PROTOCOLREASON TENDERCAPTION.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$PROGINDEX TENDERCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$DOCNUMBER TENDERCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SECURITYTSIZE TENDERCAPTION.SECURITYTSIZE%TYPE := :NEW.SECURITYTSIZE;
  new$SECURITYASIZE TENDERCAPTION.SECURITYASIZE%TYPE := :NEW.SECURITYASIZE;
  new$AVANSSIZE TENDERCAPTION.AVANSSIZE%TYPE := :NEW.AVANSSIZE;
  new$PREFERENCECRIPPLE TENDERCAPTION.PREFERENCECRIPPLE%TYPE := :NEW.PREFERENCECRIPPLE;
  new$PREFERENCERUSPRODUCT TENDERCAPTION.PREFERENCERUSPRODUCT%TYPE := :NEW.PREFERENCERUSPRODUCT;
  new$PREFERENCEPRISON TENDERCAPTION.PREFERENCEPRISON%TYPE := :NEW.PREFERENCEPRISON;
  new$AGREEMENTEXECUTIONDATE TENDERCAPTION.AGREEMENTEXECUTIONDATE%TYPE := :NEW.AGREEMENTEXECUTIONDATE;
  new$PURCHASECODE TENDERCAPTION.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$PURCHASESOCIALNKO TENDERCAPTION.PURCHASESOCIALNKO%TYPE := :NEW.PURCHASESOCIALNKO;
  new$AVERSION TENDERCAPTION.AVERSION%TYPE := :NEW.AVERSION;
  new$PARENTREF TENDERCAPTION.PARENTREF%TYPE := :NEW.PARENTREF;
  new$TEMPREJECTCAUSE TENDERCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
  new$REJECTCAUSE TENDERCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  CurVal$ NUMBER(10);
  DetCount$ NUMBER(10);
  ParentProgIndex$ NUMBER(10);
  ParentInnerNumber$ NUMBER(10);
  AdjParentRef$ NUMBER(10);
  AdjParentInnerNumber$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_TENDERCAPTION_BU_0)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  /*         ( ) */
  if (new$ProgIndex = 230 and new$Multipurpose is null) then
    new$Multipurpose := 0;
  END IF;
  if (new$AcceptSumma is null) then
    new$AcceptSumma := 0;
  END IF;
  if (new$YearAcceptSumma is null) then
    new$YearAcceptSumma := 0;
  END IF;
  if (new$Allowance is null) then
    new$Allowance := 0;
  END IF;
  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if (not((new$BudgetRef is null) and (:old.BudgetRef is null))) then
      select count(ID)         into DetCount$ from TENDERSOURCEORG where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERCONTACTS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERSUPDOCUMENT where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERSUPPLEMENTS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERYARDSTICKS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TenderLot where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  if (new$SaleType is null) then
    new$SaleType := 0;
  END IF;
  if (new$TenderOption is null) then
    new$TenderOption := 0;
  END IF;
  if (new$InnerNumber is Null) then
    new$InnerNumber := GEN_ID('G_TenderInnerNumber',1);
  END IF;
  if (new$RefinementCause is Null) then
    new$RefinementCause := 0;
  END IF;
  if (new$Preference is Null) then
    new$Preference := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$SupportUndertaker is null) then
    new$SupportUndertaker := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_3 (TR_TENDERCAPTION_BU_3)
-- Create 03.12.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   /*             */
   new$AdjustmentRef := :OLD.AdjustmentRef;

-- - - - - - - - - - - - -
-- BU_5 (TR_TENDERCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_TENDERCAPTION_BU_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/
  if ((new$InnerNumber <> :old.InnerNumber) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber)) then
    RaiseException('EX_AGR_CHANGEINNERNUMS');
  END IF;

  /*   !!!*/
  if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and
  ((new$Accepted = 1) or (new$AcceptDate is null))) then
    RaiseException('EX_RollbackCancel');
  END IF;

  /*  ,     LastAccepted*/
  if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) or
  ((:old.Accepted = 0) and (new$Accepted = 1) and (new$AcceptDate is not null))) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;

    else
      RaiseException('EX_Ten_ChangeStateAdjust');
    END IF;
  END IF;

  /*    ,     LastAccepted*/
  if (((:old.AcceptDate is not null) and (:old.Accepted = 1)) and
  ((new$Accepted = 0) or (new$AcceptDate is null))) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 0;

    else
      RaiseException('EX_Ten_ChangeStateAdjust');
    END IF;
  END IF;

  /*   ,     LastAdjustment*/
  if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 0)) or
  ((:old.Accepted = 1) and (new$Accepted = 0) and (new$AcceptDate is not null))) then
    if (new$LastAdjustment = 1) then
      new$LastAdjustment := 0;
      new$LastAccepted := 0;

    else
      RaiseException('EX_Ten_ChangeStateAdjust');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_TENDERCAPTION_BU_30)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  /* :  /    / */
  if (new$ParentRef is not null
  /*  ,   */
  and  (:old.ParentRef is null
  or (:old.ParentRef is not null and :old.ParentRef <> new$ParentRef)))
  then
    /* :     ParentRef  */
    if (new$LastAdjustment = 0) then
      RaiseException('EX_ChangeAdjTenderParentRef');
    END IF;
    BEGIN
      select ProgIndex, InnerNumber
      into ParentProgIndex$, ParentInnerNumber$     from TenderCaption
      where ID=new$ParentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /* :  /    / */
    if  ((new$ProgIndex=243 and ParentProgIndex$ <> 242)
    or (new$ProgIndex=241 and ParentProgIndex$ <> 240))
    then
      RaiseException('EX_IncorrectTenderParentRef');
    END IF;
    /* :       /     ( ,    ) */
    if (new$AdjustmentRef is not null) then
      BEGIN
        select ParentRef
        into AdjParentRef$       from TenderCaption
        where ID=new$AdjustmentRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (AdjParentRef$ is not null) then
        BEGIN
          select InnerNumber
          into AdjParentInnerNumber$         from TenderCaption
          where ID=AdjParentRef$

          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        if (AdjParentInnerNumber$ <> ParentInnerNumber$) then
          RaiseException('EX_IncorrectAdjTenderParentRef');
        END IF;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_50 (TR_TENDERCAPTION_BU_50)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  if (new$InnerNumber is not null) then
    CurVal$ := GEN_ID('G_TENDERINNERNUMBER',0);
    if (CurVal$ < new$InnerNumber) then
      CurVal$ := GEN_ID('G_TENDERINNERNUMBER',new$InnerNumber - CurVal$);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_TENDERCAPTION_BU_200)
-- Create 03.12.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   /*        */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
        VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef);
   END IF;

-- - - - - - - - - - - - -
-- BU_600 (tendercaption_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_TENDERCAPTION_BU_700)
-- Create 14.10.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_TENDERCAPTION SET
    ID = new$ID,
    BUDGETREF = new$BUDGETREF,
    FACIALACCCLS = new$FACIALACCCLS,
    MULTIPURPOSE = new$MULTIPURPOSE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    PERIOD = new$PERIOD,
    ACCEPTSUMMA = new$ACCEPTSUMMA,
    SALETYPE = new$SALETYPE,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DOCSTATEREF = new$DOCSTATEREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    ACCEPTED = new$ACCEPTED,
    EXPORTDATE = new$EXPORTDATE,
    YEARACCEPTSUMMA = new$YEARACCEPTSUMMA,
    TENDEROPTION = new$TENDEROPTION,
    TENDERTARGET = new$TENDERTARGET,
    RVERSION = new$RVERSION,
    ALLOWANCE = new$ALLOWANCE,
    REFINEMENTCAUSE = new$REFINEMENTCAUSE,
    PREFERENCE = new$PREFERENCE,
    PREFERENCESIZE = new$PREFERENCESIZE,
    SECURITY = new$SECURITY,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PERIODYEAR = new$PERIODYEAR,
    SUPPORTUNDERTAKER = new$SUPPORTUNDERTAKER,
    AYEAR = new$AYEAR,
    REWORKCAUSE = new$REWORKCAUSE,
    NOTE = new$NOTE,
    REALID = new$REALID,
    INNERNUMBER = new$INNERNUMBER,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    PROTOCOLREASON = new$PROTOCOLREASON,
    PROGINDEX = new$PROGINDEX,
    DOCNUMBER = new$DOCNUMBER,
    SECURITYTSIZE = new$SECURITYTSIZE,
    SECURITYASIZE = new$SECURITYASIZE,
    AVANSSIZE = new$AVANSSIZE,
    PREFERENCECRIPPLE = new$PREFERENCECRIPPLE,
    PREFERENCERUSPRODUCT = new$PREFERENCERUSPRODUCT,
    PREFERENCEPRISON = new$PREFERENCEPRISON,
    AGREEMENTEXECUTIONDATE = new$AGREEMENTEXECUTIONDATE,
    PURCHASECODE = new$PURCHASECODE,
    PURCHASESOCIALNKO = new$PURCHASESOCIALNKO,
    AVERSION = new$AVERSION,
    PARENTREF = new$PARENTREF,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_TENDERCAPTION_AU_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.1*/
  /*      */
  /*     ,       */
  if ((new$AdjustmentNumber > 0) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update TenderCaption set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

  /*       LastAdjustment    */
  if ((new$AdjustmentNumber > 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update TenderCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_TENDERCAPTION_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   2.0*/
  /*       ,      */
  if (:old.FacialAccCls <> new$FacialAccCls) then
    update TenderProduct set
    RVersion = -1,
    FacialAccCls = new$FacialAccCls
    where
    (RecordIndex = new$ID) and (ProgIndex = 230);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_TENDERCAPTION_AU_500)
-- Create 28.04.2005
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
           VALUES (139, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
            WHERE (TableID = 139) AND (RecordId = new$ID);
   END IF;

END;
/
update TENDERCAPTION set
  REJECTCAUSE = TempRejectCause
/
commit work 
/
ALTER TABLE TB_TENDERCAPTION DROP (TempRejectCause)
/

CREATE OR REPLACE VIEW TENDERCAPTION (
  ID,
  BUDGETREF,
  FACIALACCCLS,
  MULTIPURPOSE,
  DOCUMENTDATE,
  ACCEPTDATE,
  PERIOD,
  ACCEPTSUMMA,
  SALETYPE,
  REJECTCLS,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  DOCSTATEREF,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  LASTADJUSTMENT,
  LASTACCEPTED,
  ADJUSTMENTREF,
  ACCEPTED,
  EXPORTDATE,
  YEARACCEPTSUMMA,
  TENDEROPTION,
  TENDERTARGET,
  RVERSION,
  ALLOWANCE,
  REFINEMENTCAUSE,
  PREFERENCE,
  PREFERENCESIZE,
  SECURITY,
  UNKNOWNAMOUNT,
  PERIODYEAR,
  SUPPORTUNDERTAKER,
  AYEAR,
  REWORKCAUSE,
  NOTE,
  REALID,
  INNERNUMBER,
  ADJUSTMENTNUMBER,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  PROTOCOLREASON,
  PROGINDEX,
  DOCNUMBER,
  SECURITYTSIZE,
  SECURITYASIZE,
  AVANSSIZE,
  PREFERENCECRIPPLE,
  PREFERENCERUSPRODUCT,
  PREFERENCEPRISON,
  AGREEMENTEXECUTIONDATE,
  PURCHASECODE,
  PURCHASESOCIALNKO,
  AVERSION,
  PARENTREF,
  REJECTCAUSE)
AS
  SELECT
    ID,
    BUDGETREF,
    FACIALACCCLS,
    MULTIPURPOSE,
    DOCUMENTDATE,
    ACCEPTDATE,
    PERIOD,
    ACCEPTSUMMA,
    SALETYPE,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DOCSTATEREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    LASTADJUSTMENT,
    LASTACCEPTED,
    ADJUSTMENTREF,
    ACCEPTED,
    EXPORTDATE,
    YEARACCEPTSUMMA,
    TENDEROPTION,
    TENDERTARGET,
    RVERSION,
    ALLOWANCE,
    REFINEMENTCAUSE,
    PREFERENCE,
    PREFERENCESIZE,
    SECURITY,
    UNKNOWNAMOUNT,
    PERIODYEAR,
    SUPPORTUNDERTAKER,
    AYEAR,
    REWORKCAUSE,
    NOTE,
    REALID,
    INNERNUMBER,
    ADJUSTMENTNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    PROTOCOLREASON,
    PROGINDEX,
    DOCNUMBER,
    SECURITYTSIZE,
    SECURITYASIZE,
    AVANSSIZE,
    PREFERENCECRIPPLE,
    PREFERENCERUSPRODUCT,
    PREFERENCEPRISON,
    AGREEMENTEXECUTIONDATE,
    PURCHASECODE,
    PURCHASESOCIALNKO,
    AVERSION,
    PARENTREF,
    REJECTCAUSE
  FROM TB_TENDERCAPTION
/

CREATE OR REPLACE TRIGGER TR_TENDERCAPTION_ID
  INSTEAD OF DELETE
  ON TENDERCAPTION
  FOR EACH ROW
DECLARE
  cnt$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_TENDERCAPTION_BD)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   5.1 */
  select count(ID) into cnt$ from TenderCaption where (AdjustmentRef = :old.ID) ;
  /*    ,    */
  if (cnt$ = 0) then
    delete from TenderSupDocument where (RecordIndex = :old.ID);
    delete from TenderYardsticks where (RecordIndex = :old.ID);
    delete from TenderSourceOrg where (RecordIndex = :old.ID);
    delete from TenderContacts where (RecordIndex = :old.ID);
    delete from TenderSupplements where (RecordIndex = :old.ID);
    delete from TenderProduct where (RecordIndex = :old.ID);
    delete from TenderLot where (RecordIndex = :old.ID);

  else
    RaiseException('EX_Ten_CantDelAdjustmented');
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_TENDERCAPTION
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_0 (TR_TenderCaption_AD)
-- Last update 06.08.2010
-- - - - - - - - - - - - -

  delete from TENDERPRODUCT where (RecordIndex = :old.ID);
  delete from TenderSourceOrg where (RecordIndex = :old.ID);

-- - - - - - - - - - - - -
-- AD_10 (TR_TENDERCAPTION_AD_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/
  /*   LastAdjustment     */
  if ((:old.AdjustmentNumber > 0) and (:old.LastAdjustment = 1)) then
    update TenderCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;
  /*   LastAccepted     */
  if ((:old.AdjustmentNumber > 0) and (:old.LastAccepted = 1)) then
    update TenderCaption set
    LastAccepted = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AD_200 (TR_TENDERCAPTION_AD_200)
-- Create 03.12.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  /*         */
  delete from StateJumpHistory where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_TENDERCAPTION_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordId, DeleteDate, ProgIndex) values (139, :old.ID, SYSDATE, :old.ProgIndex);

END;
/

CREATE OR REPLACE TRIGGER TR_TENDERCAPTION_II
  INSTEAD OF INSERT
  ON TENDERCAPTION
  FOR EACH ROW
DECLARE
  new$ID TENDERCAPTION.ID%TYPE := :NEW.ID;
  new$BUDGETREF TENDERCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FACIALACCCLS TENDERCAPTION.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$MULTIPURPOSE TENDERCAPTION.MULTIPURPOSE%TYPE := :NEW.MULTIPURPOSE;
  new$DOCUMENTDATE TENDERCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE TENDERCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PERIOD TENDERCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$ACCEPTSUMMA TENDERCAPTION.ACCEPTSUMMA%TYPE := :NEW.ACCEPTSUMMA;
  new$SALETYPE TENDERCAPTION.SALETYPE%TYPE := :NEW.SALETYPE;
  new$REJECTCLS TENDERCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS TENDERCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID TENDERCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID TENDERCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCSTATEREF TENDERCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CREATERUSER TENDERCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TENDERCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE TENDERCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER TENDERCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$LASTADJUSTMENT TENDERCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED TENDERCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$ADJUSTMENTREF TENDERCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ACCEPTED TENDERCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$EXPORTDATE TENDERCAPTION.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$YEARACCEPTSUMMA TENDERCAPTION.YEARACCEPTSUMMA%TYPE := :NEW.YEARACCEPTSUMMA;
  new$TENDEROPTION TENDERCAPTION.TENDEROPTION%TYPE := :NEW.TENDEROPTION;
  new$TENDERTARGET TENDERCAPTION.TENDERTARGET%TYPE := :NEW.TENDERTARGET;
  new$RVERSION TENDERCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$ALLOWANCE TENDERCAPTION.ALLOWANCE%TYPE := :NEW.ALLOWANCE;
  new$REFINEMENTCAUSE TENDERCAPTION.REFINEMENTCAUSE%TYPE := :NEW.REFINEMENTCAUSE;
  new$PREFERENCE TENDERCAPTION.PREFERENCE%TYPE := :NEW.PREFERENCE;
  new$PREFERENCESIZE TENDERCAPTION.PREFERENCESIZE%TYPE := :NEW.PREFERENCESIZE;
  new$SECURITY TENDERCAPTION.SECURITY%TYPE := :NEW.SECURITY;
  new$UNKNOWNAMOUNT TENDERCAPTION.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PERIODYEAR TENDERCAPTION.PERIODYEAR%TYPE := :NEW.PERIODYEAR;
  new$SUPPORTUNDERTAKER TENDERCAPTION.SUPPORTUNDERTAKER%TYPE := :NEW.SUPPORTUNDERTAKER;
  new$AYEAR TENDERCAPTION.AYEAR%TYPE := :NEW.AYEAR;
  new$REWORKCAUSE TENDERCAPTION.REWORKCAUSE%TYPE := :NEW.REWORKCAUSE;
  new$NOTE TENDERCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$REALID TENDERCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER TENDERCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTNUMBER TENDERCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$SENDERIDKEY TENDERCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY TENDERCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$PROTOCOLREASON TENDERCAPTION.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$PROGINDEX TENDERCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$DOCNUMBER TENDERCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SECURITYTSIZE TENDERCAPTION.SECURITYTSIZE%TYPE := :NEW.SECURITYTSIZE;
  new$SECURITYASIZE TENDERCAPTION.SECURITYASIZE%TYPE := :NEW.SECURITYASIZE;
  new$AVANSSIZE TENDERCAPTION.AVANSSIZE%TYPE := :NEW.AVANSSIZE;
  new$PREFERENCECRIPPLE TENDERCAPTION.PREFERENCECRIPPLE%TYPE := :NEW.PREFERENCECRIPPLE;
  new$PREFERENCERUSPRODUCT TENDERCAPTION.PREFERENCERUSPRODUCT%TYPE := :NEW.PREFERENCERUSPRODUCT;
  new$PREFERENCEPRISON TENDERCAPTION.PREFERENCEPRISON%TYPE := :NEW.PREFERENCEPRISON;
  new$AGREEMENTEXECUTIONDATE TENDERCAPTION.AGREEMENTEXECUTIONDATE%TYPE := :NEW.AGREEMENTEXECUTIONDATE;
  new$PURCHASECODE TENDERCAPTION.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$PURCHASESOCIALNKO TENDERCAPTION.PURCHASESOCIALNKO%TYPE := :NEW.PURCHASESOCIALNKO;
  new$AVERSION TENDERCAPTION.AVERSION%TYPE := :NEW.AVERSION;
  new$PARENTREF TENDERCAPTION.PARENTREF%TYPE := :NEW.PARENTREF;
  new$REJECTCAUSE TENDERCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  Tmp$ NUMBER(10);
  AdjID$ NUMBER(10);
  CurVal$ NUMBER(10);
  ParentProgIndex$ NUMBER(10);
  ParentInnerNumber$ NUMBER(10);
  AdjParentRef$ NUMBER(10);
  AdjParentInnerNumber$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_TENDERCAPTION_BI)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  /*         ( ) */
  if (new$ProgIndex = 230 and new$Multipurpose is null) then
    new$Multipurpose := 0;
  END IF;
  if (new$AcceptSumma is null) then
    new$AcceptSumma := 0;
  END IF;
  if (new$YearAcceptSumma is null) then
    new$YearAcceptSumma := 0;
  END IF;
  if (new$Allowance is null) then
    new$Allowance := 0;
  END IF;

  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    BEGIN
      select fa.BudgetRef       into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = new$FacialAccCls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    GetIntConst(-1,3,new$BudgetRef);
  END IF;

  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  if (new$SaleType is null) then
    new$SaleType := 0;
  END IF;
  if (new$TenderOption is null) then
    new$TenderOption := 0;
  END IF;
  if (new$InnerNumber is Null) then
    new$InnerNumber := GEN_ID('G_TenderInnerNumber',1);
  END IF;
  if (new$RefinementCause is Null) then
    new$RefinementCause := 0;
  END IF;
  if (new$Preference is Null) then
    new$Preference := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$SupportUndertaker is null) then
    new$SupportUndertaker := 0;
  END IF;
  if (new$PurchaseSocialNKO is null) then
    new$PurchaseSocialNKO := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_TENDERCAPTION_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_TENDERCAPTION_BI_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/

  /*    .*/
  if (new$InnerNumber is null) then
    RaiseException('EX_Ten_InnerNumsIsNull');
  END IF;

  /*    */
  select max(AdjustmentNumber)
  into Tmp$         from TenderCaption
  where (InnerNumber = new$InnerNumber)
  ;
  /*      ,   0*/
  if (Tmp$ is null) then
    new$AdjustmentNumber := 0;

  else
    new$AdjustmentNumber := Tmp$ + 1;
  END IF;

  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;

  else
    new$LastAdjustment := 1;
  END IF;

  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then
    new$LastAccepted := 1;

  else
    new$LastAccepted := 0;
  END IF;

  /*    */
  if (new$AdjustmentNumber > 0) then
    /*      -    */
    select count(ID), max(ID)
    into Tmp$, AdjID$             from TenderCaption
    where (InnerNumber = new$InnerNumber) and (LastAccepted = 1)
    ;
    /*   ,  */
    if (Tmp$ <> 1) then
      RaiseException('EX_Ten_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID)
    into Tmp$             from TenderCaption
    where (InnerNumber = new$InnerNumber) and (AcceptDate is null)
    ;
    if (Tmp$ > 0) then
      RaiseException('EX_Ten_AdjustDuplicate');
    END IF;
    /* ,    ,    */
    new$AdjustmentRef := AdjID$;

  else /*     */
    /*       (    )*/
    new$AdjustmentRef := null;

  END IF;

-- - - - - - - - - - - - -
-- BI_30 (TR_TENDERCAPTION_BI_30)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (new$ParentRef is not null) then
    BEGIN
      select ProgIndex, InnerNumber
      into ParentProgIndex$, ParentInnerNumber$     from TenderCaption
      where ID=new$ParentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /* :  /    / */
    if  ((new$ProgIndex=243 and ParentProgIndex$ <> 242)
    or (new$ProgIndex=241 and ParentProgIndex$ <> 240))
    then
      RaiseException('EX_IncorrectTenderParentRef');
    END IF;
    /* :       /     ( ,    ) */
    if (new$AdjustmentRef is not null) then
      BEGIN
        select ParentRef
        into AdjParentRef$       from TenderCaption
        where ID=new$AdjustmentRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (AdjParentRef$ is not null) then
        BEGIN
          select InnerNumber
          into AdjParentInnerNumber$         from TenderCaption
          where ID=AdjParentRef$

          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        if (AdjParentInnerNumber$ <> ParentInnerNumber$) then
          RaiseException('EX_IncorrectAdjTenderParentRef');
        END IF;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_40 (TR_TENDERCAPTION_BI_40)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$senderId is null) then
    new$senderIdKey := -1;

  else
    new$senderIdKey := new$senderId;
  END IF;
  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;

  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_50 (TR_TENDERCAPTION_BI_50)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  if (new$InnerNumber is not null) then
    CurVal$ := GEN_ID('G_TENDERINNERNUMBER',0);
    if (CurVal$ < new$InnerNumber) then
      CurVal$ := GEN_ID('G_TENDERINNERNUMBER',new$InnerNumber - CurVal$);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_TENDERCAPTION_BI_500)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- BI_600 (tendercaption_realid_bi_600)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_TENDERCAPTION (
    ID,
    BUDGETREF,
    FACIALACCCLS,
    MULTIPURPOSE,
    DOCUMENTDATE,
    ACCEPTDATE,
    PERIOD,
    ACCEPTSUMMA,
    SALETYPE,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DOCSTATEREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    LASTADJUSTMENT,
    LASTACCEPTED,
    ADJUSTMENTREF,
    ACCEPTED,
    EXPORTDATE,
    YEARACCEPTSUMMA,
    TENDEROPTION,
    TENDERTARGET,
    RVERSION,
    ALLOWANCE,
    REFINEMENTCAUSE,
    PREFERENCE,
    PREFERENCESIZE,
    SECURITY,
    UNKNOWNAMOUNT,
    PERIODYEAR,
    SUPPORTUNDERTAKER,
    AYEAR,
    REWORKCAUSE,
    NOTE,
    REALID,
    INNERNUMBER,
    ADJUSTMENTNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    PROTOCOLREASON,
    PROGINDEX,
    DOCNUMBER,
    SECURITYTSIZE,
    SECURITYASIZE,
    AVANSSIZE,
    PREFERENCECRIPPLE,
    PREFERENCERUSPRODUCT,
    PREFERENCEPRISON,
    AGREEMENTEXECUTIONDATE,
    PURCHASECODE,
    PURCHASESOCIALNKO,
    AVERSION,
    PARENTREF,
    REJECTCAUSE
  ) VALUES (
    new$ID,
    new$BUDGETREF,
    new$FACIALACCCLS,
    new$MULTIPURPOSE,
    new$DOCUMENTDATE,
    new$ACCEPTDATE,
    new$PERIOD,
    new$ACCEPTSUMMA,
    new$SALETYPE,
    new$REJECTCLS,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$DOCSTATEREF,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$LASTADJUSTMENT,
    new$LASTACCEPTED,
    new$ADJUSTMENTREF,
    new$ACCEPTED,
    new$EXPORTDATE,
    new$YEARACCEPTSUMMA,
    new$TENDEROPTION,
    new$TENDERTARGET,
    new$RVERSION,
    new$ALLOWANCE,
    new$REFINEMENTCAUSE,
    new$PREFERENCE,
    new$PREFERENCESIZE,
    new$SECURITY,
    new$UNKNOWNAMOUNT,
    new$PERIODYEAR,
    new$SUPPORTUNDERTAKER,
    new$AYEAR,
    new$REWORKCAUSE,
    new$NOTE,
    new$REALID,
    new$INNERNUMBER,
    new$ADJUSTMENTNUMBER,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$PROTOCOLREASON,
    new$PROGINDEX,
    new$DOCNUMBER,
    new$SECURITYTSIZE,
    new$SECURITYASIZE,
    new$AVANSSIZE,
    new$PREFERENCECRIPPLE,
    new$PREFERENCERUSPRODUCT,
    new$PREFERENCEPRISON,
    new$AGREEMENTEXECUTIONDATE,
    new$PURCHASECODE,
    new$PURCHASESOCIALNKO,
    new$AVERSION,
    new$PARENTREF,
    new$REJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_10 (TR_TENDERCAPTION_AI_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/
  /*      */
  if ((new$AdjustmentNumber > 0) and (new$LastAdjustment = 1)) then
    update TenderCaption set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);
    if (new$LastAccepted = 1) then
      update TenderCaption set
      LastAccepted = 0,
      RVersion = -1
      where (ID = new$AdjustmentRef);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_TENDERCAPTION_AI_500)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   DELETE FROM delrecindexes
         WHERE (tableid = 139) AND (recordid = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_TENDERCAPTION_IU
  INSTEAD OF UPDATE
  ON TENDERCAPTION
  FOR EACH ROW
DECLARE
  new$ID TENDERCAPTION.ID%TYPE := :NEW.ID;
  new$BUDGETREF TENDERCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FACIALACCCLS TENDERCAPTION.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$MULTIPURPOSE TENDERCAPTION.MULTIPURPOSE%TYPE := :NEW.MULTIPURPOSE;
  new$DOCUMENTDATE TENDERCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE TENDERCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PERIOD TENDERCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$ACCEPTSUMMA TENDERCAPTION.ACCEPTSUMMA%TYPE := :NEW.ACCEPTSUMMA;
  new$SALETYPE TENDERCAPTION.SALETYPE%TYPE := :NEW.SALETYPE;
  new$REJECTCLS TENDERCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS TENDERCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID TENDERCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID TENDERCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCSTATEREF TENDERCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CREATERUSER TENDERCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TENDERCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE TENDERCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER TENDERCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$LASTADJUSTMENT TENDERCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED TENDERCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$ADJUSTMENTREF TENDERCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ACCEPTED TENDERCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$EXPORTDATE TENDERCAPTION.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$YEARACCEPTSUMMA TENDERCAPTION.YEARACCEPTSUMMA%TYPE := :NEW.YEARACCEPTSUMMA;
  new$TENDEROPTION TENDERCAPTION.TENDEROPTION%TYPE := :NEW.TENDEROPTION;
  new$TENDERTARGET TENDERCAPTION.TENDERTARGET%TYPE := :NEW.TENDERTARGET;
  new$RVERSION TENDERCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$ALLOWANCE TENDERCAPTION.ALLOWANCE%TYPE := :NEW.ALLOWANCE;
  new$REFINEMENTCAUSE TENDERCAPTION.REFINEMENTCAUSE%TYPE := :NEW.REFINEMENTCAUSE;
  new$PREFERENCE TENDERCAPTION.PREFERENCE%TYPE := :NEW.PREFERENCE;
  new$PREFERENCESIZE TENDERCAPTION.PREFERENCESIZE%TYPE := :NEW.PREFERENCESIZE;
  new$SECURITY TENDERCAPTION.SECURITY%TYPE := :NEW.SECURITY;
  new$UNKNOWNAMOUNT TENDERCAPTION.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PERIODYEAR TENDERCAPTION.PERIODYEAR%TYPE := :NEW.PERIODYEAR;
  new$SUPPORTUNDERTAKER TENDERCAPTION.SUPPORTUNDERTAKER%TYPE := :NEW.SUPPORTUNDERTAKER;
  new$AYEAR TENDERCAPTION.AYEAR%TYPE := :NEW.AYEAR;
  new$REWORKCAUSE TENDERCAPTION.REWORKCAUSE%TYPE := :NEW.REWORKCAUSE;
  new$NOTE TENDERCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$REALID TENDERCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER TENDERCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTNUMBER TENDERCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$SENDERIDKEY TENDERCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY TENDERCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$PROTOCOLREASON TENDERCAPTION.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$PROGINDEX TENDERCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$DOCNUMBER TENDERCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SECURITYTSIZE TENDERCAPTION.SECURITYTSIZE%TYPE := :NEW.SECURITYTSIZE;
  new$SECURITYASIZE TENDERCAPTION.SECURITYASIZE%TYPE := :NEW.SECURITYASIZE;
  new$AVANSSIZE TENDERCAPTION.AVANSSIZE%TYPE := :NEW.AVANSSIZE;
  new$PREFERENCECRIPPLE TENDERCAPTION.PREFERENCECRIPPLE%TYPE := :NEW.PREFERENCECRIPPLE;
  new$PREFERENCERUSPRODUCT TENDERCAPTION.PREFERENCERUSPRODUCT%TYPE := :NEW.PREFERENCERUSPRODUCT;
  new$PREFERENCEPRISON TENDERCAPTION.PREFERENCEPRISON%TYPE := :NEW.PREFERENCEPRISON;
  new$AGREEMENTEXECUTIONDATE TENDERCAPTION.AGREEMENTEXECUTIONDATE%TYPE := :NEW.AGREEMENTEXECUTIONDATE;
  new$PURCHASECODE TENDERCAPTION.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$PURCHASESOCIALNKO TENDERCAPTION.PURCHASESOCIALNKO%TYPE := :NEW.PURCHASESOCIALNKO;
  new$AVERSION TENDERCAPTION.AVERSION%TYPE := :NEW.AVERSION;
  new$PARENTREF TENDERCAPTION.PARENTREF%TYPE := :NEW.PARENTREF;
  new$REJECTCAUSE TENDERCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  CurVal$ NUMBER(10);
  DetCount$ NUMBER(10);
  ParentProgIndex$ NUMBER(10);
  ParentInnerNumber$ NUMBER(10);
  AdjParentRef$ NUMBER(10);
  AdjParentInnerNumber$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_TENDERCAPTION_BU_0)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  /*         ( ) */
  if (new$ProgIndex = 230 and new$Multipurpose is null) then
    new$Multipurpose := 0;
  END IF;
  if (new$AcceptSumma is null) then
    new$AcceptSumma := 0;
  END IF;
  if (new$YearAcceptSumma is null) then
    new$YearAcceptSumma := 0;
  END IF;
  if (new$Allowance is null) then
    new$Allowance := 0;
  END IF;
  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if (not((new$BudgetRef is null) and (:old.BudgetRef is null))) then
      select count(ID)         into DetCount$ from TENDERSOURCEORG where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERCONTACTS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERSUPDOCUMENT where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERSUPPLEMENTS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERYARDSTICKS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TenderLot where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  if (new$SaleType is null) then
    new$SaleType := 0;
  END IF;
  if (new$TenderOption is null) then
    new$TenderOption := 0;
  END IF;
  if (new$InnerNumber is Null) then
    new$InnerNumber := GEN_ID('G_TenderInnerNumber',1);
  END IF;
  if (new$RefinementCause is Null) then
    new$RefinementCause := 0;
  END IF;
  if (new$Preference is Null) then
    new$Preference := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$SupportUndertaker is null) then
    new$SupportUndertaker := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_3 (TR_TENDERCAPTION_BU_3)
-- Create 03.12.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   /*             */
   new$AdjustmentRef := :OLD.AdjustmentRef;

-- - - - - - - - - - - - -
-- BU_5 (TR_TENDERCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_TENDERCAPTION_BU_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/
  if ((new$InnerNumber <> :old.InnerNumber) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber)) then
    RaiseException('EX_AGR_CHANGEINNERNUMS');
  END IF;

  /*   !!!*/
  if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and
  ((new$Accepted = 1) or (new$AcceptDate is null))) then
    RaiseException('EX_RollbackCancel');
  END IF;

  /*  ,     LastAccepted*/
  if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) or
  ((:old.Accepted = 0) and (new$Accepted = 1) and (new$AcceptDate is not null))) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;

    else
      RaiseException('EX_Ten_ChangeStateAdjust');
    END IF;
  END IF;

  /*    ,     LastAccepted*/
  if (((:old.AcceptDate is not null) and (:old.Accepted = 1)) and
  ((new$Accepted = 0) or (new$AcceptDate is null))) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 0;

    else
      RaiseException('EX_Ten_ChangeStateAdjust');
    END IF;
  END IF;

  /*   ,     LastAdjustment*/
  if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 0)) or
  ((:old.Accepted = 1) and (new$Accepted = 0) and (new$AcceptDate is not null))) then
    if (new$LastAdjustment = 1) then
      new$LastAdjustment := 0;
      new$LastAccepted := 0;

    else
      RaiseException('EX_Ten_ChangeStateAdjust');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_TENDERCAPTION_BU_30)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  /* :  /    / */
  if (new$ParentRef is not null
  /*  ,   */
  and  (:old.ParentRef is null
  or (:old.ParentRef is not null and :old.ParentRef <> new$ParentRef)))
  then
    /* :     ParentRef  */
    if (new$LastAdjustment = 0) then
      RaiseException('EX_ChangeAdjTenderParentRef');
    END IF;
    BEGIN
      select ProgIndex, InnerNumber
      into ParentProgIndex$, ParentInnerNumber$     from TenderCaption
      where ID=new$ParentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /* :  /    / */
    if  ((new$ProgIndex=243 and ParentProgIndex$ <> 242)
    or (new$ProgIndex=241 and ParentProgIndex$ <> 240))
    then
      RaiseException('EX_IncorrectTenderParentRef');
    END IF;
    /* :       /     ( ,    ) */
    if (new$AdjustmentRef is not null) then
      BEGIN
        select ParentRef
        into AdjParentRef$       from TenderCaption
        where ID=new$AdjustmentRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (AdjParentRef$ is not null) then
        BEGIN
          select InnerNumber
          into AdjParentInnerNumber$         from TenderCaption
          where ID=AdjParentRef$

          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        if (AdjParentInnerNumber$ <> ParentInnerNumber$) then
          RaiseException('EX_IncorrectAdjTenderParentRef');
        END IF;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_50 (TR_TENDERCAPTION_BU_50)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  if (new$InnerNumber is not null) then
    CurVal$ := GEN_ID('G_TENDERINNERNUMBER',0);
    if (CurVal$ < new$InnerNumber) then
      CurVal$ := GEN_ID('G_TENDERINNERNUMBER',new$InnerNumber - CurVal$);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_TENDERCAPTION_BU_200)
-- Create 03.12.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   /*        */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
        VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef);
   END IF;

-- - - - - - - - - - - - -
-- BU_600 (tendercaption_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_TENDERCAPTION_BU_700)
-- Create 14.10.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_TENDERCAPTION SET
    ID = new$ID,
    BUDGETREF = new$BUDGETREF,
    FACIALACCCLS = new$FACIALACCCLS,
    MULTIPURPOSE = new$MULTIPURPOSE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    PERIOD = new$PERIOD,
    ACCEPTSUMMA = new$ACCEPTSUMMA,
    SALETYPE = new$SALETYPE,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DOCSTATEREF = new$DOCSTATEREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    ACCEPTED = new$ACCEPTED,
    EXPORTDATE = new$EXPORTDATE,
    YEARACCEPTSUMMA = new$YEARACCEPTSUMMA,
    TENDEROPTION = new$TENDEROPTION,
    TENDERTARGET = new$TENDERTARGET,
    RVERSION = new$RVERSION,
    ALLOWANCE = new$ALLOWANCE,
    REFINEMENTCAUSE = new$REFINEMENTCAUSE,
    PREFERENCE = new$PREFERENCE,
    PREFERENCESIZE = new$PREFERENCESIZE,
    SECURITY = new$SECURITY,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PERIODYEAR = new$PERIODYEAR,
    SUPPORTUNDERTAKER = new$SUPPORTUNDERTAKER,
    AYEAR = new$AYEAR,
    REWORKCAUSE = new$REWORKCAUSE,
    NOTE = new$NOTE,
    REALID = new$REALID,
    INNERNUMBER = new$INNERNUMBER,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    PROTOCOLREASON = new$PROTOCOLREASON,
    PROGINDEX = new$PROGINDEX,
    DOCNUMBER = new$DOCNUMBER,
    SECURITYTSIZE = new$SECURITYTSIZE,
    SECURITYASIZE = new$SECURITYASIZE,
    AVANSSIZE = new$AVANSSIZE,
    PREFERENCECRIPPLE = new$PREFERENCECRIPPLE,
    PREFERENCERUSPRODUCT = new$PREFERENCERUSPRODUCT,
    PREFERENCEPRISON = new$PREFERENCEPRISON,
    AGREEMENTEXECUTIONDATE = new$AGREEMENTEXECUTIONDATE,
    PURCHASECODE = new$PURCHASECODE,
    PURCHASESOCIALNKO = new$PURCHASESOCIALNKO,
    AVERSION = new$AVERSION,
    PARENTREF = new$PARENTREF,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_TENDERCAPTION_AU_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.1*/
  /*      */
  /*     ,       */
  if ((new$AdjustmentNumber > 0) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update TenderCaption set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

  /*       LastAdjustment    */
  if ((new$AdjustmentNumber > 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update TenderCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_TENDERCAPTION_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   2.0*/
  /*       ,      */
  if (:old.FacialAccCls <> new$FacialAccCls) then
    update TenderProduct set
    RVersion = -1,
    FacialAccCls = new$FacialAccCls
    where
    (RecordIndex = new$ID) and (ProgIndex = 230);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_TENDERCAPTION_AU_500)
-- Create 28.04.2005
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
           VALUES (139, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
            WHERE (TableID = 139) AND (RecordId = new$ID);
   END IF;

END;
/
ALTER TRIGGER TR_TENDERCAPTION_BU_500 ENABLE
/
commit work 
/
ALTER TRIGGER TR_UTFC_BU_500 DISABLE
/
ALTER TABLE TB_UTYPEDFORMSCAPTION ADD (
  TempRejectCause VARCHAR2(255)
)
/

CREATE OR REPLACE VIEW UTYPEDFORMSCAPTION (
  ID,
  REGIONCLS,
  ACCEPTDATE,
  DOCNUMBER,
  NOTE,
  TYPEDFORM,
  PROGINDEX,
  FACIALACC_CLS,
  ORG_REF,
  CREATERUSER,
  UPDATERUSER,
  CREATEDATE,
  UPDATEDATE,
  EMAIL,
  STATE,
  ERROR,
  SOURCEID,
  SOURCEMAILID,
  AUTOTASKSSERVER,
  DEPARTMENTCLS,
  SENDERID,
  SENDERRECORDID,
  CRYPTOSTATUS,
  UTFRINDEX,
  REPORTDATE,
  ESTIMDATE,
  SELF,
  CLIENTSTYPE,
  SENDKIT,
  SENDSTS,
  SENDDOC,
  MANUALEXEC,
  DATAMODE,
  BUDGETREF,
  REPORTYEAR,
  REJECTCLS,
  REJECTCAUSE,
  DOCSTATEREF,
  RVERSION,
  LASTEXTRCHANGE,
  VERSIONID,
  CONSCLIENT,
  FINT1,
  FINT2,
  FINT3,
  FINT4,
  FINT5,
  FINT6,
  FINT7,
  PARAMS,
  FORMTEXTID,
  REGTEXTID,
  PERIODTEXTID,
  REPORTMONTH,
  ACTIVITYKIND,
  PERIOD,
  TEMPREJECTCAUSE)
AS
  SELECT
    ID,
    REGIONCLS,
    ACCEPTDATE,
    DOCNUMBER,
    NOTE,
    TYPEDFORM,
    PROGINDEX,
    FACIALACC_CLS,
    ORG_REF,
    CREATERUSER,
    UPDATERUSER,
    CREATEDATE,
    UPDATEDATE,
    EMAIL,
    STATE,
    ERROR,
    SOURCEID,
    SOURCEMAILID,
    AUTOTASKSSERVER,
    DEPARTMENTCLS,
    SENDERID,
    SENDERRECORDID,
    CRYPTOSTATUS,
    UTFRINDEX,
    REPORTDATE,
    ESTIMDATE,
    SELF,
    CLIENTSTYPE,
    SENDKIT,
    SENDSTS,
    SENDDOC,
    MANUALEXEC,
    DATAMODE,
    BUDGETREF,
    REPORTYEAR,
    REJECTCLS,
    REJECTCAUSE,
    DOCSTATEREF,
    RVERSION,
    LASTEXTRCHANGE,
    VERSIONID,
    CONSCLIENT,
    FINT1,
    FINT2,
    FINT3,
    FINT4,
    FINT5,
    FINT6,
    FINT7,
    PARAMS,
    FORMTEXTID,
    REGTEXTID,
    PERIODTEXTID,
    REPORTMONTH,
    ACTIVITYKIND,
    PERIOD,
    TEMPREJECTCAUSE
  FROM TB_UTYPEDFORMSCAPTION
/

CREATE OR REPLACE TRIGGER TR_UTFC_ID
  INSTEAD OF DELETE
  ON UTYPEDFORMSCAPTION
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_UTFC_BD)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*    */
  delete from uTypedFormsDetail where RecordIndex = :old.id;
    
  /*        */
  delete from uTypedImportRegistry where RecordIndex = :old.id;

-- - - - - - - - - - - - -
-- BD_10 (TR_UTFC_BD10)
-- Create 30.11.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  /*       */
  DELETE FROM utfctree WHERE (utfcparent = :old.id) OR (utfckid = :old.id);

-- - - - - - - - - - - - -
-- BD_20 (TR_UTFC_BD20)
-- Create 15.12.2005
-- - - - - - - - - - - - -

  /*        */
  if (not :old.VERSIONID is null) then
    update UTYPEDFORMSVERSION utfv
    set REPORTNUMBER = (select count(utfc.ID) - 1
                        from utypedformscaption utfc
                        where (utfc.VERSIONID = :old.VERSIONID))
    where utfv.ID = :old.VERSIONID;
  end if;  

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_UTYPEDFORMSCAPTION
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_200 (TR_UTFC_AD_200)
-- Create 14.09.2005
-- - - - - - - - - - - - -

  /*      */
  delete from StateJumpHistory where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_UTFC_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  INSERT INTO delrecindexes(tableid, recordid, deletedate, ProgIndex)
  VALUES (1301, :old.ID, SYSDATE, :old.ProgIndex);

END;
/

CREATE OR REPLACE TRIGGER TR_UTFC_II
  INSTEAD OF INSERT
  ON UTYPEDFORMSCAPTION
  FOR EACH ROW
DECLARE
  new$ID UTYPEDFORMSCAPTION.ID%TYPE := :NEW.ID;
  new$REGIONCLS UTYPEDFORMSCAPTION.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$ACCEPTDATE UTYPEDFORMSCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCNUMBER UTYPEDFORMSCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$NOTE UTYPEDFORMSCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$TYPEDFORM UTYPEDFORMSCAPTION.TYPEDFORM%TYPE := :NEW.TYPEDFORM;
  new$PROGINDEX UTYPEDFORMSCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$FACIALACC_CLS UTYPEDFORMSCAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$ORG_REF UTYPEDFORMSCAPTION.ORG_REF%TYPE := :NEW.ORG_REF;
  new$CREATERUSER UTYPEDFORMSCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER UTYPEDFORMSCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$CREATEDATE UTYPEDFORMSCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE UTYPEDFORMSCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$EMAIL UTYPEDFORMSCAPTION.EMAIL%TYPE := :NEW.EMAIL;
  new$STATE UTYPEDFORMSCAPTION.STATE%TYPE := :NEW.STATE;
  new$ERROR UTYPEDFORMSCAPTION.ERROR%TYPE := :NEW.ERROR;
  new$SOURCEID UTYPEDFORMSCAPTION.SOURCEID%TYPE := :NEW.SOURCEID;
  new$SOURCEMAILID UTYPEDFORMSCAPTION.SOURCEMAILID%TYPE := :NEW.SOURCEMAILID;
  new$AUTOTASKSSERVER UTYPEDFORMSCAPTION.AUTOTASKSSERVER%TYPE := :NEW.AUTOTASKSSERVER;
  new$DEPARTMENTCLS UTYPEDFORMSCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$SENDERID UTYPEDFORMSCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID UTYPEDFORMSCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$CRYPTOSTATUS UTYPEDFORMSCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$UTFRINDEX UTYPEDFORMSCAPTION.UTFRINDEX%TYPE := :NEW.UTFRINDEX;
  new$REPORTDATE UTYPEDFORMSCAPTION.REPORTDATE%TYPE := :NEW.REPORTDATE;
  new$ESTIMDATE UTYPEDFORMSCAPTION.ESTIMDATE%TYPE := :NEW.ESTIMDATE;
  new$SELF UTYPEDFORMSCAPTION.SELF%TYPE := :NEW.SELF;
  new$CLIENTSTYPE UTYPEDFORMSCAPTION.CLIENTSTYPE%TYPE := :NEW.CLIENTSTYPE;
  new$SENDKIT UTYPEDFORMSCAPTION.SENDKIT%TYPE := :NEW.SENDKIT;
  new$SENDSTS UTYPEDFORMSCAPTION.SENDSTS%TYPE := :NEW.SENDSTS;
  new$SENDDOC UTYPEDFORMSCAPTION.SENDDOC%TYPE := :NEW.SENDDOC;
  new$MANUALEXEC UTYPEDFORMSCAPTION.MANUALEXEC%TYPE := :NEW.MANUALEXEC;
  new$DATAMODE UTYPEDFORMSCAPTION.DATAMODE%TYPE := :NEW.DATAMODE;
  new$BUDGETREF UTYPEDFORMSCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$REPORTYEAR UTYPEDFORMSCAPTION.REPORTYEAR%TYPE := :NEW.REPORTYEAR;
  new$REJECTCLS UTYPEDFORMSCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTCAUSE UTYPEDFORMSCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$DOCSTATEREF UTYPEDFORMSCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION UTYPEDFORMSCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$LASTEXTRCHANGE UTYPEDFORMSCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$VERSIONID UTYPEDFORMSCAPTION.VERSIONID%TYPE := :NEW.VERSIONID;
  new$CONSCLIENT UTYPEDFORMSCAPTION.CONSCLIENT%TYPE := :NEW.CONSCLIENT;
  new$FINT1 UTYPEDFORMSCAPTION.FINT1%TYPE := :NEW.FINT1;
  new$FINT2 UTYPEDFORMSCAPTION.FINT2%TYPE := :NEW.FINT2;
  new$FINT3 UTYPEDFORMSCAPTION.FINT3%TYPE := :NEW.FINT3;
  new$FINT4 UTYPEDFORMSCAPTION.FINT4%TYPE := :NEW.FINT4;
  new$FINT5 UTYPEDFORMSCAPTION.FINT5%TYPE := :NEW.FINT5;
  new$FINT6 UTYPEDFORMSCAPTION.FINT6%TYPE := :NEW.FINT6;
  new$FINT7 UTYPEDFORMSCAPTION.FINT7%TYPE := :NEW.FINT7;
  new$PARAMS UTYPEDFORMSCAPTION.PARAMS%TYPE := :NEW.PARAMS;
  new$FORMTEXTID UTYPEDFORMSCAPTION.FORMTEXTID%TYPE := :NEW.FORMTEXTID;
  new$REGTEXTID UTYPEDFORMSCAPTION.REGTEXTID%TYPE := :NEW.REGTEXTID;
  new$PERIODTEXTID UTYPEDFORMSCAPTION.PERIODTEXTID%TYPE := :NEW.PERIODTEXTID;
  new$REPORTMONTH UTYPEDFORMSCAPTION.REPORTMONTH%TYPE := :NEW.REPORTMONTH;
  new$ACTIVITYKIND UTYPEDFORMSCAPTION.ACTIVITYKIND%TYPE := :NEW.ACTIVITYKIND;
  new$PERIOD UTYPEDFORMSCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$TEMPREJECTCAUSE UTYPEDFORMSCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  Cnt$ NUMBER(10);
  NeedVersion$ NUMBER(5);
  ActiveVersion$ NUMBER(10);
  ReportPeriod$ NUMBER(10);
  AMonth$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_UTFC_BI)
-- Create 02.03.2004
-- Last update 15.12.2005
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL
        INTO new$ID
        FROM DUAL;
   END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_UTFC_BI10)
-- Version 8.00.00.2
-- - - - - - - - - - - - -

  if (new$TYPEDFORM is null) then 
    new$TYPEDFORM := 0;
  END IF;
  if (new$utfrindex is null) then 
    new$utfrindex := 0;
  END IF;
  if (new$self is null) then 
    new$self := 0;
  END IF;
  if (new$sendkit is null) then 
    new$sendkit := 0;
  END IF;
  if (new$sendsts is null) then 
    new$sendsts := 0;
  END IF;
  if (new$senddoc is null) then 
    new$senddoc := 0;
  END IF;
  if (new$manualexec is null) then 
    new$manualexec := 0;
  END IF;
  if (new$period is null) then 
    new$period := 0;
  END IF;
  if (new$clientstype is null) then 
    new$clientstype := 0;
  END IF;
  if (new$datamode is null) then 
    new$datamode := 0;
  END IF;
  if (new$departmentcls is null) then 
    new$departmentcls := 0;
  END IF;
  if (new$ActivityKind is null) then 
    new$ActivityKind := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then 
    BEGIN
      select fa.BudgetRef      into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$email is null) then 
    new$email := '';
  END IF;
  new$email := UPPER(new$email);
  if (not new$autotasksserver is null) then
    new$autotasksserver := UPPER(new$autotasksserver);
  END IF;

-- - - - - - - - - - - - -
-- BI_20 (TR_UTFC_BI20)
-- Create 22.05.2004
-- Last update 15.12.2008
-- - - - - - - - - - - - -

    /*     ,     */
    BEGIN
      select utf.NEEDVERSION into NeedVersion$
      from UTYPEDFORMS utf
      where (utf.ID = new$TYPEDFORM);
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        NeedVersion$ := NULL;
    END;  
    
    if (NeedVersion$ = 1) then
        /*     ,    */
        if (new$VERSIONID is null) then
            /*      ,  */
            if (new$SENDERID is not null) then
                /*       ""*/
                BEGIN
                  select UTFV.ID into ActiveVersion$
                  from UTYPEDFORMSVERSION UTFV
                  where ((UTFV.TYPEDFORM = new$TYPEDFORM)
                      and (UTFV.IsCurrentForURM = 1));
                EXCEPTION
                  WHEN NO_DATA_FOUND THEN
                    ActiveVersion$ := NULL;
                END;                      
            else
                /*       ""*/
                BEGIN
                  select UTFV.ID into ActiveVersion$
                  from UTYPEDFORMSVERSION UTFV
                  where ((UTFV.TYPEDFORM = new$TYPEDFORM)
                      and (UTFV.ISCURRENT = 1));
                EXCEPTION
                  WHEN NO_DATA_FOUND THEN
                    ActiveVersion$ := NULL;
                END;                      
            end if;

            /*     */
            new$VERSIONID := ActiveVersion$;

            /*     */
            select count(ID) into CNT$ from UTYPEDFORMSVERSION where (ID = new$VERSIONID) AND (ROWNUM = 1);
            if (CNT$ = 0 ) then
              RaiseException('EX_NOT_ACTIVE_VERSION');
            end if;  
        end if;
    end if;

-- - - - - - - - - - - - -
-- BI_50 (TR_UTFC_BI50)
-- Version 8.00.00.2
-- - - - - - - - - - - - -

  BEGIN
    /*    */
    select utf.Period
    into ReportPeriod$   from utypedforms utf
    where utf.id = new$TypedForm
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*       */
  if (ReportPeriod$  = 30) then
    /*     12  */    
    new$REPORTMONTH := 12;
      
  else
    if (ReportPeriod$  = 20) then
      /*          */
      if ((new$ReportMonth is null) or (new$ReportMonth = 0)) then
        /*    ,    */        
        new$ReportMonth := 3;
              
      else
        AMonth$ := new$ReportMonth;
        if (AMonth$ between 1 and 3) then
          AMonth$ := 3;
                  
        else 
          if (AMonth$ between 4 and 6) then
            AMonth$ := 6;
                    
          else 
            if (AMonth$ between 7 and 9) then
              AMonth$ := 9;
                      
            else
              AMonth$ := 12;
            END IF;
          END IF;
        END IF;

        new$ReportMonth := AMonth$;
          
      END IF;
    else
      if ((ReportPeriod$  = 10) and (new$ReportMonth is null)) then
        new$ReportMonth := 1;
          
      END IF;
    END IF;
  END IF;
  if (new$REPORTYEAR is null) then 
    new$REPORTYEAR := 0;
  END IF;
  /*          */
  if (ReportPeriod$  > 0) then
    new$REPORTDATE := new$REPORTYEAR * 10000 + new$REPORTMONTH * 100 + 01;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_UTFC_BI500)
-- Create 2.03.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_UTYPEDFORMSCAPTION (
    ID,
    REGIONCLS,
    ACCEPTDATE,
    DOCNUMBER,
    NOTE,
    TYPEDFORM,
    PROGINDEX,
    FACIALACC_CLS,
    ORG_REF,
    CREATERUSER,
    UPDATERUSER,
    CREATEDATE,
    UPDATEDATE,
    EMAIL,
    STATE,
    ERROR,
    SOURCEID,
    SOURCEMAILID,
    AUTOTASKSSERVER,
    DEPARTMENTCLS,
    SENDERID,
    SENDERRECORDID,
    CRYPTOSTATUS,
    UTFRINDEX,
    REPORTDATE,
    ESTIMDATE,
    SELF,
    CLIENTSTYPE,
    SENDKIT,
    SENDSTS,
    SENDDOC,
    MANUALEXEC,
    DATAMODE,
    BUDGETREF,
    REPORTYEAR,
    REJECTCLS,
    REJECTCAUSE,
    DOCSTATEREF,
    RVERSION,
    LASTEXTRCHANGE,
    VERSIONID,
    CONSCLIENT,
    FINT1,
    FINT2,
    FINT3,
    FINT4,
    FINT5,
    FINT6,
    FINT7,
    PARAMS,
    FORMTEXTID,
    REGTEXTID,
    PERIODTEXTID,
    REPORTMONTH,
    ACTIVITYKIND,
    PERIOD,
    TEMPREJECTCAUSE
  ) VALUES (
    new$ID,
    new$REGIONCLS,
    new$ACCEPTDATE,
    new$DOCNUMBER,
    new$NOTE,
    new$TYPEDFORM,
    new$PROGINDEX,
    new$FACIALACC_CLS,
    new$ORG_REF,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$EMAIL,
    new$STATE,
    new$ERROR,
    new$SOURCEID,
    new$SOURCEMAILID,
    new$AUTOTASKSSERVER,
    new$DEPARTMENTCLS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$CRYPTOSTATUS,
    new$UTFRINDEX,
    new$REPORTDATE,
    new$ESTIMDATE,
    new$SELF,
    new$CLIENTSTYPE,
    new$SENDKIT,
    new$SENDSTS,
    new$SENDDOC,
    new$MANUALEXEC,
    new$DATAMODE,
    new$BUDGETREF,
    new$REPORTYEAR,
    new$REJECTCLS,
    new$REJECTCAUSE,
    new$DOCSTATEREF,
    new$RVERSION,
    new$LASTEXTRCHANGE,
    new$VERSIONID,
    new$CONSCLIENT,
    new$FINT1,
    new$FINT2,
    new$FINT3,
    new$FINT4,
    new$FINT5,
    new$FINT6,
    new$FINT7,
    new$PARAMS,
    new$FORMTEXTID,
    new$REGTEXTID,
    new$PERIODTEXTID,
    new$REPORTMONTH,
    new$ACTIVITYKIND,
    new$PERIOD,
    new$TEMPREJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_UTFC_AI_500)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   DELETE FROM delrecindexes
         WHERE (tableid = 1301) AND (recordid = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_UTFC_IU
  INSTEAD OF UPDATE
  ON UTYPEDFORMSCAPTION
  FOR EACH ROW
DECLARE
  new$ID UTYPEDFORMSCAPTION.ID%TYPE := :NEW.ID;
  new$REGIONCLS UTYPEDFORMSCAPTION.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$ACCEPTDATE UTYPEDFORMSCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCNUMBER UTYPEDFORMSCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$NOTE UTYPEDFORMSCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$TYPEDFORM UTYPEDFORMSCAPTION.TYPEDFORM%TYPE := :NEW.TYPEDFORM;
  new$PROGINDEX UTYPEDFORMSCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$FACIALACC_CLS UTYPEDFORMSCAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$ORG_REF UTYPEDFORMSCAPTION.ORG_REF%TYPE := :NEW.ORG_REF;
  new$CREATERUSER UTYPEDFORMSCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER UTYPEDFORMSCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$CREATEDATE UTYPEDFORMSCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE UTYPEDFORMSCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$EMAIL UTYPEDFORMSCAPTION.EMAIL%TYPE := :NEW.EMAIL;
  new$STATE UTYPEDFORMSCAPTION.STATE%TYPE := :NEW.STATE;
  new$ERROR UTYPEDFORMSCAPTION.ERROR%TYPE := :NEW.ERROR;
  new$SOURCEID UTYPEDFORMSCAPTION.SOURCEID%TYPE := :NEW.SOURCEID;
  new$SOURCEMAILID UTYPEDFORMSCAPTION.SOURCEMAILID%TYPE := :NEW.SOURCEMAILID;
  new$AUTOTASKSSERVER UTYPEDFORMSCAPTION.AUTOTASKSSERVER%TYPE := :NEW.AUTOTASKSSERVER;
  new$DEPARTMENTCLS UTYPEDFORMSCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$SENDERID UTYPEDFORMSCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID UTYPEDFORMSCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$CRYPTOSTATUS UTYPEDFORMSCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$UTFRINDEX UTYPEDFORMSCAPTION.UTFRINDEX%TYPE := :NEW.UTFRINDEX;
  new$REPORTDATE UTYPEDFORMSCAPTION.REPORTDATE%TYPE := :NEW.REPORTDATE;
  new$ESTIMDATE UTYPEDFORMSCAPTION.ESTIMDATE%TYPE := :NEW.ESTIMDATE;
  new$SELF UTYPEDFORMSCAPTION.SELF%TYPE := :NEW.SELF;
  new$CLIENTSTYPE UTYPEDFORMSCAPTION.CLIENTSTYPE%TYPE := :NEW.CLIENTSTYPE;
  new$SENDKIT UTYPEDFORMSCAPTION.SENDKIT%TYPE := :NEW.SENDKIT;
  new$SENDSTS UTYPEDFORMSCAPTION.SENDSTS%TYPE := :NEW.SENDSTS;
  new$SENDDOC UTYPEDFORMSCAPTION.SENDDOC%TYPE := :NEW.SENDDOC;
  new$MANUALEXEC UTYPEDFORMSCAPTION.MANUALEXEC%TYPE := :NEW.MANUALEXEC;
  new$DATAMODE UTYPEDFORMSCAPTION.DATAMODE%TYPE := :NEW.DATAMODE;
  new$BUDGETREF UTYPEDFORMSCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$REPORTYEAR UTYPEDFORMSCAPTION.REPORTYEAR%TYPE := :NEW.REPORTYEAR;
  new$REJECTCLS UTYPEDFORMSCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTCAUSE UTYPEDFORMSCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$DOCSTATEREF UTYPEDFORMSCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION UTYPEDFORMSCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$LASTEXTRCHANGE UTYPEDFORMSCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$VERSIONID UTYPEDFORMSCAPTION.VERSIONID%TYPE := :NEW.VERSIONID;
  new$CONSCLIENT UTYPEDFORMSCAPTION.CONSCLIENT%TYPE := :NEW.CONSCLIENT;
  new$FINT1 UTYPEDFORMSCAPTION.FINT1%TYPE := :NEW.FINT1;
  new$FINT2 UTYPEDFORMSCAPTION.FINT2%TYPE := :NEW.FINT2;
  new$FINT3 UTYPEDFORMSCAPTION.FINT3%TYPE := :NEW.FINT3;
  new$FINT4 UTYPEDFORMSCAPTION.FINT4%TYPE := :NEW.FINT4;
  new$FINT5 UTYPEDFORMSCAPTION.FINT5%TYPE := :NEW.FINT5;
  new$FINT6 UTYPEDFORMSCAPTION.FINT6%TYPE := :NEW.FINT6;
  new$FINT7 UTYPEDFORMSCAPTION.FINT7%TYPE := :NEW.FINT7;
  new$PARAMS UTYPEDFORMSCAPTION.PARAMS%TYPE := :NEW.PARAMS;
  new$FORMTEXTID UTYPEDFORMSCAPTION.FORMTEXTID%TYPE := :NEW.FORMTEXTID;
  new$REGTEXTID UTYPEDFORMSCAPTION.REGTEXTID%TYPE := :NEW.REGTEXTID;
  new$PERIODTEXTID UTYPEDFORMSCAPTION.PERIODTEXTID%TYPE := :NEW.PERIODTEXTID;
  new$REPORTMONTH UTYPEDFORMSCAPTION.REPORTMONTH%TYPE := :NEW.REPORTMONTH;
  new$ACTIVITYKIND UTYPEDFORMSCAPTION.ACTIVITYKIND%TYPE := :NEW.ACTIVITYKIND;
  new$PERIOD UTYPEDFORMSCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$TEMPREJECTCAUSE UTYPEDFORMSCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  Cnt$ NUMBER(10);
  NeedVersion$ NUMBER(5);
  ActiveVersion$ NUMBER(10);
  ReportPeriod$ NUMBER(10);
  AMonth$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_UTFC_BU)
-- Create 02.03.2004
-- Last update 15.12.2005
-- - - - - - - - - - - - -

  /*      ID -   */
  IF (new$ID IS NULL) THEN SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL; END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_UTFC_BU10)
-- Version 8.00.00.2
-- - - - - - - - - - - - -

  if (new$typedform is null) then 
    new$typedform := 0;
  END IF;
  if (new$utfrindex is null) then 
    new$utfrindex := 0;
  END IF;
  if (new$self is null) then 
    new$self := 0;
  END IF;
  if (new$sendkit is null) then 
    new$sendkit := 0;
  END IF;
  if (new$sendsts is null) then 
    new$sendsts := 0;
  END IF;
  if (new$senddoc is null) then 
    new$senddoc := 0;
  END IF;
  if (new$manualexec is null) then 
    new$manualexec := 0;
  END IF;
  if (new$period is null) then 
    new$period := 0;
  END IF;
  if (new$clientstype is null) then 
    new$clientstype := 0;
  END IF;
  if (new$datamode is null) then 
    new$datamode := 0;
  END IF;
  if (new$departmentcls is null) then 
    new$departmentcls := 0;
  END IF;
  if (new$ActivityKind is null) then 
    new$ActivityKind := 0;
  END IF;
  if (new$BudgetRef is null) then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$email is null) then 
    new$email := '';
  END IF;
  new$email := UPPER(new$email);
  if (not new$autotasksserver is null) then
    new$autotasksserver := UPPER(new$autotasksserver);
  END IF;

-- - - - - - - - - - - - -
-- BU_20 (TR_UTFC_BU20)
-- Create 22.05.2004
-- Last update 15.12.2008
-- - - - - - - - - - - - -

    /*     ,     */
    BEGIN
      select utf.NEEDVERSION into NeedVersion$
      from UTYPEDFORMS utf
      where (utf.ID = new$TYPEDFORM);
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        NeedVersion$ := NULL;
    END;  
    
    if (NeedVersion$ = 1) then
        /*     ,    */
        if (new$VERSIONID is null) then
            /*      ,  */
            if (new$SENDERID is not null) then
                /*       ""*/
                BEGIN
                  select UTFV.ID into ActiveVersion$
                  from UTYPEDFORMSVERSION UTFV
                  where ((UTFV.TYPEDFORM = new$TYPEDFORM)
                      and (UTFV.IsCurrentForURM = 1));
                EXCEPTION
                  WHEN NO_DATA_FOUND THEN
                    ActiveVersion$ := NULL;
                END;                      
            else
                /*       ""*/
                BEGIN
                  select UTFV.ID into ActiveVersion$
                  from UTYPEDFORMSVERSION UTFV
                  where ((UTFV.TYPEDFORM = new$TYPEDFORM)
                      and (UTFV.ISCURRENT = 1));
                EXCEPTION
                  WHEN NO_DATA_FOUND THEN
                    ActiveVersion$ := NULL;
                END;                      
            end if;

            /*     */
            new$VERSIONID := ActiveVersion$;

            /*     */
            select count(ID) into CNT$ from UTYPEDFORMSVERSION where (ID = new$VERSIONID) AND (ROWNUM = 1);
            if (CNT$ = 0 ) then
              RaiseException('EX_NOT_ACTIVE_VERSION');
            end if;  
        end if;
    end if;

-- - - - - - - - - - - - -
-- BU_50 (TR_UTFC_BU50)
-- Version 8.00.00.2
-- - - - - - - - - - - - -

  BEGIN
    /*    */
    select utf.Period
    into ReportPeriod$   from utypedforms utf
    where utf.id = new$TypedForm
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*       */
  if (ReportPeriod$  = 30) then
    /*     12  */    
    new$REPORTMONTH := 12;
      
  else
    if (ReportPeriod$  = 20) then
      /*          */
      if ((new$ReportMonth is null) or (new$ReportMonth = 0)) then
        /*    ,    */        
        new$ReportMonth := 3;
              
      else
        AMonth$ := new$ReportMonth;
        if (AMonth$ between 1 and 3) then
          AMonth$ := 3;
                  
        else 
          if (AMonth$ between 4 and 6) then
            AMonth$ := 6;
                    
          else 
            if (AMonth$ between 7 and 9) then
              AMonth$ := 9;
                      
            else
              AMonth$ := 12;
            END IF;
          END IF;
        END IF;

        new$ReportMonth := AMonth$;
          
      END IF;
    else
      if ((ReportPeriod$  = 10) and (new$ReportMonth is null)) then
        new$ReportMonth := 1;
          
      END IF;
    END IF;
  END IF;
  if (new$REPORTYEAR is null) then 
    new$REPORTYEAR := 0;
  END IF;
  /*          */
  if (ReportPeriod$  > 0) then
    new$REPORTDATE := new$REPORTYEAR * 10000 + new$REPORTMONTH * 100 + 01;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_UTFC_BU_200)
-- Create 14.09.2005
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  /*       */
  if (new$DOCSTATEREF <> :old.DOCSTATEREF) then
    insert into StateJumpHistory(DocID, BeginStateRef, EndStateRef)
      values(new$id, :old.DOCSTATEREF, :new.DOCSTATEREF);
  end if;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_UTYPEDFORMSCAPTION SET
    ID = new$ID,
    REGIONCLS = new$REGIONCLS,
    ACCEPTDATE = new$ACCEPTDATE,
    DOCNUMBER = new$DOCNUMBER,
    NOTE = new$NOTE,
    TYPEDFORM = new$TYPEDFORM,
    PROGINDEX = new$PROGINDEX,
    FACIALACC_CLS = new$FACIALACC_CLS,
    ORG_REF = new$ORG_REF,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    EMAIL = new$EMAIL,
    STATE = new$STATE,
    ERROR = new$ERROR,
    SOURCEID = new$SOURCEID,
    SOURCEMAILID = new$SOURCEMAILID,
    AUTOTASKSSERVER = new$AUTOTASKSSERVER,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    UTFRINDEX = new$UTFRINDEX,
    REPORTDATE = new$REPORTDATE,
    ESTIMDATE = new$ESTIMDATE,
    SELF = new$SELF,
    CLIENTSTYPE = new$CLIENTSTYPE,
    SENDKIT = new$SENDKIT,
    SENDSTS = new$SENDSTS,
    SENDDOC = new$SENDDOC,
    MANUALEXEC = new$MANUALEXEC,
    DATAMODE = new$DATAMODE,
    BUDGETREF = new$BUDGETREF,
    REPORTYEAR = new$REPORTYEAR,
    REJECTCLS = new$REJECTCLS,
    REJECTCAUSE = new$REJECTCAUSE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    VERSIONID = new$VERSIONID,
    CONSCLIENT = new$CONSCLIENT,
    FINT1 = new$FINT1,
    FINT2 = new$FINT2,
    FINT3 = new$FINT3,
    FINT4 = new$FINT4,
    FINT5 = new$FINT5,
    FINT6 = new$FINT6,
    FINT7 = new$FINT7,
    PARAMS = new$PARAMS,
    FORMTEXTID = new$FORMTEXTID,
    REGTEXTID = new$REGTEXTID,
    PERIODTEXTID = new$PERIODTEXTID,
    REPORTMONTH = new$REPORTMONTH,
    ACTIVITYKIND = new$ACTIVITYKIND,
    PERIOD = new$PERIOD,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);
 
  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

END;
/
update UTYPEDFORMSCAPTION set
  TempRejectCause = REJECTCAUSE
/
commit work 
/
ALTER TABLE TB_UTYPEDFORMSCAPTION DROP (REJECTCAUSE)
/

CREATE OR REPLACE VIEW UTYPEDFORMSCAPTION (
  ID,
  REGIONCLS,
  ACCEPTDATE,
  DOCNUMBER,
  NOTE,
  TYPEDFORM,
  PROGINDEX,
  FACIALACC_CLS,
  ORG_REF,
  CREATERUSER,
  UPDATERUSER,
  CREATEDATE,
  UPDATEDATE,
  EMAIL,
  STATE,
  ERROR,
  SOURCEID,
  SOURCEMAILID,
  AUTOTASKSSERVER,
  DEPARTMENTCLS,
  SENDERID,
  SENDERRECORDID,
  CRYPTOSTATUS,
  UTFRINDEX,
  REPORTDATE,
  ESTIMDATE,
  SELF,
  CLIENTSTYPE,
  SENDKIT,
  SENDSTS,
  SENDDOC,
  MANUALEXEC,
  DATAMODE,
  BUDGETREF,
  REPORTYEAR,
  REJECTCLS,
  DOCSTATEREF,
  RVERSION,
  LASTEXTRCHANGE,
  VERSIONID,
  CONSCLIENT,
  FINT1,
  FINT2,
  FINT3,
  FINT4,
  FINT5,
  FINT6,
  FINT7,
  PARAMS,
  FORMTEXTID,
  REGTEXTID,
  PERIODTEXTID,
  REPORTMONTH,
  ACTIVITYKIND,
  PERIOD,
  TEMPREJECTCAUSE)
AS
  SELECT
    ID,
    REGIONCLS,
    ACCEPTDATE,
    DOCNUMBER,
    NOTE,
    TYPEDFORM,
    PROGINDEX,
    FACIALACC_CLS,
    ORG_REF,
    CREATERUSER,
    UPDATERUSER,
    CREATEDATE,
    UPDATEDATE,
    EMAIL,
    STATE,
    ERROR,
    SOURCEID,
    SOURCEMAILID,
    AUTOTASKSSERVER,
    DEPARTMENTCLS,
    SENDERID,
    SENDERRECORDID,
    CRYPTOSTATUS,
    UTFRINDEX,
    REPORTDATE,
    ESTIMDATE,
    SELF,
    CLIENTSTYPE,
    SENDKIT,
    SENDSTS,
    SENDDOC,
    MANUALEXEC,
    DATAMODE,
    BUDGETREF,
    REPORTYEAR,
    REJECTCLS,
    DOCSTATEREF,
    RVERSION,
    LASTEXTRCHANGE,
    VERSIONID,
    CONSCLIENT,
    FINT1,
    FINT2,
    FINT3,
    FINT4,
    FINT5,
    FINT6,
    FINT7,
    PARAMS,
    FORMTEXTID,
    REGTEXTID,
    PERIODTEXTID,
    REPORTMONTH,
    ACTIVITYKIND,
    PERIOD,
    TEMPREJECTCAUSE
  FROM TB_UTYPEDFORMSCAPTION
/

CREATE OR REPLACE TRIGGER TR_UTFC_ID
  INSTEAD OF DELETE
  ON UTYPEDFORMSCAPTION
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_UTFC_BD)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*    */
  delete from uTypedFormsDetail where RecordIndex = :old.id;
    
  /*        */
  delete from uTypedImportRegistry where RecordIndex = :old.id;

-- - - - - - - - - - - - -
-- BD_10 (TR_UTFC_BD10)
-- Create 30.11.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  /*       */
  DELETE FROM utfctree WHERE (utfcparent = :old.id) OR (utfckid = :old.id);

-- - - - - - - - - - - - -
-- BD_20 (TR_UTFC_BD20)
-- Create 15.12.2005
-- - - - - - - - - - - - -

  /*        */
  if (not :old.VERSIONID is null) then
    update UTYPEDFORMSVERSION utfv
    set REPORTNUMBER = (select count(utfc.ID) - 1
                        from utypedformscaption utfc
                        where (utfc.VERSIONID = :old.VERSIONID))
    where utfv.ID = :old.VERSIONID;
  end if;  

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_UTYPEDFORMSCAPTION
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_200 (TR_UTFC_AD_200)
-- Create 14.09.2005
-- - - - - - - - - - - - -

  /*      */
  delete from StateJumpHistory where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_UTFC_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  INSERT INTO delrecindexes(tableid, recordid, deletedate, ProgIndex)
  VALUES (1301, :old.ID, SYSDATE, :old.ProgIndex);

END;
/

CREATE OR REPLACE TRIGGER TR_UTFC_II
  INSTEAD OF INSERT
  ON UTYPEDFORMSCAPTION
  FOR EACH ROW
DECLARE
  new$ID UTYPEDFORMSCAPTION.ID%TYPE := :NEW.ID;
  new$REGIONCLS UTYPEDFORMSCAPTION.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$ACCEPTDATE UTYPEDFORMSCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCNUMBER UTYPEDFORMSCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$NOTE UTYPEDFORMSCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$TYPEDFORM UTYPEDFORMSCAPTION.TYPEDFORM%TYPE := :NEW.TYPEDFORM;
  new$PROGINDEX UTYPEDFORMSCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$FACIALACC_CLS UTYPEDFORMSCAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$ORG_REF UTYPEDFORMSCAPTION.ORG_REF%TYPE := :NEW.ORG_REF;
  new$CREATERUSER UTYPEDFORMSCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER UTYPEDFORMSCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$CREATEDATE UTYPEDFORMSCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE UTYPEDFORMSCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$EMAIL UTYPEDFORMSCAPTION.EMAIL%TYPE := :NEW.EMAIL;
  new$STATE UTYPEDFORMSCAPTION.STATE%TYPE := :NEW.STATE;
  new$ERROR UTYPEDFORMSCAPTION.ERROR%TYPE := :NEW.ERROR;
  new$SOURCEID UTYPEDFORMSCAPTION.SOURCEID%TYPE := :NEW.SOURCEID;
  new$SOURCEMAILID UTYPEDFORMSCAPTION.SOURCEMAILID%TYPE := :NEW.SOURCEMAILID;
  new$AUTOTASKSSERVER UTYPEDFORMSCAPTION.AUTOTASKSSERVER%TYPE := :NEW.AUTOTASKSSERVER;
  new$DEPARTMENTCLS UTYPEDFORMSCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$SENDERID UTYPEDFORMSCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID UTYPEDFORMSCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$CRYPTOSTATUS UTYPEDFORMSCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$UTFRINDEX UTYPEDFORMSCAPTION.UTFRINDEX%TYPE := :NEW.UTFRINDEX;
  new$REPORTDATE UTYPEDFORMSCAPTION.REPORTDATE%TYPE := :NEW.REPORTDATE;
  new$ESTIMDATE UTYPEDFORMSCAPTION.ESTIMDATE%TYPE := :NEW.ESTIMDATE;
  new$SELF UTYPEDFORMSCAPTION.SELF%TYPE := :NEW.SELF;
  new$CLIENTSTYPE UTYPEDFORMSCAPTION.CLIENTSTYPE%TYPE := :NEW.CLIENTSTYPE;
  new$SENDKIT UTYPEDFORMSCAPTION.SENDKIT%TYPE := :NEW.SENDKIT;
  new$SENDSTS UTYPEDFORMSCAPTION.SENDSTS%TYPE := :NEW.SENDSTS;
  new$SENDDOC UTYPEDFORMSCAPTION.SENDDOC%TYPE := :NEW.SENDDOC;
  new$MANUALEXEC UTYPEDFORMSCAPTION.MANUALEXEC%TYPE := :NEW.MANUALEXEC;
  new$DATAMODE UTYPEDFORMSCAPTION.DATAMODE%TYPE := :NEW.DATAMODE;
  new$BUDGETREF UTYPEDFORMSCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$REPORTYEAR UTYPEDFORMSCAPTION.REPORTYEAR%TYPE := :NEW.REPORTYEAR;
  new$REJECTCLS UTYPEDFORMSCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$DOCSTATEREF UTYPEDFORMSCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION UTYPEDFORMSCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$LASTEXTRCHANGE UTYPEDFORMSCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$VERSIONID UTYPEDFORMSCAPTION.VERSIONID%TYPE := :NEW.VERSIONID;
  new$CONSCLIENT UTYPEDFORMSCAPTION.CONSCLIENT%TYPE := :NEW.CONSCLIENT;
  new$FINT1 UTYPEDFORMSCAPTION.FINT1%TYPE := :NEW.FINT1;
  new$FINT2 UTYPEDFORMSCAPTION.FINT2%TYPE := :NEW.FINT2;
  new$FINT3 UTYPEDFORMSCAPTION.FINT3%TYPE := :NEW.FINT3;
  new$FINT4 UTYPEDFORMSCAPTION.FINT4%TYPE := :NEW.FINT4;
  new$FINT5 UTYPEDFORMSCAPTION.FINT5%TYPE := :NEW.FINT5;
  new$FINT6 UTYPEDFORMSCAPTION.FINT6%TYPE := :NEW.FINT6;
  new$FINT7 UTYPEDFORMSCAPTION.FINT7%TYPE := :NEW.FINT7;
  new$PARAMS UTYPEDFORMSCAPTION.PARAMS%TYPE := :NEW.PARAMS;
  new$FORMTEXTID UTYPEDFORMSCAPTION.FORMTEXTID%TYPE := :NEW.FORMTEXTID;
  new$REGTEXTID UTYPEDFORMSCAPTION.REGTEXTID%TYPE := :NEW.REGTEXTID;
  new$PERIODTEXTID UTYPEDFORMSCAPTION.PERIODTEXTID%TYPE := :NEW.PERIODTEXTID;
  new$REPORTMONTH UTYPEDFORMSCAPTION.REPORTMONTH%TYPE := :NEW.REPORTMONTH;
  new$ACTIVITYKIND UTYPEDFORMSCAPTION.ACTIVITYKIND%TYPE := :NEW.ACTIVITYKIND;
  new$PERIOD UTYPEDFORMSCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$TEMPREJECTCAUSE UTYPEDFORMSCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  Cnt$ NUMBER(10);
  NeedVersion$ NUMBER(5);
  ActiveVersion$ NUMBER(10);
  ReportPeriod$ NUMBER(10);
  AMonth$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_UTFC_BI)
-- Create 02.03.2004
-- Last update 15.12.2005
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL
        INTO new$ID
        FROM DUAL;
   END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_UTFC_BI10)
-- Version 8.00.00.2
-- - - - - - - - - - - - -

  if (new$TYPEDFORM is null) then 
    new$TYPEDFORM := 0;
  END IF;
  if (new$utfrindex is null) then 
    new$utfrindex := 0;
  END IF;
  if (new$self is null) then 
    new$self := 0;
  END IF;
  if (new$sendkit is null) then 
    new$sendkit := 0;
  END IF;
  if (new$sendsts is null) then 
    new$sendsts := 0;
  END IF;
  if (new$senddoc is null) then 
    new$senddoc := 0;
  END IF;
  if (new$manualexec is null) then 
    new$manualexec := 0;
  END IF;
  if (new$period is null) then 
    new$period := 0;
  END IF;
  if (new$clientstype is null) then 
    new$clientstype := 0;
  END IF;
  if (new$datamode is null) then 
    new$datamode := 0;
  END IF;
  if (new$departmentcls is null) then 
    new$departmentcls := 0;
  END IF;
  if (new$ActivityKind is null) then 
    new$ActivityKind := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then 
    BEGIN
      select fa.BudgetRef      into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$email is null) then 
    new$email := '';
  END IF;
  new$email := UPPER(new$email);
  if (not new$autotasksserver is null) then
    new$autotasksserver := UPPER(new$autotasksserver);
  END IF;

-- - - - - - - - - - - - -
-- BI_20 (TR_UTFC_BI20)
-- Create 22.05.2004
-- Last update 15.12.2008
-- - - - - - - - - - - - -

    /*     ,     */
    BEGIN
      select utf.NEEDVERSION into NeedVersion$
      from UTYPEDFORMS utf
      where (utf.ID = new$TYPEDFORM);
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        NeedVersion$ := NULL;
    END;  
    
    if (NeedVersion$ = 1) then
        /*     ,    */
        if (new$VERSIONID is null) then
            /*      ,  */
            if (new$SENDERID is not null) then
                /*       ""*/
                BEGIN
                  select UTFV.ID into ActiveVersion$
                  from UTYPEDFORMSVERSION UTFV
                  where ((UTFV.TYPEDFORM = new$TYPEDFORM)
                      and (UTFV.IsCurrentForURM = 1));
                EXCEPTION
                  WHEN NO_DATA_FOUND THEN
                    ActiveVersion$ := NULL;
                END;                      
            else
                /*       ""*/
                BEGIN
                  select UTFV.ID into ActiveVersion$
                  from UTYPEDFORMSVERSION UTFV
                  where ((UTFV.TYPEDFORM = new$TYPEDFORM)
                      and (UTFV.ISCURRENT = 1));
                EXCEPTION
                  WHEN NO_DATA_FOUND THEN
                    ActiveVersion$ := NULL;
                END;                      
            end if;

            /*     */
            new$VERSIONID := ActiveVersion$;

            /*     */
            select count(ID) into CNT$ from UTYPEDFORMSVERSION where (ID = new$VERSIONID) AND (ROWNUM = 1);
            if (CNT$ = 0 ) then
              RaiseException('EX_NOT_ACTIVE_VERSION');
            end if;  
        end if;
    end if;

-- - - - - - - - - - - - -
-- BI_50 (TR_UTFC_BI50)
-- Version 8.00.00.2
-- - - - - - - - - - - - -

  BEGIN
    /*    */
    select utf.Period
    into ReportPeriod$   from utypedforms utf
    where utf.id = new$TypedForm
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*       */
  if (ReportPeriod$  = 30) then
    /*     12  */    
    new$REPORTMONTH := 12;
      
  else
    if (ReportPeriod$  = 20) then
      /*          */
      if ((new$ReportMonth is null) or (new$ReportMonth = 0)) then
        /*    ,    */        
        new$ReportMonth := 3;
              
      else
        AMonth$ := new$ReportMonth;
        if (AMonth$ between 1 and 3) then
          AMonth$ := 3;
                  
        else 
          if (AMonth$ between 4 and 6) then
            AMonth$ := 6;
                    
          else 
            if (AMonth$ between 7 and 9) then
              AMonth$ := 9;
                      
            else
              AMonth$ := 12;
            END IF;
          END IF;
        END IF;

        new$ReportMonth := AMonth$;
          
      END IF;
    else
      if ((ReportPeriod$  = 10) and (new$ReportMonth is null)) then
        new$ReportMonth := 1;
          
      END IF;
    END IF;
  END IF;
  if (new$REPORTYEAR is null) then 
    new$REPORTYEAR := 0;
  END IF;
  /*          */
  if (ReportPeriod$  > 0) then
    new$REPORTDATE := new$REPORTYEAR * 10000 + new$REPORTMONTH * 100 + 01;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_UTFC_BI500)
-- Create 2.03.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_UTYPEDFORMSCAPTION (
    ID,
    REGIONCLS,
    ACCEPTDATE,
    DOCNUMBER,
    NOTE,
    TYPEDFORM,
    PROGINDEX,
    FACIALACC_CLS,
    ORG_REF,
    CREATERUSER,
    UPDATERUSER,
    CREATEDATE,
    UPDATEDATE,
    EMAIL,
    STATE,
    ERROR,
    SOURCEID,
    SOURCEMAILID,
    AUTOTASKSSERVER,
    DEPARTMENTCLS,
    SENDERID,
    SENDERRECORDID,
    CRYPTOSTATUS,
    UTFRINDEX,
    REPORTDATE,
    ESTIMDATE,
    SELF,
    CLIENTSTYPE,
    SENDKIT,
    SENDSTS,
    SENDDOC,
    MANUALEXEC,
    DATAMODE,
    BUDGETREF,
    REPORTYEAR,
    REJECTCLS,
    DOCSTATEREF,
    RVERSION,
    LASTEXTRCHANGE,
    VERSIONID,
    CONSCLIENT,
    FINT1,
    FINT2,
    FINT3,
    FINT4,
    FINT5,
    FINT6,
    FINT7,
    PARAMS,
    FORMTEXTID,
    REGTEXTID,
    PERIODTEXTID,
    REPORTMONTH,
    ACTIVITYKIND,
    PERIOD,
    TEMPREJECTCAUSE
  ) VALUES (
    new$ID,
    new$REGIONCLS,
    new$ACCEPTDATE,
    new$DOCNUMBER,
    new$NOTE,
    new$TYPEDFORM,
    new$PROGINDEX,
    new$FACIALACC_CLS,
    new$ORG_REF,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$EMAIL,
    new$STATE,
    new$ERROR,
    new$SOURCEID,
    new$SOURCEMAILID,
    new$AUTOTASKSSERVER,
    new$DEPARTMENTCLS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$CRYPTOSTATUS,
    new$UTFRINDEX,
    new$REPORTDATE,
    new$ESTIMDATE,
    new$SELF,
    new$CLIENTSTYPE,
    new$SENDKIT,
    new$SENDSTS,
    new$SENDDOC,
    new$MANUALEXEC,
    new$DATAMODE,
    new$BUDGETREF,
    new$REPORTYEAR,
    new$REJECTCLS,
    new$DOCSTATEREF,
    new$RVERSION,
    new$LASTEXTRCHANGE,
    new$VERSIONID,
    new$CONSCLIENT,
    new$FINT1,
    new$FINT2,
    new$FINT3,
    new$FINT4,
    new$FINT5,
    new$FINT6,
    new$FINT7,
    new$PARAMS,
    new$FORMTEXTID,
    new$REGTEXTID,
    new$PERIODTEXTID,
    new$REPORTMONTH,
    new$ACTIVITYKIND,
    new$PERIOD,
    new$TEMPREJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_UTFC_AI_500)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   DELETE FROM delrecindexes
         WHERE (tableid = 1301) AND (recordid = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_UTFC_IU
  INSTEAD OF UPDATE
  ON UTYPEDFORMSCAPTION
  FOR EACH ROW
DECLARE
  new$ID UTYPEDFORMSCAPTION.ID%TYPE := :NEW.ID;
  new$REGIONCLS UTYPEDFORMSCAPTION.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$ACCEPTDATE UTYPEDFORMSCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCNUMBER UTYPEDFORMSCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$NOTE UTYPEDFORMSCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$TYPEDFORM UTYPEDFORMSCAPTION.TYPEDFORM%TYPE := :NEW.TYPEDFORM;
  new$PROGINDEX UTYPEDFORMSCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$FACIALACC_CLS UTYPEDFORMSCAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$ORG_REF UTYPEDFORMSCAPTION.ORG_REF%TYPE := :NEW.ORG_REF;
  new$CREATERUSER UTYPEDFORMSCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER UTYPEDFORMSCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$CREATEDATE UTYPEDFORMSCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE UTYPEDFORMSCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$EMAIL UTYPEDFORMSCAPTION.EMAIL%TYPE := :NEW.EMAIL;
  new$STATE UTYPEDFORMSCAPTION.STATE%TYPE := :NEW.STATE;
  new$ERROR UTYPEDFORMSCAPTION.ERROR%TYPE := :NEW.ERROR;
  new$SOURCEID UTYPEDFORMSCAPTION.SOURCEID%TYPE := :NEW.SOURCEID;
  new$SOURCEMAILID UTYPEDFORMSCAPTION.SOURCEMAILID%TYPE := :NEW.SOURCEMAILID;
  new$AUTOTASKSSERVER UTYPEDFORMSCAPTION.AUTOTASKSSERVER%TYPE := :NEW.AUTOTASKSSERVER;
  new$DEPARTMENTCLS UTYPEDFORMSCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$SENDERID UTYPEDFORMSCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID UTYPEDFORMSCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$CRYPTOSTATUS UTYPEDFORMSCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$UTFRINDEX UTYPEDFORMSCAPTION.UTFRINDEX%TYPE := :NEW.UTFRINDEX;
  new$REPORTDATE UTYPEDFORMSCAPTION.REPORTDATE%TYPE := :NEW.REPORTDATE;
  new$ESTIMDATE UTYPEDFORMSCAPTION.ESTIMDATE%TYPE := :NEW.ESTIMDATE;
  new$SELF UTYPEDFORMSCAPTION.SELF%TYPE := :NEW.SELF;
  new$CLIENTSTYPE UTYPEDFORMSCAPTION.CLIENTSTYPE%TYPE := :NEW.CLIENTSTYPE;
  new$SENDKIT UTYPEDFORMSCAPTION.SENDKIT%TYPE := :NEW.SENDKIT;
  new$SENDSTS UTYPEDFORMSCAPTION.SENDSTS%TYPE := :NEW.SENDSTS;
  new$SENDDOC UTYPEDFORMSCAPTION.SENDDOC%TYPE := :NEW.SENDDOC;
  new$MANUALEXEC UTYPEDFORMSCAPTION.MANUALEXEC%TYPE := :NEW.MANUALEXEC;
  new$DATAMODE UTYPEDFORMSCAPTION.DATAMODE%TYPE := :NEW.DATAMODE;
  new$BUDGETREF UTYPEDFORMSCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$REPORTYEAR UTYPEDFORMSCAPTION.REPORTYEAR%TYPE := :NEW.REPORTYEAR;
  new$REJECTCLS UTYPEDFORMSCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$DOCSTATEREF UTYPEDFORMSCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION UTYPEDFORMSCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$LASTEXTRCHANGE UTYPEDFORMSCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$VERSIONID UTYPEDFORMSCAPTION.VERSIONID%TYPE := :NEW.VERSIONID;
  new$CONSCLIENT UTYPEDFORMSCAPTION.CONSCLIENT%TYPE := :NEW.CONSCLIENT;
  new$FINT1 UTYPEDFORMSCAPTION.FINT1%TYPE := :NEW.FINT1;
  new$FINT2 UTYPEDFORMSCAPTION.FINT2%TYPE := :NEW.FINT2;
  new$FINT3 UTYPEDFORMSCAPTION.FINT3%TYPE := :NEW.FINT3;
  new$FINT4 UTYPEDFORMSCAPTION.FINT4%TYPE := :NEW.FINT4;
  new$FINT5 UTYPEDFORMSCAPTION.FINT5%TYPE := :NEW.FINT5;
  new$FINT6 UTYPEDFORMSCAPTION.FINT6%TYPE := :NEW.FINT6;
  new$FINT7 UTYPEDFORMSCAPTION.FINT7%TYPE := :NEW.FINT7;
  new$PARAMS UTYPEDFORMSCAPTION.PARAMS%TYPE := :NEW.PARAMS;
  new$FORMTEXTID UTYPEDFORMSCAPTION.FORMTEXTID%TYPE := :NEW.FORMTEXTID;
  new$REGTEXTID UTYPEDFORMSCAPTION.REGTEXTID%TYPE := :NEW.REGTEXTID;
  new$PERIODTEXTID UTYPEDFORMSCAPTION.PERIODTEXTID%TYPE := :NEW.PERIODTEXTID;
  new$REPORTMONTH UTYPEDFORMSCAPTION.REPORTMONTH%TYPE := :NEW.REPORTMONTH;
  new$ACTIVITYKIND UTYPEDFORMSCAPTION.ACTIVITYKIND%TYPE := :NEW.ACTIVITYKIND;
  new$PERIOD UTYPEDFORMSCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$TEMPREJECTCAUSE UTYPEDFORMSCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  Cnt$ NUMBER(10);
  NeedVersion$ NUMBER(5);
  ActiveVersion$ NUMBER(10);
  ReportPeriod$ NUMBER(10);
  AMonth$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_UTFC_BU)
-- Create 02.03.2004
-- Last update 15.12.2005
-- - - - - - - - - - - - -

  /*      ID -   */
  IF (new$ID IS NULL) THEN SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL; END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_UTFC_BU10)
-- Version 8.00.00.2
-- - - - - - - - - - - - -

  if (new$typedform is null) then 
    new$typedform := 0;
  END IF;
  if (new$utfrindex is null) then 
    new$utfrindex := 0;
  END IF;
  if (new$self is null) then 
    new$self := 0;
  END IF;
  if (new$sendkit is null) then 
    new$sendkit := 0;
  END IF;
  if (new$sendsts is null) then 
    new$sendsts := 0;
  END IF;
  if (new$senddoc is null) then 
    new$senddoc := 0;
  END IF;
  if (new$manualexec is null) then 
    new$manualexec := 0;
  END IF;
  if (new$period is null) then 
    new$period := 0;
  END IF;
  if (new$clientstype is null) then 
    new$clientstype := 0;
  END IF;
  if (new$datamode is null) then 
    new$datamode := 0;
  END IF;
  if (new$departmentcls is null) then 
    new$departmentcls := 0;
  END IF;
  if (new$ActivityKind is null) then 
    new$ActivityKind := 0;
  END IF;
  if (new$BudgetRef is null) then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$email is null) then 
    new$email := '';
  END IF;
  new$email := UPPER(new$email);
  if (not new$autotasksserver is null) then
    new$autotasksserver := UPPER(new$autotasksserver);
  END IF;

-- - - - - - - - - - - - -
-- BU_20 (TR_UTFC_BU20)
-- Create 22.05.2004
-- Last update 15.12.2008
-- - - - - - - - - - - - -

    /*     ,     */
    BEGIN
      select utf.NEEDVERSION into NeedVersion$
      from UTYPEDFORMS utf
      where (utf.ID = new$TYPEDFORM);
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        NeedVersion$ := NULL;
    END;  
    
    if (NeedVersion$ = 1) then
        /*     ,    */
        if (new$VERSIONID is null) then
            /*      ,  */
            if (new$SENDERID is not null) then
                /*       ""*/
                BEGIN
                  select UTFV.ID into ActiveVersion$
                  from UTYPEDFORMSVERSION UTFV
                  where ((UTFV.TYPEDFORM = new$TYPEDFORM)
                      and (UTFV.IsCurrentForURM = 1));
                EXCEPTION
                  WHEN NO_DATA_FOUND THEN
                    ActiveVersion$ := NULL;
                END;                      
            else
                /*       ""*/
                BEGIN
                  select UTFV.ID into ActiveVersion$
                  from UTYPEDFORMSVERSION UTFV
                  where ((UTFV.TYPEDFORM = new$TYPEDFORM)
                      and (UTFV.ISCURRENT = 1));
                EXCEPTION
                  WHEN NO_DATA_FOUND THEN
                    ActiveVersion$ := NULL;
                END;                      
            end if;

            /*     */
            new$VERSIONID := ActiveVersion$;

            /*     */
            select count(ID) into CNT$ from UTYPEDFORMSVERSION where (ID = new$VERSIONID) AND (ROWNUM = 1);
            if (CNT$ = 0 ) then
              RaiseException('EX_NOT_ACTIVE_VERSION');
            end if;  
        end if;
    end if;

-- - - - - - - - - - - - -
-- BU_50 (TR_UTFC_BU50)
-- Version 8.00.00.2
-- - - - - - - - - - - - -

  BEGIN
    /*    */
    select utf.Period
    into ReportPeriod$   from utypedforms utf
    where utf.id = new$TypedForm
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*       */
  if (ReportPeriod$  = 30) then
    /*     12  */    
    new$REPORTMONTH := 12;
      
  else
    if (ReportPeriod$  = 20) then
      /*          */
      if ((new$ReportMonth is null) or (new$ReportMonth = 0)) then
        /*    ,    */        
        new$ReportMonth := 3;
              
      else
        AMonth$ := new$ReportMonth;
        if (AMonth$ between 1 and 3) then
          AMonth$ := 3;
                  
        else 
          if (AMonth$ between 4 and 6) then
            AMonth$ := 6;
                    
          else 
            if (AMonth$ between 7 and 9) then
              AMonth$ := 9;
                      
            else
              AMonth$ := 12;
            END IF;
          END IF;
        END IF;

        new$ReportMonth := AMonth$;
          
      END IF;
    else
      if ((ReportPeriod$  = 10) and (new$ReportMonth is null)) then
        new$ReportMonth := 1;
          
      END IF;
    END IF;
  END IF;
  if (new$REPORTYEAR is null) then 
    new$REPORTYEAR := 0;
  END IF;
  /*          */
  if (ReportPeriod$  > 0) then
    new$REPORTDATE := new$REPORTYEAR * 10000 + new$REPORTMONTH * 100 + 01;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_UTFC_BU_200)
-- Create 14.09.2005
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  /*       */
  if (new$DOCSTATEREF <> :old.DOCSTATEREF) then
    insert into StateJumpHistory(DocID, BeginStateRef, EndStateRef)
      values(new$id, :old.DOCSTATEREF, :new.DOCSTATEREF);
  end if;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_UTYPEDFORMSCAPTION SET
    ID = new$ID,
    REGIONCLS = new$REGIONCLS,
    ACCEPTDATE = new$ACCEPTDATE,
    DOCNUMBER = new$DOCNUMBER,
    NOTE = new$NOTE,
    TYPEDFORM = new$TYPEDFORM,
    PROGINDEX = new$PROGINDEX,
    FACIALACC_CLS = new$FACIALACC_CLS,
    ORG_REF = new$ORG_REF,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    EMAIL = new$EMAIL,
    STATE = new$STATE,
    ERROR = new$ERROR,
    SOURCEID = new$SOURCEID,
    SOURCEMAILID = new$SOURCEMAILID,
    AUTOTASKSSERVER = new$AUTOTASKSSERVER,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    UTFRINDEX = new$UTFRINDEX,
    REPORTDATE = new$REPORTDATE,
    ESTIMDATE = new$ESTIMDATE,
    SELF = new$SELF,
    CLIENTSTYPE = new$CLIENTSTYPE,
    SENDKIT = new$SENDKIT,
    SENDSTS = new$SENDSTS,
    SENDDOC = new$SENDDOC,
    MANUALEXEC = new$MANUALEXEC,
    DATAMODE = new$DATAMODE,
    BUDGETREF = new$BUDGETREF,
    REPORTYEAR = new$REPORTYEAR,
    REJECTCLS = new$REJECTCLS,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    VERSIONID = new$VERSIONID,
    CONSCLIENT = new$CONSCLIENT,
    FINT1 = new$FINT1,
    FINT2 = new$FINT2,
    FINT3 = new$FINT3,
    FINT4 = new$FINT4,
    FINT5 = new$FINT5,
    FINT6 = new$FINT6,
    FINT7 = new$FINT7,
    PARAMS = new$PARAMS,
    FORMTEXTID = new$FORMTEXTID,
    REGTEXTID = new$REGTEXTID,
    PERIODTEXTID = new$PERIODTEXTID,
    REPORTMONTH = new$REPORTMONTH,
    ACTIVITYKIND = new$ACTIVITYKIND,
    PERIOD = new$PERIOD,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);
 
  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

END;
/
ALTER TABLE TB_UTYPEDFORMSCAPTION ADD (
  REJECTCAUSE VARCHAR2(1000)
)
/

CREATE OR REPLACE VIEW UTYPEDFORMSCAPTION (
  ID,
  REGIONCLS,
  ACCEPTDATE,
  DOCNUMBER,
  NOTE,
  TYPEDFORM,
  PROGINDEX,
  FACIALACC_CLS,
  ORG_REF,
  CREATERUSER,
  UPDATERUSER,
  CREATEDATE,
  UPDATEDATE,
  EMAIL,
  STATE,
  ERROR,
  SOURCEID,
  SOURCEMAILID,
  AUTOTASKSSERVER,
  DEPARTMENTCLS,
  SENDERID,
  SENDERRECORDID,
  CRYPTOSTATUS,
  UTFRINDEX,
  REPORTDATE,
  ESTIMDATE,
  SELF,
  CLIENTSTYPE,
  SENDKIT,
  SENDSTS,
  SENDDOC,
  MANUALEXEC,
  DATAMODE,
  BUDGETREF,
  REPORTYEAR,
  REJECTCLS,
  DOCSTATEREF,
  RVERSION,
  LASTEXTRCHANGE,
  VERSIONID,
  CONSCLIENT,
  FINT1,
  FINT2,
  FINT3,
  FINT4,
  FINT5,
  FINT6,
  FINT7,
  PARAMS,
  FORMTEXTID,
  REGTEXTID,
  PERIODTEXTID,
  REPORTMONTH,
  ACTIVITYKIND,
  PERIOD,
  TEMPREJECTCAUSE,
  REJECTCAUSE)
AS
  SELECT
    ID,
    REGIONCLS,
    ACCEPTDATE,
    DOCNUMBER,
    NOTE,
    TYPEDFORM,
    PROGINDEX,
    FACIALACC_CLS,
    ORG_REF,
    CREATERUSER,
    UPDATERUSER,
    CREATEDATE,
    UPDATEDATE,
    EMAIL,
    STATE,
    ERROR,
    SOURCEID,
    SOURCEMAILID,
    AUTOTASKSSERVER,
    DEPARTMENTCLS,
    SENDERID,
    SENDERRECORDID,
    CRYPTOSTATUS,
    UTFRINDEX,
    REPORTDATE,
    ESTIMDATE,
    SELF,
    CLIENTSTYPE,
    SENDKIT,
    SENDSTS,
    SENDDOC,
    MANUALEXEC,
    DATAMODE,
    BUDGETREF,
    REPORTYEAR,
    REJECTCLS,
    DOCSTATEREF,
    RVERSION,
    LASTEXTRCHANGE,
    VERSIONID,
    CONSCLIENT,
    FINT1,
    FINT2,
    FINT3,
    FINT4,
    FINT5,
    FINT6,
    FINT7,
    PARAMS,
    FORMTEXTID,
    REGTEXTID,
    PERIODTEXTID,
    REPORTMONTH,
    ACTIVITYKIND,
    PERIOD,
    TEMPREJECTCAUSE,
    REJECTCAUSE
  FROM TB_UTYPEDFORMSCAPTION
/

CREATE OR REPLACE TRIGGER TR_UTFC_ID
  INSTEAD OF DELETE
  ON UTYPEDFORMSCAPTION
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_UTFC_BD)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*    */
  delete from uTypedFormsDetail where RecordIndex = :old.id;
    
  /*        */
  delete from uTypedImportRegistry where RecordIndex = :old.id;

-- - - - - - - - - - - - -
-- BD_10 (TR_UTFC_BD10)
-- Create 30.11.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  /*       */
  DELETE FROM utfctree WHERE (utfcparent = :old.id) OR (utfckid = :old.id);

-- - - - - - - - - - - - -
-- BD_20 (TR_UTFC_BD20)
-- Create 15.12.2005
-- - - - - - - - - - - - -

  /*        */
  if (not :old.VERSIONID is null) then
    update UTYPEDFORMSVERSION utfv
    set REPORTNUMBER = (select count(utfc.ID) - 1
                        from utypedformscaption utfc
                        where (utfc.VERSIONID = :old.VERSIONID))
    where utfv.ID = :old.VERSIONID;
  end if;  

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_UTYPEDFORMSCAPTION
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_200 (TR_UTFC_AD_200)
-- Create 14.09.2005
-- - - - - - - - - - - - -

  /*      */
  delete from StateJumpHistory where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_UTFC_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  INSERT INTO delrecindexes(tableid, recordid, deletedate, ProgIndex)
  VALUES (1301, :old.ID, SYSDATE, :old.ProgIndex);

END;
/

CREATE OR REPLACE TRIGGER TR_UTFC_II
  INSTEAD OF INSERT
  ON UTYPEDFORMSCAPTION
  FOR EACH ROW
DECLARE
  new$ID UTYPEDFORMSCAPTION.ID%TYPE := :NEW.ID;
  new$REGIONCLS UTYPEDFORMSCAPTION.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$ACCEPTDATE UTYPEDFORMSCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCNUMBER UTYPEDFORMSCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$NOTE UTYPEDFORMSCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$TYPEDFORM UTYPEDFORMSCAPTION.TYPEDFORM%TYPE := :NEW.TYPEDFORM;
  new$PROGINDEX UTYPEDFORMSCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$FACIALACC_CLS UTYPEDFORMSCAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$ORG_REF UTYPEDFORMSCAPTION.ORG_REF%TYPE := :NEW.ORG_REF;
  new$CREATERUSER UTYPEDFORMSCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER UTYPEDFORMSCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$CREATEDATE UTYPEDFORMSCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE UTYPEDFORMSCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$EMAIL UTYPEDFORMSCAPTION.EMAIL%TYPE := :NEW.EMAIL;
  new$STATE UTYPEDFORMSCAPTION.STATE%TYPE := :NEW.STATE;
  new$ERROR UTYPEDFORMSCAPTION.ERROR%TYPE := :NEW.ERROR;
  new$SOURCEID UTYPEDFORMSCAPTION.SOURCEID%TYPE := :NEW.SOURCEID;
  new$SOURCEMAILID UTYPEDFORMSCAPTION.SOURCEMAILID%TYPE := :NEW.SOURCEMAILID;
  new$AUTOTASKSSERVER UTYPEDFORMSCAPTION.AUTOTASKSSERVER%TYPE := :NEW.AUTOTASKSSERVER;
  new$DEPARTMENTCLS UTYPEDFORMSCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$SENDERID UTYPEDFORMSCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID UTYPEDFORMSCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$CRYPTOSTATUS UTYPEDFORMSCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$UTFRINDEX UTYPEDFORMSCAPTION.UTFRINDEX%TYPE := :NEW.UTFRINDEX;
  new$REPORTDATE UTYPEDFORMSCAPTION.REPORTDATE%TYPE := :NEW.REPORTDATE;
  new$ESTIMDATE UTYPEDFORMSCAPTION.ESTIMDATE%TYPE := :NEW.ESTIMDATE;
  new$SELF UTYPEDFORMSCAPTION.SELF%TYPE := :NEW.SELF;
  new$CLIENTSTYPE UTYPEDFORMSCAPTION.CLIENTSTYPE%TYPE := :NEW.CLIENTSTYPE;
  new$SENDKIT UTYPEDFORMSCAPTION.SENDKIT%TYPE := :NEW.SENDKIT;
  new$SENDSTS UTYPEDFORMSCAPTION.SENDSTS%TYPE := :NEW.SENDSTS;
  new$SENDDOC UTYPEDFORMSCAPTION.SENDDOC%TYPE := :NEW.SENDDOC;
  new$MANUALEXEC UTYPEDFORMSCAPTION.MANUALEXEC%TYPE := :NEW.MANUALEXEC;
  new$DATAMODE UTYPEDFORMSCAPTION.DATAMODE%TYPE := :NEW.DATAMODE;
  new$BUDGETREF UTYPEDFORMSCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$REPORTYEAR UTYPEDFORMSCAPTION.REPORTYEAR%TYPE := :NEW.REPORTYEAR;
  new$REJECTCLS UTYPEDFORMSCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$DOCSTATEREF UTYPEDFORMSCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION UTYPEDFORMSCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$LASTEXTRCHANGE UTYPEDFORMSCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$VERSIONID UTYPEDFORMSCAPTION.VERSIONID%TYPE := :NEW.VERSIONID;
  new$CONSCLIENT UTYPEDFORMSCAPTION.CONSCLIENT%TYPE := :NEW.CONSCLIENT;
  new$FINT1 UTYPEDFORMSCAPTION.FINT1%TYPE := :NEW.FINT1;
  new$FINT2 UTYPEDFORMSCAPTION.FINT2%TYPE := :NEW.FINT2;
  new$FINT3 UTYPEDFORMSCAPTION.FINT3%TYPE := :NEW.FINT3;
  new$FINT4 UTYPEDFORMSCAPTION.FINT4%TYPE := :NEW.FINT4;
  new$FINT5 UTYPEDFORMSCAPTION.FINT5%TYPE := :NEW.FINT5;
  new$FINT6 UTYPEDFORMSCAPTION.FINT6%TYPE := :NEW.FINT6;
  new$FINT7 UTYPEDFORMSCAPTION.FINT7%TYPE := :NEW.FINT7;
  new$PARAMS UTYPEDFORMSCAPTION.PARAMS%TYPE := :NEW.PARAMS;
  new$FORMTEXTID UTYPEDFORMSCAPTION.FORMTEXTID%TYPE := :NEW.FORMTEXTID;
  new$REGTEXTID UTYPEDFORMSCAPTION.REGTEXTID%TYPE := :NEW.REGTEXTID;
  new$PERIODTEXTID UTYPEDFORMSCAPTION.PERIODTEXTID%TYPE := :NEW.PERIODTEXTID;
  new$REPORTMONTH UTYPEDFORMSCAPTION.REPORTMONTH%TYPE := :NEW.REPORTMONTH;
  new$ACTIVITYKIND UTYPEDFORMSCAPTION.ACTIVITYKIND%TYPE := :NEW.ACTIVITYKIND;
  new$PERIOD UTYPEDFORMSCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$TEMPREJECTCAUSE UTYPEDFORMSCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
  new$REJECTCAUSE UTYPEDFORMSCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  Cnt$ NUMBER(10);
  NeedVersion$ NUMBER(5);
  ActiveVersion$ NUMBER(10);
  ReportPeriod$ NUMBER(10);
  AMonth$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_UTFC_BI)
-- Create 02.03.2004
-- Last update 15.12.2005
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL
        INTO new$ID
        FROM DUAL;
   END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_UTFC_BI10)
-- Version 8.00.00.2
-- - - - - - - - - - - - -

  if (new$TYPEDFORM is null) then 
    new$TYPEDFORM := 0;
  END IF;
  if (new$utfrindex is null) then 
    new$utfrindex := 0;
  END IF;
  if (new$self is null) then 
    new$self := 0;
  END IF;
  if (new$sendkit is null) then 
    new$sendkit := 0;
  END IF;
  if (new$sendsts is null) then 
    new$sendsts := 0;
  END IF;
  if (new$senddoc is null) then 
    new$senddoc := 0;
  END IF;
  if (new$manualexec is null) then 
    new$manualexec := 0;
  END IF;
  if (new$period is null) then 
    new$period := 0;
  END IF;
  if (new$clientstype is null) then 
    new$clientstype := 0;
  END IF;
  if (new$datamode is null) then 
    new$datamode := 0;
  END IF;
  if (new$departmentcls is null) then 
    new$departmentcls := 0;
  END IF;
  if (new$ActivityKind is null) then 
    new$ActivityKind := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then 
    BEGIN
      select fa.BudgetRef      into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$email is null) then 
    new$email := '';
  END IF;
  new$email := UPPER(new$email);
  if (not new$autotasksserver is null) then
    new$autotasksserver := UPPER(new$autotasksserver);
  END IF;

-- - - - - - - - - - - - -
-- BI_20 (TR_UTFC_BI20)
-- Create 22.05.2004
-- Last update 15.12.2008
-- - - - - - - - - - - - -

    /*     ,     */
    BEGIN
      select utf.NEEDVERSION into NeedVersion$
      from UTYPEDFORMS utf
      where (utf.ID = new$TYPEDFORM);
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        NeedVersion$ := NULL;
    END;  
    
    if (NeedVersion$ = 1) then
        /*     ,    */
        if (new$VERSIONID is null) then
            /*      ,  */
            if (new$SENDERID is not null) then
                /*       ""*/
                BEGIN
                  select UTFV.ID into ActiveVersion$
                  from UTYPEDFORMSVERSION UTFV
                  where ((UTFV.TYPEDFORM = new$TYPEDFORM)
                      and (UTFV.IsCurrentForURM = 1));
                EXCEPTION
                  WHEN NO_DATA_FOUND THEN
                    ActiveVersion$ := NULL;
                END;                      
            else
                /*       ""*/
                BEGIN
                  select UTFV.ID into ActiveVersion$
                  from UTYPEDFORMSVERSION UTFV
                  where ((UTFV.TYPEDFORM = new$TYPEDFORM)
                      and (UTFV.ISCURRENT = 1));
                EXCEPTION
                  WHEN NO_DATA_FOUND THEN
                    ActiveVersion$ := NULL;
                END;                      
            end if;

            /*     */
            new$VERSIONID := ActiveVersion$;

            /*     */
            select count(ID) into CNT$ from UTYPEDFORMSVERSION where (ID = new$VERSIONID) AND (ROWNUM = 1);
            if (CNT$ = 0 ) then
              RaiseException('EX_NOT_ACTIVE_VERSION');
            end if;  
        end if;
    end if;

-- - - - - - - - - - - - -
-- BI_50 (TR_UTFC_BI50)
-- Version 8.00.00.2
-- - - - - - - - - - - - -

  BEGIN
    /*    */
    select utf.Period
    into ReportPeriod$   from utypedforms utf
    where utf.id = new$TypedForm
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*       */
  if (ReportPeriod$  = 30) then
    /*     12  */    
    new$REPORTMONTH := 12;
      
  else
    if (ReportPeriod$  = 20) then
      /*          */
      if ((new$ReportMonth is null) or (new$ReportMonth = 0)) then
        /*    ,    */        
        new$ReportMonth := 3;
              
      else
        AMonth$ := new$ReportMonth;
        if (AMonth$ between 1 and 3) then
          AMonth$ := 3;
                  
        else 
          if (AMonth$ between 4 and 6) then
            AMonth$ := 6;
                    
          else 
            if (AMonth$ between 7 and 9) then
              AMonth$ := 9;
                      
            else
              AMonth$ := 12;
            END IF;
          END IF;
        END IF;

        new$ReportMonth := AMonth$;
          
      END IF;
    else
      if ((ReportPeriod$  = 10) and (new$ReportMonth is null)) then
        new$ReportMonth := 1;
          
      END IF;
    END IF;
  END IF;
  if (new$REPORTYEAR is null) then 
    new$REPORTYEAR := 0;
  END IF;
  /*          */
  if (ReportPeriod$  > 0) then
    new$REPORTDATE := new$REPORTYEAR * 10000 + new$REPORTMONTH * 100 + 01;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_UTFC_BI500)
-- Create 2.03.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_UTYPEDFORMSCAPTION (
    ID,
    REGIONCLS,
    ACCEPTDATE,
    DOCNUMBER,
    NOTE,
    TYPEDFORM,
    PROGINDEX,
    FACIALACC_CLS,
    ORG_REF,
    CREATERUSER,
    UPDATERUSER,
    CREATEDATE,
    UPDATEDATE,
    EMAIL,
    STATE,
    ERROR,
    SOURCEID,
    SOURCEMAILID,
    AUTOTASKSSERVER,
    DEPARTMENTCLS,
    SENDERID,
    SENDERRECORDID,
    CRYPTOSTATUS,
    UTFRINDEX,
    REPORTDATE,
    ESTIMDATE,
    SELF,
    CLIENTSTYPE,
    SENDKIT,
    SENDSTS,
    SENDDOC,
    MANUALEXEC,
    DATAMODE,
    BUDGETREF,
    REPORTYEAR,
    REJECTCLS,
    DOCSTATEREF,
    RVERSION,
    LASTEXTRCHANGE,
    VERSIONID,
    CONSCLIENT,
    FINT1,
    FINT2,
    FINT3,
    FINT4,
    FINT5,
    FINT6,
    FINT7,
    PARAMS,
    FORMTEXTID,
    REGTEXTID,
    PERIODTEXTID,
    REPORTMONTH,
    ACTIVITYKIND,
    PERIOD,
    TEMPREJECTCAUSE,
    REJECTCAUSE
  ) VALUES (
    new$ID,
    new$REGIONCLS,
    new$ACCEPTDATE,
    new$DOCNUMBER,
    new$NOTE,
    new$TYPEDFORM,
    new$PROGINDEX,
    new$FACIALACC_CLS,
    new$ORG_REF,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$EMAIL,
    new$STATE,
    new$ERROR,
    new$SOURCEID,
    new$SOURCEMAILID,
    new$AUTOTASKSSERVER,
    new$DEPARTMENTCLS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$CRYPTOSTATUS,
    new$UTFRINDEX,
    new$REPORTDATE,
    new$ESTIMDATE,
    new$SELF,
    new$CLIENTSTYPE,
    new$SENDKIT,
    new$SENDSTS,
    new$SENDDOC,
    new$MANUALEXEC,
    new$DATAMODE,
    new$BUDGETREF,
    new$REPORTYEAR,
    new$REJECTCLS,
    new$DOCSTATEREF,
    new$RVERSION,
    new$LASTEXTRCHANGE,
    new$VERSIONID,
    new$CONSCLIENT,
    new$FINT1,
    new$FINT2,
    new$FINT3,
    new$FINT4,
    new$FINT5,
    new$FINT6,
    new$FINT7,
    new$PARAMS,
    new$FORMTEXTID,
    new$REGTEXTID,
    new$PERIODTEXTID,
    new$REPORTMONTH,
    new$ACTIVITYKIND,
    new$PERIOD,
    new$TEMPREJECTCAUSE,
    new$REJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_UTFC_AI_500)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   DELETE FROM delrecindexes
         WHERE (tableid = 1301) AND (recordid = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_UTFC_IU
  INSTEAD OF UPDATE
  ON UTYPEDFORMSCAPTION
  FOR EACH ROW
DECLARE
  new$ID UTYPEDFORMSCAPTION.ID%TYPE := :NEW.ID;
  new$REGIONCLS UTYPEDFORMSCAPTION.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$ACCEPTDATE UTYPEDFORMSCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCNUMBER UTYPEDFORMSCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$NOTE UTYPEDFORMSCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$TYPEDFORM UTYPEDFORMSCAPTION.TYPEDFORM%TYPE := :NEW.TYPEDFORM;
  new$PROGINDEX UTYPEDFORMSCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$FACIALACC_CLS UTYPEDFORMSCAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$ORG_REF UTYPEDFORMSCAPTION.ORG_REF%TYPE := :NEW.ORG_REF;
  new$CREATERUSER UTYPEDFORMSCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER UTYPEDFORMSCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$CREATEDATE UTYPEDFORMSCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE UTYPEDFORMSCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$EMAIL UTYPEDFORMSCAPTION.EMAIL%TYPE := :NEW.EMAIL;
  new$STATE UTYPEDFORMSCAPTION.STATE%TYPE := :NEW.STATE;
  new$ERROR UTYPEDFORMSCAPTION.ERROR%TYPE := :NEW.ERROR;
  new$SOURCEID UTYPEDFORMSCAPTION.SOURCEID%TYPE := :NEW.SOURCEID;
  new$SOURCEMAILID UTYPEDFORMSCAPTION.SOURCEMAILID%TYPE := :NEW.SOURCEMAILID;
  new$AUTOTASKSSERVER UTYPEDFORMSCAPTION.AUTOTASKSSERVER%TYPE := :NEW.AUTOTASKSSERVER;
  new$DEPARTMENTCLS UTYPEDFORMSCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$SENDERID UTYPEDFORMSCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID UTYPEDFORMSCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$CRYPTOSTATUS UTYPEDFORMSCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$UTFRINDEX UTYPEDFORMSCAPTION.UTFRINDEX%TYPE := :NEW.UTFRINDEX;
  new$REPORTDATE UTYPEDFORMSCAPTION.REPORTDATE%TYPE := :NEW.REPORTDATE;
  new$ESTIMDATE UTYPEDFORMSCAPTION.ESTIMDATE%TYPE := :NEW.ESTIMDATE;
  new$SELF UTYPEDFORMSCAPTION.SELF%TYPE := :NEW.SELF;
  new$CLIENTSTYPE UTYPEDFORMSCAPTION.CLIENTSTYPE%TYPE := :NEW.CLIENTSTYPE;
  new$SENDKIT UTYPEDFORMSCAPTION.SENDKIT%TYPE := :NEW.SENDKIT;
  new$SENDSTS UTYPEDFORMSCAPTION.SENDSTS%TYPE := :NEW.SENDSTS;
  new$SENDDOC UTYPEDFORMSCAPTION.SENDDOC%TYPE := :NEW.SENDDOC;
  new$MANUALEXEC UTYPEDFORMSCAPTION.MANUALEXEC%TYPE := :NEW.MANUALEXEC;
  new$DATAMODE UTYPEDFORMSCAPTION.DATAMODE%TYPE := :NEW.DATAMODE;
  new$BUDGETREF UTYPEDFORMSCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$REPORTYEAR UTYPEDFORMSCAPTION.REPORTYEAR%TYPE := :NEW.REPORTYEAR;
  new$REJECTCLS UTYPEDFORMSCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$DOCSTATEREF UTYPEDFORMSCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION UTYPEDFORMSCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$LASTEXTRCHANGE UTYPEDFORMSCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$VERSIONID UTYPEDFORMSCAPTION.VERSIONID%TYPE := :NEW.VERSIONID;
  new$CONSCLIENT UTYPEDFORMSCAPTION.CONSCLIENT%TYPE := :NEW.CONSCLIENT;
  new$FINT1 UTYPEDFORMSCAPTION.FINT1%TYPE := :NEW.FINT1;
  new$FINT2 UTYPEDFORMSCAPTION.FINT2%TYPE := :NEW.FINT2;
  new$FINT3 UTYPEDFORMSCAPTION.FINT3%TYPE := :NEW.FINT3;
  new$FINT4 UTYPEDFORMSCAPTION.FINT4%TYPE := :NEW.FINT4;
  new$FINT5 UTYPEDFORMSCAPTION.FINT5%TYPE := :NEW.FINT5;
  new$FINT6 UTYPEDFORMSCAPTION.FINT6%TYPE := :NEW.FINT6;
  new$FINT7 UTYPEDFORMSCAPTION.FINT7%TYPE := :NEW.FINT7;
  new$PARAMS UTYPEDFORMSCAPTION.PARAMS%TYPE := :NEW.PARAMS;
  new$FORMTEXTID UTYPEDFORMSCAPTION.FORMTEXTID%TYPE := :NEW.FORMTEXTID;
  new$REGTEXTID UTYPEDFORMSCAPTION.REGTEXTID%TYPE := :NEW.REGTEXTID;
  new$PERIODTEXTID UTYPEDFORMSCAPTION.PERIODTEXTID%TYPE := :NEW.PERIODTEXTID;
  new$REPORTMONTH UTYPEDFORMSCAPTION.REPORTMONTH%TYPE := :NEW.REPORTMONTH;
  new$ACTIVITYKIND UTYPEDFORMSCAPTION.ACTIVITYKIND%TYPE := :NEW.ACTIVITYKIND;
  new$PERIOD UTYPEDFORMSCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$TEMPREJECTCAUSE UTYPEDFORMSCAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
  new$REJECTCAUSE UTYPEDFORMSCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  Cnt$ NUMBER(10);
  NeedVersion$ NUMBER(5);
  ActiveVersion$ NUMBER(10);
  ReportPeriod$ NUMBER(10);
  AMonth$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_UTFC_BU)
-- Create 02.03.2004
-- Last update 15.12.2005
-- - - - - - - - - - - - -

  /*      ID -   */
  IF (new$ID IS NULL) THEN SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL; END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_UTFC_BU10)
-- Version 8.00.00.2
-- - - - - - - - - - - - -

  if (new$typedform is null) then 
    new$typedform := 0;
  END IF;
  if (new$utfrindex is null) then 
    new$utfrindex := 0;
  END IF;
  if (new$self is null) then 
    new$self := 0;
  END IF;
  if (new$sendkit is null) then 
    new$sendkit := 0;
  END IF;
  if (new$sendsts is null) then 
    new$sendsts := 0;
  END IF;
  if (new$senddoc is null) then 
    new$senddoc := 0;
  END IF;
  if (new$manualexec is null) then 
    new$manualexec := 0;
  END IF;
  if (new$period is null) then 
    new$period := 0;
  END IF;
  if (new$clientstype is null) then 
    new$clientstype := 0;
  END IF;
  if (new$datamode is null) then 
    new$datamode := 0;
  END IF;
  if (new$departmentcls is null) then 
    new$departmentcls := 0;
  END IF;
  if (new$ActivityKind is null) then 
    new$ActivityKind := 0;
  END IF;
  if (new$BudgetRef is null) then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$email is null) then 
    new$email := '';
  END IF;
  new$email := UPPER(new$email);
  if (not new$autotasksserver is null) then
    new$autotasksserver := UPPER(new$autotasksserver);
  END IF;

-- - - - - - - - - - - - -
-- BU_20 (TR_UTFC_BU20)
-- Create 22.05.2004
-- Last update 15.12.2008
-- - - - - - - - - - - - -

    /*     ,     */
    BEGIN
      select utf.NEEDVERSION into NeedVersion$
      from UTYPEDFORMS utf
      where (utf.ID = new$TYPEDFORM);
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        NeedVersion$ := NULL;
    END;  
    
    if (NeedVersion$ = 1) then
        /*     ,    */
        if (new$VERSIONID is null) then
            /*      ,  */
            if (new$SENDERID is not null) then
                /*       ""*/
                BEGIN
                  select UTFV.ID into ActiveVersion$
                  from UTYPEDFORMSVERSION UTFV
                  where ((UTFV.TYPEDFORM = new$TYPEDFORM)
                      and (UTFV.IsCurrentForURM = 1));
                EXCEPTION
                  WHEN NO_DATA_FOUND THEN
                    ActiveVersion$ := NULL;
                END;                      
            else
                /*       ""*/
                BEGIN
                  select UTFV.ID into ActiveVersion$
                  from UTYPEDFORMSVERSION UTFV
                  where ((UTFV.TYPEDFORM = new$TYPEDFORM)
                      and (UTFV.ISCURRENT = 1));
                EXCEPTION
                  WHEN NO_DATA_FOUND THEN
                    ActiveVersion$ := NULL;
                END;                      
            end if;

            /*     */
            new$VERSIONID := ActiveVersion$;

            /*     */
            select count(ID) into CNT$ from UTYPEDFORMSVERSION where (ID = new$VERSIONID) AND (ROWNUM = 1);
            if (CNT$ = 0 ) then
              RaiseException('EX_NOT_ACTIVE_VERSION');
            end if;  
        end if;
    end if;

-- - - - - - - - - - - - -
-- BU_50 (TR_UTFC_BU50)
-- Version 8.00.00.2
-- - - - - - - - - - - - -

  BEGIN
    /*    */
    select utf.Period
    into ReportPeriod$   from utypedforms utf
    where utf.id = new$TypedForm
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*       */
  if (ReportPeriod$  = 30) then
    /*     12  */    
    new$REPORTMONTH := 12;
      
  else
    if (ReportPeriod$  = 20) then
      /*          */
      if ((new$ReportMonth is null) or (new$ReportMonth = 0)) then
        /*    ,    */        
        new$ReportMonth := 3;
              
      else
        AMonth$ := new$ReportMonth;
        if (AMonth$ between 1 and 3) then
          AMonth$ := 3;
                  
        else 
          if (AMonth$ between 4 and 6) then
            AMonth$ := 6;
                    
          else 
            if (AMonth$ between 7 and 9) then
              AMonth$ := 9;
                      
            else
              AMonth$ := 12;
            END IF;
          END IF;
        END IF;

        new$ReportMonth := AMonth$;
          
      END IF;
    else
      if ((ReportPeriod$  = 10) and (new$ReportMonth is null)) then
        new$ReportMonth := 1;
          
      END IF;
    END IF;
  END IF;
  if (new$REPORTYEAR is null) then 
    new$REPORTYEAR := 0;
  END IF;
  /*          */
  if (ReportPeriod$  > 0) then
    new$REPORTDATE := new$REPORTYEAR * 10000 + new$REPORTMONTH * 100 + 01;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_UTFC_BU_200)
-- Create 14.09.2005
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  /*       */
  if (new$DOCSTATEREF <> :old.DOCSTATEREF) then
    insert into StateJumpHistory(DocID, BeginStateRef, EndStateRef)
      values(new$id, :old.DOCSTATEREF, :new.DOCSTATEREF);
  end if;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_UTYPEDFORMSCAPTION SET
    ID = new$ID,
    REGIONCLS = new$REGIONCLS,
    ACCEPTDATE = new$ACCEPTDATE,
    DOCNUMBER = new$DOCNUMBER,
    NOTE = new$NOTE,
    TYPEDFORM = new$TYPEDFORM,
    PROGINDEX = new$PROGINDEX,
    FACIALACC_CLS = new$FACIALACC_CLS,
    ORG_REF = new$ORG_REF,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    EMAIL = new$EMAIL,
    STATE = new$STATE,
    ERROR = new$ERROR,
    SOURCEID = new$SOURCEID,
    SOURCEMAILID = new$SOURCEMAILID,
    AUTOTASKSSERVER = new$AUTOTASKSSERVER,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    UTFRINDEX = new$UTFRINDEX,
    REPORTDATE = new$REPORTDATE,
    ESTIMDATE = new$ESTIMDATE,
    SELF = new$SELF,
    CLIENTSTYPE = new$CLIENTSTYPE,
    SENDKIT = new$SENDKIT,
    SENDSTS = new$SENDSTS,
    SENDDOC = new$SENDDOC,
    MANUALEXEC = new$MANUALEXEC,
    DATAMODE = new$DATAMODE,
    BUDGETREF = new$BUDGETREF,
    REPORTYEAR = new$REPORTYEAR,
    REJECTCLS = new$REJECTCLS,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    VERSIONID = new$VERSIONID,
    CONSCLIENT = new$CONSCLIENT,
    FINT1 = new$FINT1,
    FINT2 = new$FINT2,
    FINT3 = new$FINT3,
    FINT4 = new$FINT4,
    FINT5 = new$FINT5,
    FINT6 = new$FINT6,
    FINT7 = new$FINT7,
    PARAMS = new$PARAMS,
    FORMTEXTID = new$FORMTEXTID,
    REGTEXTID = new$REGTEXTID,
    PERIODTEXTID = new$PERIODTEXTID,
    REPORTMONTH = new$REPORTMONTH,
    ACTIVITYKIND = new$ACTIVITYKIND,
    PERIOD = new$PERIOD,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);
 
  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

END;
/
update UTYPEDFORMSCAPTION set
  REJECTCAUSE = TempRejectCause
/
commit work 
/
ALTER TABLE TB_UTYPEDFORMSCAPTION DROP (TempRejectCause)
/

CREATE OR REPLACE VIEW UTYPEDFORMSCAPTION (
  ID,
  REGIONCLS,
  ACCEPTDATE,
  DOCNUMBER,
  NOTE,
  TYPEDFORM,
  PROGINDEX,
  FACIALACC_CLS,
  ORG_REF,
  CREATERUSER,
  UPDATERUSER,
  CREATEDATE,
  UPDATEDATE,
  EMAIL,
  STATE,
  ERROR,
  SOURCEID,
  SOURCEMAILID,
  AUTOTASKSSERVER,
  DEPARTMENTCLS,
  SENDERID,
  SENDERRECORDID,
  CRYPTOSTATUS,
  UTFRINDEX,
  REPORTDATE,
  ESTIMDATE,
  SELF,
  CLIENTSTYPE,
  SENDKIT,
  SENDSTS,
  SENDDOC,
  MANUALEXEC,
  DATAMODE,
  BUDGETREF,
  REPORTYEAR,
  REJECTCLS,
  DOCSTATEREF,
  RVERSION,
  LASTEXTRCHANGE,
  VERSIONID,
  CONSCLIENT,
  FINT1,
  FINT2,
  FINT3,
  FINT4,
  FINT5,
  FINT6,
  FINT7,
  PARAMS,
  FORMTEXTID,
  REGTEXTID,
  PERIODTEXTID,
  REPORTMONTH,
  ACTIVITYKIND,
  PERIOD,
  REJECTCAUSE)
AS
  SELECT
    ID,
    REGIONCLS,
    ACCEPTDATE,
    DOCNUMBER,
    NOTE,
    TYPEDFORM,
    PROGINDEX,
    FACIALACC_CLS,
    ORG_REF,
    CREATERUSER,
    UPDATERUSER,
    CREATEDATE,
    UPDATEDATE,
    EMAIL,
    STATE,
    ERROR,
    SOURCEID,
    SOURCEMAILID,
    AUTOTASKSSERVER,
    DEPARTMENTCLS,
    SENDERID,
    SENDERRECORDID,
    CRYPTOSTATUS,
    UTFRINDEX,
    REPORTDATE,
    ESTIMDATE,
    SELF,
    CLIENTSTYPE,
    SENDKIT,
    SENDSTS,
    SENDDOC,
    MANUALEXEC,
    DATAMODE,
    BUDGETREF,
    REPORTYEAR,
    REJECTCLS,
    DOCSTATEREF,
    RVERSION,
    LASTEXTRCHANGE,
    VERSIONID,
    CONSCLIENT,
    FINT1,
    FINT2,
    FINT3,
    FINT4,
    FINT5,
    FINT6,
    FINT7,
    PARAMS,
    FORMTEXTID,
    REGTEXTID,
    PERIODTEXTID,
    REPORTMONTH,
    ACTIVITYKIND,
    PERIOD,
    REJECTCAUSE
  FROM TB_UTYPEDFORMSCAPTION
/

CREATE OR REPLACE TRIGGER TR_UTFC_ID
  INSTEAD OF DELETE
  ON UTYPEDFORMSCAPTION
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_UTFC_BD)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*    */
  delete from uTypedFormsDetail where RecordIndex = :old.id;
    
  /*        */
  delete from uTypedImportRegistry where RecordIndex = :old.id;

-- - - - - - - - - - - - -
-- BD_10 (TR_UTFC_BD10)
-- Create 30.11.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  /*       */
  DELETE FROM utfctree WHERE (utfcparent = :old.id) OR (utfckid = :old.id);

-- - - - - - - - - - - - -
-- BD_20 (TR_UTFC_BD20)
-- Create 15.12.2005
-- - - - - - - - - - - - -

  /*        */
  if (not :old.VERSIONID is null) then
    update UTYPEDFORMSVERSION utfv
    set REPORTNUMBER = (select count(utfc.ID) - 1
                        from utypedformscaption utfc
                        where (utfc.VERSIONID = :old.VERSIONID))
    where utfv.ID = :old.VERSIONID;
  end if;  

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_UTYPEDFORMSCAPTION
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_200 (TR_UTFC_AD_200)
-- Create 14.09.2005
-- - - - - - - - - - - - -

  /*      */
  delete from StateJumpHistory where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_UTFC_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  INSERT INTO delrecindexes(tableid, recordid, deletedate, ProgIndex)
  VALUES (1301, :old.ID, SYSDATE, :old.ProgIndex);

END;
/

CREATE OR REPLACE TRIGGER TR_UTFC_II
  INSTEAD OF INSERT
  ON UTYPEDFORMSCAPTION
  FOR EACH ROW
DECLARE
  new$ID UTYPEDFORMSCAPTION.ID%TYPE := :NEW.ID;
  new$REGIONCLS UTYPEDFORMSCAPTION.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$ACCEPTDATE UTYPEDFORMSCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCNUMBER UTYPEDFORMSCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$NOTE UTYPEDFORMSCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$TYPEDFORM UTYPEDFORMSCAPTION.TYPEDFORM%TYPE := :NEW.TYPEDFORM;
  new$PROGINDEX UTYPEDFORMSCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$FACIALACC_CLS UTYPEDFORMSCAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$ORG_REF UTYPEDFORMSCAPTION.ORG_REF%TYPE := :NEW.ORG_REF;
  new$CREATERUSER UTYPEDFORMSCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER UTYPEDFORMSCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$CREATEDATE UTYPEDFORMSCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE UTYPEDFORMSCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$EMAIL UTYPEDFORMSCAPTION.EMAIL%TYPE := :NEW.EMAIL;
  new$STATE UTYPEDFORMSCAPTION.STATE%TYPE := :NEW.STATE;
  new$ERROR UTYPEDFORMSCAPTION.ERROR%TYPE := :NEW.ERROR;
  new$SOURCEID UTYPEDFORMSCAPTION.SOURCEID%TYPE := :NEW.SOURCEID;
  new$SOURCEMAILID UTYPEDFORMSCAPTION.SOURCEMAILID%TYPE := :NEW.SOURCEMAILID;
  new$AUTOTASKSSERVER UTYPEDFORMSCAPTION.AUTOTASKSSERVER%TYPE := :NEW.AUTOTASKSSERVER;
  new$DEPARTMENTCLS UTYPEDFORMSCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$SENDERID UTYPEDFORMSCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID UTYPEDFORMSCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$CRYPTOSTATUS UTYPEDFORMSCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$UTFRINDEX UTYPEDFORMSCAPTION.UTFRINDEX%TYPE := :NEW.UTFRINDEX;
  new$REPORTDATE UTYPEDFORMSCAPTION.REPORTDATE%TYPE := :NEW.REPORTDATE;
  new$ESTIMDATE UTYPEDFORMSCAPTION.ESTIMDATE%TYPE := :NEW.ESTIMDATE;
  new$SELF UTYPEDFORMSCAPTION.SELF%TYPE := :NEW.SELF;
  new$CLIENTSTYPE UTYPEDFORMSCAPTION.CLIENTSTYPE%TYPE := :NEW.CLIENTSTYPE;
  new$SENDKIT UTYPEDFORMSCAPTION.SENDKIT%TYPE := :NEW.SENDKIT;
  new$SENDSTS UTYPEDFORMSCAPTION.SENDSTS%TYPE := :NEW.SENDSTS;
  new$SENDDOC UTYPEDFORMSCAPTION.SENDDOC%TYPE := :NEW.SENDDOC;
  new$MANUALEXEC UTYPEDFORMSCAPTION.MANUALEXEC%TYPE := :NEW.MANUALEXEC;
  new$DATAMODE UTYPEDFORMSCAPTION.DATAMODE%TYPE := :NEW.DATAMODE;
  new$BUDGETREF UTYPEDFORMSCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$REPORTYEAR UTYPEDFORMSCAPTION.REPORTYEAR%TYPE := :NEW.REPORTYEAR;
  new$REJECTCLS UTYPEDFORMSCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$DOCSTATEREF UTYPEDFORMSCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION UTYPEDFORMSCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$LASTEXTRCHANGE UTYPEDFORMSCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$VERSIONID UTYPEDFORMSCAPTION.VERSIONID%TYPE := :NEW.VERSIONID;
  new$CONSCLIENT UTYPEDFORMSCAPTION.CONSCLIENT%TYPE := :NEW.CONSCLIENT;
  new$FINT1 UTYPEDFORMSCAPTION.FINT1%TYPE := :NEW.FINT1;
  new$FINT2 UTYPEDFORMSCAPTION.FINT2%TYPE := :NEW.FINT2;
  new$FINT3 UTYPEDFORMSCAPTION.FINT3%TYPE := :NEW.FINT3;
  new$FINT4 UTYPEDFORMSCAPTION.FINT4%TYPE := :NEW.FINT4;
  new$FINT5 UTYPEDFORMSCAPTION.FINT5%TYPE := :NEW.FINT5;
  new$FINT6 UTYPEDFORMSCAPTION.FINT6%TYPE := :NEW.FINT6;
  new$FINT7 UTYPEDFORMSCAPTION.FINT7%TYPE := :NEW.FINT7;
  new$PARAMS UTYPEDFORMSCAPTION.PARAMS%TYPE := :NEW.PARAMS;
  new$FORMTEXTID UTYPEDFORMSCAPTION.FORMTEXTID%TYPE := :NEW.FORMTEXTID;
  new$REGTEXTID UTYPEDFORMSCAPTION.REGTEXTID%TYPE := :NEW.REGTEXTID;
  new$PERIODTEXTID UTYPEDFORMSCAPTION.PERIODTEXTID%TYPE := :NEW.PERIODTEXTID;
  new$REPORTMONTH UTYPEDFORMSCAPTION.REPORTMONTH%TYPE := :NEW.REPORTMONTH;
  new$ACTIVITYKIND UTYPEDFORMSCAPTION.ACTIVITYKIND%TYPE := :NEW.ACTIVITYKIND;
  new$PERIOD UTYPEDFORMSCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$REJECTCAUSE UTYPEDFORMSCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  Cnt$ NUMBER(10);
  NeedVersion$ NUMBER(5);
  ActiveVersion$ NUMBER(10);
  ReportPeriod$ NUMBER(10);
  AMonth$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_UTFC_BI)
-- Create 02.03.2004
-- Last update 15.12.2005
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL
        INTO new$ID
        FROM DUAL;
   END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_UTFC_BI10)
-- Version 8.00.00.2
-- - - - - - - - - - - - -

  if (new$TYPEDFORM is null) then 
    new$TYPEDFORM := 0;
  END IF;
  if (new$utfrindex is null) then 
    new$utfrindex := 0;
  END IF;
  if (new$self is null) then 
    new$self := 0;
  END IF;
  if (new$sendkit is null) then 
    new$sendkit := 0;
  END IF;
  if (new$sendsts is null) then 
    new$sendsts := 0;
  END IF;
  if (new$senddoc is null) then 
    new$senddoc := 0;
  END IF;
  if (new$manualexec is null) then 
    new$manualexec := 0;
  END IF;
  if (new$period is null) then 
    new$period := 0;
  END IF;
  if (new$clientstype is null) then 
    new$clientstype := 0;
  END IF;
  if (new$datamode is null) then 
    new$datamode := 0;
  END IF;
  if (new$departmentcls is null) then 
    new$departmentcls := 0;
  END IF;
  if (new$ActivityKind is null) then 
    new$ActivityKind := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then 
    BEGIN
      select fa.BudgetRef      into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$email is null) then 
    new$email := '';
  END IF;
  new$email := UPPER(new$email);
  if (not new$autotasksserver is null) then
    new$autotasksserver := UPPER(new$autotasksserver);
  END IF;

-- - - - - - - - - - - - -
-- BI_20 (TR_UTFC_BI20)
-- Create 22.05.2004
-- Last update 15.12.2008
-- - - - - - - - - - - - -

    /*     ,     */
    BEGIN
      select utf.NEEDVERSION into NeedVersion$
      from UTYPEDFORMS utf
      where (utf.ID = new$TYPEDFORM);
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        NeedVersion$ := NULL;
    END;  
    
    if (NeedVersion$ = 1) then
        /*     ,    */
        if (new$VERSIONID is null) then
            /*      ,  */
            if (new$SENDERID is not null) then
                /*       ""*/
                BEGIN
                  select UTFV.ID into ActiveVersion$
                  from UTYPEDFORMSVERSION UTFV
                  where ((UTFV.TYPEDFORM = new$TYPEDFORM)
                      and (UTFV.IsCurrentForURM = 1));
                EXCEPTION
                  WHEN NO_DATA_FOUND THEN
                    ActiveVersion$ := NULL;
                END;                      
            else
                /*       ""*/
                BEGIN
                  select UTFV.ID into ActiveVersion$
                  from UTYPEDFORMSVERSION UTFV
                  where ((UTFV.TYPEDFORM = new$TYPEDFORM)
                      and (UTFV.ISCURRENT = 1));
                EXCEPTION
                  WHEN NO_DATA_FOUND THEN
                    ActiveVersion$ := NULL;
                END;                      
            end if;

            /*     */
            new$VERSIONID := ActiveVersion$;

            /*     */
            select count(ID) into CNT$ from UTYPEDFORMSVERSION where (ID = new$VERSIONID) AND (ROWNUM = 1);
            if (CNT$ = 0 ) then
              RaiseException('EX_NOT_ACTIVE_VERSION');
            end if;  
        end if;
    end if;

-- - - - - - - - - - - - -
-- BI_50 (TR_UTFC_BI50)
-- Version 8.00.00.2
-- - - - - - - - - - - - -

  BEGIN
    /*    */
    select utf.Period
    into ReportPeriod$   from utypedforms utf
    where utf.id = new$TypedForm
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*       */
  if (ReportPeriod$  = 30) then
    /*     12  */    
    new$REPORTMONTH := 12;
      
  else
    if (ReportPeriod$  = 20) then
      /*          */
      if ((new$ReportMonth is null) or (new$ReportMonth = 0)) then
        /*    ,    */        
        new$ReportMonth := 3;
              
      else
        AMonth$ := new$ReportMonth;
        if (AMonth$ between 1 and 3) then
          AMonth$ := 3;
                  
        else 
          if (AMonth$ between 4 and 6) then
            AMonth$ := 6;
                    
          else 
            if (AMonth$ between 7 and 9) then
              AMonth$ := 9;
                      
            else
              AMonth$ := 12;
            END IF;
          END IF;
        END IF;

        new$ReportMonth := AMonth$;
          
      END IF;
    else
      if ((ReportPeriod$  = 10) and (new$ReportMonth is null)) then
        new$ReportMonth := 1;
          
      END IF;
    END IF;
  END IF;
  if (new$REPORTYEAR is null) then 
    new$REPORTYEAR := 0;
  END IF;
  /*          */
  if (ReportPeriod$  > 0) then
    new$REPORTDATE := new$REPORTYEAR * 10000 + new$REPORTMONTH * 100 + 01;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_UTFC_BI500)
-- Create 2.03.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_UTYPEDFORMSCAPTION (
    ID,
    REGIONCLS,
    ACCEPTDATE,
    DOCNUMBER,
    NOTE,
    TYPEDFORM,
    PROGINDEX,
    FACIALACC_CLS,
    ORG_REF,
    CREATERUSER,
    UPDATERUSER,
    CREATEDATE,
    UPDATEDATE,
    EMAIL,
    STATE,
    ERROR,
    SOURCEID,
    SOURCEMAILID,
    AUTOTASKSSERVER,
    DEPARTMENTCLS,
    SENDERID,
    SENDERRECORDID,
    CRYPTOSTATUS,
    UTFRINDEX,
    REPORTDATE,
    ESTIMDATE,
    SELF,
    CLIENTSTYPE,
    SENDKIT,
    SENDSTS,
    SENDDOC,
    MANUALEXEC,
    DATAMODE,
    BUDGETREF,
    REPORTYEAR,
    REJECTCLS,
    DOCSTATEREF,
    RVERSION,
    LASTEXTRCHANGE,
    VERSIONID,
    CONSCLIENT,
    FINT1,
    FINT2,
    FINT3,
    FINT4,
    FINT5,
    FINT6,
    FINT7,
    PARAMS,
    FORMTEXTID,
    REGTEXTID,
    PERIODTEXTID,
    REPORTMONTH,
    ACTIVITYKIND,
    PERIOD,
    REJECTCAUSE
  ) VALUES (
    new$ID,
    new$REGIONCLS,
    new$ACCEPTDATE,
    new$DOCNUMBER,
    new$NOTE,
    new$TYPEDFORM,
    new$PROGINDEX,
    new$FACIALACC_CLS,
    new$ORG_REF,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$EMAIL,
    new$STATE,
    new$ERROR,
    new$SOURCEID,
    new$SOURCEMAILID,
    new$AUTOTASKSSERVER,
    new$DEPARTMENTCLS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$CRYPTOSTATUS,
    new$UTFRINDEX,
    new$REPORTDATE,
    new$ESTIMDATE,
    new$SELF,
    new$CLIENTSTYPE,
    new$SENDKIT,
    new$SENDSTS,
    new$SENDDOC,
    new$MANUALEXEC,
    new$DATAMODE,
    new$BUDGETREF,
    new$REPORTYEAR,
    new$REJECTCLS,
    new$DOCSTATEREF,
    new$RVERSION,
    new$LASTEXTRCHANGE,
    new$VERSIONID,
    new$CONSCLIENT,
    new$FINT1,
    new$FINT2,
    new$FINT3,
    new$FINT4,
    new$FINT5,
    new$FINT6,
    new$FINT7,
    new$PARAMS,
    new$FORMTEXTID,
    new$REGTEXTID,
    new$PERIODTEXTID,
    new$REPORTMONTH,
    new$ACTIVITYKIND,
    new$PERIOD,
    new$REJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_UTFC_AI_500)
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   DELETE FROM delrecindexes
         WHERE (tableid = 1301) AND (recordid = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_UTFC_IU
  INSTEAD OF UPDATE
  ON UTYPEDFORMSCAPTION
  FOR EACH ROW
DECLARE
  new$ID UTYPEDFORMSCAPTION.ID%TYPE := :NEW.ID;
  new$REGIONCLS UTYPEDFORMSCAPTION.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$ACCEPTDATE UTYPEDFORMSCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCNUMBER UTYPEDFORMSCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$NOTE UTYPEDFORMSCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$TYPEDFORM UTYPEDFORMSCAPTION.TYPEDFORM%TYPE := :NEW.TYPEDFORM;
  new$PROGINDEX UTYPEDFORMSCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$FACIALACC_CLS UTYPEDFORMSCAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$ORG_REF UTYPEDFORMSCAPTION.ORG_REF%TYPE := :NEW.ORG_REF;
  new$CREATERUSER UTYPEDFORMSCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER UTYPEDFORMSCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$CREATEDATE UTYPEDFORMSCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE UTYPEDFORMSCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$EMAIL UTYPEDFORMSCAPTION.EMAIL%TYPE := :NEW.EMAIL;
  new$STATE UTYPEDFORMSCAPTION.STATE%TYPE := :NEW.STATE;
  new$ERROR UTYPEDFORMSCAPTION.ERROR%TYPE := :NEW.ERROR;
  new$SOURCEID UTYPEDFORMSCAPTION.SOURCEID%TYPE := :NEW.SOURCEID;
  new$SOURCEMAILID UTYPEDFORMSCAPTION.SOURCEMAILID%TYPE := :NEW.SOURCEMAILID;
  new$AUTOTASKSSERVER UTYPEDFORMSCAPTION.AUTOTASKSSERVER%TYPE := :NEW.AUTOTASKSSERVER;
  new$DEPARTMENTCLS UTYPEDFORMSCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$SENDERID UTYPEDFORMSCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID UTYPEDFORMSCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$CRYPTOSTATUS UTYPEDFORMSCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$UTFRINDEX UTYPEDFORMSCAPTION.UTFRINDEX%TYPE := :NEW.UTFRINDEX;
  new$REPORTDATE UTYPEDFORMSCAPTION.REPORTDATE%TYPE := :NEW.REPORTDATE;
  new$ESTIMDATE UTYPEDFORMSCAPTION.ESTIMDATE%TYPE := :NEW.ESTIMDATE;
  new$SELF UTYPEDFORMSCAPTION.SELF%TYPE := :NEW.SELF;
  new$CLIENTSTYPE UTYPEDFORMSCAPTION.CLIENTSTYPE%TYPE := :NEW.CLIENTSTYPE;
  new$SENDKIT UTYPEDFORMSCAPTION.SENDKIT%TYPE := :NEW.SENDKIT;
  new$SENDSTS UTYPEDFORMSCAPTION.SENDSTS%TYPE := :NEW.SENDSTS;
  new$SENDDOC UTYPEDFORMSCAPTION.SENDDOC%TYPE := :NEW.SENDDOC;
  new$MANUALEXEC UTYPEDFORMSCAPTION.MANUALEXEC%TYPE := :NEW.MANUALEXEC;
  new$DATAMODE UTYPEDFORMSCAPTION.DATAMODE%TYPE := :NEW.DATAMODE;
  new$BUDGETREF UTYPEDFORMSCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$REPORTYEAR UTYPEDFORMSCAPTION.REPORTYEAR%TYPE := :NEW.REPORTYEAR;
  new$REJECTCLS UTYPEDFORMSCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$DOCSTATEREF UTYPEDFORMSCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION UTYPEDFORMSCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$LASTEXTRCHANGE UTYPEDFORMSCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$VERSIONID UTYPEDFORMSCAPTION.VERSIONID%TYPE := :NEW.VERSIONID;
  new$CONSCLIENT UTYPEDFORMSCAPTION.CONSCLIENT%TYPE := :NEW.CONSCLIENT;
  new$FINT1 UTYPEDFORMSCAPTION.FINT1%TYPE := :NEW.FINT1;
  new$FINT2 UTYPEDFORMSCAPTION.FINT2%TYPE := :NEW.FINT2;
  new$FINT3 UTYPEDFORMSCAPTION.FINT3%TYPE := :NEW.FINT3;
  new$FINT4 UTYPEDFORMSCAPTION.FINT4%TYPE := :NEW.FINT4;
  new$FINT5 UTYPEDFORMSCAPTION.FINT5%TYPE := :NEW.FINT5;
  new$FINT6 UTYPEDFORMSCAPTION.FINT6%TYPE := :NEW.FINT6;
  new$FINT7 UTYPEDFORMSCAPTION.FINT7%TYPE := :NEW.FINT7;
  new$PARAMS UTYPEDFORMSCAPTION.PARAMS%TYPE := :NEW.PARAMS;
  new$FORMTEXTID UTYPEDFORMSCAPTION.FORMTEXTID%TYPE := :NEW.FORMTEXTID;
  new$REGTEXTID UTYPEDFORMSCAPTION.REGTEXTID%TYPE := :NEW.REGTEXTID;
  new$PERIODTEXTID UTYPEDFORMSCAPTION.PERIODTEXTID%TYPE := :NEW.PERIODTEXTID;
  new$REPORTMONTH UTYPEDFORMSCAPTION.REPORTMONTH%TYPE := :NEW.REPORTMONTH;
  new$ACTIVITYKIND UTYPEDFORMSCAPTION.ACTIVITYKIND%TYPE := :NEW.ACTIVITYKIND;
  new$PERIOD UTYPEDFORMSCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$REJECTCAUSE UTYPEDFORMSCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  Cnt$ NUMBER(10);
  NeedVersion$ NUMBER(5);
  ActiveVersion$ NUMBER(10);
  ReportPeriod$ NUMBER(10);
  AMonth$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_UTFC_BU)
-- Create 02.03.2004
-- Last update 15.12.2005
-- - - - - - - - - - - - -

  /*      ID -   */
  IF (new$ID IS NULL) THEN SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL; END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_UTFC_BU10)
-- Version 8.00.00.2
-- - - - - - - - - - - - -

  if (new$typedform is null) then 
    new$typedform := 0;
  END IF;
  if (new$utfrindex is null) then 
    new$utfrindex := 0;
  END IF;
  if (new$self is null) then 
    new$self := 0;
  END IF;
  if (new$sendkit is null) then 
    new$sendkit := 0;
  END IF;
  if (new$sendsts is null) then 
    new$sendsts := 0;
  END IF;
  if (new$senddoc is null) then 
    new$senddoc := 0;
  END IF;
  if (new$manualexec is null) then 
    new$manualexec := 0;
  END IF;
  if (new$period is null) then 
    new$period := 0;
  END IF;
  if (new$clientstype is null) then 
    new$clientstype := 0;
  END IF;
  if (new$datamode is null) then 
    new$datamode := 0;
  END IF;
  if (new$departmentcls is null) then 
    new$departmentcls := 0;
  END IF;
  if (new$ActivityKind is null) then 
    new$ActivityKind := 0;
  END IF;
  if (new$BudgetRef is null) then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$email is null) then 
    new$email := '';
  END IF;
  new$email := UPPER(new$email);
  if (not new$autotasksserver is null) then
    new$autotasksserver := UPPER(new$autotasksserver);
  END IF;

-- - - - - - - - - - - - -
-- BU_20 (TR_UTFC_BU20)
-- Create 22.05.2004
-- Last update 15.12.2008
-- - - - - - - - - - - - -

    /*     ,     */
    BEGIN
      select utf.NEEDVERSION into NeedVersion$
      from UTYPEDFORMS utf
      where (utf.ID = new$TYPEDFORM);
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        NeedVersion$ := NULL;
    END;  
    
    if (NeedVersion$ = 1) then
        /*     ,    */
        if (new$VERSIONID is null) then
            /*      ,  */
            if (new$SENDERID is not null) then
                /*       ""*/
                BEGIN
                  select UTFV.ID into ActiveVersion$
                  from UTYPEDFORMSVERSION UTFV
                  where ((UTFV.TYPEDFORM = new$TYPEDFORM)
                      and (UTFV.IsCurrentForURM = 1));
                EXCEPTION
                  WHEN NO_DATA_FOUND THEN
                    ActiveVersion$ := NULL;
                END;                      
            else
                /*       ""*/
                BEGIN
                  select UTFV.ID into ActiveVersion$
                  from UTYPEDFORMSVERSION UTFV
                  where ((UTFV.TYPEDFORM = new$TYPEDFORM)
                      and (UTFV.ISCURRENT = 1));
                EXCEPTION
                  WHEN NO_DATA_FOUND THEN
                    ActiveVersion$ := NULL;
                END;                      
            end if;

            /*     */
            new$VERSIONID := ActiveVersion$;

            /*     */
            select count(ID) into CNT$ from UTYPEDFORMSVERSION where (ID = new$VERSIONID) AND (ROWNUM = 1);
            if (CNT$ = 0 ) then
              RaiseException('EX_NOT_ACTIVE_VERSION');
            end if;  
        end if;
    end if;

-- - - - - - - - - - - - -
-- BU_50 (TR_UTFC_BU50)
-- Version 8.00.00.2
-- - - - - - - - - - - - -

  BEGIN
    /*    */
    select utf.Period
    into ReportPeriod$   from utypedforms utf
    where utf.id = new$TypedForm
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*       */
  if (ReportPeriod$  = 30) then
    /*     12  */    
    new$REPORTMONTH := 12;
      
  else
    if (ReportPeriod$  = 20) then
      /*          */
      if ((new$ReportMonth is null) or (new$ReportMonth = 0)) then
        /*    ,    */        
        new$ReportMonth := 3;
              
      else
        AMonth$ := new$ReportMonth;
        if (AMonth$ between 1 and 3) then
          AMonth$ := 3;
                  
        else 
          if (AMonth$ between 4 and 6) then
            AMonth$ := 6;
                    
          else 
            if (AMonth$ between 7 and 9) then
              AMonth$ := 9;
                      
            else
              AMonth$ := 12;
            END IF;
          END IF;
        END IF;

        new$ReportMonth := AMonth$;
          
      END IF;
    else
      if ((ReportPeriod$  = 10) and (new$ReportMonth is null)) then
        new$ReportMonth := 1;
          
      END IF;
    END IF;
  END IF;
  if (new$REPORTYEAR is null) then 
    new$REPORTYEAR := 0;
  END IF;
  /*          */
  if (ReportPeriod$  > 0) then
    new$REPORTDATE := new$REPORTYEAR * 10000 + new$REPORTMONTH * 100 + 01;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_UTFC_BU_200)
-- Create 14.09.2005
-- Last update 25.05.2005
-- - - - - - - - - - - - -

  /*       */
  if (new$DOCSTATEREF <> :old.DOCSTATEREF) then
    insert into StateJumpHistory(DocID, BeginStateRef, EndStateRef)
      values(new$id, :old.DOCSTATEREF, :new.DOCSTATEREF);
  end if;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_UTYPEDFORMSCAPTION SET
    ID = new$ID,
    REGIONCLS = new$REGIONCLS,
    ACCEPTDATE = new$ACCEPTDATE,
    DOCNUMBER = new$DOCNUMBER,
    NOTE = new$NOTE,
    TYPEDFORM = new$TYPEDFORM,
    PROGINDEX = new$PROGINDEX,
    FACIALACC_CLS = new$FACIALACC_CLS,
    ORG_REF = new$ORG_REF,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    EMAIL = new$EMAIL,
    STATE = new$STATE,
    ERROR = new$ERROR,
    SOURCEID = new$SOURCEID,
    SOURCEMAILID = new$SOURCEMAILID,
    AUTOTASKSSERVER = new$AUTOTASKSSERVER,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    UTFRINDEX = new$UTFRINDEX,
    REPORTDATE = new$REPORTDATE,
    ESTIMDATE = new$ESTIMDATE,
    SELF = new$SELF,
    CLIENTSTYPE = new$CLIENTSTYPE,
    SENDKIT = new$SENDKIT,
    SENDSTS = new$SENDSTS,
    SENDDOC = new$SENDDOC,
    MANUALEXEC = new$MANUALEXEC,
    DATAMODE = new$DATAMODE,
    BUDGETREF = new$BUDGETREF,
    REPORTYEAR = new$REPORTYEAR,
    REJECTCLS = new$REJECTCLS,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    VERSIONID = new$VERSIONID,
    CONSCLIENT = new$CONSCLIENT,
    FINT1 = new$FINT1,
    FINT2 = new$FINT2,
    FINT3 = new$FINT3,
    FINT4 = new$FINT4,
    FINT5 = new$FINT5,
    FINT6 = new$FINT6,
    FINT7 = new$FINT7,
    PARAMS = new$PARAMS,
    FORMTEXTID = new$FORMTEXTID,
    REGTEXTID = new$REGTEXTID,
    PERIODTEXTID = new$PERIODTEXTID,
    REPORTMONTH = new$REPORTMONTH,
    ACTIVITYKIND = new$ACTIVITYKIND,
    PERIOD = new$PERIOD,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);
 
  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

END;
/
ALTER TRIGGER TR_UTFC_BU_500 ENABLE
/
commit work 
/
ALTER TRIGGER TR_UNIONNOTIFYCAPTION_BU_500 DISABLE
/
ALTER TABLE UNIONNOTIFYCAPTION ADD (
  TempRejectCause VARCHAR2(255)
)
/
update UNIONNOTIFYCAPTION set
  TempRejectCause = REJECTCAUSE
/
commit work 
/
ALTER TABLE UNIONNOTIFYCAPTION DROP (REJECTCAUSE)
/
ALTER TABLE UNIONNOTIFYCAPTION ADD (
  REJECTCAUSE VARCHAR2(1000)
)
/
update UNIONNOTIFYCAPTION set
  REJECTCAUSE = TempRejectCause
/
commit work 
/
ALTER TABLE UNIONNOTIFYCAPTION DROP (TempRejectCause)
/
ALTER TRIGGER TR_UNIONNOTIFYCAPTION_BU_500 ENABLE
/
commit work 
/
ALTER TRIGGER TR_ALLOWANCECAPTION_BU_500 DISABLE
/
ALTER TABLE TB_ALLOWANCECAPTION ADD (
  TempRejectCause VARCHAR2(255)
)
/

CREATE OR REPLACE VIEW ALLOWANCECAPTION (
  ID,
  ALLOWANCETYPE,
  ACCEPTORORGREF,
  FACIALACC_CLS,
  NUMBERGENERAL,
  NUMBERGENERALADD,
  NUMBERDOC,
  NUMBERADD,
  BEGINDATE,
  ENDDATE,
  CONSTITUTIVEDOCTYPE,
  CONSTITUTIVEDATE,
  CONSTITUTIVENUMBER,
  CONSTITUTIVEORGAN,
  REGISTERFIO,
  REGISTERJOB,
  REGISTERDATE,
  REGISTERORGAN,
  RETURNNOTIFYNUMBER,
  RETURNNOTIFYDATE,
  RETURNREJECTCAUSE,
  RETURNDATE,
  RETURNFIO,
  RETURNJOB,
  SENDERID,
  SENDERRECORDID,
  REJECT_CLS,
  REJECTCAUSE,
  NUMBERRETURNTRANZACTION,
  NUMBERREJECTTRANZACTION,
  BUDGETREF,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  DOCSTATEREF,
  CRYPTOSTATUS,
  PROGINDEX,
  RVERSION,
  INPUTDATE,
  REQUESTNUMBER,
  NOTE,
  LASTEXTRCHANGE,
  TEMPREJECTCAUSE)
AS
  SELECT
    ID,
    ALLOWANCETYPE,
    ACCEPTORORGREF,
    FACIALACC_CLS,
    NUMBERGENERAL,
    NUMBERGENERALADD,
    NUMBERDOC,
    NUMBERADD,
    BEGINDATE,
    ENDDATE,
    CONSTITUTIVEDOCTYPE,
    CONSTITUTIVEDATE,
    CONSTITUTIVENUMBER,
    CONSTITUTIVEORGAN,
    REGISTERFIO,
    REGISTERJOB,
    REGISTERDATE,
    REGISTERORGAN,
    RETURNNOTIFYNUMBER,
    RETURNNOTIFYDATE,
    RETURNREJECTCAUSE,
    RETURNDATE,
    RETURNFIO,
    RETURNJOB,
    SENDERID,
    SENDERRECORDID,
    REJECT_CLS,
    REJECTCAUSE,
    NUMBERRETURNTRANZACTION,
    NUMBERREJECTTRANZACTION,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    DOCSTATEREF,
    CRYPTOSTATUS,
    PROGINDEX,
    RVERSION,
    INPUTDATE,
    REQUESTNUMBER,
    NOTE,
    LASTEXTRCHANGE,
    TEMPREJECTCAUSE
  FROM TB_ALLOWANCECAPTION
/

CREATE OR REPLACE TRIGGER TR_ALLOWANCECAPTION_ID
  INSTEAD OF DELETE
  ON ALLOWANCECAPTION
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_AllowanceCaption_BD)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

 --   
 delete 
  from AllowanceDetail
 where 
  (RecordIndex = :old.id);

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_ALLOWANCECAPTION
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_200 (TR_ALLOWANCECAPTION_AD_200)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

  --      
  delete 
    from 
      StateJumpHistory
    where 
      DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_ALLOWANCECAPTION_AD_500)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate,ProgIndex) values(5000,:old.ID,SYSDATE,:old.ProgIndex);

END;
/

CREATE OR REPLACE TRIGGER TR_ALLOWANCECAPTION_II
  INSTEAD OF INSERT
  ON ALLOWANCECAPTION
  FOR EACH ROW
DECLARE
  new$ID ALLOWANCECAPTION.ID%TYPE := :NEW.ID;
  new$ALLOWANCETYPE ALLOWANCECAPTION.ALLOWANCETYPE%TYPE := :NEW.ALLOWANCETYPE;
  new$ACCEPTORORGREF ALLOWANCECAPTION.ACCEPTORORGREF%TYPE := :NEW.ACCEPTORORGREF;
  new$FACIALACC_CLS ALLOWANCECAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NUMBERGENERAL ALLOWANCECAPTION.NUMBERGENERAL%TYPE := :NEW.NUMBERGENERAL;
  new$NUMBERGENERALADD ALLOWANCECAPTION.NUMBERGENERALADD%TYPE := :NEW.NUMBERGENERALADD;
  new$NUMBERDOC ALLOWANCECAPTION.NUMBERDOC%TYPE := :NEW.NUMBERDOC;
  new$NUMBERADD ALLOWANCECAPTION.NUMBERADD%TYPE := :NEW.NUMBERADD;
  new$BEGINDATE ALLOWANCECAPTION.BEGINDATE%TYPE := :NEW.BEGINDATE;
  new$ENDDATE ALLOWANCECAPTION.ENDDATE%TYPE := :NEW.ENDDATE;
  new$CONSTITUTIVEDOCTYPE ALLOWANCECAPTION.CONSTITUTIVEDOCTYPE%TYPE := :NEW.CONSTITUTIVEDOCTYPE;
  new$CONSTITUTIVEDATE ALLOWANCECAPTION.CONSTITUTIVEDATE%TYPE := :NEW.CONSTITUTIVEDATE;
  new$CONSTITUTIVENUMBER ALLOWANCECAPTION.CONSTITUTIVENUMBER%TYPE := :NEW.CONSTITUTIVENUMBER;
  new$CONSTITUTIVEORGAN ALLOWANCECAPTION.CONSTITUTIVEORGAN%TYPE := :NEW.CONSTITUTIVEORGAN;
  new$REGISTERFIO ALLOWANCECAPTION.REGISTERFIO%TYPE := :NEW.REGISTERFIO;
  new$REGISTERJOB ALLOWANCECAPTION.REGISTERJOB%TYPE := :NEW.REGISTERJOB;
  new$REGISTERDATE ALLOWANCECAPTION.REGISTERDATE%TYPE := :NEW.REGISTERDATE;
  new$REGISTERORGAN ALLOWANCECAPTION.REGISTERORGAN%TYPE := :NEW.REGISTERORGAN;
  new$RETURNNOTIFYNUMBER ALLOWANCECAPTION.RETURNNOTIFYNUMBER%TYPE := :NEW.RETURNNOTIFYNUMBER;
  new$RETURNNOTIFYDATE ALLOWANCECAPTION.RETURNNOTIFYDATE%TYPE := :NEW.RETURNNOTIFYDATE;
  new$RETURNREJECTCAUSE ALLOWANCECAPTION.RETURNREJECTCAUSE%TYPE := :NEW.RETURNREJECTCAUSE;
  new$RETURNDATE ALLOWANCECAPTION.RETURNDATE%TYPE := :NEW.RETURNDATE;
  new$RETURNFIO ALLOWANCECAPTION.RETURNFIO%TYPE := :NEW.RETURNFIO;
  new$RETURNJOB ALLOWANCECAPTION.RETURNJOB%TYPE := :NEW.RETURNJOB;
  new$SENDERID ALLOWANCECAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID ALLOWANCECAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REJECT_CLS ALLOWANCECAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE ALLOWANCECAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$NUMBERRETURNTRANZACTION ALLOWANCECAPTION.NUMBERRETURNTRANZACTION%TYPE := :NEW.NUMBERRETURNTRANZACTION;
  new$NUMBERREJECTTRANZACTION ALLOWANCECAPTION.NUMBERREJECTTRANZACTION%TYPE := :NEW.NUMBERREJECTTRANZACTION;
  new$BUDGETREF ALLOWANCECAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER ALLOWANCECAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ALLOWANCECAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ALLOWANCECAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ALLOWANCECAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$DOCSTATEREF ALLOWANCECAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ALLOWANCECAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$PROGINDEX ALLOWANCECAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RVERSION ALLOWANCECAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$INPUTDATE ALLOWANCECAPTION.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$REQUESTNUMBER ALLOWANCECAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$NOTE ALLOWANCECAPTION.NOTE%TYPE := :NEW.NOTE;
  new$LASTEXTRCHANGE ALLOWANCECAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$TEMPREJECTCAUSE ALLOWANCECAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  val_maxLN$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ALLOWANCECAPTION_BI)
-- Create 10.04.2007
-- Last update 11.12.2009
-- - - - - - - - - - - - -

  if (new$id is null) then select g_Shared.nextval into new$id from dual; end if;
  if (new$AcceptorOrgRef is null) then new$AcceptorOrgRef := 0; end if;
  if (new$FacialAcc_Cls is null) then new$FacialAcc_Cls := 0; end if;
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
    then GetIntConst(-1, 3, new$BudgetRef);
  end if;

-- - - - - - - - - - - - -
-- BI_5 (TR_ALLOWANCECAPTION_BI_5)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

  if (new$Progindex is null) then new$Progindex := 110; end if;

-- - - - - - - - - - - - -
-- BI_60 (TR_ALLOWANCECAPTION_BI_60)
-- Create 08.04.2010
-- Last update 08.04.2010
-- - - - - - - - - - - - -

  IF (new$RegisterDate IS NOT NULL) THEN
    SELECT MAX(det.LineNumber)
	INTO val_maxLN$
    FROM AllowanceDetail det
      LEFT JOIN AllowanceCaption cap ON (cap.id = det.RecordIndex)
    WHERE cap.FacialAcc_Cls = new$facialacc_cls;

    IF (val_maxLN$ IS NULL) THEN
      val_maxLN$ := 1;
    ELSE
      val_maxLN$ := val_maxLN$ + 1;
	END IF;  

    FOR R$ IN (SELECT id val_det_id FROM AllowanceDetail
      WHERE RecordIndex = new$id)
    LOOP
      UPDATE AllowanceDetail SET
        LineNumber = val_maxLN$
      WHERE
        (id = R$.val_det_id) AND (LineNumber IS NULL);
      val_maxLN$ := val_maxLN$ + 1;
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_ALLOWANCECAPTION_BI_500)
-- Create 10.04.2007
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_ALLOWANCECAPTION (
    ID,
    ALLOWANCETYPE,
    ACCEPTORORGREF,
    FACIALACC_CLS,
    NUMBERGENERAL,
    NUMBERGENERALADD,
    NUMBERDOC,
    NUMBERADD,
    BEGINDATE,
    ENDDATE,
    CONSTITUTIVEDOCTYPE,
    CONSTITUTIVEDATE,
    CONSTITUTIVENUMBER,
    CONSTITUTIVEORGAN,
    REGISTERFIO,
    REGISTERJOB,
    REGISTERDATE,
    REGISTERORGAN,
    RETURNNOTIFYNUMBER,
    RETURNNOTIFYDATE,
    RETURNREJECTCAUSE,
    RETURNDATE,
    RETURNFIO,
    RETURNJOB,
    SENDERID,
    SENDERRECORDID,
    REJECT_CLS,
    REJECTCAUSE,
    NUMBERRETURNTRANZACTION,
    NUMBERREJECTTRANZACTION,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    DOCSTATEREF,
    CRYPTOSTATUS,
    PROGINDEX,
    RVERSION,
    INPUTDATE,
    REQUESTNUMBER,
    NOTE,
    LASTEXTRCHANGE,
    TEMPREJECTCAUSE
  ) VALUES (
    new$ID,
    new$ALLOWANCETYPE,
    new$ACCEPTORORGREF,
    new$FACIALACC_CLS,
    new$NUMBERGENERAL,
    new$NUMBERGENERALADD,
    new$NUMBERDOC,
    new$NUMBERADD,
    new$BEGINDATE,
    new$ENDDATE,
    new$CONSTITUTIVEDOCTYPE,
    new$CONSTITUTIVEDATE,
    new$CONSTITUTIVENUMBER,
    new$CONSTITUTIVEORGAN,
    new$REGISTERFIO,
    new$REGISTERJOB,
    new$REGISTERDATE,
    new$REGISTERORGAN,
    new$RETURNNOTIFYNUMBER,
    new$RETURNNOTIFYDATE,
    new$RETURNREJECTCAUSE,
    new$RETURNDATE,
    new$RETURNFIO,
    new$RETURNJOB,
    new$SENDERID,
    new$SENDERRECORDID,
    new$REJECT_CLS,
    new$REJECTCAUSE,
    new$NUMBERRETURNTRANZACTION,
    new$NUMBERREJECTTRANZACTION,
    new$BUDGETREF,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$DOCSTATEREF,
    new$CRYPTOSTATUS,
    new$PROGINDEX,
    new$RVERSION,
    new$INPUTDATE,
    new$REQUESTNUMBER,
    new$NOTE,
    new$LASTEXTRCHANGE,
    new$TEMPREJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_ALLOWANCECAPTION_AI_500)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 5000) and (RecordID = :new.ID);

END;
/

CREATE OR REPLACE TRIGGER TR_ALLOWANCECAPTION_IU
  INSTEAD OF UPDATE
  ON ALLOWANCECAPTION
  FOR EACH ROW
DECLARE
  new$ID ALLOWANCECAPTION.ID%TYPE := :NEW.ID;
  new$ALLOWANCETYPE ALLOWANCECAPTION.ALLOWANCETYPE%TYPE := :NEW.ALLOWANCETYPE;
  new$ACCEPTORORGREF ALLOWANCECAPTION.ACCEPTORORGREF%TYPE := :NEW.ACCEPTORORGREF;
  new$FACIALACC_CLS ALLOWANCECAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NUMBERGENERAL ALLOWANCECAPTION.NUMBERGENERAL%TYPE := :NEW.NUMBERGENERAL;
  new$NUMBERGENERALADD ALLOWANCECAPTION.NUMBERGENERALADD%TYPE := :NEW.NUMBERGENERALADD;
  new$NUMBERDOC ALLOWANCECAPTION.NUMBERDOC%TYPE := :NEW.NUMBERDOC;
  new$NUMBERADD ALLOWANCECAPTION.NUMBERADD%TYPE := :NEW.NUMBERADD;
  new$BEGINDATE ALLOWANCECAPTION.BEGINDATE%TYPE := :NEW.BEGINDATE;
  new$ENDDATE ALLOWANCECAPTION.ENDDATE%TYPE := :NEW.ENDDATE;
  new$CONSTITUTIVEDOCTYPE ALLOWANCECAPTION.CONSTITUTIVEDOCTYPE%TYPE := :NEW.CONSTITUTIVEDOCTYPE;
  new$CONSTITUTIVEDATE ALLOWANCECAPTION.CONSTITUTIVEDATE%TYPE := :NEW.CONSTITUTIVEDATE;
  new$CONSTITUTIVENUMBER ALLOWANCECAPTION.CONSTITUTIVENUMBER%TYPE := :NEW.CONSTITUTIVENUMBER;
  new$CONSTITUTIVEORGAN ALLOWANCECAPTION.CONSTITUTIVEORGAN%TYPE := :NEW.CONSTITUTIVEORGAN;
  new$REGISTERFIO ALLOWANCECAPTION.REGISTERFIO%TYPE := :NEW.REGISTERFIO;
  new$REGISTERJOB ALLOWANCECAPTION.REGISTERJOB%TYPE := :NEW.REGISTERJOB;
  new$REGISTERDATE ALLOWANCECAPTION.REGISTERDATE%TYPE := :NEW.REGISTERDATE;
  new$REGISTERORGAN ALLOWANCECAPTION.REGISTERORGAN%TYPE := :NEW.REGISTERORGAN;
  new$RETURNNOTIFYNUMBER ALLOWANCECAPTION.RETURNNOTIFYNUMBER%TYPE := :NEW.RETURNNOTIFYNUMBER;
  new$RETURNNOTIFYDATE ALLOWANCECAPTION.RETURNNOTIFYDATE%TYPE := :NEW.RETURNNOTIFYDATE;
  new$RETURNREJECTCAUSE ALLOWANCECAPTION.RETURNREJECTCAUSE%TYPE := :NEW.RETURNREJECTCAUSE;
  new$RETURNDATE ALLOWANCECAPTION.RETURNDATE%TYPE := :NEW.RETURNDATE;
  new$RETURNFIO ALLOWANCECAPTION.RETURNFIO%TYPE := :NEW.RETURNFIO;
  new$RETURNJOB ALLOWANCECAPTION.RETURNJOB%TYPE := :NEW.RETURNJOB;
  new$SENDERID ALLOWANCECAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID ALLOWANCECAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REJECT_CLS ALLOWANCECAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE ALLOWANCECAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$NUMBERRETURNTRANZACTION ALLOWANCECAPTION.NUMBERRETURNTRANZACTION%TYPE := :NEW.NUMBERRETURNTRANZACTION;
  new$NUMBERREJECTTRANZACTION ALLOWANCECAPTION.NUMBERREJECTTRANZACTION%TYPE := :NEW.NUMBERREJECTTRANZACTION;
  new$BUDGETREF ALLOWANCECAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER ALLOWANCECAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ALLOWANCECAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ALLOWANCECAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ALLOWANCECAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$DOCSTATEREF ALLOWANCECAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ALLOWANCECAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$PROGINDEX ALLOWANCECAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RVERSION ALLOWANCECAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$INPUTDATE ALLOWANCECAPTION.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$REQUESTNUMBER ALLOWANCECAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$NOTE ALLOWANCECAPTION.NOTE%TYPE := :NEW.NOTE;
  new$LASTEXTRCHANGE ALLOWANCECAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$TEMPREJECTCAUSE ALLOWANCECAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  cnt$ Number(10);
  val_maxLN$ Number(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_ALLOWANCECAPTION_BU)
-- Create 10.04.2007
-- - - - - - - - - - - - -

  if (new$AcceptorOrgRef is null) then new$AcceptorOrgRef := 0; end if;
  if (new$FacialAcc_Cls is null) then new$FacialAcc_Cls := 0; end if;

  IF (new$BudgetRef <> :OLD.BudgetRef) THEN
    IF ( NOT((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL)) ) THEN
      SELECT count(ad.id) into cnt$ 
      FROM AllowanceDetail ad WHERE ad.recordindex = new$ID and ROWNUM = 1;
      IF (cnt$ > 0) THEN
        RaiseEXCEPTION('Ex_CantModufyBudget');
      END IF;  
    END IF;    
  END IF;

-- - - - - - - - - - - - -
-- BU_60 (TR_ALLOWANCECAPTION_BU_60)
-- Create 12.03.2010
-- Last update 12.03.2010
-- - - - - - - - - - - - -

  IF ((:OLD.RegisterDate IS NULL) AND (new$RegisterDate IS NOT NULL)) THEN
    SELECT MAX(det.LineNumber)
    INTO val_maxLN$
    FROM AllowanceDetail det
      LEFT JOIN AllowanceCaption cap ON (cap.id = det.RecordIndex)
    WHERE cap.FacialAcc_Cls = new$facialacc_cls ;

    IF (val_maxLN$ IS NULL) THEN
      val_maxLN$ := 1;
    ELSE
      val_maxLN$ := val_maxLN$ + 1;
    END IF;  

    FOR R$ IN (SELECT id val_det_id FROM AllowanceDetail
      WHERE RecordIndex = new$id)
    LOOP
      UPDATE AllowanceDetail SET
        LineNumber = val_maxLN$
      WHERE
        (id = R$.val_det_id) AND (LineNumber IS NULL);
      val_maxLN$ := val_maxLN$ + 1;
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (tr_Allowancecaption_BU200)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

   --      
   IF (:OLD.DOCSTATEREF <> new$DOCSTATEREF) THEN
      INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
        VALUES (new$ID, :OLD.DOCSTATEREF, new$DOCSTATEREF);
   END IF;     

-- - - - - - - - - - - - -
-- BU_700 (TR_ALLOWANCECAPTION_BU_700)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

 if (new$RVersion is null) then
   new$RVersion:=1;
 elsif ((new$RVersion = -1) and (:Old.RVersion <> -1)) then
   new$RVersion:=:Old.RVersion;
 else
   new$RVersion:=:Old.RVersion+1;
 end if;  

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_ALLOWANCECAPTION SET
    ID = new$ID,
    ALLOWANCETYPE = new$ALLOWANCETYPE,
    ACCEPTORORGREF = new$ACCEPTORORGREF,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NUMBERGENERAL = new$NUMBERGENERAL,
    NUMBERGENERALADD = new$NUMBERGENERALADD,
    NUMBERDOC = new$NUMBERDOC,
    NUMBERADD = new$NUMBERADD,
    BEGINDATE = new$BEGINDATE,
    ENDDATE = new$ENDDATE,
    CONSTITUTIVEDOCTYPE = new$CONSTITUTIVEDOCTYPE,
    CONSTITUTIVEDATE = new$CONSTITUTIVEDATE,
    CONSTITUTIVENUMBER = new$CONSTITUTIVENUMBER,
    CONSTITUTIVEORGAN = new$CONSTITUTIVEORGAN,
    REGISTERFIO = new$REGISTERFIO,
    REGISTERJOB = new$REGISTERJOB,
    REGISTERDATE = new$REGISTERDATE,
    REGISTERORGAN = new$REGISTERORGAN,
    RETURNNOTIFYNUMBER = new$RETURNNOTIFYNUMBER,
    RETURNNOTIFYDATE = new$RETURNNOTIFYDATE,
    RETURNREJECTCAUSE = new$RETURNREJECTCAUSE,
    RETURNDATE = new$RETURNDATE,
    RETURNFIO = new$RETURNFIO,
    RETURNJOB = new$RETURNJOB,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    NUMBERRETURNTRANZACTION = new$NUMBERRETURNTRANZACTION,
    NUMBERREJECTTRANZACTION = new$NUMBERREJECTTRANZACTION,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    DOCSTATEREF = new$DOCSTATEREF,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    PROGINDEX = new$PROGINDEX,
    RVERSION = new$RVERSION,
    INPUTDATE = new$INPUTDATE,
    REQUESTNUMBER = new$REQUESTNUMBER,
    NOTE = new$NOTE,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_500 (TR_ALLOWANCECAPTION_AU_500)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

  if (:new.ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (5000, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=5000) and (RecordId=:new.ID);
  end if;

END;
/
update ALLOWANCECAPTION set
  TempRejectCause = REJECTCAUSE
/
commit work 
/
ALTER TABLE TB_ALLOWANCECAPTION DROP (REJECTCAUSE)
/

CREATE OR REPLACE VIEW ALLOWANCECAPTION (
  ID,
  ALLOWANCETYPE,
  ACCEPTORORGREF,
  FACIALACC_CLS,
  NUMBERGENERAL,
  NUMBERGENERALADD,
  NUMBERDOC,
  NUMBERADD,
  BEGINDATE,
  ENDDATE,
  CONSTITUTIVEDOCTYPE,
  CONSTITUTIVEDATE,
  CONSTITUTIVENUMBER,
  CONSTITUTIVEORGAN,
  REGISTERFIO,
  REGISTERJOB,
  REGISTERDATE,
  REGISTERORGAN,
  RETURNNOTIFYNUMBER,
  RETURNNOTIFYDATE,
  RETURNREJECTCAUSE,
  RETURNDATE,
  RETURNFIO,
  RETURNJOB,
  SENDERID,
  SENDERRECORDID,
  REJECT_CLS,
  NUMBERRETURNTRANZACTION,
  NUMBERREJECTTRANZACTION,
  BUDGETREF,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  DOCSTATEREF,
  CRYPTOSTATUS,
  PROGINDEX,
  RVERSION,
  INPUTDATE,
  REQUESTNUMBER,
  NOTE,
  LASTEXTRCHANGE,
  TEMPREJECTCAUSE)
AS
  SELECT
    ID,
    ALLOWANCETYPE,
    ACCEPTORORGREF,
    FACIALACC_CLS,
    NUMBERGENERAL,
    NUMBERGENERALADD,
    NUMBERDOC,
    NUMBERADD,
    BEGINDATE,
    ENDDATE,
    CONSTITUTIVEDOCTYPE,
    CONSTITUTIVEDATE,
    CONSTITUTIVENUMBER,
    CONSTITUTIVEORGAN,
    REGISTERFIO,
    REGISTERJOB,
    REGISTERDATE,
    REGISTERORGAN,
    RETURNNOTIFYNUMBER,
    RETURNNOTIFYDATE,
    RETURNREJECTCAUSE,
    RETURNDATE,
    RETURNFIO,
    RETURNJOB,
    SENDERID,
    SENDERRECORDID,
    REJECT_CLS,
    NUMBERRETURNTRANZACTION,
    NUMBERREJECTTRANZACTION,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    DOCSTATEREF,
    CRYPTOSTATUS,
    PROGINDEX,
    RVERSION,
    INPUTDATE,
    REQUESTNUMBER,
    NOTE,
    LASTEXTRCHANGE,
    TEMPREJECTCAUSE
  FROM TB_ALLOWANCECAPTION
/

CREATE OR REPLACE TRIGGER TR_ALLOWANCECAPTION_ID
  INSTEAD OF DELETE
  ON ALLOWANCECAPTION
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_AllowanceCaption_BD)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

 --   
 delete 
  from AllowanceDetail
 where 
  (RecordIndex = :old.id);

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_ALLOWANCECAPTION
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_200 (TR_ALLOWANCECAPTION_AD_200)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

  --      
  delete 
    from 
      StateJumpHistory
    where 
      DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_ALLOWANCECAPTION_AD_500)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate,ProgIndex) values(5000,:old.ID,SYSDATE,:old.ProgIndex);

END;
/

CREATE OR REPLACE TRIGGER TR_ALLOWANCECAPTION_II
  INSTEAD OF INSERT
  ON ALLOWANCECAPTION
  FOR EACH ROW
DECLARE
  new$ID ALLOWANCECAPTION.ID%TYPE := :NEW.ID;
  new$ALLOWANCETYPE ALLOWANCECAPTION.ALLOWANCETYPE%TYPE := :NEW.ALLOWANCETYPE;
  new$ACCEPTORORGREF ALLOWANCECAPTION.ACCEPTORORGREF%TYPE := :NEW.ACCEPTORORGREF;
  new$FACIALACC_CLS ALLOWANCECAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NUMBERGENERAL ALLOWANCECAPTION.NUMBERGENERAL%TYPE := :NEW.NUMBERGENERAL;
  new$NUMBERGENERALADD ALLOWANCECAPTION.NUMBERGENERALADD%TYPE := :NEW.NUMBERGENERALADD;
  new$NUMBERDOC ALLOWANCECAPTION.NUMBERDOC%TYPE := :NEW.NUMBERDOC;
  new$NUMBERADD ALLOWANCECAPTION.NUMBERADD%TYPE := :NEW.NUMBERADD;
  new$BEGINDATE ALLOWANCECAPTION.BEGINDATE%TYPE := :NEW.BEGINDATE;
  new$ENDDATE ALLOWANCECAPTION.ENDDATE%TYPE := :NEW.ENDDATE;
  new$CONSTITUTIVEDOCTYPE ALLOWANCECAPTION.CONSTITUTIVEDOCTYPE%TYPE := :NEW.CONSTITUTIVEDOCTYPE;
  new$CONSTITUTIVEDATE ALLOWANCECAPTION.CONSTITUTIVEDATE%TYPE := :NEW.CONSTITUTIVEDATE;
  new$CONSTITUTIVENUMBER ALLOWANCECAPTION.CONSTITUTIVENUMBER%TYPE := :NEW.CONSTITUTIVENUMBER;
  new$CONSTITUTIVEORGAN ALLOWANCECAPTION.CONSTITUTIVEORGAN%TYPE := :NEW.CONSTITUTIVEORGAN;
  new$REGISTERFIO ALLOWANCECAPTION.REGISTERFIO%TYPE := :NEW.REGISTERFIO;
  new$REGISTERJOB ALLOWANCECAPTION.REGISTERJOB%TYPE := :NEW.REGISTERJOB;
  new$REGISTERDATE ALLOWANCECAPTION.REGISTERDATE%TYPE := :NEW.REGISTERDATE;
  new$REGISTERORGAN ALLOWANCECAPTION.REGISTERORGAN%TYPE := :NEW.REGISTERORGAN;
  new$RETURNNOTIFYNUMBER ALLOWANCECAPTION.RETURNNOTIFYNUMBER%TYPE := :NEW.RETURNNOTIFYNUMBER;
  new$RETURNNOTIFYDATE ALLOWANCECAPTION.RETURNNOTIFYDATE%TYPE := :NEW.RETURNNOTIFYDATE;
  new$RETURNREJECTCAUSE ALLOWANCECAPTION.RETURNREJECTCAUSE%TYPE := :NEW.RETURNREJECTCAUSE;
  new$RETURNDATE ALLOWANCECAPTION.RETURNDATE%TYPE := :NEW.RETURNDATE;
  new$RETURNFIO ALLOWANCECAPTION.RETURNFIO%TYPE := :NEW.RETURNFIO;
  new$RETURNJOB ALLOWANCECAPTION.RETURNJOB%TYPE := :NEW.RETURNJOB;
  new$SENDERID ALLOWANCECAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID ALLOWANCECAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REJECT_CLS ALLOWANCECAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$NUMBERRETURNTRANZACTION ALLOWANCECAPTION.NUMBERRETURNTRANZACTION%TYPE := :NEW.NUMBERRETURNTRANZACTION;
  new$NUMBERREJECTTRANZACTION ALLOWANCECAPTION.NUMBERREJECTTRANZACTION%TYPE := :NEW.NUMBERREJECTTRANZACTION;
  new$BUDGETREF ALLOWANCECAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER ALLOWANCECAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ALLOWANCECAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ALLOWANCECAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ALLOWANCECAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$DOCSTATEREF ALLOWANCECAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ALLOWANCECAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$PROGINDEX ALLOWANCECAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RVERSION ALLOWANCECAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$INPUTDATE ALLOWANCECAPTION.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$REQUESTNUMBER ALLOWANCECAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$NOTE ALLOWANCECAPTION.NOTE%TYPE := :NEW.NOTE;
  new$LASTEXTRCHANGE ALLOWANCECAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$TEMPREJECTCAUSE ALLOWANCECAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  val_maxLN$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ALLOWANCECAPTION_BI)
-- Create 10.04.2007
-- Last update 11.12.2009
-- - - - - - - - - - - - -

  if (new$id is null) then select g_Shared.nextval into new$id from dual; end if;
  if (new$AcceptorOrgRef is null) then new$AcceptorOrgRef := 0; end if;
  if (new$FacialAcc_Cls is null) then new$FacialAcc_Cls := 0; end if;
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
    then GetIntConst(-1, 3, new$BudgetRef);
  end if;

-- - - - - - - - - - - - -
-- BI_5 (TR_ALLOWANCECAPTION_BI_5)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

  if (new$Progindex is null) then new$Progindex := 110; end if;

-- - - - - - - - - - - - -
-- BI_60 (TR_ALLOWANCECAPTION_BI_60)
-- Create 08.04.2010
-- Last update 08.04.2010
-- - - - - - - - - - - - -

  IF (new$RegisterDate IS NOT NULL) THEN
    SELECT MAX(det.LineNumber)
	INTO val_maxLN$
    FROM AllowanceDetail det
      LEFT JOIN AllowanceCaption cap ON (cap.id = det.RecordIndex)
    WHERE cap.FacialAcc_Cls = new$facialacc_cls;

    IF (val_maxLN$ IS NULL) THEN
      val_maxLN$ := 1;
    ELSE
      val_maxLN$ := val_maxLN$ + 1;
	END IF;  

    FOR R$ IN (SELECT id val_det_id FROM AllowanceDetail
      WHERE RecordIndex = new$id)
    LOOP
      UPDATE AllowanceDetail SET
        LineNumber = val_maxLN$
      WHERE
        (id = R$.val_det_id) AND (LineNumber IS NULL);
      val_maxLN$ := val_maxLN$ + 1;
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_ALLOWANCECAPTION_BI_500)
-- Create 10.04.2007
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_ALLOWANCECAPTION (
    ID,
    ALLOWANCETYPE,
    ACCEPTORORGREF,
    FACIALACC_CLS,
    NUMBERGENERAL,
    NUMBERGENERALADD,
    NUMBERDOC,
    NUMBERADD,
    BEGINDATE,
    ENDDATE,
    CONSTITUTIVEDOCTYPE,
    CONSTITUTIVEDATE,
    CONSTITUTIVENUMBER,
    CONSTITUTIVEORGAN,
    REGISTERFIO,
    REGISTERJOB,
    REGISTERDATE,
    REGISTERORGAN,
    RETURNNOTIFYNUMBER,
    RETURNNOTIFYDATE,
    RETURNREJECTCAUSE,
    RETURNDATE,
    RETURNFIO,
    RETURNJOB,
    SENDERID,
    SENDERRECORDID,
    REJECT_CLS,
    NUMBERRETURNTRANZACTION,
    NUMBERREJECTTRANZACTION,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    DOCSTATEREF,
    CRYPTOSTATUS,
    PROGINDEX,
    RVERSION,
    INPUTDATE,
    REQUESTNUMBER,
    NOTE,
    LASTEXTRCHANGE,
    TEMPREJECTCAUSE
  ) VALUES (
    new$ID,
    new$ALLOWANCETYPE,
    new$ACCEPTORORGREF,
    new$FACIALACC_CLS,
    new$NUMBERGENERAL,
    new$NUMBERGENERALADD,
    new$NUMBERDOC,
    new$NUMBERADD,
    new$BEGINDATE,
    new$ENDDATE,
    new$CONSTITUTIVEDOCTYPE,
    new$CONSTITUTIVEDATE,
    new$CONSTITUTIVENUMBER,
    new$CONSTITUTIVEORGAN,
    new$REGISTERFIO,
    new$REGISTERJOB,
    new$REGISTERDATE,
    new$REGISTERORGAN,
    new$RETURNNOTIFYNUMBER,
    new$RETURNNOTIFYDATE,
    new$RETURNREJECTCAUSE,
    new$RETURNDATE,
    new$RETURNFIO,
    new$RETURNJOB,
    new$SENDERID,
    new$SENDERRECORDID,
    new$REJECT_CLS,
    new$NUMBERRETURNTRANZACTION,
    new$NUMBERREJECTTRANZACTION,
    new$BUDGETREF,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$DOCSTATEREF,
    new$CRYPTOSTATUS,
    new$PROGINDEX,
    new$RVERSION,
    new$INPUTDATE,
    new$REQUESTNUMBER,
    new$NOTE,
    new$LASTEXTRCHANGE,
    new$TEMPREJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_ALLOWANCECAPTION_AI_500)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 5000) and (RecordID = :new.ID);

END;
/

CREATE OR REPLACE TRIGGER TR_ALLOWANCECAPTION_IU
  INSTEAD OF UPDATE
  ON ALLOWANCECAPTION
  FOR EACH ROW
DECLARE
  new$ID ALLOWANCECAPTION.ID%TYPE := :NEW.ID;
  new$ALLOWANCETYPE ALLOWANCECAPTION.ALLOWANCETYPE%TYPE := :NEW.ALLOWANCETYPE;
  new$ACCEPTORORGREF ALLOWANCECAPTION.ACCEPTORORGREF%TYPE := :NEW.ACCEPTORORGREF;
  new$FACIALACC_CLS ALLOWANCECAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NUMBERGENERAL ALLOWANCECAPTION.NUMBERGENERAL%TYPE := :NEW.NUMBERGENERAL;
  new$NUMBERGENERALADD ALLOWANCECAPTION.NUMBERGENERALADD%TYPE := :NEW.NUMBERGENERALADD;
  new$NUMBERDOC ALLOWANCECAPTION.NUMBERDOC%TYPE := :NEW.NUMBERDOC;
  new$NUMBERADD ALLOWANCECAPTION.NUMBERADD%TYPE := :NEW.NUMBERADD;
  new$BEGINDATE ALLOWANCECAPTION.BEGINDATE%TYPE := :NEW.BEGINDATE;
  new$ENDDATE ALLOWANCECAPTION.ENDDATE%TYPE := :NEW.ENDDATE;
  new$CONSTITUTIVEDOCTYPE ALLOWANCECAPTION.CONSTITUTIVEDOCTYPE%TYPE := :NEW.CONSTITUTIVEDOCTYPE;
  new$CONSTITUTIVEDATE ALLOWANCECAPTION.CONSTITUTIVEDATE%TYPE := :NEW.CONSTITUTIVEDATE;
  new$CONSTITUTIVENUMBER ALLOWANCECAPTION.CONSTITUTIVENUMBER%TYPE := :NEW.CONSTITUTIVENUMBER;
  new$CONSTITUTIVEORGAN ALLOWANCECAPTION.CONSTITUTIVEORGAN%TYPE := :NEW.CONSTITUTIVEORGAN;
  new$REGISTERFIO ALLOWANCECAPTION.REGISTERFIO%TYPE := :NEW.REGISTERFIO;
  new$REGISTERJOB ALLOWANCECAPTION.REGISTERJOB%TYPE := :NEW.REGISTERJOB;
  new$REGISTERDATE ALLOWANCECAPTION.REGISTERDATE%TYPE := :NEW.REGISTERDATE;
  new$REGISTERORGAN ALLOWANCECAPTION.REGISTERORGAN%TYPE := :NEW.REGISTERORGAN;
  new$RETURNNOTIFYNUMBER ALLOWANCECAPTION.RETURNNOTIFYNUMBER%TYPE := :NEW.RETURNNOTIFYNUMBER;
  new$RETURNNOTIFYDATE ALLOWANCECAPTION.RETURNNOTIFYDATE%TYPE := :NEW.RETURNNOTIFYDATE;
  new$RETURNREJECTCAUSE ALLOWANCECAPTION.RETURNREJECTCAUSE%TYPE := :NEW.RETURNREJECTCAUSE;
  new$RETURNDATE ALLOWANCECAPTION.RETURNDATE%TYPE := :NEW.RETURNDATE;
  new$RETURNFIO ALLOWANCECAPTION.RETURNFIO%TYPE := :NEW.RETURNFIO;
  new$RETURNJOB ALLOWANCECAPTION.RETURNJOB%TYPE := :NEW.RETURNJOB;
  new$SENDERID ALLOWANCECAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID ALLOWANCECAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REJECT_CLS ALLOWANCECAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$NUMBERRETURNTRANZACTION ALLOWANCECAPTION.NUMBERRETURNTRANZACTION%TYPE := :NEW.NUMBERRETURNTRANZACTION;
  new$NUMBERREJECTTRANZACTION ALLOWANCECAPTION.NUMBERREJECTTRANZACTION%TYPE := :NEW.NUMBERREJECTTRANZACTION;
  new$BUDGETREF ALLOWANCECAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER ALLOWANCECAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ALLOWANCECAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ALLOWANCECAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ALLOWANCECAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$DOCSTATEREF ALLOWANCECAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ALLOWANCECAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$PROGINDEX ALLOWANCECAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RVERSION ALLOWANCECAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$INPUTDATE ALLOWANCECAPTION.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$REQUESTNUMBER ALLOWANCECAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$NOTE ALLOWANCECAPTION.NOTE%TYPE := :NEW.NOTE;
  new$LASTEXTRCHANGE ALLOWANCECAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$TEMPREJECTCAUSE ALLOWANCECAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  cnt$ Number(10);
  val_maxLN$ Number(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_ALLOWANCECAPTION_BU)
-- Create 10.04.2007
-- - - - - - - - - - - - -

  if (new$AcceptorOrgRef is null) then new$AcceptorOrgRef := 0; end if;
  if (new$FacialAcc_Cls is null) then new$FacialAcc_Cls := 0; end if;

  IF (new$BudgetRef <> :OLD.BudgetRef) THEN
    IF ( NOT((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL)) ) THEN
      SELECT count(ad.id) into cnt$ 
      FROM AllowanceDetail ad WHERE ad.recordindex = new$ID and ROWNUM = 1;
      IF (cnt$ > 0) THEN
        RaiseEXCEPTION('Ex_CantModufyBudget');
      END IF;  
    END IF;    
  END IF;

-- - - - - - - - - - - - -
-- BU_60 (TR_ALLOWANCECAPTION_BU_60)
-- Create 12.03.2010
-- Last update 12.03.2010
-- - - - - - - - - - - - -

  IF ((:OLD.RegisterDate IS NULL) AND (new$RegisterDate IS NOT NULL)) THEN
    SELECT MAX(det.LineNumber)
    INTO val_maxLN$
    FROM AllowanceDetail det
      LEFT JOIN AllowanceCaption cap ON (cap.id = det.RecordIndex)
    WHERE cap.FacialAcc_Cls = new$facialacc_cls ;

    IF (val_maxLN$ IS NULL) THEN
      val_maxLN$ := 1;
    ELSE
      val_maxLN$ := val_maxLN$ + 1;
    END IF;  

    FOR R$ IN (SELECT id val_det_id FROM AllowanceDetail
      WHERE RecordIndex = new$id)
    LOOP
      UPDATE AllowanceDetail SET
        LineNumber = val_maxLN$
      WHERE
        (id = R$.val_det_id) AND (LineNumber IS NULL);
      val_maxLN$ := val_maxLN$ + 1;
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (tr_Allowancecaption_BU200)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

   --      
   IF (:OLD.DOCSTATEREF <> new$DOCSTATEREF) THEN
      INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
        VALUES (new$ID, :OLD.DOCSTATEREF, new$DOCSTATEREF);
   END IF;     

-- - - - - - - - - - - - -
-- BU_700 (TR_ALLOWANCECAPTION_BU_700)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

 if (new$RVersion is null) then
   new$RVersion:=1;
 elsif ((new$RVersion = -1) and (:Old.RVersion <> -1)) then
   new$RVersion:=:Old.RVersion;
 else
   new$RVersion:=:Old.RVersion+1;
 end if;  

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_ALLOWANCECAPTION SET
    ID = new$ID,
    ALLOWANCETYPE = new$ALLOWANCETYPE,
    ACCEPTORORGREF = new$ACCEPTORORGREF,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NUMBERGENERAL = new$NUMBERGENERAL,
    NUMBERGENERALADD = new$NUMBERGENERALADD,
    NUMBERDOC = new$NUMBERDOC,
    NUMBERADD = new$NUMBERADD,
    BEGINDATE = new$BEGINDATE,
    ENDDATE = new$ENDDATE,
    CONSTITUTIVEDOCTYPE = new$CONSTITUTIVEDOCTYPE,
    CONSTITUTIVEDATE = new$CONSTITUTIVEDATE,
    CONSTITUTIVENUMBER = new$CONSTITUTIVENUMBER,
    CONSTITUTIVEORGAN = new$CONSTITUTIVEORGAN,
    REGISTERFIO = new$REGISTERFIO,
    REGISTERJOB = new$REGISTERJOB,
    REGISTERDATE = new$REGISTERDATE,
    REGISTERORGAN = new$REGISTERORGAN,
    RETURNNOTIFYNUMBER = new$RETURNNOTIFYNUMBER,
    RETURNNOTIFYDATE = new$RETURNNOTIFYDATE,
    RETURNREJECTCAUSE = new$RETURNREJECTCAUSE,
    RETURNDATE = new$RETURNDATE,
    RETURNFIO = new$RETURNFIO,
    RETURNJOB = new$RETURNJOB,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REJECT_CLS = new$REJECT_CLS,
    NUMBERRETURNTRANZACTION = new$NUMBERRETURNTRANZACTION,
    NUMBERREJECTTRANZACTION = new$NUMBERREJECTTRANZACTION,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    DOCSTATEREF = new$DOCSTATEREF,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    PROGINDEX = new$PROGINDEX,
    RVERSION = new$RVERSION,
    INPUTDATE = new$INPUTDATE,
    REQUESTNUMBER = new$REQUESTNUMBER,
    NOTE = new$NOTE,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_500 (TR_ALLOWANCECAPTION_AU_500)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

  if (:new.ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (5000, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=5000) and (RecordId=:new.ID);
  end if;

END;
/
ALTER TABLE TB_ALLOWANCECAPTION ADD (
  REJECTCAUSE VARCHAR2(1000)
)
/

CREATE OR REPLACE VIEW ALLOWANCECAPTION (
  ID,
  ALLOWANCETYPE,
  ACCEPTORORGREF,
  FACIALACC_CLS,
  NUMBERGENERAL,
  NUMBERGENERALADD,
  NUMBERDOC,
  NUMBERADD,
  BEGINDATE,
  ENDDATE,
  CONSTITUTIVEDOCTYPE,
  CONSTITUTIVEDATE,
  CONSTITUTIVENUMBER,
  CONSTITUTIVEORGAN,
  REGISTERFIO,
  REGISTERJOB,
  REGISTERDATE,
  REGISTERORGAN,
  RETURNNOTIFYNUMBER,
  RETURNNOTIFYDATE,
  RETURNREJECTCAUSE,
  RETURNDATE,
  RETURNFIO,
  RETURNJOB,
  SENDERID,
  SENDERRECORDID,
  REJECT_CLS,
  NUMBERRETURNTRANZACTION,
  NUMBERREJECTTRANZACTION,
  BUDGETREF,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  DOCSTATEREF,
  CRYPTOSTATUS,
  PROGINDEX,
  RVERSION,
  INPUTDATE,
  REQUESTNUMBER,
  NOTE,
  LASTEXTRCHANGE,
  TEMPREJECTCAUSE,
  REJECTCAUSE)
AS
  SELECT
    ID,
    ALLOWANCETYPE,
    ACCEPTORORGREF,
    FACIALACC_CLS,
    NUMBERGENERAL,
    NUMBERGENERALADD,
    NUMBERDOC,
    NUMBERADD,
    BEGINDATE,
    ENDDATE,
    CONSTITUTIVEDOCTYPE,
    CONSTITUTIVEDATE,
    CONSTITUTIVENUMBER,
    CONSTITUTIVEORGAN,
    REGISTERFIO,
    REGISTERJOB,
    REGISTERDATE,
    REGISTERORGAN,
    RETURNNOTIFYNUMBER,
    RETURNNOTIFYDATE,
    RETURNREJECTCAUSE,
    RETURNDATE,
    RETURNFIO,
    RETURNJOB,
    SENDERID,
    SENDERRECORDID,
    REJECT_CLS,
    NUMBERRETURNTRANZACTION,
    NUMBERREJECTTRANZACTION,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    DOCSTATEREF,
    CRYPTOSTATUS,
    PROGINDEX,
    RVERSION,
    INPUTDATE,
    REQUESTNUMBER,
    NOTE,
    LASTEXTRCHANGE,
    TEMPREJECTCAUSE,
    REJECTCAUSE
  FROM TB_ALLOWANCECAPTION
/

CREATE OR REPLACE TRIGGER TR_ALLOWANCECAPTION_ID
  INSTEAD OF DELETE
  ON ALLOWANCECAPTION
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_AllowanceCaption_BD)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

 --   
 delete 
  from AllowanceDetail
 where 
  (RecordIndex = :old.id);

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_ALLOWANCECAPTION
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_200 (TR_ALLOWANCECAPTION_AD_200)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

  --      
  delete 
    from 
      StateJumpHistory
    where 
      DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_ALLOWANCECAPTION_AD_500)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate,ProgIndex) values(5000,:old.ID,SYSDATE,:old.ProgIndex);

END;
/

CREATE OR REPLACE TRIGGER TR_ALLOWANCECAPTION_II
  INSTEAD OF INSERT
  ON ALLOWANCECAPTION
  FOR EACH ROW
DECLARE
  new$ID ALLOWANCECAPTION.ID%TYPE := :NEW.ID;
  new$ALLOWANCETYPE ALLOWANCECAPTION.ALLOWANCETYPE%TYPE := :NEW.ALLOWANCETYPE;
  new$ACCEPTORORGREF ALLOWANCECAPTION.ACCEPTORORGREF%TYPE := :NEW.ACCEPTORORGREF;
  new$FACIALACC_CLS ALLOWANCECAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NUMBERGENERAL ALLOWANCECAPTION.NUMBERGENERAL%TYPE := :NEW.NUMBERGENERAL;
  new$NUMBERGENERALADD ALLOWANCECAPTION.NUMBERGENERALADD%TYPE := :NEW.NUMBERGENERALADD;
  new$NUMBERDOC ALLOWANCECAPTION.NUMBERDOC%TYPE := :NEW.NUMBERDOC;
  new$NUMBERADD ALLOWANCECAPTION.NUMBERADD%TYPE := :NEW.NUMBERADD;
  new$BEGINDATE ALLOWANCECAPTION.BEGINDATE%TYPE := :NEW.BEGINDATE;
  new$ENDDATE ALLOWANCECAPTION.ENDDATE%TYPE := :NEW.ENDDATE;
  new$CONSTITUTIVEDOCTYPE ALLOWANCECAPTION.CONSTITUTIVEDOCTYPE%TYPE := :NEW.CONSTITUTIVEDOCTYPE;
  new$CONSTITUTIVEDATE ALLOWANCECAPTION.CONSTITUTIVEDATE%TYPE := :NEW.CONSTITUTIVEDATE;
  new$CONSTITUTIVENUMBER ALLOWANCECAPTION.CONSTITUTIVENUMBER%TYPE := :NEW.CONSTITUTIVENUMBER;
  new$CONSTITUTIVEORGAN ALLOWANCECAPTION.CONSTITUTIVEORGAN%TYPE := :NEW.CONSTITUTIVEORGAN;
  new$REGISTERFIO ALLOWANCECAPTION.REGISTERFIO%TYPE := :NEW.REGISTERFIO;
  new$REGISTERJOB ALLOWANCECAPTION.REGISTERJOB%TYPE := :NEW.REGISTERJOB;
  new$REGISTERDATE ALLOWANCECAPTION.REGISTERDATE%TYPE := :NEW.REGISTERDATE;
  new$REGISTERORGAN ALLOWANCECAPTION.REGISTERORGAN%TYPE := :NEW.REGISTERORGAN;
  new$RETURNNOTIFYNUMBER ALLOWANCECAPTION.RETURNNOTIFYNUMBER%TYPE := :NEW.RETURNNOTIFYNUMBER;
  new$RETURNNOTIFYDATE ALLOWANCECAPTION.RETURNNOTIFYDATE%TYPE := :NEW.RETURNNOTIFYDATE;
  new$RETURNREJECTCAUSE ALLOWANCECAPTION.RETURNREJECTCAUSE%TYPE := :NEW.RETURNREJECTCAUSE;
  new$RETURNDATE ALLOWANCECAPTION.RETURNDATE%TYPE := :NEW.RETURNDATE;
  new$RETURNFIO ALLOWANCECAPTION.RETURNFIO%TYPE := :NEW.RETURNFIO;
  new$RETURNJOB ALLOWANCECAPTION.RETURNJOB%TYPE := :NEW.RETURNJOB;
  new$SENDERID ALLOWANCECAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID ALLOWANCECAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REJECT_CLS ALLOWANCECAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$NUMBERRETURNTRANZACTION ALLOWANCECAPTION.NUMBERRETURNTRANZACTION%TYPE := :NEW.NUMBERRETURNTRANZACTION;
  new$NUMBERREJECTTRANZACTION ALLOWANCECAPTION.NUMBERREJECTTRANZACTION%TYPE := :NEW.NUMBERREJECTTRANZACTION;
  new$BUDGETREF ALLOWANCECAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER ALLOWANCECAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ALLOWANCECAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ALLOWANCECAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ALLOWANCECAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$DOCSTATEREF ALLOWANCECAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ALLOWANCECAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$PROGINDEX ALLOWANCECAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RVERSION ALLOWANCECAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$INPUTDATE ALLOWANCECAPTION.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$REQUESTNUMBER ALLOWANCECAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$NOTE ALLOWANCECAPTION.NOTE%TYPE := :NEW.NOTE;
  new$LASTEXTRCHANGE ALLOWANCECAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$TEMPREJECTCAUSE ALLOWANCECAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
  new$REJECTCAUSE ALLOWANCECAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  val_maxLN$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ALLOWANCECAPTION_BI)
-- Create 10.04.2007
-- Last update 11.12.2009
-- - - - - - - - - - - - -

  if (new$id is null) then select g_Shared.nextval into new$id from dual; end if;
  if (new$AcceptorOrgRef is null) then new$AcceptorOrgRef := 0; end if;
  if (new$FacialAcc_Cls is null) then new$FacialAcc_Cls := 0; end if;
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
    then GetIntConst(-1, 3, new$BudgetRef);
  end if;

-- - - - - - - - - - - - -
-- BI_5 (TR_ALLOWANCECAPTION_BI_5)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

  if (new$Progindex is null) then new$Progindex := 110; end if;

-- - - - - - - - - - - - -
-- BI_60 (TR_ALLOWANCECAPTION_BI_60)
-- Create 08.04.2010
-- Last update 08.04.2010
-- - - - - - - - - - - - -

  IF (new$RegisterDate IS NOT NULL) THEN
    SELECT MAX(det.LineNumber)
	INTO val_maxLN$
    FROM AllowanceDetail det
      LEFT JOIN AllowanceCaption cap ON (cap.id = det.RecordIndex)
    WHERE cap.FacialAcc_Cls = new$facialacc_cls;

    IF (val_maxLN$ IS NULL) THEN
      val_maxLN$ := 1;
    ELSE
      val_maxLN$ := val_maxLN$ + 1;
	END IF;  

    FOR R$ IN (SELECT id val_det_id FROM AllowanceDetail
      WHERE RecordIndex = new$id)
    LOOP
      UPDATE AllowanceDetail SET
        LineNumber = val_maxLN$
      WHERE
        (id = R$.val_det_id) AND (LineNumber IS NULL);
      val_maxLN$ := val_maxLN$ + 1;
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_ALLOWANCECAPTION_BI_500)
-- Create 10.04.2007
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_ALLOWANCECAPTION (
    ID,
    ALLOWANCETYPE,
    ACCEPTORORGREF,
    FACIALACC_CLS,
    NUMBERGENERAL,
    NUMBERGENERALADD,
    NUMBERDOC,
    NUMBERADD,
    BEGINDATE,
    ENDDATE,
    CONSTITUTIVEDOCTYPE,
    CONSTITUTIVEDATE,
    CONSTITUTIVENUMBER,
    CONSTITUTIVEORGAN,
    REGISTERFIO,
    REGISTERJOB,
    REGISTERDATE,
    REGISTERORGAN,
    RETURNNOTIFYNUMBER,
    RETURNNOTIFYDATE,
    RETURNREJECTCAUSE,
    RETURNDATE,
    RETURNFIO,
    RETURNJOB,
    SENDERID,
    SENDERRECORDID,
    REJECT_CLS,
    NUMBERRETURNTRANZACTION,
    NUMBERREJECTTRANZACTION,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    DOCSTATEREF,
    CRYPTOSTATUS,
    PROGINDEX,
    RVERSION,
    INPUTDATE,
    REQUESTNUMBER,
    NOTE,
    LASTEXTRCHANGE,
    TEMPREJECTCAUSE,
    REJECTCAUSE
  ) VALUES (
    new$ID,
    new$ALLOWANCETYPE,
    new$ACCEPTORORGREF,
    new$FACIALACC_CLS,
    new$NUMBERGENERAL,
    new$NUMBERGENERALADD,
    new$NUMBERDOC,
    new$NUMBERADD,
    new$BEGINDATE,
    new$ENDDATE,
    new$CONSTITUTIVEDOCTYPE,
    new$CONSTITUTIVEDATE,
    new$CONSTITUTIVENUMBER,
    new$CONSTITUTIVEORGAN,
    new$REGISTERFIO,
    new$REGISTERJOB,
    new$REGISTERDATE,
    new$REGISTERORGAN,
    new$RETURNNOTIFYNUMBER,
    new$RETURNNOTIFYDATE,
    new$RETURNREJECTCAUSE,
    new$RETURNDATE,
    new$RETURNFIO,
    new$RETURNJOB,
    new$SENDERID,
    new$SENDERRECORDID,
    new$REJECT_CLS,
    new$NUMBERRETURNTRANZACTION,
    new$NUMBERREJECTTRANZACTION,
    new$BUDGETREF,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$DOCSTATEREF,
    new$CRYPTOSTATUS,
    new$PROGINDEX,
    new$RVERSION,
    new$INPUTDATE,
    new$REQUESTNUMBER,
    new$NOTE,
    new$LASTEXTRCHANGE,
    new$TEMPREJECTCAUSE,
    new$REJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_ALLOWANCECAPTION_AI_500)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 5000) and (RecordID = :new.ID);

END;
/

CREATE OR REPLACE TRIGGER TR_ALLOWANCECAPTION_IU
  INSTEAD OF UPDATE
  ON ALLOWANCECAPTION
  FOR EACH ROW
DECLARE
  new$ID ALLOWANCECAPTION.ID%TYPE := :NEW.ID;
  new$ALLOWANCETYPE ALLOWANCECAPTION.ALLOWANCETYPE%TYPE := :NEW.ALLOWANCETYPE;
  new$ACCEPTORORGREF ALLOWANCECAPTION.ACCEPTORORGREF%TYPE := :NEW.ACCEPTORORGREF;
  new$FACIALACC_CLS ALLOWANCECAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NUMBERGENERAL ALLOWANCECAPTION.NUMBERGENERAL%TYPE := :NEW.NUMBERGENERAL;
  new$NUMBERGENERALADD ALLOWANCECAPTION.NUMBERGENERALADD%TYPE := :NEW.NUMBERGENERALADD;
  new$NUMBERDOC ALLOWANCECAPTION.NUMBERDOC%TYPE := :NEW.NUMBERDOC;
  new$NUMBERADD ALLOWANCECAPTION.NUMBERADD%TYPE := :NEW.NUMBERADD;
  new$BEGINDATE ALLOWANCECAPTION.BEGINDATE%TYPE := :NEW.BEGINDATE;
  new$ENDDATE ALLOWANCECAPTION.ENDDATE%TYPE := :NEW.ENDDATE;
  new$CONSTITUTIVEDOCTYPE ALLOWANCECAPTION.CONSTITUTIVEDOCTYPE%TYPE := :NEW.CONSTITUTIVEDOCTYPE;
  new$CONSTITUTIVEDATE ALLOWANCECAPTION.CONSTITUTIVEDATE%TYPE := :NEW.CONSTITUTIVEDATE;
  new$CONSTITUTIVENUMBER ALLOWANCECAPTION.CONSTITUTIVENUMBER%TYPE := :NEW.CONSTITUTIVENUMBER;
  new$CONSTITUTIVEORGAN ALLOWANCECAPTION.CONSTITUTIVEORGAN%TYPE := :NEW.CONSTITUTIVEORGAN;
  new$REGISTERFIO ALLOWANCECAPTION.REGISTERFIO%TYPE := :NEW.REGISTERFIO;
  new$REGISTERJOB ALLOWANCECAPTION.REGISTERJOB%TYPE := :NEW.REGISTERJOB;
  new$REGISTERDATE ALLOWANCECAPTION.REGISTERDATE%TYPE := :NEW.REGISTERDATE;
  new$REGISTERORGAN ALLOWANCECAPTION.REGISTERORGAN%TYPE := :NEW.REGISTERORGAN;
  new$RETURNNOTIFYNUMBER ALLOWANCECAPTION.RETURNNOTIFYNUMBER%TYPE := :NEW.RETURNNOTIFYNUMBER;
  new$RETURNNOTIFYDATE ALLOWANCECAPTION.RETURNNOTIFYDATE%TYPE := :NEW.RETURNNOTIFYDATE;
  new$RETURNREJECTCAUSE ALLOWANCECAPTION.RETURNREJECTCAUSE%TYPE := :NEW.RETURNREJECTCAUSE;
  new$RETURNDATE ALLOWANCECAPTION.RETURNDATE%TYPE := :NEW.RETURNDATE;
  new$RETURNFIO ALLOWANCECAPTION.RETURNFIO%TYPE := :NEW.RETURNFIO;
  new$RETURNJOB ALLOWANCECAPTION.RETURNJOB%TYPE := :NEW.RETURNJOB;
  new$SENDERID ALLOWANCECAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID ALLOWANCECAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REJECT_CLS ALLOWANCECAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$NUMBERRETURNTRANZACTION ALLOWANCECAPTION.NUMBERRETURNTRANZACTION%TYPE := :NEW.NUMBERRETURNTRANZACTION;
  new$NUMBERREJECTTRANZACTION ALLOWANCECAPTION.NUMBERREJECTTRANZACTION%TYPE := :NEW.NUMBERREJECTTRANZACTION;
  new$BUDGETREF ALLOWANCECAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER ALLOWANCECAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ALLOWANCECAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ALLOWANCECAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ALLOWANCECAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$DOCSTATEREF ALLOWANCECAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ALLOWANCECAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$PROGINDEX ALLOWANCECAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RVERSION ALLOWANCECAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$INPUTDATE ALLOWANCECAPTION.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$REQUESTNUMBER ALLOWANCECAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$NOTE ALLOWANCECAPTION.NOTE%TYPE := :NEW.NOTE;
  new$LASTEXTRCHANGE ALLOWANCECAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$TEMPREJECTCAUSE ALLOWANCECAPTION.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
  new$REJECTCAUSE ALLOWANCECAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  cnt$ Number(10);
  val_maxLN$ Number(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_ALLOWANCECAPTION_BU)
-- Create 10.04.2007
-- - - - - - - - - - - - -

  if (new$AcceptorOrgRef is null) then new$AcceptorOrgRef := 0; end if;
  if (new$FacialAcc_Cls is null) then new$FacialAcc_Cls := 0; end if;

  IF (new$BudgetRef <> :OLD.BudgetRef) THEN
    IF ( NOT((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL)) ) THEN
      SELECT count(ad.id) into cnt$ 
      FROM AllowanceDetail ad WHERE ad.recordindex = new$ID and ROWNUM = 1;
      IF (cnt$ > 0) THEN
        RaiseEXCEPTION('Ex_CantModufyBudget');
      END IF;  
    END IF;    
  END IF;

-- - - - - - - - - - - - -
-- BU_60 (TR_ALLOWANCECAPTION_BU_60)
-- Create 12.03.2010
-- Last update 12.03.2010
-- - - - - - - - - - - - -

  IF ((:OLD.RegisterDate IS NULL) AND (new$RegisterDate IS NOT NULL)) THEN
    SELECT MAX(det.LineNumber)
    INTO val_maxLN$
    FROM AllowanceDetail det
      LEFT JOIN AllowanceCaption cap ON (cap.id = det.RecordIndex)
    WHERE cap.FacialAcc_Cls = new$facialacc_cls ;

    IF (val_maxLN$ IS NULL) THEN
      val_maxLN$ := 1;
    ELSE
      val_maxLN$ := val_maxLN$ + 1;
    END IF;  

    FOR R$ IN (SELECT id val_det_id FROM AllowanceDetail
      WHERE RecordIndex = new$id)
    LOOP
      UPDATE AllowanceDetail SET
        LineNumber = val_maxLN$
      WHERE
        (id = R$.val_det_id) AND (LineNumber IS NULL);
      val_maxLN$ := val_maxLN$ + 1;
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (tr_Allowancecaption_BU200)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

   --      
   IF (:OLD.DOCSTATEREF <> new$DOCSTATEREF) THEN
      INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
        VALUES (new$ID, :OLD.DOCSTATEREF, new$DOCSTATEREF);
   END IF;     

-- - - - - - - - - - - - -
-- BU_700 (TR_ALLOWANCECAPTION_BU_700)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

 if (new$RVersion is null) then
   new$RVersion:=1;
 elsif ((new$RVersion = -1) and (:Old.RVersion <> -1)) then
   new$RVersion:=:Old.RVersion;
 else
   new$RVersion:=:Old.RVersion+1;
 end if;  

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_ALLOWANCECAPTION SET
    ID = new$ID,
    ALLOWANCETYPE = new$ALLOWANCETYPE,
    ACCEPTORORGREF = new$ACCEPTORORGREF,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NUMBERGENERAL = new$NUMBERGENERAL,
    NUMBERGENERALADD = new$NUMBERGENERALADD,
    NUMBERDOC = new$NUMBERDOC,
    NUMBERADD = new$NUMBERADD,
    BEGINDATE = new$BEGINDATE,
    ENDDATE = new$ENDDATE,
    CONSTITUTIVEDOCTYPE = new$CONSTITUTIVEDOCTYPE,
    CONSTITUTIVEDATE = new$CONSTITUTIVEDATE,
    CONSTITUTIVENUMBER = new$CONSTITUTIVENUMBER,
    CONSTITUTIVEORGAN = new$CONSTITUTIVEORGAN,
    REGISTERFIO = new$REGISTERFIO,
    REGISTERJOB = new$REGISTERJOB,
    REGISTERDATE = new$REGISTERDATE,
    REGISTERORGAN = new$REGISTERORGAN,
    RETURNNOTIFYNUMBER = new$RETURNNOTIFYNUMBER,
    RETURNNOTIFYDATE = new$RETURNNOTIFYDATE,
    RETURNREJECTCAUSE = new$RETURNREJECTCAUSE,
    RETURNDATE = new$RETURNDATE,
    RETURNFIO = new$RETURNFIO,
    RETURNJOB = new$RETURNJOB,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REJECT_CLS = new$REJECT_CLS,
    NUMBERRETURNTRANZACTION = new$NUMBERRETURNTRANZACTION,
    NUMBERREJECTTRANZACTION = new$NUMBERREJECTTRANZACTION,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    DOCSTATEREF = new$DOCSTATEREF,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    PROGINDEX = new$PROGINDEX,
    RVERSION = new$RVERSION,
    INPUTDATE = new$INPUTDATE,
    REQUESTNUMBER = new$REQUESTNUMBER,
    NOTE = new$NOTE,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_500 (TR_ALLOWANCECAPTION_AU_500)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

  if (:new.ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (5000, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=5000) and (RecordId=:new.ID);
  end if;

END;
/
update ALLOWANCECAPTION set
  REJECTCAUSE = TempRejectCause
/
commit work 
/
ALTER TABLE TB_ALLOWANCECAPTION DROP (TempRejectCause)
/

CREATE OR REPLACE VIEW ALLOWANCECAPTION (
  ID,
  ALLOWANCETYPE,
  ACCEPTORORGREF,
  FACIALACC_CLS,
  NUMBERGENERAL,
  NUMBERGENERALADD,
  NUMBERDOC,
  NUMBERADD,
  BEGINDATE,
  ENDDATE,
  CONSTITUTIVEDOCTYPE,
  CONSTITUTIVEDATE,
  CONSTITUTIVENUMBER,
  CONSTITUTIVEORGAN,
  REGISTERFIO,
  REGISTERJOB,
  REGISTERDATE,
  REGISTERORGAN,
  RETURNNOTIFYNUMBER,
  RETURNNOTIFYDATE,
  RETURNREJECTCAUSE,
  RETURNDATE,
  RETURNFIO,
  RETURNJOB,
  SENDERID,
  SENDERRECORDID,
  REJECT_CLS,
  NUMBERRETURNTRANZACTION,
  NUMBERREJECTTRANZACTION,
  BUDGETREF,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  DOCSTATEREF,
  CRYPTOSTATUS,
  PROGINDEX,
  RVERSION,
  INPUTDATE,
  REQUESTNUMBER,
  NOTE,
  LASTEXTRCHANGE,
  REJECTCAUSE)
AS
  SELECT
    ID,
    ALLOWANCETYPE,
    ACCEPTORORGREF,
    FACIALACC_CLS,
    NUMBERGENERAL,
    NUMBERGENERALADD,
    NUMBERDOC,
    NUMBERADD,
    BEGINDATE,
    ENDDATE,
    CONSTITUTIVEDOCTYPE,
    CONSTITUTIVEDATE,
    CONSTITUTIVENUMBER,
    CONSTITUTIVEORGAN,
    REGISTERFIO,
    REGISTERJOB,
    REGISTERDATE,
    REGISTERORGAN,
    RETURNNOTIFYNUMBER,
    RETURNNOTIFYDATE,
    RETURNREJECTCAUSE,
    RETURNDATE,
    RETURNFIO,
    RETURNJOB,
    SENDERID,
    SENDERRECORDID,
    REJECT_CLS,
    NUMBERRETURNTRANZACTION,
    NUMBERREJECTTRANZACTION,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    DOCSTATEREF,
    CRYPTOSTATUS,
    PROGINDEX,
    RVERSION,
    INPUTDATE,
    REQUESTNUMBER,
    NOTE,
    LASTEXTRCHANGE,
    REJECTCAUSE
  FROM TB_ALLOWANCECAPTION
/

CREATE OR REPLACE TRIGGER TR_ALLOWANCECAPTION_ID
  INSTEAD OF DELETE
  ON ALLOWANCECAPTION
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_AllowanceCaption_BD)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

 --   
 delete 
  from AllowanceDetail
 where 
  (RecordIndex = :old.id);

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_ALLOWANCECAPTION
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_200 (TR_ALLOWANCECAPTION_AD_200)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

  --      
  delete 
    from 
      StateJumpHistory
    where 
      DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_ALLOWANCECAPTION_AD_500)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate,ProgIndex) values(5000,:old.ID,SYSDATE,:old.ProgIndex);

END;
/

CREATE OR REPLACE TRIGGER TR_ALLOWANCECAPTION_II
  INSTEAD OF INSERT
  ON ALLOWANCECAPTION
  FOR EACH ROW
DECLARE
  new$ID ALLOWANCECAPTION.ID%TYPE := :NEW.ID;
  new$ALLOWANCETYPE ALLOWANCECAPTION.ALLOWANCETYPE%TYPE := :NEW.ALLOWANCETYPE;
  new$ACCEPTORORGREF ALLOWANCECAPTION.ACCEPTORORGREF%TYPE := :NEW.ACCEPTORORGREF;
  new$FACIALACC_CLS ALLOWANCECAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NUMBERGENERAL ALLOWANCECAPTION.NUMBERGENERAL%TYPE := :NEW.NUMBERGENERAL;
  new$NUMBERGENERALADD ALLOWANCECAPTION.NUMBERGENERALADD%TYPE := :NEW.NUMBERGENERALADD;
  new$NUMBERDOC ALLOWANCECAPTION.NUMBERDOC%TYPE := :NEW.NUMBERDOC;
  new$NUMBERADD ALLOWANCECAPTION.NUMBERADD%TYPE := :NEW.NUMBERADD;
  new$BEGINDATE ALLOWANCECAPTION.BEGINDATE%TYPE := :NEW.BEGINDATE;
  new$ENDDATE ALLOWANCECAPTION.ENDDATE%TYPE := :NEW.ENDDATE;
  new$CONSTITUTIVEDOCTYPE ALLOWANCECAPTION.CONSTITUTIVEDOCTYPE%TYPE := :NEW.CONSTITUTIVEDOCTYPE;
  new$CONSTITUTIVEDATE ALLOWANCECAPTION.CONSTITUTIVEDATE%TYPE := :NEW.CONSTITUTIVEDATE;
  new$CONSTITUTIVENUMBER ALLOWANCECAPTION.CONSTITUTIVENUMBER%TYPE := :NEW.CONSTITUTIVENUMBER;
  new$CONSTITUTIVEORGAN ALLOWANCECAPTION.CONSTITUTIVEORGAN%TYPE := :NEW.CONSTITUTIVEORGAN;
  new$REGISTERFIO ALLOWANCECAPTION.REGISTERFIO%TYPE := :NEW.REGISTERFIO;
  new$REGISTERJOB ALLOWANCECAPTION.REGISTERJOB%TYPE := :NEW.REGISTERJOB;
  new$REGISTERDATE ALLOWANCECAPTION.REGISTERDATE%TYPE := :NEW.REGISTERDATE;
  new$REGISTERORGAN ALLOWANCECAPTION.REGISTERORGAN%TYPE := :NEW.REGISTERORGAN;
  new$RETURNNOTIFYNUMBER ALLOWANCECAPTION.RETURNNOTIFYNUMBER%TYPE := :NEW.RETURNNOTIFYNUMBER;
  new$RETURNNOTIFYDATE ALLOWANCECAPTION.RETURNNOTIFYDATE%TYPE := :NEW.RETURNNOTIFYDATE;
  new$RETURNREJECTCAUSE ALLOWANCECAPTION.RETURNREJECTCAUSE%TYPE := :NEW.RETURNREJECTCAUSE;
  new$RETURNDATE ALLOWANCECAPTION.RETURNDATE%TYPE := :NEW.RETURNDATE;
  new$RETURNFIO ALLOWANCECAPTION.RETURNFIO%TYPE := :NEW.RETURNFIO;
  new$RETURNJOB ALLOWANCECAPTION.RETURNJOB%TYPE := :NEW.RETURNJOB;
  new$SENDERID ALLOWANCECAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID ALLOWANCECAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REJECT_CLS ALLOWANCECAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$NUMBERRETURNTRANZACTION ALLOWANCECAPTION.NUMBERRETURNTRANZACTION%TYPE := :NEW.NUMBERRETURNTRANZACTION;
  new$NUMBERREJECTTRANZACTION ALLOWANCECAPTION.NUMBERREJECTTRANZACTION%TYPE := :NEW.NUMBERREJECTTRANZACTION;
  new$BUDGETREF ALLOWANCECAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER ALLOWANCECAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ALLOWANCECAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ALLOWANCECAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ALLOWANCECAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$DOCSTATEREF ALLOWANCECAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ALLOWANCECAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$PROGINDEX ALLOWANCECAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RVERSION ALLOWANCECAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$INPUTDATE ALLOWANCECAPTION.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$REQUESTNUMBER ALLOWANCECAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$NOTE ALLOWANCECAPTION.NOTE%TYPE := :NEW.NOTE;
  new$LASTEXTRCHANGE ALLOWANCECAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$REJECTCAUSE ALLOWANCECAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  val_maxLN$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ALLOWANCECAPTION_BI)
-- Create 10.04.2007
-- Last update 11.12.2009
-- - - - - - - - - - - - -

  if (new$id is null) then select g_Shared.nextval into new$id from dual; end if;
  if (new$AcceptorOrgRef is null) then new$AcceptorOrgRef := 0; end if;
  if (new$FacialAcc_Cls is null) then new$FacialAcc_Cls := 0; end if;
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
    then GetIntConst(-1, 3, new$BudgetRef);
  end if;

-- - - - - - - - - - - - -
-- BI_5 (TR_ALLOWANCECAPTION_BI_5)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

  if (new$Progindex is null) then new$Progindex := 110; end if;

-- - - - - - - - - - - - -
-- BI_60 (TR_ALLOWANCECAPTION_BI_60)
-- Create 08.04.2010
-- Last update 08.04.2010
-- - - - - - - - - - - - -

  IF (new$RegisterDate IS NOT NULL) THEN
    SELECT MAX(det.LineNumber)
	INTO val_maxLN$
    FROM AllowanceDetail det
      LEFT JOIN AllowanceCaption cap ON (cap.id = det.RecordIndex)
    WHERE cap.FacialAcc_Cls = new$facialacc_cls;

    IF (val_maxLN$ IS NULL) THEN
      val_maxLN$ := 1;
    ELSE
      val_maxLN$ := val_maxLN$ + 1;
	END IF;  

    FOR R$ IN (SELECT id val_det_id FROM AllowanceDetail
      WHERE RecordIndex = new$id)
    LOOP
      UPDATE AllowanceDetail SET
        LineNumber = val_maxLN$
      WHERE
        (id = R$.val_det_id) AND (LineNumber IS NULL);
      val_maxLN$ := val_maxLN$ + 1;
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_ALLOWANCECAPTION_BI_500)
-- Create 10.04.2007
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_ALLOWANCECAPTION (
    ID,
    ALLOWANCETYPE,
    ACCEPTORORGREF,
    FACIALACC_CLS,
    NUMBERGENERAL,
    NUMBERGENERALADD,
    NUMBERDOC,
    NUMBERADD,
    BEGINDATE,
    ENDDATE,
    CONSTITUTIVEDOCTYPE,
    CONSTITUTIVEDATE,
    CONSTITUTIVENUMBER,
    CONSTITUTIVEORGAN,
    REGISTERFIO,
    REGISTERJOB,
    REGISTERDATE,
    REGISTERORGAN,
    RETURNNOTIFYNUMBER,
    RETURNNOTIFYDATE,
    RETURNREJECTCAUSE,
    RETURNDATE,
    RETURNFIO,
    RETURNJOB,
    SENDERID,
    SENDERRECORDID,
    REJECT_CLS,
    NUMBERRETURNTRANZACTION,
    NUMBERREJECTTRANZACTION,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    DOCSTATEREF,
    CRYPTOSTATUS,
    PROGINDEX,
    RVERSION,
    INPUTDATE,
    REQUESTNUMBER,
    NOTE,
    LASTEXTRCHANGE,
    REJECTCAUSE
  ) VALUES (
    new$ID,
    new$ALLOWANCETYPE,
    new$ACCEPTORORGREF,
    new$FACIALACC_CLS,
    new$NUMBERGENERAL,
    new$NUMBERGENERALADD,
    new$NUMBERDOC,
    new$NUMBERADD,
    new$BEGINDATE,
    new$ENDDATE,
    new$CONSTITUTIVEDOCTYPE,
    new$CONSTITUTIVEDATE,
    new$CONSTITUTIVENUMBER,
    new$CONSTITUTIVEORGAN,
    new$REGISTERFIO,
    new$REGISTERJOB,
    new$REGISTERDATE,
    new$REGISTERORGAN,
    new$RETURNNOTIFYNUMBER,
    new$RETURNNOTIFYDATE,
    new$RETURNREJECTCAUSE,
    new$RETURNDATE,
    new$RETURNFIO,
    new$RETURNJOB,
    new$SENDERID,
    new$SENDERRECORDID,
    new$REJECT_CLS,
    new$NUMBERRETURNTRANZACTION,
    new$NUMBERREJECTTRANZACTION,
    new$BUDGETREF,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$DOCSTATEREF,
    new$CRYPTOSTATUS,
    new$PROGINDEX,
    new$RVERSION,
    new$INPUTDATE,
    new$REQUESTNUMBER,
    new$NOTE,
    new$LASTEXTRCHANGE,
    new$REJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_ALLOWANCECAPTION_AI_500)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 5000) and (RecordID = :new.ID);

END;
/

CREATE OR REPLACE TRIGGER TR_ALLOWANCECAPTION_IU
  INSTEAD OF UPDATE
  ON ALLOWANCECAPTION
  FOR EACH ROW
DECLARE
  new$ID ALLOWANCECAPTION.ID%TYPE := :NEW.ID;
  new$ALLOWANCETYPE ALLOWANCECAPTION.ALLOWANCETYPE%TYPE := :NEW.ALLOWANCETYPE;
  new$ACCEPTORORGREF ALLOWANCECAPTION.ACCEPTORORGREF%TYPE := :NEW.ACCEPTORORGREF;
  new$FACIALACC_CLS ALLOWANCECAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NUMBERGENERAL ALLOWANCECAPTION.NUMBERGENERAL%TYPE := :NEW.NUMBERGENERAL;
  new$NUMBERGENERALADD ALLOWANCECAPTION.NUMBERGENERALADD%TYPE := :NEW.NUMBERGENERALADD;
  new$NUMBERDOC ALLOWANCECAPTION.NUMBERDOC%TYPE := :NEW.NUMBERDOC;
  new$NUMBERADD ALLOWANCECAPTION.NUMBERADD%TYPE := :NEW.NUMBERADD;
  new$BEGINDATE ALLOWANCECAPTION.BEGINDATE%TYPE := :NEW.BEGINDATE;
  new$ENDDATE ALLOWANCECAPTION.ENDDATE%TYPE := :NEW.ENDDATE;
  new$CONSTITUTIVEDOCTYPE ALLOWANCECAPTION.CONSTITUTIVEDOCTYPE%TYPE := :NEW.CONSTITUTIVEDOCTYPE;
  new$CONSTITUTIVEDATE ALLOWANCECAPTION.CONSTITUTIVEDATE%TYPE := :NEW.CONSTITUTIVEDATE;
  new$CONSTITUTIVENUMBER ALLOWANCECAPTION.CONSTITUTIVENUMBER%TYPE := :NEW.CONSTITUTIVENUMBER;
  new$CONSTITUTIVEORGAN ALLOWANCECAPTION.CONSTITUTIVEORGAN%TYPE := :NEW.CONSTITUTIVEORGAN;
  new$REGISTERFIO ALLOWANCECAPTION.REGISTERFIO%TYPE := :NEW.REGISTERFIO;
  new$REGISTERJOB ALLOWANCECAPTION.REGISTERJOB%TYPE := :NEW.REGISTERJOB;
  new$REGISTERDATE ALLOWANCECAPTION.REGISTERDATE%TYPE := :NEW.REGISTERDATE;
  new$REGISTERORGAN ALLOWANCECAPTION.REGISTERORGAN%TYPE := :NEW.REGISTERORGAN;
  new$RETURNNOTIFYNUMBER ALLOWANCECAPTION.RETURNNOTIFYNUMBER%TYPE := :NEW.RETURNNOTIFYNUMBER;
  new$RETURNNOTIFYDATE ALLOWANCECAPTION.RETURNNOTIFYDATE%TYPE := :NEW.RETURNNOTIFYDATE;
  new$RETURNREJECTCAUSE ALLOWANCECAPTION.RETURNREJECTCAUSE%TYPE := :NEW.RETURNREJECTCAUSE;
  new$RETURNDATE ALLOWANCECAPTION.RETURNDATE%TYPE := :NEW.RETURNDATE;
  new$RETURNFIO ALLOWANCECAPTION.RETURNFIO%TYPE := :NEW.RETURNFIO;
  new$RETURNJOB ALLOWANCECAPTION.RETURNJOB%TYPE := :NEW.RETURNJOB;
  new$SENDERID ALLOWANCECAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID ALLOWANCECAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REJECT_CLS ALLOWANCECAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$NUMBERRETURNTRANZACTION ALLOWANCECAPTION.NUMBERRETURNTRANZACTION%TYPE := :NEW.NUMBERRETURNTRANZACTION;
  new$NUMBERREJECTTRANZACTION ALLOWANCECAPTION.NUMBERREJECTTRANZACTION%TYPE := :NEW.NUMBERREJECTTRANZACTION;
  new$BUDGETREF ALLOWANCECAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER ALLOWANCECAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ALLOWANCECAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ALLOWANCECAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ALLOWANCECAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$DOCSTATEREF ALLOWANCECAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ALLOWANCECAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$PROGINDEX ALLOWANCECAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RVERSION ALLOWANCECAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$INPUTDATE ALLOWANCECAPTION.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$REQUESTNUMBER ALLOWANCECAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$NOTE ALLOWANCECAPTION.NOTE%TYPE := :NEW.NOTE;
  new$LASTEXTRCHANGE ALLOWANCECAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$REJECTCAUSE ALLOWANCECAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  cnt$ Number(10);
  val_maxLN$ Number(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_ALLOWANCECAPTION_BU)
-- Create 10.04.2007
-- - - - - - - - - - - - -

  if (new$AcceptorOrgRef is null) then new$AcceptorOrgRef := 0; end if;
  if (new$FacialAcc_Cls is null) then new$FacialAcc_Cls := 0; end if;

  IF (new$BudgetRef <> :OLD.BudgetRef) THEN
    IF ( NOT((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL)) ) THEN
      SELECT count(ad.id) into cnt$ 
      FROM AllowanceDetail ad WHERE ad.recordindex = new$ID and ROWNUM = 1;
      IF (cnt$ > 0) THEN
        RaiseEXCEPTION('Ex_CantModufyBudget');
      END IF;  
    END IF;    
  END IF;

-- - - - - - - - - - - - -
-- BU_60 (TR_ALLOWANCECAPTION_BU_60)
-- Create 12.03.2010
-- Last update 12.03.2010
-- - - - - - - - - - - - -

  IF ((:OLD.RegisterDate IS NULL) AND (new$RegisterDate IS NOT NULL)) THEN
    SELECT MAX(det.LineNumber)
    INTO val_maxLN$
    FROM AllowanceDetail det
      LEFT JOIN AllowanceCaption cap ON (cap.id = det.RecordIndex)
    WHERE cap.FacialAcc_Cls = new$facialacc_cls ;

    IF (val_maxLN$ IS NULL) THEN
      val_maxLN$ := 1;
    ELSE
      val_maxLN$ := val_maxLN$ + 1;
    END IF;  

    FOR R$ IN (SELECT id val_det_id FROM AllowanceDetail
      WHERE RecordIndex = new$id)
    LOOP
      UPDATE AllowanceDetail SET
        LineNumber = val_maxLN$
      WHERE
        (id = R$.val_det_id) AND (LineNumber IS NULL);
      val_maxLN$ := val_maxLN$ + 1;
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (tr_Allowancecaption_BU200)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

   --      
   IF (:OLD.DOCSTATEREF <> new$DOCSTATEREF) THEN
      INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
        VALUES (new$ID, :OLD.DOCSTATEREF, new$DOCSTATEREF);
   END IF;     

-- - - - - - - - - - - - -
-- BU_700 (TR_ALLOWANCECAPTION_BU_700)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

 if (new$RVersion is null) then
   new$RVersion:=1;
 elsif ((new$RVersion = -1) and (:Old.RVersion <> -1)) then
   new$RVersion:=:Old.RVersion;
 else
   new$RVersion:=:Old.RVersion+1;
 end if;  

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_ALLOWANCECAPTION SET
    ID = new$ID,
    ALLOWANCETYPE = new$ALLOWANCETYPE,
    ACCEPTORORGREF = new$ACCEPTORORGREF,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NUMBERGENERAL = new$NUMBERGENERAL,
    NUMBERGENERALADD = new$NUMBERGENERALADD,
    NUMBERDOC = new$NUMBERDOC,
    NUMBERADD = new$NUMBERADD,
    BEGINDATE = new$BEGINDATE,
    ENDDATE = new$ENDDATE,
    CONSTITUTIVEDOCTYPE = new$CONSTITUTIVEDOCTYPE,
    CONSTITUTIVEDATE = new$CONSTITUTIVEDATE,
    CONSTITUTIVENUMBER = new$CONSTITUTIVENUMBER,
    CONSTITUTIVEORGAN = new$CONSTITUTIVEORGAN,
    REGISTERFIO = new$REGISTERFIO,
    REGISTERJOB = new$REGISTERJOB,
    REGISTERDATE = new$REGISTERDATE,
    REGISTERORGAN = new$REGISTERORGAN,
    RETURNNOTIFYNUMBER = new$RETURNNOTIFYNUMBER,
    RETURNNOTIFYDATE = new$RETURNNOTIFYDATE,
    RETURNREJECTCAUSE = new$RETURNREJECTCAUSE,
    RETURNDATE = new$RETURNDATE,
    RETURNFIO = new$RETURNFIO,
    RETURNJOB = new$RETURNJOB,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REJECT_CLS = new$REJECT_CLS,
    NUMBERRETURNTRANZACTION = new$NUMBERRETURNTRANZACTION,
    NUMBERREJECTTRANZACTION = new$NUMBERREJECTTRANZACTION,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    DOCSTATEREF = new$DOCSTATEREF,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    PROGINDEX = new$PROGINDEX,
    RVERSION = new$RVERSION,
    INPUTDATE = new$INPUTDATE,
    REQUESTNUMBER = new$REQUESTNUMBER,
    NOTE = new$NOTE,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_500 (TR_ALLOWANCECAPTION_AU_500)
-- Create 24.12.2009
-- Last update 24.12.2009
-- - - - - - - - - - - - -

  if (:new.ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (5000, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=5000) and (RecordId=:new.ID);
  end if;

END;
/
ALTER TRIGGER TR_ALLOWANCECAPTION_BU_500 ENABLE
/
commit work 
/
ALTER TRIGGER TR_CORRECTIONCAPTION_BU_500 DISABLE
/
ALTER TABLE CORRECTIONCAPTION ADD (
  TempRejectCause VARCHAR2(255)
)
/
update CORRECTIONCAPTION set
  TempRejectCause = REJECTCAUSE
/
commit work 
/
ALTER TABLE CORRECTIONCAPTION DROP (REJECTCAUSE)
/
ALTER TABLE CORRECTIONCAPTION ADD (
  REJECTCAUSE VARCHAR2(1000)
)
/
update CORRECTIONCAPTION set
  REJECTCAUSE = TempRejectCause
/
commit work 
/
ALTER TABLE CORRECTIONCAPTION DROP (TempRejectCause)
/
ALTER TRIGGER TR_CORRECTIONCAPTION_BU_500 ENABLE
/
commit work 
/
ALTER TRIGGER TR_LAYERTASKS_BU_500 DISABLE
/
ALTER TABLE LAYERTASKS ADD (
  TempRejectCause VARCHAR2(255)
)
/
update LAYERTASKS set
  TempRejectCause = REJECTCAUSE
/
commit work 
/
ALTER TABLE LAYERTASKS DROP (REJECTCAUSE)
/
ALTER TABLE LAYERTASKS ADD (
  REJECTCAUSE VARCHAR2(1000)
)
/
update LAYERTASKS set
  REJECTCAUSE = TempRejectCause
/
commit work 
/
ALTER TABLE LAYERTASKS DROP (TempRejectCause)
/
ALTER TRIGGER TR_LAYERTASKS_BU_500 ENABLE
/
commit work 
/
ALTER TRIGGER TR_ORGANIZATIONS_BU_500 DISABLE
/
-- ALTER TRIGGER TR_ORGANIZATIONS_BU
CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_IU
  INSTEAD OF UPDATE
  ON ORGANIZATIONS
  FOR EACH ROW
DECLARE
  new$ID ORGANIZATIONS.ID%TYPE := :NEW.ID;
  new$NAME ORGANIZATIONS.NAME%TYPE := :NEW.NAME;
  new$GOSNI ORGANIZATIONS.GOSNI%TYPE := :NEW.GOSNI;
  new$CITY ORGANIZATIONS.CITY%TYPE := :NEW.CITY;
  new$COUNTRY ORGANIZATIONS.COUNTRY%TYPE := :NEW.COUNTRY;
  new$PHONE ORGANIZATIONS.PHONE%TYPE := :NEW.PHONE;
  new$ADDRESS ORGANIZATIONS.ADDRESS%TYPE := :NEW.ADDRESS;
  new$ORG_CLS ORGANIZATIONS.ORG_CLS%TYPE := :NEW.ORG_CLS;
  new$INN20 ORGANIZATIONS.INN20%TYPE := :NEW.INN20;
  new$SUBINN ORGANIZATIONS.SUBINN%TYPE := :NEW.SUBINN;
  new$FACIALACC ORGANIZATIONS.FACIALACC%TYPE := :NEW.FACIALACC;
  new$REGIONCLS ORGANIZATIONS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$DIRNAME ORGANIZATIONS.DIRNAME%TYPE := :NEW.DIRNAME;
  new$BUGNAME ORGANIZATIONS.BUGNAME%TYPE := :NEW.BUGNAME;
  new$DIRPHONE ORGANIZATIONS.DIRPHONE%TYPE := :NEW.DIRPHONE;
  new$BUGPHONE ORGANIZATIONS.BUGPHONE%TYPE := :NEW.BUGPHONE;
  new$RCORG ORGANIZATIONS.RCORG%TYPE := :NEW.RCORG;
  new$CREATERUSER ORGANIZATIONS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ORGANIZATIONS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ORGANIZATIONS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ORGANIZATIONS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$INN ORGANIZATIONS.INN%TYPE := :NEW.INN;
  new$OKATO ORGANIZATIONS.OKATO%TYPE := :NEW.OKATO;
  new$EMAIL ORGANIZATIONS.EMAIL%TYPE := :NEW.EMAIL;
  new$WEBSITE ORGANIZATIONS.WEBSITE%TYPE := :NEW.WEBSITE;
  new$UFKCODE ORGANIZATIONS.UFKCODE%TYPE := :NEW.UFKCODE;
  new$ADDOKATO ORGANIZATIONS.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$SHORTNAME ORGANIZATIONS.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$RVERSION ORGANIZATIONS.RVERSION%TYPE := :NEW.RVERSION;
  new$SENDERID ORGANIZATIONS.SENDERID%TYPE := :NEW.SENDERID;
  new$KVSR ORGANIZATIONS.KVSR%TYPE := :NEW.KVSR;
  new$OKFS ORGANIZATIONS.OKFS%TYPE := :NEW.OKFS;
  new$OKOPF ORGANIZATIONS.OKOPF%TYPE := :NEW.OKOPF;
  new$OPENDATE ORGANIZATIONS.OPENDATE%TYPE := :NEW.OPENDATE;
  new$CLOSEDATE ORGANIZATIONS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$CHANGEDATE ORGANIZATIONS.CHANGEDATE%TYPE := :NEW.CHANGEDATE;
  new$GENERALORG_REF ORGANIZATIONS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$FEDERALREGIONCODE ORGANIZATIONS.FEDERALREGIONCODE%TYPE := :NEW.FEDERALREGIONCODE;
  new$ORG_TYPE ORGANIZATIONS.ORG_TYPE%TYPE := :NEW.ORG_TYPE;
  new$BUDGETREF ORGANIZATIONS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUPPLIERSTATUS ORGANIZATIONS.SUPPLIERSTATUS%TYPE := :NEW.SUPPLIERSTATUS;
  new$COUNTRYCODE ORGANIZATIONS.COUNTRYCODE%TYPE := :NEW.COUNTRYCODE;
  new$DATECLOSE ORGANIZATIONS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$ORGCODE ORGANIZATIONS.ORGCODE%TYPE := :NEW.ORGCODE;
  new$COSTAUTHORITY ORGANIZATIONS.COSTAUTHORITY%TYPE := :NEW.COSTAUTHORITY;
  new$INCOMEAUTHORITY ORGANIZATIONS.INCOMEAUTHORITY%TYPE := :NEW.INCOMEAUTHORITY;
  new$DEBTAUTHORITY ORGANIZATIONS.DEBTAUTHORITY%TYPE := :NEW.DEBTAUTHORITY;
  new$SVRAUTHORITY ORGANIZATIONS.SVRAUTHORITY%TYPE := :NEW.SVRAUTHORITY;
  new$CLIENTID ORGANIZATIONS.CLIENTID%TYPE := :NEW.CLIENTID;
  new$DATEOPEN ORGANIZATIONS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$FUID ORGANIZATIONS.FUID%TYPE := :NEW.FUID;
  new$OKPO ORGANIZATIONS.OKPO%TYPE := :NEW.OKPO;
  new$OKTMO ORGANIZATIONS.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCSTATEREF ORGANIZATIONS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ORGANIZATIONS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$OGRN ORGANIZATIONS.OGRN%TYPE := :NEW.OGRN;
  new$REJECT_CLS ORGANIZATIONS.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE ORGANIZATIONS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$EXTID ORGANIZATIONS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER ORGANIZATIONS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE ORGANIZATIONS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$REMOTEPBSCODE ORGANIZATIONS.REMOTEPBSCODE%TYPE := :NEW.REMOTEPBSCODE;
  new$REMOTENOTPBSCODE ORGANIZATIONS.REMOTENOTPBSCODE%TYPE := :NEW.REMOTENOTPBSCODE;
  new$USECHECK_CARD ORGANIZATIONS.USECHECK_CARD%TYPE := :NEW.USECHECK_CARD;
  new$EXTROOTID ORGANIZATIONS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION ORGANIZATIONS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE ORGANIZATIONS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$RECORDOWNERORGREF ORGANIZATIONS.RECORDOWNERORGREF%TYPE := :NEW.RECORDOWNERORGREF;
--
  CNT$ NUMBER(10);
  c1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (tr_organizations_bu)
-- Version 11.30.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$gosni is null) then
--     new$gosni := 0;
--   END IF;
--   if (new$city is null) then
--     getvarcharconst(-1,7,new$city);
--   END IF;
--   if (new$country is null) then
--     new$country := '';
--   END IF;
--   if (new$countrycode is null) then
--     new$countrycode := 643;
--   END IF;
--   if (new$org_cls is null) then
--     new$org_cls:= 0;
--   END IF;
--   if (new$inn20 is null) then
--     new$inn20:= '';
--   END IF;
--   if (new$rcorg is null) then
--     new$rcorg := 0;
--   END IF;
--   if (new$regioncls is null) then
--     new$regioncls := 0;
--   END IF;
--   if (new$okato is null) then
--     new$okato := 0;
--   END IF;
--   if (new$kvsr is null) then
--     new$kvsr := 0;
--   END IF;
--   if (new$okfs is null) then
--     new$okfs := 0;
--   END IF;
--   if (new$okopf is null) then
--     new$okopf := 0;
--   END IF;
--   if (new$federalregioncode is null) then
--     getintconst(-1, 27,new$federalregioncode);
--   END IF;
--   if (new$federalregioncode is null) then
--     new$federalregioncode := 0;
--   END IF;
--   if (new$budgetref is null) then
--     new$budgetref := 0;
--   END IF;
--   /*    - */
--   if (new$org_type is null) then
--     new$org_type := 20000;
--   END IF;
--   /*        */
--   if ((new$generalorg_ref is null) or (new$org_type < 10000) or (new$org_type >= 20000)) then
--     new$generalorg_ref := new$id;
--   END IF;
-- 
--   /*    10 ,      */
--   if ((new$inn <> :old.inn) or ((:old.inn is null) and (new$inn is not null))) then
--     if ((new$inn > 9999999999.9) and (new$inn20 <> '')) then
--       RaiseException('ex_wrongkpp');
--     END IF;
--   END IF;
--   if ( ((new$inn <> :old.inn) or ((:old.inn is null) and (new$inn is not null)))
--   or ( (new$inn20 <> :old.inn20) or ((:old.inn20 is null) and (new$inn20 is not null))) )
--   then
--     check_unique_organization(new$inn,  new$inn20);
--   END IF;
-- 
--   if (new$regioncls <> :old.regioncls) then
--     update dfaccountsbuhtable set
--     regioncls = new$regioncls
--     where id = any (select id from org_accounts where org_ref = new$id);
--   END IF;
--   /*      */
--   if (:old.id = 0) then
--     RaiseException('ex_cantmodifyunknownorg');
--   END IF;
--   /*        */
--   if ((new$org_type<>:old.org_type) or (new$costauthority<>:old.costauthority))
--   then
--     c1$ := new$costauthority;
--     if (new$org_type between 10100 and 10299) then
--       new$costauthority:= 1;
--     END IF;
--     if (new$org_type between 10300 and 10399) then
--       new$costauthority:= 2;
--     END IF;
--     if (new$org_type between 10400 and 10499) then
--       new$costauthority:= 4;
--     END IF;
--     if (((new$org_type between 10500 and 10599) and (new$costauthority<>16)) or
--     (((new$org_type between 10000 and 10099) or (new$org_type between 10600 and 10799))
--     and (new$costauthority=0))) then
--       new$costauthority:= 8;
--     END IF;
--     if ((new$org_type=:old.org_type) and (c1$<>new$costauthority)) then
--       RaiseException('ex_wrongcostauthority');
--     END IF;
--   END IF;
--   /*    RegionCls  ,  
--          */
--   if (new$regioncls <> :old.regioncls) then
--     update facialacc_cls fac set
--     fac.regioncls = new$regioncls
--     where
--     new$id = fac.org_ref;
-- 
--   END IF;
--   if (new$UseCheck_Card is null) then
--     new$UseCheck_Card := 0;
--   END IF;
--   if (new$RecordOwnerOrgRef is null) then
--     new$RecordOwnerOrgRef := 0;
--   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_ORGANIZATIONS_BU_10)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$FacialAcc <> :old.FacialAcc) then
    select count(id) into CNT$ from Organizations
      where (FacialAcc = new$FacialAcc) and (id <> new$id) AND (ROWNUM = 1);
    if (CNT$ <> 0) then
      RaiseException('ex_DublicateFacialAcc');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_100 (TR_ORGANIZATIONS_BU_100)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*   */
  if ((new$DateClose is not null) and (:old.DateClose is null)) then
    /*        */
    update Org_Accounts set
    DateClose = new$DateClose,
    CloseCode = CloseCode + 10
    where Org_Ref = new$Id;

  END IF;
  /*  /      */
  if (((new$DateClose is not null) and (:old.DateClose is null)) or (new$DateClose <> :old.DateClose)) then
    /*     / */
    update FacialAcc_Cls set
    DateClose = new$DateClose,
    CloseCode = CloseCode + 10
    where Org_ref = new$Id;
  END IF;
  /*   */
  if ((new$DateClose is null) and (:old.DateClose is not null)) then
    update Org_Accounts set
    CloseCode = CloseCode - 10
    where Org_Ref = new$Id;

    /*     / */
    update FacialAcc_Cls set
    DateClose = new$DateClose,
    CloseCode = CloseCode - 10
    where Org_ref = new$Id;

  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_ORGANIZATIONS_BU_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

  if (new$id <> new$GeneralOrg_Ref) then
    select count(*) into cnt$
    from Organizations o where (o.id = new$GeneralOrg_Ref) AND (ROWNUM = 1);

    if cnt$ = 0 then
      RaiseException('ex_GeneralOrgNotFound');
    end if;
  end if;

  if (new$GeneralOrg_Ref <> :old.GeneralOrg_Ref) then
    update FacialAcc_CLS set
      GeneralOrg_Ref = new$GeneralOrg_Ref
    where
      Org_Ref = new$id;
  end if;

-- - - - - - - - - - - - -
-- BU_210 (TR_ORGANIZATIONS_BU_210)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$DOCSTATEREF <> :old.DOCSTATEREF) then
    insert into StateJumpHistory(DocID, BeginStateRef, EndStateRef)
    values(new$id, :old.DOCSTATEREF, new$DOCSTATEREF);
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_ORGANIZATIONS_BU_700)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  IF (new$RVersion IS NULL) THEN
    new$RVersion := 1;
  ELSIF ( (new$RVersion = -1) AND (:OLD.RVersion <> -1) ) THEN
    new$RVersion := :OLD.RVersion;
  ELSE
    new$RVersion := :OLD.RVersion + 1;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_ORGANIZATIONS SET
    ID = new$ID,
    NAME = new$NAME,
    GOSNI = new$GOSNI,
    CITY = new$CITY,
    COUNTRY = new$COUNTRY,
    PHONE = new$PHONE,
    ADDRESS = new$ADDRESS,
    ORG_CLS = new$ORG_CLS,
    INN20 = new$INN20,
    SUBINN = new$SUBINN,
    FACIALACC = new$FACIALACC,
    REGIONCLS = new$REGIONCLS,
    DIRNAME = new$DIRNAME,
    BUGNAME = new$BUGNAME,
    DIRPHONE = new$DIRPHONE,
    BUGPHONE = new$BUGPHONE,
    RCORG = new$RCORG,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    INN = new$INN,
    OKATO = new$OKATO,
    EMAIL = new$EMAIL,
    WEBSITE = new$WEBSITE,
    UFKCODE = new$UFKCODE,
    ADDOKATO = new$ADDOKATO,
    SHORTNAME = new$SHORTNAME,
    RVERSION = new$RVERSION,
    SENDERID = new$SENDERID,
    KVSR = new$KVSR,
    OKFS = new$OKFS,
    OKOPF = new$OKOPF,
    OPENDATE = new$OPENDATE,
    CLOSEDATE = new$CLOSEDATE,
    CHANGEDATE = new$CHANGEDATE,
    GENERALORG_REF = new$GENERALORG_REF,
    FEDERALREGIONCODE = new$FEDERALREGIONCODE,
    ORG_TYPE = new$ORG_TYPE,
    BUDGETREF = new$BUDGETREF,
    SUPPLIERSTATUS = new$SUPPLIERSTATUS,
    COUNTRYCODE = new$COUNTRYCODE,
    DATECLOSE = new$DATECLOSE,
    ORGCODE = new$ORGCODE,
    COSTAUTHORITY = new$COSTAUTHORITY,
    INCOMEAUTHORITY = new$INCOMEAUTHORITY,
    DEBTAUTHORITY = new$DEBTAUTHORITY,
    SVRAUTHORITY = new$SVRAUTHORITY,
    CLIENTID = new$CLIENTID,
    DATEOPEN = new$DATEOPEN,
    FUID = new$FUID,
    OKPO = new$OKPO,
    OKTMO = new$OKTMO,
    DOCSTATEREF = new$DOCSTATEREF,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    OGRN = new$OGRN,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    REMOTEPBSCODE = new$REMOTEPBSCODE,
    REMOTENOTPBSCODE = new$REMOTENOTPBSCODE,
    USECHECK_CARD = new$USECHECK_CARD,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    RECORDOWNERORGREF = new$RECORDOWNERORGREF
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AU_100 (TR_ORGANIZATIONS_AU_100)
-- Create 27.07.2007
-- - - - - - - - - - - - -

-- Comment   / 


  /*    */
  if ((new$DateClose is not null) and (:old.DateClose is null)) then
    update Banks set DateClose = new$DateClose where (id = new$ID) and (DateClose is null);
  end if;

  /*    */
  if ((new$DateClose is null) and (:old.DateClose is not null)) then
    update Banks set DateClose = null where (id = new$ID) and (DateClose is not null);
  end if;

-- - - - - - - - - - - - -
-- AU_200 (TR_ORGANIZATIONS_AU_200)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$BudgetRef <> :old.BudgetRef) then
    update FacialAcc_CLS set
    BudgetRef = new$BudgetRef
    where
    (ORG_REF = new$id)and((BudgetRef = :old.BudgetRef)or(BudgetRef<>0));
  END IF;
  /*     ,    */
  if ((new$KVSR <> :old.KVSR)and(new$Org_Type >= 10100)and(new$Org_Type <= 10299)) then
    update KVSR set
    Org_Ref = new$id
    where
    id = new$KVSR;
  END IF;
  if (new$KVSR <> :old.KVSR) then
    update FacialAcc_CLS set
    KVSR = new$KVSR
    where
    (ORG_REF = new$id) and (KVSR = :old.KVSR);
  END IF;
  if (new$BudgetRef <> :old.BudgetRef) then
    update organizations set
    BudgetRef = new$BudgetRef
    where
    (generalorg_ref = new$id) and (id <> new$id);
  END IF;
  if (new$KVSR <> :old.KVSR) then
    update organizations set
    KVSR = new$KVSR
    where
    (generalorg_ref = new$id) and (id <> new$id);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_ORGANIZATIONS_AU_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (27, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=27) and (RecordId=new$ID);
  end if;

END;
/
ALTER TABLE TB_ORGANIZATIONS ADD (
  TempRejectCause VARCHAR2(255)
)
/

CREATE OR REPLACE VIEW ORGANIZATIONS (
  ID,
  NAME,
  GOSNI,
  CITY,
  COUNTRY,
  PHONE,
  ADDRESS,
  ORG_CLS,
  INN20,
  SUBINN,
  FACIALACC,
  REGIONCLS,
  DIRNAME,
  BUGNAME,
  DIRPHONE,
  BUGPHONE,
  RCORG,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  INN,
  OKATO,
  EMAIL,
  WEBSITE,
  UFKCODE,
  ADDOKATO,
  SHORTNAME,
  RVERSION,
  SENDERID,
  KVSR,
  OKFS,
  OKOPF,
  OPENDATE,
  CLOSEDATE,
  CHANGEDATE,
  GENERALORG_REF,
  FEDERALREGIONCODE,
  ORG_TYPE,
  BUDGETREF,
  SUPPLIERSTATUS,
  COUNTRYCODE,
  DATECLOSE,
  ORGCODE,
  COSTAUTHORITY,
  INCOMEAUTHORITY,
  DEBTAUTHORITY,
  SVRAUTHORITY,
  CLIENTID,
  DATEOPEN,
  FUID,
  OKPO,
  OKTMO,
  DOCSTATEREF,
  CRYPTOSTATUS,
  OGRN,
  REJECT_CLS,
  REJECTCAUSE,
  EXTID,
  EXTOWNER,
  EXTSYNCDATE,
  REMOTEPBSCODE,
  REMOTENOTPBSCODE,
  USECHECK_CARD,
  EXTROOTID,
  EXTVERSION,
  EXTVERSIONDATE,
  RECORDOWNERORGREF,
  TEMPREJECTCAUSE)
AS
  SELECT
    ID,
    NAME,
    GOSNI,
    CITY,
    COUNTRY,
    PHONE,
    ADDRESS,
    ORG_CLS,
    INN20,
    SUBINN,
    FACIALACC,
    REGIONCLS,
    DIRNAME,
    BUGNAME,
    DIRPHONE,
    BUGPHONE,
    RCORG,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    INN,
    OKATO,
    EMAIL,
    WEBSITE,
    UFKCODE,
    ADDOKATO,
    SHORTNAME,
    RVERSION,
    SENDERID,
    KVSR,
    OKFS,
    OKOPF,
    OPENDATE,
    CLOSEDATE,
    CHANGEDATE,
    GENERALORG_REF,
    FEDERALREGIONCODE,
    ORG_TYPE,
    BUDGETREF,
    SUPPLIERSTATUS,
    COUNTRYCODE,
    DATECLOSE,
    ORGCODE,
    COSTAUTHORITY,
    INCOMEAUTHORITY,
    DEBTAUTHORITY,
    SVRAUTHORITY,
    CLIENTID,
    DATEOPEN,
    FUID,
    OKPO,
    OKTMO,
    DOCSTATEREF,
    CRYPTOSTATUS,
    OGRN,
    REJECT_CLS,
    REJECTCAUSE,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    REMOTEPBSCODE,
    REMOTENOTPBSCODE,
    USECHECK_CARD,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    RECORDOWNERORGREF,
    TEMPREJECTCAUSE
  FROM TB_ORGANIZATIONS
/

CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_ID
  INSTEAD OF DELETE
  ON ORGANIZATIONS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_ORGANIZATIONS_BD)
-- Last update 09.06.2008
-- - - - - - - - - - - - -

  if (:old.ID = 0) then
    RaiseException('ex_CantDelUnknownOrg');
  end if;

  delete from Org_Accounts where org_ref = :old.id;
  delete from Banks where id = :old.id;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_ORGANIZATIONS
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_200 (TR_ORGANIZATIONS_AD_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

update Organizations set
    GeneralOrg_Ref = id
  where
    GeneralOrg_Ref = :old.id;

-- - - - - - - - - - - - -
-- AD_210 (TR_ORGANIZATIONS_AD_210)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*       */
  delete 
  from 
  StateJumpHistory
  where 
  DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_ORGANIZATIONS_AD_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate) values(27, :old.ID ,SYSDATE);

END;
/

CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_II
  INSTEAD OF INSERT
  ON ORGANIZATIONS
  FOR EACH ROW
DECLARE
  new$ID ORGANIZATIONS.ID%TYPE := :NEW.ID;
  new$NAME ORGANIZATIONS.NAME%TYPE := :NEW.NAME;
  new$GOSNI ORGANIZATIONS.GOSNI%TYPE := :NEW.GOSNI;
  new$CITY ORGANIZATIONS.CITY%TYPE := :NEW.CITY;
  new$COUNTRY ORGANIZATIONS.COUNTRY%TYPE := :NEW.COUNTRY;
  new$PHONE ORGANIZATIONS.PHONE%TYPE := :NEW.PHONE;
  new$ADDRESS ORGANIZATIONS.ADDRESS%TYPE := :NEW.ADDRESS;
  new$ORG_CLS ORGANIZATIONS.ORG_CLS%TYPE := :NEW.ORG_CLS;
  new$INN20 ORGANIZATIONS.INN20%TYPE := :NEW.INN20;
  new$SUBINN ORGANIZATIONS.SUBINN%TYPE := :NEW.SUBINN;
  new$FACIALACC ORGANIZATIONS.FACIALACC%TYPE := :NEW.FACIALACC;
  new$REGIONCLS ORGANIZATIONS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$DIRNAME ORGANIZATIONS.DIRNAME%TYPE := :NEW.DIRNAME;
  new$BUGNAME ORGANIZATIONS.BUGNAME%TYPE := :NEW.BUGNAME;
  new$DIRPHONE ORGANIZATIONS.DIRPHONE%TYPE := :NEW.DIRPHONE;
  new$BUGPHONE ORGANIZATIONS.BUGPHONE%TYPE := :NEW.BUGPHONE;
  new$RCORG ORGANIZATIONS.RCORG%TYPE := :NEW.RCORG;
  new$CREATERUSER ORGANIZATIONS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ORGANIZATIONS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ORGANIZATIONS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ORGANIZATIONS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$INN ORGANIZATIONS.INN%TYPE := :NEW.INN;
  new$OKATO ORGANIZATIONS.OKATO%TYPE := :NEW.OKATO;
  new$EMAIL ORGANIZATIONS.EMAIL%TYPE := :NEW.EMAIL;
  new$WEBSITE ORGANIZATIONS.WEBSITE%TYPE := :NEW.WEBSITE;
  new$UFKCODE ORGANIZATIONS.UFKCODE%TYPE := :NEW.UFKCODE;
  new$ADDOKATO ORGANIZATIONS.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$SHORTNAME ORGANIZATIONS.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$RVERSION ORGANIZATIONS.RVERSION%TYPE := :NEW.RVERSION;
  new$SENDERID ORGANIZATIONS.SENDERID%TYPE := :NEW.SENDERID;
  new$KVSR ORGANIZATIONS.KVSR%TYPE := :NEW.KVSR;
  new$OKFS ORGANIZATIONS.OKFS%TYPE := :NEW.OKFS;
  new$OKOPF ORGANIZATIONS.OKOPF%TYPE := :NEW.OKOPF;
  new$OPENDATE ORGANIZATIONS.OPENDATE%TYPE := :NEW.OPENDATE;
  new$CLOSEDATE ORGANIZATIONS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$CHANGEDATE ORGANIZATIONS.CHANGEDATE%TYPE := :NEW.CHANGEDATE;
  new$GENERALORG_REF ORGANIZATIONS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$FEDERALREGIONCODE ORGANIZATIONS.FEDERALREGIONCODE%TYPE := :NEW.FEDERALREGIONCODE;
  new$ORG_TYPE ORGANIZATIONS.ORG_TYPE%TYPE := :NEW.ORG_TYPE;
  new$BUDGETREF ORGANIZATIONS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUPPLIERSTATUS ORGANIZATIONS.SUPPLIERSTATUS%TYPE := :NEW.SUPPLIERSTATUS;
  new$COUNTRYCODE ORGANIZATIONS.COUNTRYCODE%TYPE := :NEW.COUNTRYCODE;
  new$DATECLOSE ORGANIZATIONS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$ORGCODE ORGANIZATIONS.ORGCODE%TYPE := :NEW.ORGCODE;
  new$COSTAUTHORITY ORGANIZATIONS.COSTAUTHORITY%TYPE := :NEW.COSTAUTHORITY;
  new$INCOMEAUTHORITY ORGANIZATIONS.INCOMEAUTHORITY%TYPE := :NEW.INCOMEAUTHORITY;
  new$DEBTAUTHORITY ORGANIZATIONS.DEBTAUTHORITY%TYPE := :NEW.DEBTAUTHORITY;
  new$SVRAUTHORITY ORGANIZATIONS.SVRAUTHORITY%TYPE := :NEW.SVRAUTHORITY;
  new$CLIENTID ORGANIZATIONS.CLIENTID%TYPE := :NEW.CLIENTID;
  new$DATEOPEN ORGANIZATIONS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$FUID ORGANIZATIONS.FUID%TYPE := :NEW.FUID;
  new$OKPO ORGANIZATIONS.OKPO%TYPE := :NEW.OKPO;
  new$OKTMO ORGANIZATIONS.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCSTATEREF ORGANIZATIONS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ORGANIZATIONS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$OGRN ORGANIZATIONS.OGRN%TYPE := :NEW.OGRN;
  new$REJECT_CLS ORGANIZATIONS.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE ORGANIZATIONS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$EXTID ORGANIZATIONS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER ORGANIZATIONS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE ORGANIZATIONS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$REMOTEPBSCODE ORGANIZATIONS.REMOTEPBSCODE%TYPE := :NEW.REMOTEPBSCODE;
  new$REMOTENOTPBSCODE ORGANIZATIONS.REMOTENOTPBSCODE%TYPE := :NEW.REMOTENOTPBSCODE;
  new$USECHECK_CARD ORGANIZATIONS.USECHECK_CARD%TYPE := :NEW.USECHECK_CARD;
  new$EXTROOTID ORGANIZATIONS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION ORGANIZATIONS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE ORGANIZATIONS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$RECORDOWNERORGREF ORGANIZATIONS.RECORDOWNERORGREF%TYPE := :NEW.RECORDOWNERORGREF;
  new$TEMPREJECTCAUSE ORGANIZATIONS.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  CNT$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (tr_Organizations_bi)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$FUID is null) then
    new$FUID := new$id;
  END IF;
  if (new$GOSNI is null) then
    new$GOSNI := 0;
  END IF;
  if (new$Name is null) then
    new$Name := '  ';
  END IF;
  if (new$City is null) then
    GetVarcharConst(-1,7,new$City);
  END IF;
  if (new$COUNTRY is null) then
    new$COUNTRY := '';
  END IF;
  if (new$CountryCode is null) then
    new$CountryCode := 643;
  END IF;
  if (new$ORG_CLS is NULL) then
    new$ORG_CLS:= 0;
  END IF;
  if (new$SubINN is null) then
    new$SubINN:= 0;
  END IF;
  if (new$INN20 is null) then
    new$INN20:= '';
  END IF;
  if (new$RCOrg is null) then
    new$RCOrg := 0;
  END IF;
  if (new$RegionCls is null) then
    new$RegionCls := 0;
  END IF;
  if (new$OKATO is null) then
    new$OKATO := 0;
  END IF;
  if (new$KVSR is null) then
    new$KVSR := 0;
  END IF;
  if (new$OKFS is null) then
    new$OKFS := 0;
  END IF;
  if (new$OKOPF is null) then
    new$OKOPF := 0;
  END IF;
  if (new$FederalRegionCode is null) then
    GetIntConst(-1, 27,new$FederalRegionCode);
  END IF;
  if (new$FederalRegionCode is null) then
    new$FederalRegionCode := 0;
  END IF;
  if (new$BudgetRef is null) then
    new$BudgetRef := 0;
  END IF;
  /*    - */
  if (new$org_type is null) then
    new$org_type := 20000;
  END IF;
  /*        */
  if ((new$generalorg_ref is null) or (new$org_type < 10000) or (new$org_type >= 20000)) then
    new$generalorg_ref := new$id;
  END IF;
  /*    10 ,      */
  if ((new$INN > 9999999999.9) and (new$INN20 <> '') and (new$INN20 is not null)) then
    RaiseException('EX_WRONGKPP');
  END IF;
  check_unique_organization(new$inn,  new$inn20);
  if (new$CostAuthority is null) then
    new$CostAuthority:= 0;
  END IF;
  if (new$IncomeAuthority is null) then
    new$IncomeAuthority := 0;
  END IF;
  if (new$DebtAuthority is null) then
    new$DebtAuthority := 0;
  END IF;
  if (new$SVRAuthority is null) then
    new$SVRAuthority := 0;
  END IF;
  /*        */
  if (new$Org_Type is not null)
  then
    if (new$Org_Type between 10100 and 10299) then
      new$CostAuthority:= 1;
    END IF;
    if (new$Org_Type between 10300 and 10399) then
      new$CostAuthority:= 2;
    END IF;
    if (new$Org_Type between 10400 and 10499) then
      new$CostAuthority:= 4;
    END IF;
    if (((new$Org_Type between 10500 and 10599) and (new$CostAuthority<>16)) or
    (((new$Org_Type between 10000 and 10099) or (new$Org_Type between 10600 and 10799))
    and (new$CostAuthority=0))) then
      new$CostAuthority:= 8;

    END IF;
  END IF;
  if (new$UseCheck_Card is null) then
    new$UseCheck_Card := 0;
  END IF;
  if (new$RecordOwnerOrgRef is null) then
    new$RecordOwnerOrgRef := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_ORGANIZATIONS_BI_10)
-- Last update 19.10.2006
-- - - - - - - - - - - - -

  if (new$FacialAcc is not null) then
    select count(id) into cnt$ from Organizations where (FacialAcc = new$FacialAcc) AND (ROWNUM = 1);
    if (cnt$ <> 0) then RaiseException('ex_DublicateFacialAcc'); end if;
  end if;

-- - - - - - - - - - - - -
-- BI_200 (TR_ORGANIZATIONS_BI_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

  if (new$id <> new$GeneralOrg_Ref) then
    select count(*) into cnt$
    from Organizations o where (o.id = new$GeneralOrg_Ref) AND (ROWNUM = 1);

    if cnt$ = 0 then
      RaiseException('ex_GeneralOrgNotFound');
    end if;

    /*       ,     */
    if (new$KVSR = 0) then
      select o.KVSR into new$KVSR
      from Organizations o
      where o.id = new$GeneralOrg_Ref;
    end if;
  end if;

-- - - - - - - - - - - - -
-- BI_500 (TR_ORGANIZATIONS_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_ORGANIZATIONS (
    ID,
    NAME,
    GOSNI,
    CITY,
    COUNTRY,
    PHONE,
    ADDRESS,
    ORG_CLS,
    INN20,
    SUBINN,
    FACIALACC,
    REGIONCLS,
    DIRNAME,
    BUGNAME,
    DIRPHONE,
    BUGPHONE,
    RCORG,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    INN,
    OKATO,
    EMAIL,
    WEBSITE,
    UFKCODE,
    ADDOKATO,
    SHORTNAME,
    RVERSION,
    SENDERID,
    KVSR,
    OKFS,
    OKOPF,
    OPENDATE,
    CLOSEDATE,
    CHANGEDATE,
    GENERALORG_REF,
    FEDERALREGIONCODE,
    ORG_TYPE,
    BUDGETREF,
    SUPPLIERSTATUS,
    COUNTRYCODE,
    DATECLOSE,
    ORGCODE,
    COSTAUTHORITY,
    INCOMEAUTHORITY,
    DEBTAUTHORITY,
    SVRAUTHORITY,
    CLIENTID,
    DATEOPEN,
    FUID,
    OKPO,
    OKTMO,
    DOCSTATEREF,
    CRYPTOSTATUS,
    OGRN,
    REJECT_CLS,
    REJECTCAUSE,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    REMOTEPBSCODE,
    REMOTENOTPBSCODE,
    USECHECK_CARD,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    RECORDOWNERORGREF,
    TEMPREJECTCAUSE
  ) VALUES (
    new$ID,
    new$NAME,
    new$GOSNI,
    new$CITY,
    new$COUNTRY,
    new$PHONE,
    new$ADDRESS,
    new$ORG_CLS,
    new$INN20,
    new$SUBINN,
    new$FACIALACC,
    new$REGIONCLS,
    new$DIRNAME,
    new$BUGNAME,
    new$DIRPHONE,
    new$BUGPHONE,
    new$RCORG,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$INN,
    new$OKATO,
    new$EMAIL,
    new$WEBSITE,
    new$UFKCODE,
    new$ADDOKATO,
    new$SHORTNAME,
    new$RVERSION,
    new$SENDERID,
    new$KVSR,
    new$OKFS,
    new$OKOPF,
    new$OPENDATE,
    new$CLOSEDATE,
    new$CHANGEDATE,
    new$GENERALORG_REF,
    new$FEDERALREGIONCODE,
    new$ORG_TYPE,
    new$BUDGETREF,
    new$SUPPLIERSTATUS,
    new$COUNTRYCODE,
    new$DATECLOSE,
    new$ORGCODE,
    new$COSTAUTHORITY,
    new$INCOMEAUTHORITY,
    new$DEBTAUTHORITY,
    new$SVRAUTHORITY,
    new$CLIENTID,
    new$DATEOPEN,
    new$FUID,
    new$OKPO,
    new$OKTMO,
    new$DOCSTATEREF,
    new$CRYPTOSTATUS,
    new$OGRN,
    new$REJECT_CLS,
    new$REJECTCAUSE,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$REMOTEPBSCODE,
    new$REMOTENOTPBSCODE,
    new$USECHECK_CARD,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$RECORDOWNERORGREF,
    new$TEMPREJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_ORGANIZATIONS_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 27) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_IU
  INSTEAD OF UPDATE
  ON ORGANIZATIONS
  FOR EACH ROW
DECLARE
  new$ID ORGANIZATIONS.ID%TYPE := :NEW.ID;
  new$NAME ORGANIZATIONS.NAME%TYPE := :NEW.NAME;
  new$GOSNI ORGANIZATIONS.GOSNI%TYPE := :NEW.GOSNI;
  new$CITY ORGANIZATIONS.CITY%TYPE := :NEW.CITY;
  new$COUNTRY ORGANIZATIONS.COUNTRY%TYPE := :NEW.COUNTRY;
  new$PHONE ORGANIZATIONS.PHONE%TYPE := :NEW.PHONE;
  new$ADDRESS ORGANIZATIONS.ADDRESS%TYPE := :NEW.ADDRESS;
  new$ORG_CLS ORGANIZATIONS.ORG_CLS%TYPE := :NEW.ORG_CLS;
  new$INN20 ORGANIZATIONS.INN20%TYPE := :NEW.INN20;
  new$SUBINN ORGANIZATIONS.SUBINN%TYPE := :NEW.SUBINN;
  new$FACIALACC ORGANIZATIONS.FACIALACC%TYPE := :NEW.FACIALACC;
  new$REGIONCLS ORGANIZATIONS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$DIRNAME ORGANIZATIONS.DIRNAME%TYPE := :NEW.DIRNAME;
  new$BUGNAME ORGANIZATIONS.BUGNAME%TYPE := :NEW.BUGNAME;
  new$DIRPHONE ORGANIZATIONS.DIRPHONE%TYPE := :NEW.DIRPHONE;
  new$BUGPHONE ORGANIZATIONS.BUGPHONE%TYPE := :NEW.BUGPHONE;
  new$RCORG ORGANIZATIONS.RCORG%TYPE := :NEW.RCORG;
  new$CREATERUSER ORGANIZATIONS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ORGANIZATIONS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ORGANIZATIONS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ORGANIZATIONS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$INN ORGANIZATIONS.INN%TYPE := :NEW.INN;
  new$OKATO ORGANIZATIONS.OKATO%TYPE := :NEW.OKATO;
  new$EMAIL ORGANIZATIONS.EMAIL%TYPE := :NEW.EMAIL;
  new$WEBSITE ORGANIZATIONS.WEBSITE%TYPE := :NEW.WEBSITE;
  new$UFKCODE ORGANIZATIONS.UFKCODE%TYPE := :NEW.UFKCODE;
  new$ADDOKATO ORGANIZATIONS.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$SHORTNAME ORGANIZATIONS.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$RVERSION ORGANIZATIONS.RVERSION%TYPE := :NEW.RVERSION;
  new$SENDERID ORGANIZATIONS.SENDERID%TYPE := :NEW.SENDERID;
  new$KVSR ORGANIZATIONS.KVSR%TYPE := :NEW.KVSR;
  new$OKFS ORGANIZATIONS.OKFS%TYPE := :NEW.OKFS;
  new$OKOPF ORGANIZATIONS.OKOPF%TYPE := :NEW.OKOPF;
  new$OPENDATE ORGANIZATIONS.OPENDATE%TYPE := :NEW.OPENDATE;
  new$CLOSEDATE ORGANIZATIONS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$CHANGEDATE ORGANIZATIONS.CHANGEDATE%TYPE := :NEW.CHANGEDATE;
  new$GENERALORG_REF ORGANIZATIONS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$FEDERALREGIONCODE ORGANIZATIONS.FEDERALREGIONCODE%TYPE := :NEW.FEDERALREGIONCODE;
  new$ORG_TYPE ORGANIZATIONS.ORG_TYPE%TYPE := :NEW.ORG_TYPE;
  new$BUDGETREF ORGANIZATIONS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUPPLIERSTATUS ORGANIZATIONS.SUPPLIERSTATUS%TYPE := :NEW.SUPPLIERSTATUS;
  new$COUNTRYCODE ORGANIZATIONS.COUNTRYCODE%TYPE := :NEW.COUNTRYCODE;
  new$DATECLOSE ORGANIZATIONS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$ORGCODE ORGANIZATIONS.ORGCODE%TYPE := :NEW.ORGCODE;
  new$COSTAUTHORITY ORGANIZATIONS.COSTAUTHORITY%TYPE := :NEW.COSTAUTHORITY;
  new$INCOMEAUTHORITY ORGANIZATIONS.INCOMEAUTHORITY%TYPE := :NEW.INCOMEAUTHORITY;
  new$DEBTAUTHORITY ORGANIZATIONS.DEBTAUTHORITY%TYPE := :NEW.DEBTAUTHORITY;
  new$SVRAUTHORITY ORGANIZATIONS.SVRAUTHORITY%TYPE := :NEW.SVRAUTHORITY;
  new$CLIENTID ORGANIZATIONS.CLIENTID%TYPE := :NEW.CLIENTID;
  new$DATEOPEN ORGANIZATIONS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$FUID ORGANIZATIONS.FUID%TYPE := :NEW.FUID;
  new$OKPO ORGANIZATIONS.OKPO%TYPE := :NEW.OKPO;
  new$OKTMO ORGANIZATIONS.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCSTATEREF ORGANIZATIONS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ORGANIZATIONS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$OGRN ORGANIZATIONS.OGRN%TYPE := :NEW.OGRN;
  new$REJECT_CLS ORGANIZATIONS.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE ORGANIZATIONS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$EXTID ORGANIZATIONS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER ORGANIZATIONS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE ORGANIZATIONS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$REMOTEPBSCODE ORGANIZATIONS.REMOTEPBSCODE%TYPE := :NEW.REMOTEPBSCODE;
  new$REMOTENOTPBSCODE ORGANIZATIONS.REMOTENOTPBSCODE%TYPE := :NEW.REMOTENOTPBSCODE;
  new$USECHECK_CARD ORGANIZATIONS.USECHECK_CARD%TYPE := :NEW.USECHECK_CARD;
  new$EXTROOTID ORGANIZATIONS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION ORGANIZATIONS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE ORGANIZATIONS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$RECORDOWNERORGREF ORGANIZATIONS.RECORDOWNERORGREF%TYPE := :NEW.RECORDOWNERORGREF;
  new$TEMPREJECTCAUSE ORGANIZATIONS.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  CNT$ NUMBER(10);
  c1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (tr_organizations_bu)
-- Version 11.30.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$gosni is null) then
--     new$gosni := 0;
--   END IF;
--   if (new$city is null) then
--     getvarcharconst(-1,7,new$city);
--   END IF;
--   if (new$country is null) then
--     new$country := '';
--   END IF;
--   if (new$countrycode is null) then
--     new$countrycode := 643;
--   END IF;
--   if (new$org_cls is null) then
--     new$org_cls:= 0;
--   END IF;
--   if (new$inn20 is null) then
--     new$inn20:= '';
--   END IF;
--   if (new$rcorg is null) then
--     new$rcorg := 0;
--   END IF;
--   if (new$regioncls is null) then
--     new$regioncls := 0;
--   END IF;
--   if (new$okato is null) then
--     new$okato := 0;
--   END IF;
--   if (new$kvsr is null) then
--     new$kvsr := 0;
--   END IF;
--   if (new$okfs is null) then
--     new$okfs := 0;
--   END IF;
--   if (new$okopf is null) then
--     new$okopf := 0;
--   END IF;
--   if (new$federalregioncode is null) then
--     getintconst(-1, 27,new$federalregioncode);
--   END IF;
--   if (new$federalregioncode is null) then
--     new$federalregioncode := 0;
--   END IF;
--   if (new$budgetref is null) then
--     new$budgetref := 0;
--   END IF;
--   /*    - */
--   if (new$org_type is null) then
--     new$org_type := 20000;
--   END IF;
--   /*        */
--   if ((new$generalorg_ref is null) or (new$org_type < 10000) or (new$org_type >= 20000)) then
--     new$generalorg_ref := new$id;
--   END IF;
-- 
--   /*    10 ,      */
--   if ((new$inn <> :old.inn) or ((:old.inn is null) and (new$inn is not null))) then
--     if ((new$inn > 9999999999.9) and (new$inn20 <> '')) then
--       RaiseException('ex_wrongkpp');
--     END IF;
--   END IF;
--   if ( ((new$inn <> :old.inn) or ((:old.inn is null) and (new$inn is not null)))
--   or ( (new$inn20 <> :old.inn20) or ((:old.inn20 is null) and (new$inn20 is not null))) )
--   then
--     check_unique_organization(new$inn,  new$inn20);
--   END IF;
-- 
--   if (new$regioncls <> :old.regioncls) then
--     update dfaccountsbuhtable set
--     regioncls = new$regioncls
--     where id = any (select id from org_accounts where org_ref = new$id);
--   END IF;
--   /*      */
--   if (:old.id = 0) then
--     RaiseException('ex_cantmodifyunknownorg');
--   END IF;
--   /*        */
--   if ((new$org_type<>:old.org_type) or (new$costauthority<>:old.costauthority))
--   then
--     c1$ := new$costauthority;
--     if (new$org_type between 10100 and 10299) then
--       new$costauthority:= 1;
--     END IF;
--     if (new$org_type between 10300 and 10399) then
--       new$costauthority:= 2;
--     END IF;
--     if (new$org_type between 10400 and 10499) then
--       new$costauthority:= 4;
--     END IF;
--     if (((new$org_type between 10500 and 10599) and (new$costauthority<>16)) or
--     (((new$org_type between 10000 and 10099) or (new$org_type between 10600 and 10799))
--     and (new$costauthority=0))) then
--       new$costauthority:= 8;
--     END IF;
--     if ((new$org_type=:old.org_type) and (c1$<>new$costauthority)) then
--       RaiseException('ex_wrongcostauthority');
--     END IF;
--   END IF;
--   /*    RegionCls  ,  
--          */
--   if (new$regioncls <> :old.regioncls) then
--     update facialacc_cls fac set
--     fac.regioncls = new$regioncls
--     where
--     new$id = fac.org_ref;
-- 
--   END IF;
--   if (new$UseCheck_Card is null) then
--     new$UseCheck_Card := 0;
--   END IF;
--   if (new$RecordOwnerOrgRef is null) then
--     new$RecordOwnerOrgRef := 0;
--   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_ORGANIZATIONS_BU_10)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$FacialAcc <> :old.FacialAcc) then
    select count(id) into CNT$ from Organizations
      where (FacialAcc = new$FacialAcc) and (id <> new$id) AND (ROWNUM = 1);
    if (CNT$ <> 0) then
      RaiseException('ex_DublicateFacialAcc');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_100 (TR_ORGANIZATIONS_BU_100)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*   */
  if ((new$DateClose is not null) and (:old.DateClose is null)) then
    /*        */
    update Org_Accounts set
    DateClose = new$DateClose,
    CloseCode = CloseCode + 10
    where Org_Ref = new$Id;

  END IF;
  /*  /      */
  if (((new$DateClose is not null) and (:old.DateClose is null)) or (new$DateClose <> :old.DateClose)) then
    /*     / */
    update FacialAcc_Cls set
    DateClose = new$DateClose,
    CloseCode = CloseCode + 10
    where Org_ref = new$Id;
  END IF;
  /*   */
  if ((new$DateClose is null) and (:old.DateClose is not null)) then
    update Org_Accounts set
    CloseCode = CloseCode - 10
    where Org_Ref = new$Id;

    /*     / */
    update FacialAcc_Cls set
    DateClose = new$DateClose,
    CloseCode = CloseCode - 10
    where Org_ref = new$Id;

  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_ORGANIZATIONS_BU_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

  if (new$id <> new$GeneralOrg_Ref) then
    select count(*) into cnt$
    from Organizations o where (o.id = new$GeneralOrg_Ref) AND (ROWNUM = 1);

    if cnt$ = 0 then
      RaiseException('ex_GeneralOrgNotFound');
    end if;
  end if;

  if (new$GeneralOrg_Ref <> :old.GeneralOrg_Ref) then
    update FacialAcc_CLS set
      GeneralOrg_Ref = new$GeneralOrg_Ref
    where
      Org_Ref = new$id;
  end if;

-- - - - - - - - - - - - -
-- BU_210 (TR_ORGANIZATIONS_BU_210)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$DOCSTATEREF <> :old.DOCSTATEREF) then
    insert into StateJumpHistory(DocID, BeginStateRef, EndStateRef)
    values(new$id, :old.DOCSTATEREF, new$DOCSTATEREF);
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_ORGANIZATIONS_BU_700)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  IF (new$RVersion IS NULL) THEN
    new$RVersion := 1;
  ELSIF ( (new$RVersion = -1) AND (:OLD.RVersion <> -1) ) THEN
    new$RVersion := :OLD.RVersion;
  ELSE
    new$RVersion := :OLD.RVersion + 1;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_ORGANIZATIONS SET
    ID = new$ID,
    NAME = new$NAME,
    GOSNI = new$GOSNI,
    CITY = new$CITY,
    COUNTRY = new$COUNTRY,
    PHONE = new$PHONE,
    ADDRESS = new$ADDRESS,
    ORG_CLS = new$ORG_CLS,
    INN20 = new$INN20,
    SUBINN = new$SUBINN,
    FACIALACC = new$FACIALACC,
    REGIONCLS = new$REGIONCLS,
    DIRNAME = new$DIRNAME,
    BUGNAME = new$BUGNAME,
    DIRPHONE = new$DIRPHONE,
    BUGPHONE = new$BUGPHONE,
    RCORG = new$RCORG,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    INN = new$INN,
    OKATO = new$OKATO,
    EMAIL = new$EMAIL,
    WEBSITE = new$WEBSITE,
    UFKCODE = new$UFKCODE,
    ADDOKATO = new$ADDOKATO,
    SHORTNAME = new$SHORTNAME,
    RVERSION = new$RVERSION,
    SENDERID = new$SENDERID,
    KVSR = new$KVSR,
    OKFS = new$OKFS,
    OKOPF = new$OKOPF,
    OPENDATE = new$OPENDATE,
    CLOSEDATE = new$CLOSEDATE,
    CHANGEDATE = new$CHANGEDATE,
    GENERALORG_REF = new$GENERALORG_REF,
    FEDERALREGIONCODE = new$FEDERALREGIONCODE,
    ORG_TYPE = new$ORG_TYPE,
    BUDGETREF = new$BUDGETREF,
    SUPPLIERSTATUS = new$SUPPLIERSTATUS,
    COUNTRYCODE = new$COUNTRYCODE,
    DATECLOSE = new$DATECLOSE,
    ORGCODE = new$ORGCODE,
    COSTAUTHORITY = new$COSTAUTHORITY,
    INCOMEAUTHORITY = new$INCOMEAUTHORITY,
    DEBTAUTHORITY = new$DEBTAUTHORITY,
    SVRAUTHORITY = new$SVRAUTHORITY,
    CLIENTID = new$CLIENTID,
    DATEOPEN = new$DATEOPEN,
    FUID = new$FUID,
    OKPO = new$OKPO,
    OKTMO = new$OKTMO,
    DOCSTATEREF = new$DOCSTATEREF,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    OGRN = new$OGRN,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    REMOTEPBSCODE = new$REMOTEPBSCODE,
    REMOTENOTPBSCODE = new$REMOTENOTPBSCODE,
    USECHECK_CARD = new$USECHECK_CARD,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    RECORDOWNERORGREF = new$RECORDOWNERORGREF,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AU_100 (TR_ORGANIZATIONS_AU_100)
-- Create 27.07.2007
-- - - - - - - - - - - - -

-- Comment   / 


  /*    */
  if ((new$DateClose is not null) and (:old.DateClose is null)) then
    update Banks set DateClose = new$DateClose where (id = new$ID) and (DateClose is null);
  end if;

  /*    */
  if ((new$DateClose is null) and (:old.DateClose is not null)) then
    update Banks set DateClose = null where (id = new$ID) and (DateClose is not null);
  end if;

-- - - - - - - - - - - - -
-- AU_200 (TR_ORGANIZATIONS_AU_200)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$BudgetRef <> :old.BudgetRef) then
    update FacialAcc_CLS set
    BudgetRef = new$BudgetRef
    where
    (ORG_REF = new$id)and((BudgetRef = :old.BudgetRef)or(BudgetRef<>0));
  END IF;
  /*     ,    */
  if ((new$KVSR <> :old.KVSR)and(new$Org_Type >= 10100)and(new$Org_Type <= 10299)) then
    update KVSR set
    Org_Ref = new$id
    where
    id = new$KVSR;
  END IF;
  if (new$KVSR <> :old.KVSR) then
    update FacialAcc_CLS set
    KVSR = new$KVSR
    where
    (ORG_REF = new$id) and (KVSR = :old.KVSR);
  END IF;
  if (new$BudgetRef <> :old.BudgetRef) then
    update organizations set
    BudgetRef = new$BudgetRef
    where
    (generalorg_ref = new$id) and (id <> new$id);
  END IF;
  if (new$KVSR <> :old.KVSR) then
    update organizations set
    KVSR = new$KVSR
    where
    (generalorg_ref = new$id) and (id <> new$id);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_ORGANIZATIONS_AU_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (27, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=27) and (RecordId=new$ID);
  end if;

END;
/
update ORGANIZATIONS set
  TempRejectCause = REJECTCAUSE
/
commit work 
/
ALTER TABLE TB_ORGANIZATIONS DROP (REJECTCAUSE)
/

CREATE OR REPLACE VIEW ORGANIZATIONS (
  ID,
  NAME,
  GOSNI,
  CITY,
  COUNTRY,
  PHONE,
  ADDRESS,
  ORG_CLS,
  INN20,
  SUBINN,
  FACIALACC,
  REGIONCLS,
  DIRNAME,
  BUGNAME,
  DIRPHONE,
  BUGPHONE,
  RCORG,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  INN,
  OKATO,
  EMAIL,
  WEBSITE,
  UFKCODE,
  ADDOKATO,
  SHORTNAME,
  RVERSION,
  SENDERID,
  KVSR,
  OKFS,
  OKOPF,
  OPENDATE,
  CLOSEDATE,
  CHANGEDATE,
  GENERALORG_REF,
  FEDERALREGIONCODE,
  ORG_TYPE,
  BUDGETREF,
  SUPPLIERSTATUS,
  COUNTRYCODE,
  DATECLOSE,
  ORGCODE,
  COSTAUTHORITY,
  INCOMEAUTHORITY,
  DEBTAUTHORITY,
  SVRAUTHORITY,
  CLIENTID,
  DATEOPEN,
  FUID,
  OKPO,
  OKTMO,
  DOCSTATEREF,
  CRYPTOSTATUS,
  OGRN,
  REJECT_CLS,
  EXTID,
  EXTOWNER,
  EXTSYNCDATE,
  REMOTEPBSCODE,
  REMOTENOTPBSCODE,
  USECHECK_CARD,
  EXTROOTID,
  EXTVERSION,
  EXTVERSIONDATE,
  RECORDOWNERORGREF,
  TEMPREJECTCAUSE)
AS
  SELECT
    ID,
    NAME,
    GOSNI,
    CITY,
    COUNTRY,
    PHONE,
    ADDRESS,
    ORG_CLS,
    INN20,
    SUBINN,
    FACIALACC,
    REGIONCLS,
    DIRNAME,
    BUGNAME,
    DIRPHONE,
    BUGPHONE,
    RCORG,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    INN,
    OKATO,
    EMAIL,
    WEBSITE,
    UFKCODE,
    ADDOKATO,
    SHORTNAME,
    RVERSION,
    SENDERID,
    KVSR,
    OKFS,
    OKOPF,
    OPENDATE,
    CLOSEDATE,
    CHANGEDATE,
    GENERALORG_REF,
    FEDERALREGIONCODE,
    ORG_TYPE,
    BUDGETREF,
    SUPPLIERSTATUS,
    COUNTRYCODE,
    DATECLOSE,
    ORGCODE,
    COSTAUTHORITY,
    INCOMEAUTHORITY,
    DEBTAUTHORITY,
    SVRAUTHORITY,
    CLIENTID,
    DATEOPEN,
    FUID,
    OKPO,
    OKTMO,
    DOCSTATEREF,
    CRYPTOSTATUS,
    OGRN,
    REJECT_CLS,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    REMOTEPBSCODE,
    REMOTENOTPBSCODE,
    USECHECK_CARD,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    RECORDOWNERORGREF,
    TEMPREJECTCAUSE
  FROM TB_ORGANIZATIONS
/

CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_ID
  INSTEAD OF DELETE
  ON ORGANIZATIONS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_ORGANIZATIONS_BD)
-- Last update 09.06.2008
-- - - - - - - - - - - - -

  if (:old.ID = 0) then
    RaiseException('ex_CantDelUnknownOrg');
  end if;

  delete from Org_Accounts where org_ref = :old.id;
  delete from Banks where id = :old.id;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_ORGANIZATIONS
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_200 (TR_ORGANIZATIONS_AD_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

update Organizations set
    GeneralOrg_Ref = id
  where
    GeneralOrg_Ref = :old.id;

-- - - - - - - - - - - - -
-- AD_210 (TR_ORGANIZATIONS_AD_210)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*       */
  delete 
  from 
  StateJumpHistory
  where 
  DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_ORGANIZATIONS_AD_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate) values(27, :old.ID ,SYSDATE);

END;
/

CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_II
  INSTEAD OF INSERT
  ON ORGANIZATIONS
  FOR EACH ROW
DECLARE
  new$ID ORGANIZATIONS.ID%TYPE := :NEW.ID;
  new$NAME ORGANIZATIONS.NAME%TYPE := :NEW.NAME;
  new$GOSNI ORGANIZATIONS.GOSNI%TYPE := :NEW.GOSNI;
  new$CITY ORGANIZATIONS.CITY%TYPE := :NEW.CITY;
  new$COUNTRY ORGANIZATIONS.COUNTRY%TYPE := :NEW.COUNTRY;
  new$PHONE ORGANIZATIONS.PHONE%TYPE := :NEW.PHONE;
  new$ADDRESS ORGANIZATIONS.ADDRESS%TYPE := :NEW.ADDRESS;
  new$ORG_CLS ORGANIZATIONS.ORG_CLS%TYPE := :NEW.ORG_CLS;
  new$INN20 ORGANIZATIONS.INN20%TYPE := :NEW.INN20;
  new$SUBINN ORGANIZATIONS.SUBINN%TYPE := :NEW.SUBINN;
  new$FACIALACC ORGANIZATIONS.FACIALACC%TYPE := :NEW.FACIALACC;
  new$REGIONCLS ORGANIZATIONS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$DIRNAME ORGANIZATIONS.DIRNAME%TYPE := :NEW.DIRNAME;
  new$BUGNAME ORGANIZATIONS.BUGNAME%TYPE := :NEW.BUGNAME;
  new$DIRPHONE ORGANIZATIONS.DIRPHONE%TYPE := :NEW.DIRPHONE;
  new$BUGPHONE ORGANIZATIONS.BUGPHONE%TYPE := :NEW.BUGPHONE;
  new$RCORG ORGANIZATIONS.RCORG%TYPE := :NEW.RCORG;
  new$CREATERUSER ORGANIZATIONS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ORGANIZATIONS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ORGANIZATIONS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ORGANIZATIONS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$INN ORGANIZATIONS.INN%TYPE := :NEW.INN;
  new$OKATO ORGANIZATIONS.OKATO%TYPE := :NEW.OKATO;
  new$EMAIL ORGANIZATIONS.EMAIL%TYPE := :NEW.EMAIL;
  new$WEBSITE ORGANIZATIONS.WEBSITE%TYPE := :NEW.WEBSITE;
  new$UFKCODE ORGANIZATIONS.UFKCODE%TYPE := :NEW.UFKCODE;
  new$ADDOKATO ORGANIZATIONS.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$SHORTNAME ORGANIZATIONS.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$RVERSION ORGANIZATIONS.RVERSION%TYPE := :NEW.RVERSION;
  new$SENDERID ORGANIZATIONS.SENDERID%TYPE := :NEW.SENDERID;
  new$KVSR ORGANIZATIONS.KVSR%TYPE := :NEW.KVSR;
  new$OKFS ORGANIZATIONS.OKFS%TYPE := :NEW.OKFS;
  new$OKOPF ORGANIZATIONS.OKOPF%TYPE := :NEW.OKOPF;
  new$OPENDATE ORGANIZATIONS.OPENDATE%TYPE := :NEW.OPENDATE;
  new$CLOSEDATE ORGANIZATIONS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$CHANGEDATE ORGANIZATIONS.CHANGEDATE%TYPE := :NEW.CHANGEDATE;
  new$GENERALORG_REF ORGANIZATIONS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$FEDERALREGIONCODE ORGANIZATIONS.FEDERALREGIONCODE%TYPE := :NEW.FEDERALREGIONCODE;
  new$ORG_TYPE ORGANIZATIONS.ORG_TYPE%TYPE := :NEW.ORG_TYPE;
  new$BUDGETREF ORGANIZATIONS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUPPLIERSTATUS ORGANIZATIONS.SUPPLIERSTATUS%TYPE := :NEW.SUPPLIERSTATUS;
  new$COUNTRYCODE ORGANIZATIONS.COUNTRYCODE%TYPE := :NEW.COUNTRYCODE;
  new$DATECLOSE ORGANIZATIONS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$ORGCODE ORGANIZATIONS.ORGCODE%TYPE := :NEW.ORGCODE;
  new$COSTAUTHORITY ORGANIZATIONS.COSTAUTHORITY%TYPE := :NEW.COSTAUTHORITY;
  new$INCOMEAUTHORITY ORGANIZATIONS.INCOMEAUTHORITY%TYPE := :NEW.INCOMEAUTHORITY;
  new$DEBTAUTHORITY ORGANIZATIONS.DEBTAUTHORITY%TYPE := :NEW.DEBTAUTHORITY;
  new$SVRAUTHORITY ORGANIZATIONS.SVRAUTHORITY%TYPE := :NEW.SVRAUTHORITY;
  new$CLIENTID ORGANIZATIONS.CLIENTID%TYPE := :NEW.CLIENTID;
  new$DATEOPEN ORGANIZATIONS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$FUID ORGANIZATIONS.FUID%TYPE := :NEW.FUID;
  new$OKPO ORGANIZATIONS.OKPO%TYPE := :NEW.OKPO;
  new$OKTMO ORGANIZATIONS.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCSTATEREF ORGANIZATIONS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ORGANIZATIONS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$OGRN ORGANIZATIONS.OGRN%TYPE := :NEW.OGRN;
  new$REJECT_CLS ORGANIZATIONS.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$EXTID ORGANIZATIONS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER ORGANIZATIONS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE ORGANIZATIONS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$REMOTEPBSCODE ORGANIZATIONS.REMOTEPBSCODE%TYPE := :NEW.REMOTEPBSCODE;
  new$REMOTENOTPBSCODE ORGANIZATIONS.REMOTENOTPBSCODE%TYPE := :NEW.REMOTENOTPBSCODE;
  new$USECHECK_CARD ORGANIZATIONS.USECHECK_CARD%TYPE := :NEW.USECHECK_CARD;
  new$EXTROOTID ORGANIZATIONS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION ORGANIZATIONS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE ORGANIZATIONS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$RECORDOWNERORGREF ORGANIZATIONS.RECORDOWNERORGREF%TYPE := :NEW.RECORDOWNERORGREF;
  new$TEMPREJECTCAUSE ORGANIZATIONS.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  CNT$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (tr_Organizations_bi)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$FUID is null) then
    new$FUID := new$id;
  END IF;
  if (new$GOSNI is null) then
    new$GOSNI := 0;
  END IF;
  if (new$Name is null) then
    new$Name := '  ';
  END IF;
  if (new$City is null) then
    GetVarcharConst(-1,7,new$City);
  END IF;
  if (new$COUNTRY is null) then
    new$COUNTRY := '';
  END IF;
  if (new$CountryCode is null) then
    new$CountryCode := 643;
  END IF;
  if (new$ORG_CLS is NULL) then
    new$ORG_CLS:= 0;
  END IF;
  if (new$SubINN is null) then
    new$SubINN:= 0;
  END IF;
  if (new$INN20 is null) then
    new$INN20:= '';
  END IF;
  if (new$RCOrg is null) then
    new$RCOrg := 0;
  END IF;
  if (new$RegionCls is null) then
    new$RegionCls := 0;
  END IF;
  if (new$OKATO is null) then
    new$OKATO := 0;
  END IF;
  if (new$KVSR is null) then
    new$KVSR := 0;
  END IF;
  if (new$OKFS is null) then
    new$OKFS := 0;
  END IF;
  if (new$OKOPF is null) then
    new$OKOPF := 0;
  END IF;
  if (new$FederalRegionCode is null) then
    GetIntConst(-1, 27,new$FederalRegionCode);
  END IF;
  if (new$FederalRegionCode is null) then
    new$FederalRegionCode := 0;
  END IF;
  if (new$BudgetRef is null) then
    new$BudgetRef := 0;
  END IF;
  /*    - */
  if (new$org_type is null) then
    new$org_type := 20000;
  END IF;
  /*        */
  if ((new$generalorg_ref is null) or (new$org_type < 10000) or (new$org_type >= 20000)) then
    new$generalorg_ref := new$id;
  END IF;
  /*    10 ,      */
  if ((new$INN > 9999999999.9) and (new$INN20 <> '') and (new$INN20 is not null)) then
    RaiseException('EX_WRONGKPP');
  END IF;
  check_unique_organization(new$inn,  new$inn20);
  if (new$CostAuthority is null) then
    new$CostAuthority:= 0;
  END IF;
  if (new$IncomeAuthority is null) then
    new$IncomeAuthority := 0;
  END IF;
  if (new$DebtAuthority is null) then
    new$DebtAuthority := 0;
  END IF;
  if (new$SVRAuthority is null) then
    new$SVRAuthority := 0;
  END IF;
  /*        */
  if (new$Org_Type is not null)
  then
    if (new$Org_Type between 10100 and 10299) then
      new$CostAuthority:= 1;
    END IF;
    if (new$Org_Type between 10300 and 10399) then
      new$CostAuthority:= 2;
    END IF;
    if (new$Org_Type between 10400 and 10499) then
      new$CostAuthority:= 4;
    END IF;
    if (((new$Org_Type between 10500 and 10599) and (new$CostAuthority<>16)) or
    (((new$Org_Type between 10000 and 10099) or (new$Org_Type between 10600 and 10799))
    and (new$CostAuthority=0))) then
      new$CostAuthority:= 8;

    END IF;
  END IF;
  if (new$UseCheck_Card is null) then
    new$UseCheck_Card := 0;
  END IF;
  if (new$RecordOwnerOrgRef is null) then
    new$RecordOwnerOrgRef := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_ORGANIZATIONS_BI_10)
-- Last update 19.10.2006
-- - - - - - - - - - - - -

  if (new$FacialAcc is not null) then
    select count(id) into cnt$ from Organizations where (FacialAcc = new$FacialAcc) AND (ROWNUM = 1);
    if (cnt$ <> 0) then RaiseException('ex_DublicateFacialAcc'); end if;
  end if;

-- - - - - - - - - - - - -
-- BI_200 (TR_ORGANIZATIONS_BI_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

  if (new$id <> new$GeneralOrg_Ref) then
    select count(*) into cnt$
    from Organizations o where (o.id = new$GeneralOrg_Ref) AND (ROWNUM = 1);

    if cnt$ = 0 then
      RaiseException('ex_GeneralOrgNotFound');
    end if;

    /*       ,     */
    if (new$KVSR = 0) then
      select o.KVSR into new$KVSR
      from Organizations o
      where o.id = new$GeneralOrg_Ref;
    end if;
  end if;

-- - - - - - - - - - - - -
-- BI_500 (TR_ORGANIZATIONS_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_ORGANIZATIONS (
    ID,
    NAME,
    GOSNI,
    CITY,
    COUNTRY,
    PHONE,
    ADDRESS,
    ORG_CLS,
    INN20,
    SUBINN,
    FACIALACC,
    REGIONCLS,
    DIRNAME,
    BUGNAME,
    DIRPHONE,
    BUGPHONE,
    RCORG,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    INN,
    OKATO,
    EMAIL,
    WEBSITE,
    UFKCODE,
    ADDOKATO,
    SHORTNAME,
    RVERSION,
    SENDERID,
    KVSR,
    OKFS,
    OKOPF,
    OPENDATE,
    CLOSEDATE,
    CHANGEDATE,
    GENERALORG_REF,
    FEDERALREGIONCODE,
    ORG_TYPE,
    BUDGETREF,
    SUPPLIERSTATUS,
    COUNTRYCODE,
    DATECLOSE,
    ORGCODE,
    COSTAUTHORITY,
    INCOMEAUTHORITY,
    DEBTAUTHORITY,
    SVRAUTHORITY,
    CLIENTID,
    DATEOPEN,
    FUID,
    OKPO,
    OKTMO,
    DOCSTATEREF,
    CRYPTOSTATUS,
    OGRN,
    REJECT_CLS,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    REMOTEPBSCODE,
    REMOTENOTPBSCODE,
    USECHECK_CARD,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    RECORDOWNERORGREF,
    TEMPREJECTCAUSE
  ) VALUES (
    new$ID,
    new$NAME,
    new$GOSNI,
    new$CITY,
    new$COUNTRY,
    new$PHONE,
    new$ADDRESS,
    new$ORG_CLS,
    new$INN20,
    new$SUBINN,
    new$FACIALACC,
    new$REGIONCLS,
    new$DIRNAME,
    new$BUGNAME,
    new$DIRPHONE,
    new$BUGPHONE,
    new$RCORG,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$INN,
    new$OKATO,
    new$EMAIL,
    new$WEBSITE,
    new$UFKCODE,
    new$ADDOKATO,
    new$SHORTNAME,
    new$RVERSION,
    new$SENDERID,
    new$KVSR,
    new$OKFS,
    new$OKOPF,
    new$OPENDATE,
    new$CLOSEDATE,
    new$CHANGEDATE,
    new$GENERALORG_REF,
    new$FEDERALREGIONCODE,
    new$ORG_TYPE,
    new$BUDGETREF,
    new$SUPPLIERSTATUS,
    new$COUNTRYCODE,
    new$DATECLOSE,
    new$ORGCODE,
    new$COSTAUTHORITY,
    new$INCOMEAUTHORITY,
    new$DEBTAUTHORITY,
    new$SVRAUTHORITY,
    new$CLIENTID,
    new$DATEOPEN,
    new$FUID,
    new$OKPO,
    new$OKTMO,
    new$DOCSTATEREF,
    new$CRYPTOSTATUS,
    new$OGRN,
    new$REJECT_CLS,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$REMOTEPBSCODE,
    new$REMOTENOTPBSCODE,
    new$USECHECK_CARD,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$RECORDOWNERORGREF,
    new$TEMPREJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_ORGANIZATIONS_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 27) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_IU
  INSTEAD OF UPDATE
  ON ORGANIZATIONS
  FOR EACH ROW
DECLARE
  new$ID ORGANIZATIONS.ID%TYPE := :NEW.ID;
  new$NAME ORGANIZATIONS.NAME%TYPE := :NEW.NAME;
  new$GOSNI ORGANIZATIONS.GOSNI%TYPE := :NEW.GOSNI;
  new$CITY ORGANIZATIONS.CITY%TYPE := :NEW.CITY;
  new$COUNTRY ORGANIZATIONS.COUNTRY%TYPE := :NEW.COUNTRY;
  new$PHONE ORGANIZATIONS.PHONE%TYPE := :NEW.PHONE;
  new$ADDRESS ORGANIZATIONS.ADDRESS%TYPE := :NEW.ADDRESS;
  new$ORG_CLS ORGANIZATIONS.ORG_CLS%TYPE := :NEW.ORG_CLS;
  new$INN20 ORGANIZATIONS.INN20%TYPE := :NEW.INN20;
  new$SUBINN ORGANIZATIONS.SUBINN%TYPE := :NEW.SUBINN;
  new$FACIALACC ORGANIZATIONS.FACIALACC%TYPE := :NEW.FACIALACC;
  new$REGIONCLS ORGANIZATIONS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$DIRNAME ORGANIZATIONS.DIRNAME%TYPE := :NEW.DIRNAME;
  new$BUGNAME ORGANIZATIONS.BUGNAME%TYPE := :NEW.BUGNAME;
  new$DIRPHONE ORGANIZATIONS.DIRPHONE%TYPE := :NEW.DIRPHONE;
  new$BUGPHONE ORGANIZATIONS.BUGPHONE%TYPE := :NEW.BUGPHONE;
  new$RCORG ORGANIZATIONS.RCORG%TYPE := :NEW.RCORG;
  new$CREATERUSER ORGANIZATIONS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ORGANIZATIONS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ORGANIZATIONS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ORGANIZATIONS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$INN ORGANIZATIONS.INN%TYPE := :NEW.INN;
  new$OKATO ORGANIZATIONS.OKATO%TYPE := :NEW.OKATO;
  new$EMAIL ORGANIZATIONS.EMAIL%TYPE := :NEW.EMAIL;
  new$WEBSITE ORGANIZATIONS.WEBSITE%TYPE := :NEW.WEBSITE;
  new$UFKCODE ORGANIZATIONS.UFKCODE%TYPE := :NEW.UFKCODE;
  new$ADDOKATO ORGANIZATIONS.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$SHORTNAME ORGANIZATIONS.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$RVERSION ORGANIZATIONS.RVERSION%TYPE := :NEW.RVERSION;
  new$SENDERID ORGANIZATIONS.SENDERID%TYPE := :NEW.SENDERID;
  new$KVSR ORGANIZATIONS.KVSR%TYPE := :NEW.KVSR;
  new$OKFS ORGANIZATIONS.OKFS%TYPE := :NEW.OKFS;
  new$OKOPF ORGANIZATIONS.OKOPF%TYPE := :NEW.OKOPF;
  new$OPENDATE ORGANIZATIONS.OPENDATE%TYPE := :NEW.OPENDATE;
  new$CLOSEDATE ORGANIZATIONS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$CHANGEDATE ORGANIZATIONS.CHANGEDATE%TYPE := :NEW.CHANGEDATE;
  new$GENERALORG_REF ORGANIZATIONS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$FEDERALREGIONCODE ORGANIZATIONS.FEDERALREGIONCODE%TYPE := :NEW.FEDERALREGIONCODE;
  new$ORG_TYPE ORGANIZATIONS.ORG_TYPE%TYPE := :NEW.ORG_TYPE;
  new$BUDGETREF ORGANIZATIONS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUPPLIERSTATUS ORGANIZATIONS.SUPPLIERSTATUS%TYPE := :NEW.SUPPLIERSTATUS;
  new$COUNTRYCODE ORGANIZATIONS.COUNTRYCODE%TYPE := :NEW.COUNTRYCODE;
  new$DATECLOSE ORGANIZATIONS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$ORGCODE ORGANIZATIONS.ORGCODE%TYPE := :NEW.ORGCODE;
  new$COSTAUTHORITY ORGANIZATIONS.COSTAUTHORITY%TYPE := :NEW.COSTAUTHORITY;
  new$INCOMEAUTHORITY ORGANIZATIONS.INCOMEAUTHORITY%TYPE := :NEW.INCOMEAUTHORITY;
  new$DEBTAUTHORITY ORGANIZATIONS.DEBTAUTHORITY%TYPE := :NEW.DEBTAUTHORITY;
  new$SVRAUTHORITY ORGANIZATIONS.SVRAUTHORITY%TYPE := :NEW.SVRAUTHORITY;
  new$CLIENTID ORGANIZATIONS.CLIENTID%TYPE := :NEW.CLIENTID;
  new$DATEOPEN ORGANIZATIONS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$FUID ORGANIZATIONS.FUID%TYPE := :NEW.FUID;
  new$OKPO ORGANIZATIONS.OKPO%TYPE := :NEW.OKPO;
  new$OKTMO ORGANIZATIONS.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCSTATEREF ORGANIZATIONS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ORGANIZATIONS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$OGRN ORGANIZATIONS.OGRN%TYPE := :NEW.OGRN;
  new$REJECT_CLS ORGANIZATIONS.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$EXTID ORGANIZATIONS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER ORGANIZATIONS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE ORGANIZATIONS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$REMOTEPBSCODE ORGANIZATIONS.REMOTEPBSCODE%TYPE := :NEW.REMOTEPBSCODE;
  new$REMOTENOTPBSCODE ORGANIZATIONS.REMOTENOTPBSCODE%TYPE := :NEW.REMOTENOTPBSCODE;
  new$USECHECK_CARD ORGANIZATIONS.USECHECK_CARD%TYPE := :NEW.USECHECK_CARD;
  new$EXTROOTID ORGANIZATIONS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION ORGANIZATIONS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE ORGANIZATIONS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$RECORDOWNERORGREF ORGANIZATIONS.RECORDOWNERORGREF%TYPE := :NEW.RECORDOWNERORGREF;
  new$TEMPREJECTCAUSE ORGANIZATIONS.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
--
  CNT$ NUMBER(10);
  c1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (tr_organizations_bu)
-- Version 11.30.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$gosni is null) then
--     new$gosni := 0;
--   END IF;
--   if (new$city is null) then
--     getvarcharconst(-1,7,new$city);
--   END IF;
--   if (new$country is null) then
--     new$country := '';
--   END IF;
--   if (new$countrycode is null) then
--     new$countrycode := 643;
--   END IF;
--   if (new$org_cls is null) then
--     new$org_cls:= 0;
--   END IF;
--   if (new$inn20 is null) then
--     new$inn20:= '';
--   END IF;
--   if (new$rcorg is null) then
--     new$rcorg := 0;
--   END IF;
--   if (new$regioncls is null) then
--     new$regioncls := 0;
--   END IF;
--   if (new$okato is null) then
--     new$okato := 0;
--   END IF;
--   if (new$kvsr is null) then
--     new$kvsr := 0;
--   END IF;
--   if (new$okfs is null) then
--     new$okfs := 0;
--   END IF;
--   if (new$okopf is null) then
--     new$okopf := 0;
--   END IF;
--   if (new$federalregioncode is null) then
--     getintconst(-1, 27,new$federalregioncode);
--   END IF;
--   if (new$federalregioncode is null) then
--     new$federalregioncode := 0;
--   END IF;
--   if (new$budgetref is null) then
--     new$budgetref := 0;
--   END IF;
--   /*    - */
--   if (new$org_type is null) then
--     new$org_type := 20000;
--   END IF;
--   /*        */
--   if ((new$generalorg_ref is null) or (new$org_type < 10000) or (new$org_type >= 20000)) then
--     new$generalorg_ref := new$id;
--   END IF;
-- 
--   /*    10 ,      */
--   if ((new$inn <> :old.inn) or ((:old.inn is null) and (new$inn is not null))) then
--     if ((new$inn > 9999999999.9) and (new$inn20 <> '')) then
--       RaiseException('ex_wrongkpp');
--     END IF;
--   END IF;
--   if ( ((new$inn <> :old.inn) or ((:old.inn is null) and (new$inn is not null)))
--   or ( (new$inn20 <> :old.inn20) or ((:old.inn20 is null) and (new$inn20 is not null))) )
--   then
--     check_unique_organization(new$inn,  new$inn20);
--   END IF;
-- 
--   if (new$regioncls <> :old.regioncls) then
--     update dfaccountsbuhtable set
--     regioncls = new$regioncls
--     where id = any (select id from org_accounts where org_ref = new$id);
--   END IF;
--   /*      */
--   if (:old.id = 0) then
--     RaiseException('ex_cantmodifyunknownorg');
--   END IF;
--   /*        */
--   if ((new$org_type<>:old.org_type) or (new$costauthority<>:old.costauthority))
--   then
--     c1$ := new$costauthority;
--     if (new$org_type between 10100 and 10299) then
--       new$costauthority:= 1;
--     END IF;
--     if (new$org_type between 10300 and 10399) then
--       new$costauthority:= 2;
--     END IF;
--     if (new$org_type between 10400 and 10499) then
--       new$costauthority:= 4;
--     END IF;
--     if (((new$org_type between 10500 and 10599) and (new$costauthority<>16)) or
--     (((new$org_type between 10000 and 10099) or (new$org_type between 10600 and 10799))
--     and (new$costauthority=0))) then
--       new$costauthority:= 8;
--     END IF;
--     if ((new$org_type=:old.org_type) and (c1$<>new$costauthority)) then
--       RaiseException('ex_wrongcostauthority');
--     END IF;
--   END IF;
--   /*    RegionCls  ,  
--          */
--   if (new$regioncls <> :old.regioncls) then
--     update facialacc_cls fac set
--     fac.regioncls = new$regioncls
--     where
--     new$id = fac.org_ref;
-- 
--   END IF;
--   if (new$UseCheck_Card is null) then
--     new$UseCheck_Card := 0;
--   END IF;
--   if (new$RecordOwnerOrgRef is null) then
--     new$RecordOwnerOrgRef := 0;
--   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_ORGANIZATIONS_BU_10)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$FacialAcc <> :old.FacialAcc) then
    select count(id) into CNT$ from Organizations
      where (FacialAcc = new$FacialAcc) and (id <> new$id) AND (ROWNUM = 1);
    if (CNT$ <> 0) then
      RaiseException('ex_DublicateFacialAcc');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_100 (TR_ORGANIZATIONS_BU_100)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*   */
  if ((new$DateClose is not null) and (:old.DateClose is null)) then
    /*        */
    update Org_Accounts set
    DateClose = new$DateClose,
    CloseCode = CloseCode + 10
    where Org_Ref = new$Id;

  END IF;
  /*  /      */
  if (((new$DateClose is not null) and (:old.DateClose is null)) or (new$DateClose <> :old.DateClose)) then
    /*     / */
    update FacialAcc_Cls set
    DateClose = new$DateClose,
    CloseCode = CloseCode + 10
    where Org_ref = new$Id;
  END IF;
  /*   */
  if ((new$DateClose is null) and (:old.DateClose is not null)) then
    update Org_Accounts set
    CloseCode = CloseCode - 10
    where Org_Ref = new$Id;

    /*     / */
    update FacialAcc_Cls set
    DateClose = new$DateClose,
    CloseCode = CloseCode - 10
    where Org_ref = new$Id;

  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_ORGANIZATIONS_BU_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

  if (new$id <> new$GeneralOrg_Ref) then
    select count(*) into cnt$
    from Organizations o where (o.id = new$GeneralOrg_Ref) AND (ROWNUM = 1);

    if cnt$ = 0 then
      RaiseException('ex_GeneralOrgNotFound');
    end if;
  end if;

  if (new$GeneralOrg_Ref <> :old.GeneralOrg_Ref) then
    update FacialAcc_CLS set
      GeneralOrg_Ref = new$GeneralOrg_Ref
    where
      Org_Ref = new$id;
  end if;

-- - - - - - - - - - - - -
-- BU_210 (TR_ORGANIZATIONS_BU_210)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$DOCSTATEREF <> :old.DOCSTATEREF) then
    insert into StateJumpHistory(DocID, BeginStateRef, EndStateRef)
    values(new$id, :old.DOCSTATEREF, new$DOCSTATEREF);
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_ORGANIZATIONS_BU_700)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  IF (new$RVersion IS NULL) THEN
    new$RVersion := 1;
  ELSIF ( (new$RVersion = -1) AND (:OLD.RVersion <> -1) ) THEN
    new$RVersion := :OLD.RVersion;
  ELSE
    new$RVersion := :OLD.RVersion + 1;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_ORGANIZATIONS SET
    ID = new$ID,
    NAME = new$NAME,
    GOSNI = new$GOSNI,
    CITY = new$CITY,
    COUNTRY = new$COUNTRY,
    PHONE = new$PHONE,
    ADDRESS = new$ADDRESS,
    ORG_CLS = new$ORG_CLS,
    INN20 = new$INN20,
    SUBINN = new$SUBINN,
    FACIALACC = new$FACIALACC,
    REGIONCLS = new$REGIONCLS,
    DIRNAME = new$DIRNAME,
    BUGNAME = new$BUGNAME,
    DIRPHONE = new$DIRPHONE,
    BUGPHONE = new$BUGPHONE,
    RCORG = new$RCORG,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    INN = new$INN,
    OKATO = new$OKATO,
    EMAIL = new$EMAIL,
    WEBSITE = new$WEBSITE,
    UFKCODE = new$UFKCODE,
    ADDOKATO = new$ADDOKATO,
    SHORTNAME = new$SHORTNAME,
    RVERSION = new$RVERSION,
    SENDERID = new$SENDERID,
    KVSR = new$KVSR,
    OKFS = new$OKFS,
    OKOPF = new$OKOPF,
    OPENDATE = new$OPENDATE,
    CLOSEDATE = new$CLOSEDATE,
    CHANGEDATE = new$CHANGEDATE,
    GENERALORG_REF = new$GENERALORG_REF,
    FEDERALREGIONCODE = new$FEDERALREGIONCODE,
    ORG_TYPE = new$ORG_TYPE,
    BUDGETREF = new$BUDGETREF,
    SUPPLIERSTATUS = new$SUPPLIERSTATUS,
    COUNTRYCODE = new$COUNTRYCODE,
    DATECLOSE = new$DATECLOSE,
    ORGCODE = new$ORGCODE,
    COSTAUTHORITY = new$COSTAUTHORITY,
    INCOMEAUTHORITY = new$INCOMEAUTHORITY,
    DEBTAUTHORITY = new$DEBTAUTHORITY,
    SVRAUTHORITY = new$SVRAUTHORITY,
    CLIENTID = new$CLIENTID,
    DATEOPEN = new$DATEOPEN,
    FUID = new$FUID,
    OKPO = new$OKPO,
    OKTMO = new$OKTMO,
    DOCSTATEREF = new$DOCSTATEREF,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    OGRN = new$OGRN,
    REJECT_CLS = new$REJECT_CLS,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    REMOTEPBSCODE = new$REMOTEPBSCODE,
    REMOTENOTPBSCODE = new$REMOTENOTPBSCODE,
    USECHECK_CARD = new$USECHECK_CARD,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    RECORDOWNERORGREF = new$RECORDOWNERORGREF,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AU_100 (TR_ORGANIZATIONS_AU_100)
-- Create 27.07.2007
-- - - - - - - - - - - - -

-- Comment   / 


  /*    */
  if ((new$DateClose is not null) and (:old.DateClose is null)) then
    update Banks set DateClose = new$DateClose where (id = new$ID) and (DateClose is null);
  end if;

  /*    */
  if ((new$DateClose is null) and (:old.DateClose is not null)) then
    update Banks set DateClose = null where (id = new$ID) and (DateClose is not null);
  end if;

-- - - - - - - - - - - - -
-- AU_200 (TR_ORGANIZATIONS_AU_200)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$BudgetRef <> :old.BudgetRef) then
    update FacialAcc_CLS set
    BudgetRef = new$BudgetRef
    where
    (ORG_REF = new$id)and((BudgetRef = :old.BudgetRef)or(BudgetRef<>0));
  END IF;
  /*     ,    */
  if ((new$KVSR <> :old.KVSR)and(new$Org_Type >= 10100)and(new$Org_Type <= 10299)) then
    update KVSR set
    Org_Ref = new$id
    where
    id = new$KVSR;
  END IF;
  if (new$KVSR <> :old.KVSR) then
    update FacialAcc_CLS set
    KVSR = new$KVSR
    where
    (ORG_REF = new$id) and (KVSR = :old.KVSR);
  END IF;
  if (new$BudgetRef <> :old.BudgetRef) then
    update organizations set
    BudgetRef = new$BudgetRef
    where
    (generalorg_ref = new$id) and (id <> new$id);
  END IF;
  if (new$KVSR <> :old.KVSR) then
    update organizations set
    KVSR = new$KVSR
    where
    (generalorg_ref = new$id) and (id <> new$id);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_ORGANIZATIONS_AU_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (27, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=27) and (RecordId=new$ID);
  end if;

END;
/
ALTER TABLE TB_ORGANIZATIONS ADD (
  REJECTCAUSE VARCHAR2(1000)
)
/

CREATE OR REPLACE VIEW ORGANIZATIONS (
  ID,
  NAME,
  GOSNI,
  CITY,
  COUNTRY,
  PHONE,
  ADDRESS,
  ORG_CLS,
  INN20,
  SUBINN,
  FACIALACC,
  REGIONCLS,
  DIRNAME,
  BUGNAME,
  DIRPHONE,
  BUGPHONE,
  RCORG,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  INN,
  OKATO,
  EMAIL,
  WEBSITE,
  UFKCODE,
  ADDOKATO,
  SHORTNAME,
  RVERSION,
  SENDERID,
  KVSR,
  OKFS,
  OKOPF,
  OPENDATE,
  CLOSEDATE,
  CHANGEDATE,
  GENERALORG_REF,
  FEDERALREGIONCODE,
  ORG_TYPE,
  BUDGETREF,
  SUPPLIERSTATUS,
  COUNTRYCODE,
  DATECLOSE,
  ORGCODE,
  COSTAUTHORITY,
  INCOMEAUTHORITY,
  DEBTAUTHORITY,
  SVRAUTHORITY,
  CLIENTID,
  DATEOPEN,
  FUID,
  OKPO,
  OKTMO,
  DOCSTATEREF,
  CRYPTOSTATUS,
  OGRN,
  REJECT_CLS,
  EXTID,
  EXTOWNER,
  EXTSYNCDATE,
  REMOTEPBSCODE,
  REMOTENOTPBSCODE,
  USECHECK_CARD,
  EXTROOTID,
  EXTVERSION,
  EXTVERSIONDATE,
  RECORDOWNERORGREF,
  TEMPREJECTCAUSE,
  REJECTCAUSE)
AS
  SELECT
    ID,
    NAME,
    GOSNI,
    CITY,
    COUNTRY,
    PHONE,
    ADDRESS,
    ORG_CLS,
    INN20,
    SUBINN,
    FACIALACC,
    REGIONCLS,
    DIRNAME,
    BUGNAME,
    DIRPHONE,
    BUGPHONE,
    RCORG,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    INN,
    OKATO,
    EMAIL,
    WEBSITE,
    UFKCODE,
    ADDOKATO,
    SHORTNAME,
    RVERSION,
    SENDERID,
    KVSR,
    OKFS,
    OKOPF,
    OPENDATE,
    CLOSEDATE,
    CHANGEDATE,
    GENERALORG_REF,
    FEDERALREGIONCODE,
    ORG_TYPE,
    BUDGETREF,
    SUPPLIERSTATUS,
    COUNTRYCODE,
    DATECLOSE,
    ORGCODE,
    COSTAUTHORITY,
    INCOMEAUTHORITY,
    DEBTAUTHORITY,
    SVRAUTHORITY,
    CLIENTID,
    DATEOPEN,
    FUID,
    OKPO,
    OKTMO,
    DOCSTATEREF,
    CRYPTOSTATUS,
    OGRN,
    REJECT_CLS,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    REMOTEPBSCODE,
    REMOTENOTPBSCODE,
    USECHECK_CARD,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    RECORDOWNERORGREF,
    TEMPREJECTCAUSE,
    REJECTCAUSE
  FROM TB_ORGANIZATIONS
/

CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_ID
  INSTEAD OF DELETE
  ON ORGANIZATIONS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_ORGANIZATIONS_BD)
-- Last update 09.06.2008
-- - - - - - - - - - - - -

  if (:old.ID = 0) then
    RaiseException('ex_CantDelUnknownOrg');
  end if;

  delete from Org_Accounts where org_ref = :old.id;
  delete from Banks where id = :old.id;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_ORGANIZATIONS
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_200 (TR_ORGANIZATIONS_AD_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

update Organizations set
    GeneralOrg_Ref = id
  where
    GeneralOrg_Ref = :old.id;

-- - - - - - - - - - - - -
-- AD_210 (TR_ORGANIZATIONS_AD_210)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*       */
  delete 
  from 
  StateJumpHistory
  where 
  DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_ORGANIZATIONS_AD_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate) values(27, :old.ID ,SYSDATE);

END;
/

CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_II
  INSTEAD OF INSERT
  ON ORGANIZATIONS
  FOR EACH ROW
DECLARE
  new$ID ORGANIZATIONS.ID%TYPE := :NEW.ID;
  new$NAME ORGANIZATIONS.NAME%TYPE := :NEW.NAME;
  new$GOSNI ORGANIZATIONS.GOSNI%TYPE := :NEW.GOSNI;
  new$CITY ORGANIZATIONS.CITY%TYPE := :NEW.CITY;
  new$COUNTRY ORGANIZATIONS.COUNTRY%TYPE := :NEW.COUNTRY;
  new$PHONE ORGANIZATIONS.PHONE%TYPE := :NEW.PHONE;
  new$ADDRESS ORGANIZATIONS.ADDRESS%TYPE := :NEW.ADDRESS;
  new$ORG_CLS ORGANIZATIONS.ORG_CLS%TYPE := :NEW.ORG_CLS;
  new$INN20 ORGANIZATIONS.INN20%TYPE := :NEW.INN20;
  new$SUBINN ORGANIZATIONS.SUBINN%TYPE := :NEW.SUBINN;
  new$FACIALACC ORGANIZATIONS.FACIALACC%TYPE := :NEW.FACIALACC;
  new$REGIONCLS ORGANIZATIONS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$DIRNAME ORGANIZATIONS.DIRNAME%TYPE := :NEW.DIRNAME;
  new$BUGNAME ORGANIZATIONS.BUGNAME%TYPE := :NEW.BUGNAME;
  new$DIRPHONE ORGANIZATIONS.DIRPHONE%TYPE := :NEW.DIRPHONE;
  new$BUGPHONE ORGANIZATIONS.BUGPHONE%TYPE := :NEW.BUGPHONE;
  new$RCORG ORGANIZATIONS.RCORG%TYPE := :NEW.RCORG;
  new$CREATERUSER ORGANIZATIONS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ORGANIZATIONS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ORGANIZATIONS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ORGANIZATIONS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$INN ORGANIZATIONS.INN%TYPE := :NEW.INN;
  new$OKATO ORGANIZATIONS.OKATO%TYPE := :NEW.OKATO;
  new$EMAIL ORGANIZATIONS.EMAIL%TYPE := :NEW.EMAIL;
  new$WEBSITE ORGANIZATIONS.WEBSITE%TYPE := :NEW.WEBSITE;
  new$UFKCODE ORGANIZATIONS.UFKCODE%TYPE := :NEW.UFKCODE;
  new$ADDOKATO ORGANIZATIONS.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$SHORTNAME ORGANIZATIONS.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$RVERSION ORGANIZATIONS.RVERSION%TYPE := :NEW.RVERSION;
  new$SENDERID ORGANIZATIONS.SENDERID%TYPE := :NEW.SENDERID;
  new$KVSR ORGANIZATIONS.KVSR%TYPE := :NEW.KVSR;
  new$OKFS ORGANIZATIONS.OKFS%TYPE := :NEW.OKFS;
  new$OKOPF ORGANIZATIONS.OKOPF%TYPE := :NEW.OKOPF;
  new$OPENDATE ORGANIZATIONS.OPENDATE%TYPE := :NEW.OPENDATE;
  new$CLOSEDATE ORGANIZATIONS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$CHANGEDATE ORGANIZATIONS.CHANGEDATE%TYPE := :NEW.CHANGEDATE;
  new$GENERALORG_REF ORGANIZATIONS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$FEDERALREGIONCODE ORGANIZATIONS.FEDERALREGIONCODE%TYPE := :NEW.FEDERALREGIONCODE;
  new$ORG_TYPE ORGANIZATIONS.ORG_TYPE%TYPE := :NEW.ORG_TYPE;
  new$BUDGETREF ORGANIZATIONS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUPPLIERSTATUS ORGANIZATIONS.SUPPLIERSTATUS%TYPE := :NEW.SUPPLIERSTATUS;
  new$COUNTRYCODE ORGANIZATIONS.COUNTRYCODE%TYPE := :NEW.COUNTRYCODE;
  new$DATECLOSE ORGANIZATIONS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$ORGCODE ORGANIZATIONS.ORGCODE%TYPE := :NEW.ORGCODE;
  new$COSTAUTHORITY ORGANIZATIONS.COSTAUTHORITY%TYPE := :NEW.COSTAUTHORITY;
  new$INCOMEAUTHORITY ORGANIZATIONS.INCOMEAUTHORITY%TYPE := :NEW.INCOMEAUTHORITY;
  new$DEBTAUTHORITY ORGANIZATIONS.DEBTAUTHORITY%TYPE := :NEW.DEBTAUTHORITY;
  new$SVRAUTHORITY ORGANIZATIONS.SVRAUTHORITY%TYPE := :NEW.SVRAUTHORITY;
  new$CLIENTID ORGANIZATIONS.CLIENTID%TYPE := :NEW.CLIENTID;
  new$DATEOPEN ORGANIZATIONS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$FUID ORGANIZATIONS.FUID%TYPE := :NEW.FUID;
  new$OKPO ORGANIZATIONS.OKPO%TYPE := :NEW.OKPO;
  new$OKTMO ORGANIZATIONS.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCSTATEREF ORGANIZATIONS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ORGANIZATIONS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$OGRN ORGANIZATIONS.OGRN%TYPE := :NEW.OGRN;
  new$REJECT_CLS ORGANIZATIONS.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$EXTID ORGANIZATIONS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER ORGANIZATIONS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE ORGANIZATIONS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$REMOTEPBSCODE ORGANIZATIONS.REMOTEPBSCODE%TYPE := :NEW.REMOTEPBSCODE;
  new$REMOTENOTPBSCODE ORGANIZATIONS.REMOTENOTPBSCODE%TYPE := :NEW.REMOTENOTPBSCODE;
  new$USECHECK_CARD ORGANIZATIONS.USECHECK_CARD%TYPE := :NEW.USECHECK_CARD;
  new$EXTROOTID ORGANIZATIONS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION ORGANIZATIONS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE ORGANIZATIONS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$RECORDOWNERORGREF ORGANIZATIONS.RECORDOWNERORGREF%TYPE := :NEW.RECORDOWNERORGREF;
  new$TEMPREJECTCAUSE ORGANIZATIONS.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
  new$REJECTCAUSE ORGANIZATIONS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  CNT$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (tr_Organizations_bi)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$FUID is null) then
    new$FUID := new$id;
  END IF;
  if (new$GOSNI is null) then
    new$GOSNI := 0;
  END IF;
  if (new$Name is null) then
    new$Name := '  ';
  END IF;
  if (new$City is null) then
    GetVarcharConst(-1,7,new$City);
  END IF;
  if (new$COUNTRY is null) then
    new$COUNTRY := '';
  END IF;
  if (new$CountryCode is null) then
    new$CountryCode := 643;
  END IF;
  if (new$ORG_CLS is NULL) then
    new$ORG_CLS:= 0;
  END IF;
  if (new$SubINN is null) then
    new$SubINN:= 0;
  END IF;
  if (new$INN20 is null) then
    new$INN20:= '';
  END IF;
  if (new$RCOrg is null) then
    new$RCOrg := 0;
  END IF;
  if (new$RegionCls is null) then
    new$RegionCls := 0;
  END IF;
  if (new$OKATO is null) then
    new$OKATO := 0;
  END IF;
  if (new$KVSR is null) then
    new$KVSR := 0;
  END IF;
  if (new$OKFS is null) then
    new$OKFS := 0;
  END IF;
  if (new$OKOPF is null) then
    new$OKOPF := 0;
  END IF;
  if (new$FederalRegionCode is null) then
    GetIntConst(-1, 27,new$FederalRegionCode);
  END IF;
  if (new$FederalRegionCode is null) then
    new$FederalRegionCode := 0;
  END IF;
  if (new$BudgetRef is null) then
    new$BudgetRef := 0;
  END IF;
  /*    - */
  if (new$org_type is null) then
    new$org_type := 20000;
  END IF;
  /*        */
  if ((new$generalorg_ref is null) or (new$org_type < 10000) or (new$org_type >= 20000)) then
    new$generalorg_ref := new$id;
  END IF;
  /*    10 ,      */
  if ((new$INN > 9999999999.9) and (new$INN20 <> '') and (new$INN20 is not null)) then
    RaiseException('EX_WRONGKPP');
  END IF;
  check_unique_organization(new$inn,  new$inn20);
  if (new$CostAuthority is null) then
    new$CostAuthority:= 0;
  END IF;
  if (new$IncomeAuthority is null) then
    new$IncomeAuthority := 0;
  END IF;
  if (new$DebtAuthority is null) then
    new$DebtAuthority := 0;
  END IF;
  if (new$SVRAuthority is null) then
    new$SVRAuthority := 0;
  END IF;
  /*        */
  if (new$Org_Type is not null)
  then
    if (new$Org_Type between 10100 and 10299) then
      new$CostAuthority:= 1;
    END IF;
    if (new$Org_Type between 10300 and 10399) then
      new$CostAuthority:= 2;
    END IF;
    if (new$Org_Type between 10400 and 10499) then
      new$CostAuthority:= 4;
    END IF;
    if (((new$Org_Type between 10500 and 10599) and (new$CostAuthority<>16)) or
    (((new$Org_Type between 10000 and 10099) or (new$Org_Type between 10600 and 10799))
    and (new$CostAuthority=0))) then
      new$CostAuthority:= 8;

    END IF;
  END IF;
  if (new$UseCheck_Card is null) then
    new$UseCheck_Card := 0;
  END IF;
  if (new$RecordOwnerOrgRef is null) then
    new$RecordOwnerOrgRef := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_ORGANIZATIONS_BI_10)
-- Last update 19.10.2006
-- - - - - - - - - - - - -

  if (new$FacialAcc is not null) then
    select count(id) into cnt$ from Organizations where (FacialAcc = new$FacialAcc) AND (ROWNUM = 1);
    if (cnt$ <> 0) then RaiseException('ex_DublicateFacialAcc'); end if;
  end if;

-- - - - - - - - - - - - -
-- BI_200 (TR_ORGANIZATIONS_BI_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

  if (new$id <> new$GeneralOrg_Ref) then
    select count(*) into cnt$
    from Organizations o where (o.id = new$GeneralOrg_Ref) AND (ROWNUM = 1);

    if cnt$ = 0 then
      RaiseException('ex_GeneralOrgNotFound');
    end if;

    /*       ,     */
    if (new$KVSR = 0) then
      select o.KVSR into new$KVSR
      from Organizations o
      where o.id = new$GeneralOrg_Ref;
    end if;
  end if;

-- - - - - - - - - - - - -
-- BI_500 (TR_ORGANIZATIONS_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_ORGANIZATIONS (
    ID,
    NAME,
    GOSNI,
    CITY,
    COUNTRY,
    PHONE,
    ADDRESS,
    ORG_CLS,
    INN20,
    SUBINN,
    FACIALACC,
    REGIONCLS,
    DIRNAME,
    BUGNAME,
    DIRPHONE,
    BUGPHONE,
    RCORG,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    INN,
    OKATO,
    EMAIL,
    WEBSITE,
    UFKCODE,
    ADDOKATO,
    SHORTNAME,
    RVERSION,
    SENDERID,
    KVSR,
    OKFS,
    OKOPF,
    OPENDATE,
    CLOSEDATE,
    CHANGEDATE,
    GENERALORG_REF,
    FEDERALREGIONCODE,
    ORG_TYPE,
    BUDGETREF,
    SUPPLIERSTATUS,
    COUNTRYCODE,
    DATECLOSE,
    ORGCODE,
    COSTAUTHORITY,
    INCOMEAUTHORITY,
    DEBTAUTHORITY,
    SVRAUTHORITY,
    CLIENTID,
    DATEOPEN,
    FUID,
    OKPO,
    OKTMO,
    DOCSTATEREF,
    CRYPTOSTATUS,
    OGRN,
    REJECT_CLS,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    REMOTEPBSCODE,
    REMOTENOTPBSCODE,
    USECHECK_CARD,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    RECORDOWNERORGREF,
    TEMPREJECTCAUSE,
    REJECTCAUSE
  ) VALUES (
    new$ID,
    new$NAME,
    new$GOSNI,
    new$CITY,
    new$COUNTRY,
    new$PHONE,
    new$ADDRESS,
    new$ORG_CLS,
    new$INN20,
    new$SUBINN,
    new$FACIALACC,
    new$REGIONCLS,
    new$DIRNAME,
    new$BUGNAME,
    new$DIRPHONE,
    new$BUGPHONE,
    new$RCORG,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$INN,
    new$OKATO,
    new$EMAIL,
    new$WEBSITE,
    new$UFKCODE,
    new$ADDOKATO,
    new$SHORTNAME,
    new$RVERSION,
    new$SENDERID,
    new$KVSR,
    new$OKFS,
    new$OKOPF,
    new$OPENDATE,
    new$CLOSEDATE,
    new$CHANGEDATE,
    new$GENERALORG_REF,
    new$FEDERALREGIONCODE,
    new$ORG_TYPE,
    new$BUDGETREF,
    new$SUPPLIERSTATUS,
    new$COUNTRYCODE,
    new$DATECLOSE,
    new$ORGCODE,
    new$COSTAUTHORITY,
    new$INCOMEAUTHORITY,
    new$DEBTAUTHORITY,
    new$SVRAUTHORITY,
    new$CLIENTID,
    new$DATEOPEN,
    new$FUID,
    new$OKPO,
    new$OKTMO,
    new$DOCSTATEREF,
    new$CRYPTOSTATUS,
    new$OGRN,
    new$REJECT_CLS,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$REMOTEPBSCODE,
    new$REMOTENOTPBSCODE,
    new$USECHECK_CARD,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$RECORDOWNERORGREF,
    new$TEMPREJECTCAUSE,
    new$REJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_ORGANIZATIONS_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 27) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_IU
  INSTEAD OF UPDATE
  ON ORGANIZATIONS
  FOR EACH ROW
DECLARE
  new$ID ORGANIZATIONS.ID%TYPE := :NEW.ID;
  new$NAME ORGANIZATIONS.NAME%TYPE := :NEW.NAME;
  new$GOSNI ORGANIZATIONS.GOSNI%TYPE := :NEW.GOSNI;
  new$CITY ORGANIZATIONS.CITY%TYPE := :NEW.CITY;
  new$COUNTRY ORGANIZATIONS.COUNTRY%TYPE := :NEW.COUNTRY;
  new$PHONE ORGANIZATIONS.PHONE%TYPE := :NEW.PHONE;
  new$ADDRESS ORGANIZATIONS.ADDRESS%TYPE := :NEW.ADDRESS;
  new$ORG_CLS ORGANIZATIONS.ORG_CLS%TYPE := :NEW.ORG_CLS;
  new$INN20 ORGANIZATIONS.INN20%TYPE := :NEW.INN20;
  new$SUBINN ORGANIZATIONS.SUBINN%TYPE := :NEW.SUBINN;
  new$FACIALACC ORGANIZATIONS.FACIALACC%TYPE := :NEW.FACIALACC;
  new$REGIONCLS ORGANIZATIONS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$DIRNAME ORGANIZATIONS.DIRNAME%TYPE := :NEW.DIRNAME;
  new$BUGNAME ORGANIZATIONS.BUGNAME%TYPE := :NEW.BUGNAME;
  new$DIRPHONE ORGANIZATIONS.DIRPHONE%TYPE := :NEW.DIRPHONE;
  new$BUGPHONE ORGANIZATIONS.BUGPHONE%TYPE := :NEW.BUGPHONE;
  new$RCORG ORGANIZATIONS.RCORG%TYPE := :NEW.RCORG;
  new$CREATERUSER ORGANIZATIONS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ORGANIZATIONS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ORGANIZATIONS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ORGANIZATIONS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$INN ORGANIZATIONS.INN%TYPE := :NEW.INN;
  new$OKATO ORGANIZATIONS.OKATO%TYPE := :NEW.OKATO;
  new$EMAIL ORGANIZATIONS.EMAIL%TYPE := :NEW.EMAIL;
  new$WEBSITE ORGANIZATIONS.WEBSITE%TYPE := :NEW.WEBSITE;
  new$UFKCODE ORGANIZATIONS.UFKCODE%TYPE := :NEW.UFKCODE;
  new$ADDOKATO ORGANIZATIONS.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$SHORTNAME ORGANIZATIONS.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$RVERSION ORGANIZATIONS.RVERSION%TYPE := :NEW.RVERSION;
  new$SENDERID ORGANIZATIONS.SENDERID%TYPE := :NEW.SENDERID;
  new$KVSR ORGANIZATIONS.KVSR%TYPE := :NEW.KVSR;
  new$OKFS ORGANIZATIONS.OKFS%TYPE := :NEW.OKFS;
  new$OKOPF ORGANIZATIONS.OKOPF%TYPE := :NEW.OKOPF;
  new$OPENDATE ORGANIZATIONS.OPENDATE%TYPE := :NEW.OPENDATE;
  new$CLOSEDATE ORGANIZATIONS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$CHANGEDATE ORGANIZATIONS.CHANGEDATE%TYPE := :NEW.CHANGEDATE;
  new$GENERALORG_REF ORGANIZATIONS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$FEDERALREGIONCODE ORGANIZATIONS.FEDERALREGIONCODE%TYPE := :NEW.FEDERALREGIONCODE;
  new$ORG_TYPE ORGANIZATIONS.ORG_TYPE%TYPE := :NEW.ORG_TYPE;
  new$BUDGETREF ORGANIZATIONS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUPPLIERSTATUS ORGANIZATIONS.SUPPLIERSTATUS%TYPE := :NEW.SUPPLIERSTATUS;
  new$COUNTRYCODE ORGANIZATIONS.COUNTRYCODE%TYPE := :NEW.COUNTRYCODE;
  new$DATECLOSE ORGANIZATIONS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$ORGCODE ORGANIZATIONS.ORGCODE%TYPE := :NEW.ORGCODE;
  new$COSTAUTHORITY ORGANIZATIONS.COSTAUTHORITY%TYPE := :NEW.COSTAUTHORITY;
  new$INCOMEAUTHORITY ORGANIZATIONS.INCOMEAUTHORITY%TYPE := :NEW.INCOMEAUTHORITY;
  new$DEBTAUTHORITY ORGANIZATIONS.DEBTAUTHORITY%TYPE := :NEW.DEBTAUTHORITY;
  new$SVRAUTHORITY ORGANIZATIONS.SVRAUTHORITY%TYPE := :NEW.SVRAUTHORITY;
  new$CLIENTID ORGANIZATIONS.CLIENTID%TYPE := :NEW.CLIENTID;
  new$DATEOPEN ORGANIZATIONS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$FUID ORGANIZATIONS.FUID%TYPE := :NEW.FUID;
  new$OKPO ORGANIZATIONS.OKPO%TYPE := :NEW.OKPO;
  new$OKTMO ORGANIZATIONS.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCSTATEREF ORGANIZATIONS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ORGANIZATIONS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$OGRN ORGANIZATIONS.OGRN%TYPE := :NEW.OGRN;
  new$REJECT_CLS ORGANIZATIONS.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$EXTID ORGANIZATIONS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER ORGANIZATIONS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE ORGANIZATIONS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$REMOTEPBSCODE ORGANIZATIONS.REMOTEPBSCODE%TYPE := :NEW.REMOTEPBSCODE;
  new$REMOTENOTPBSCODE ORGANIZATIONS.REMOTENOTPBSCODE%TYPE := :NEW.REMOTENOTPBSCODE;
  new$USECHECK_CARD ORGANIZATIONS.USECHECK_CARD%TYPE := :NEW.USECHECK_CARD;
  new$EXTROOTID ORGANIZATIONS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION ORGANIZATIONS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE ORGANIZATIONS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$RECORDOWNERORGREF ORGANIZATIONS.RECORDOWNERORGREF%TYPE := :NEW.RECORDOWNERORGREF;
  new$TEMPREJECTCAUSE ORGANIZATIONS.TEMPREJECTCAUSE%TYPE := :NEW.TEMPREJECTCAUSE;
  new$REJECTCAUSE ORGANIZATIONS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  CNT$ NUMBER(10);
  c1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (tr_organizations_bu)
-- Version 11.30.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$gosni is null) then
--     new$gosni := 0;
--   END IF;
--   if (new$city is null) then
--     getvarcharconst(-1,7,new$city);
--   END IF;
--   if (new$country is null) then
--     new$country := '';
--   END IF;
--   if (new$countrycode is null) then
--     new$countrycode := 643;
--   END IF;
--   if (new$org_cls is null) then
--     new$org_cls:= 0;
--   END IF;
--   if (new$inn20 is null) then
--     new$inn20:= '';
--   END IF;
--   if (new$rcorg is null) then
--     new$rcorg := 0;
--   END IF;
--   if (new$regioncls is null) then
--     new$regioncls := 0;
--   END IF;
--   if (new$okato is null) then
--     new$okato := 0;
--   END IF;
--   if (new$kvsr is null) then
--     new$kvsr := 0;
--   END IF;
--   if (new$okfs is null) then
--     new$okfs := 0;
--   END IF;
--   if (new$okopf is null) then
--     new$okopf := 0;
--   END IF;
--   if (new$federalregioncode is null) then
--     getintconst(-1, 27,new$federalregioncode);
--   END IF;
--   if (new$federalregioncode is null) then
--     new$federalregioncode := 0;
--   END IF;
--   if (new$budgetref is null) then
--     new$budgetref := 0;
--   END IF;
--   /*    - */
--   if (new$org_type is null) then
--     new$org_type := 20000;
--   END IF;
--   /*        */
--   if ((new$generalorg_ref is null) or (new$org_type < 10000) or (new$org_type >= 20000)) then
--     new$generalorg_ref := new$id;
--   END IF;
-- 
--   /*    10 ,      */
--   if ((new$inn <> :old.inn) or ((:old.inn is null) and (new$inn is not null))) then
--     if ((new$inn > 9999999999.9) and (new$inn20 <> '')) then
--       RaiseException('ex_wrongkpp');
--     END IF;
--   END IF;
--   if ( ((new$inn <> :old.inn) or ((:old.inn is null) and (new$inn is not null)))
--   or ( (new$inn20 <> :old.inn20) or ((:old.inn20 is null) and (new$inn20 is not null))) )
--   then
--     check_unique_organization(new$inn,  new$inn20);
--   END IF;
-- 
--   if (new$regioncls <> :old.regioncls) then
--     update dfaccountsbuhtable set
--     regioncls = new$regioncls
--     where id = any (select id from org_accounts where org_ref = new$id);
--   END IF;
--   /*      */
--   if (:old.id = 0) then
--     RaiseException('ex_cantmodifyunknownorg');
--   END IF;
--   /*        */
--   if ((new$org_type<>:old.org_type) or (new$costauthority<>:old.costauthority))
--   then
--     c1$ := new$costauthority;
--     if (new$org_type between 10100 and 10299) then
--       new$costauthority:= 1;
--     END IF;
--     if (new$org_type between 10300 and 10399) then
--       new$costauthority:= 2;
--     END IF;
--     if (new$org_type between 10400 and 10499) then
--       new$costauthority:= 4;
--     END IF;
--     if (((new$org_type between 10500 and 10599) and (new$costauthority<>16)) or
--     (((new$org_type between 10000 and 10099) or (new$org_type between 10600 and 10799))
--     and (new$costauthority=0))) then
--       new$costauthority:= 8;
--     END IF;
--     if ((new$org_type=:old.org_type) and (c1$<>new$costauthority)) then
--       RaiseException('ex_wrongcostauthority');
--     END IF;
--   END IF;
--   /*    RegionCls  ,  
--          */
--   if (new$regioncls <> :old.regioncls) then
--     update facialacc_cls fac set
--     fac.regioncls = new$regioncls
--     where
--     new$id = fac.org_ref;
-- 
--   END IF;
--   if (new$UseCheck_Card is null) then
--     new$UseCheck_Card := 0;
--   END IF;
--   if (new$RecordOwnerOrgRef is null) then
--     new$RecordOwnerOrgRef := 0;
--   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_ORGANIZATIONS_BU_10)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$FacialAcc <> :old.FacialAcc) then
    select count(id) into CNT$ from Organizations
      where (FacialAcc = new$FacialAcc) and (id <> new$id) AND (ROWNUM = 1);
    if (CNT$ <> 0) then
      RaiseException('ex_DublicateFacialAcc');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_100 (TR_ORGANIZATIONS_BU_100)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*   */
  if ((new$DateClose is not null) and (:old.DateClose is null)) then
    /*        */
    update Org_Accounts set
    DateClose = new$DateClose,
    CloseCode = CloseCode + 10
    where Org_Ref = new$Id;

  END IF;
  /*  /      */
  if (((new$DateClose is not null) and (:old.DateClose is null)) or (new$DateClose <> :old.DateClose)) then
    /*     / */
    update FacialAcc_Cls set
    DateClose = new$DateClose,
    CloseCode = CloseCode + 10
    where Org_ref = new$Id;
  END IF;
  /*   */
  if ((new$DateClose is null) and (:old.DateClose is not null)) then
    update Org_Accounts set
    CloseCode = CloseCode - 10
    where Org_Ref = new$Id;

    /*     / */
    update FacialAcc_Cls set
    DateClose = new$DateClose,
    CloseCode = CloseCode - 10
    where Org_ref = new$Id;

  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_ORGANIZATIONS_BU_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

  if (new$id <> new$GeneralOrg_Ref) then
    select count(*) into cnt$
    from Organizations o where (o.id = new$GeneralOrg_Ref) AND (ROWNUM = 1);

    if cnt$ = 0 then
      RaiseException('ex_GeneralOrgNotFound');
    end if;
  end if;

  if (new$GeneralOrg_Ref <> :old.GeneralOrg_Ref) then
    update FacialAcc_CLS set
      GeneralOrg_Ref = new$GeneralOrg_Ref
    where
      Org_Ref = new$id;
  end if;

-- - - - - - - - - - - - -
-- BU_210 (TR_ORGANIZATIONS_BU_210)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$DOCSTATEREF <> :old.DOCSTATEREF) then
    insert into StateJumpHistory(DocID, BeginStateRef, EndStateRef)
    values(new$id, :old.DOCSTATEREF, new$DOCSTATEREF);
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_ORGANIZATIONS_BU_700)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  IF (new$RVersion IS NULL) THEN
    new$RVersion := 1;
  ELSIF ( (new$RVersion = -1) AND (:OLD.RVersion <> -1) ) THEN
    new$RVersion := :OLD.RVersion;
  ELSE
    new$RVersion := :OLD.RVersion + 1;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_ORGANIZATIONS SET
    ID = new$ID,
    NAME = new$NAME,
    GOSNI = new$GOSNI,
    CITY = new$CITY,
    COUNTRY = new$COUNTRY,
    PHONE = new$PHONE,
    ADDRESS = new$ADDRESS,
    ORG_CLS = new$ORG_CLS,
    INN20 = new$INN20,
    SUBINN = new$SUBINN,
    FACIALACC = new$FACIALACC,
    REGIONCLS = new$REGIONCLS,
    DIRNAME = new$DIRNAME,
    BUGNAME = new$BUGNAME,
    DIRPHONE = new$DIRPHONE,
    BUGPHONE = new$BUGPHONE,
    RCORG = new$RCORG,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    INN = new$INN,
    OKATO = new$OKATO,
    EMAIL = new$EMAIL,
    WEBSITE = new$WEBSITE,
    UFKCODE = new$UFKCODE,
    ADDOKATO = new$ADDOKATO,
    SHORTNAME = new$SHORTNAME,
    RVERSION = new$RVERSION,
    SENDERID = new$SENDERID,
    KVSR = new$KVSR,
    OKFS = new$OKFS,
    OKOPF = new$OKOPF,
    OPENDATE = new$OPENDATE,
    CLOSEDATE = new$CLOSEDATE,
    CHANGEDATE = new$CHANGEDATE,
    GENERALORG_REF = new$GENERALORG_REF,
    FEDERALREGIONCODE = new$FEDERALREGIONCODE,
    ORG_TYPE = new$ORG_TYPE,
    BUDGETREF = new$BUDGETREF,
    SUPPLIERSTATUS = new$SUPPLIERSTATUS,
    COUNTRYCODE = new$COUNTRYCODE,
    DATECLOSE = new$DATECLOSE,
    ORGCODE = new$ORGCODE,
    COSTAUTHORITY = new$COSTAUTHORITY,
    INCOMEAUTHORITY = new$INCOMEAUTHORITY,
    DEBTAUTHORITY = new$DEBTAUTHORITY,
    SVRAUTHORITY = new$SVRAUTHORITY,
    CLIENTID = new$CLIENTID,
    DATEOPEN = new$DATEOPEN,
    FUID = new$FUID,
    OKPO = new$OKPO,
    OKTMO = new$OKTMO,
    DOCSTATEREF = new$DOCSTATEREF,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    OGRN = new$OGRN,
    REJECT_CLS = new$REJECT_CLS,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    REMOTEPBSCODE = new$REMOTEPBSCODE,
    REMOTENOTPBSCODE = new$REMOTENOTPBSCODE,
    USECHECK_CARD = new$USECHECK_CARD,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    RECORDOWNERORGREF = new$RECORDOWNERORGREF,
    TEMPREJECTCAUSE = new$TEMPREJECTCAUSE,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AU_100 (TR_ORGANIZATIONS_AU_100)
-- Create 27.07.2007
-- - - - - - - - - - - - -

-- Comment   / 


  /*    */
  if ((new$DateClose is not null) and (:old.DateClose is null)) then
    update Banks set DateClose = new$DateClose where (id = new$ID) and (DateClose is null);
  end if;

  /*    */
  if ((new$DateClose is null) and (:old.DateClose is not null)) then
    update Banks set DateClose = null where (id = new$ID) and (DateClose is not null);
  end if;

-- - - - - - - - - - - - -
-- AU_200 (TR_ORGANIZATIONS_AU_200)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$BudgetRef <> :old.BudgetRef) then
    update FacialAcc_CLS set
    BudgetRef = new$BudgetRef
    where
    (ORG_REF = new$id)and((BudgetRef = :old.BudgetRef)or(BudgetRef<>0));
  END IF;
  /*     ,    */
  if ((new$KVSR <> :old.KVSR)and(new$Org_Type >= 10100)and(new$Org_Type <= 10299)) then
    update KVSR set
    Org_Ref = new$id
    where
    id = new$KVSR;
  END IF;
  if (new$KVSR <> :old.KVSR) then
    update FacialAcc_CLS set
    KVSR = new$KVSR
    where
    (ORG_REF = new$id) and (KVSR = :old.KVSR);
  END IF;
  if (new$BudgetRef <> :old.BudgetRef) then
    update organizations set
    BudgetRef = new$BudgetRef
    where
    (generalorg_ref = new$id) and (id <> new$id);
  END IF;
  if (new$KVSR <> :old.KVSR) then
    update organizations set
    KVSR = new$KVSR
    where
    (generalorg_ref = new$id) and (id <> new$id);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_ORGANIZATIONS_AU_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (27, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=27) and (RecordId=new$ID);
  end if;

END;
/
update ORGANIZATIONS set
  REJECTCAUSE = TempRejectCause
/
commit work 
/
ALTER TABLE TB_ORGANIZATIONS DROP (TempRejectCause)
/

CREATE OR REPLACE VIEW ORGANIZATIONS (
  ID,
  NAME,
  GOSNI,
  CITY,
  COUNTRY,
  PHONE,
  ADDRESS,
  ORG_CLS,
  INN20,
  SUBINN,
  FACIALACC,
  REGIONCLS,
  DIRNAME,
  BUGNAME,
  DIRPHONE,
  BUGPHONE,
  RCORG,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  INN,
  OKATO,
  EMAIL,
  WEBSITE,
  UFKCODE,
  ADDOKATO,
  SHORTNAME,
  RVERSION,
  SENDERID,
  KVSR,
  OKFS,
  OKOPF,
  OPENDATE,
  CLOSEDATE,
  CHANGEDATE,
  GENERALORG_REF,
  FEDERALREGIONCODE,
  ORG_TYPE,
  BUDGETREF,
  SUPPLIERSTATUS,
  COUNTRYCODE,
  DATECLOSE,
  ORGCODE,
  COSTAUTHORITY,
  INCOMEAUTHORITY,
  DEBTAUTHORITY,
  SVRAUTHORITY,
  CLIENTID,
  DATEOPEN,
  FUID,
  OKPO,
  OKTMO,
  DOCSTATEREF,
  CRYPTOSTATUS,
  OGRN,
  REJECT_CLS,
  EXTID,
  EXTOWNER,
  EXTSYNCDATE,
  REMOTEPBSCODE,
  REMOTENOTPBSCODE,
  USECHECK_CARD,
  EXTROOTID,
  EXTVERSION,
  EXTVERSIONDATE,
  RECORDOWNERORGREF,
  REJECTCAUSE)
AS
  SELECT
    ID,
    NAME,
    GOSNI,
    CITY,
    COUNTRY,
    PHONE,
    ADDRESS,
    ORG_CLS,
    INN20,
    SUBINN,
    FACIALACC,
    REGIONCLS,
    DIRNAME,
    BUGNAME,
    DIRPHONE,
    BUGPHONE,
    RCORG,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    INN,
    OKATO,
    EMAIL,
    WEBSITE,
    UFKCODE,
    ADDOKATO,
    SHORTNAME,
    RVERSION,
    SENDERID,
    KVSR,
    OKFS,
    OKOPF,
    OPENDATE,
    CLOSEDATE,
    CHANGEDATE,
    GENERALORG_REF,
    FEDERALREGIONCODE,
    ORG_TYPE,
    BUDGETREF,
    SUPPLIERSTATUS,
    COUNTRYCODE,
    DATECLOSE,
    ORGCODE,
    COSTAUTHORITY,
    INCOMEAUTHORITY,
    DEBTAUTHORITY,
    SVRAUTHORITY,
    CLIENTID,
    DATEOPEN,
    FUID,
    OKPO,
    OKTMO,
    DOCSTATEREF,
    CRYPTOSTATUS,
    OGRN,
    REJECT_CLS,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    REMOTEPBSCODE,
    REMOTENOTPBSCODE,
    USECHECK_CARD,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    RECORDOWNERORGREF,
    REJECTCAUSE
  FROM TB_ORGANIZATIONS
/

CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_ID
  INSTEAD OF DELETE
  ON ORGANIZATIONS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_ORGANIZATIONS_BD)
-- Last update 09.06.2008
-- - - - - - - - - - - - -

  if (:old.ID = 0) then
    RaiseException('ex_CantDelUnknownOrg');
  end if;

  delete from Org_Accounts where org_ref = :old.id;
  delete from Banks where id = :old.id;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_ORGANIZATIONS
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_200 (TR_ORGANIZATIONS_AD_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

update Organizations set
    GeneralOrg_Ref = id
  where
    GeneralOrg_Ref = :old.id;

-- - - - - - - - - - - - -
-- AD_210 (TR_ORGANIZATIONS_AD_210)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*       */
  delete 
  from 
  StateJumpHistory
  where 
  DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_ORGANIZATIONS_AD_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate) values(27, :old.ID ,SYSDATE);

END;
/

CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_II
  INSTEAD OF INSERT
  ON ORGANIZATIONS
  FOR EACH ROW
DECLARE
  new$ID ORGANIZATIONS.ID%TYPE := :NEW.ID;
  new$NAME ORGANIZATIONS.NAME%TYPE := :NEW.NAME;
  new$GOSNI ORGANIZATIONS.GOSNI%TYPE := :NEW.GOSNI;
  new$CITY ORGANIZATIONS.CITY%TYPE := :NEW.CITY;
  new$COUNTRY ORGANIZATIONS.COUNTRY%TYPE := :NEW.COUNTRY;
  new$PHONE ORGANIZATIONS.PHONE%TYPE := :NEW.PHONE;
  new$ADDRESS ORGANIZATIONS.ADDRESS%TYPE := :NEW.ADDRESS;
  new$ORG_CLS ORGANIZATIONS.ORG_CLS%TYPE := :NEW.ORG_CLS;
  new$INN20 ORGANIZATIONS.INN20%TYPE := :NEW.INN20;
  new$SUBINN ORGANIZATIONS.SUBINN%TYPE := :NEW.SUBINN;
  new$FACIALACC ORGANIZATIONS.FACIALACC%TYPE := :NEW.FACIALACC;
  new$REGIONCLS ORGANIZATIONS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$DIRNAME ORGANIZATIONS.DIRNAME%TYPE := :NEW.DIRNAME;
  new$BUGNAME ORGANIZATIONS.BUGNAME%TYPE := :NEW.BUGNAME;
  new$DIRPHONE ORGANIZATIONS.DIRPHONE%TYPE := :NEW.DIRPHONE;
  new$BUGPHONE ORGANIZATIONS.BUGPHONE%TYPE := :NEW.BUGPHONE;
  new$RCORG ORGANIZATIONS.RCORG%TYPE := :NEW.RCORG;
  new$CREATERUSER ORGANIZATIONS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ORGANIZATIONS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ORGANIZATIONS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ORGANIZATIONS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$INN ORGANIZATIONS.INN%TYPE := :NEW.INN;
  new$OKATO ORGANIZATIONS.OKATO%TYPE := :NEW.OKATO;
  new$EMAIL ORGANIZATIONS.EMAIL%TYPE := :NEW.EMAIL;
  new$WEBSITE ORGANIZATIONS.WEBSITE%TYPE := :NEW.WEBSITE;
  new$UFKCODE ORGANIZATIONS.UFKCODE%TYPE := :NEW.UFKCODE;
  new$ADDOKATO ORGANIZATIONS.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$SHORTNAME ORGANIZATIONS.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$RVERSION ORGANIZATIONS.RVERSION%TYPE := :NEW.RVERSION;
  new$SENDERID ORGANIZATIONS.SENDERID%TYPE := :NEW.SENDERID;
  new$KVSR ORGANIZATIONS.KVSR%TYPE := :NEW.KVSR;
  new$OKFS ORGANIZATIONS.OKFS%TYPE := :NEW.OKFS;
  new$OKOPF ORGANIZATIONS.OKOPF%TYPE := :NEW.OKOPF;
  new$OPENDATE ORGANIZATIONS.OPENDATE%TYPE := :NEW.OPENDATE;
  new$CLOSEDATE ORGANIZATIONS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$CHANGEDATE ORGANIZATIONS.CHANGEDATE%TYPE := :NEW.CHANGEDATE;
  new$GENERALORG_REF ORGANIZATIONS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$FEDERALREGIONCODE ORGANIZATIONS.FEDERALREGIONCODE%TYPE := :NEW.FEDERALREGIONCODE;
  new$ORG_TYPE ORGANIZATIONS.ORG_TYPE%TYPE := :NEW.ORG_TYPE;
  new$BUDGETREF ORGANIZATIONS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUPPLIERSTATUS ORGANIZATIONS.SUPPLIERSTATUS%TYPE := :NEW.SUPPLIERSTATUS;
  new$COUNTRYCODE ORGANIZATIONS.COUNTRYCODE%TYPE := :NEW.COUNTRYCODE;
  new$DATECLOSE ORGANIZATIONS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$ORGCODE ORGANIZATIONS.ORGCODE%TYPE := :NEW.ORGCODE;
  new$COSTAUTHORITY ORGANIZATIONS.COSTAUTHORITY%TYPE := :NEW.COSTAUTHORITY;
  new$INCOMEAUTHORITY ORGANIZATIONS.INCOMEAUTHORITY%TYPE := :NEW.INCOMEAUTHORITY;
  new$DEBTAUTHORITY ORGANIZATIONS.DEBTAUTHORITY%TYPE := :NEW.DEBTAUTHORITY;
  new$SVRAUTHORITY ORGANIZATIONS.SVRAUTHORITY%TYPE := :NEW.SVRAUTHORITY;
  new$CLIENTID ORGANIZATIONS.CLIENTID%TYPE := :NEW.CLIENTID;
  new$DATEOPEN ORGANIZATIONS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$FUID ORGANIZATIONS.FUID%TYPE := :NEW.FUID;
  new$OKPO ORGANIZATIONS.OKPO%TYPE := :NEW.OKPO;
  new$OKTMO ORGANIZATIONS.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCSTATEREF ORGANIZATIONS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ORGANIZATIONS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$OGRN ORGANIZATIONS.OGRN%TYPE := :NEW.OGRN;
  new$REJECT_CLS ORGANIZATIONS.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$EXTID ORGANIZATIONS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER ORGANIZATIONS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE ORGANIZATIONS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$REMOTEPBSCODE ORGANIZATIONS.REMOTEPBSCODE%TYPE := :NEW.REMOTEPBSCODE;
  new$REMOTENOTPBSCODE ORGANIZATIONS.REMOTENOTPBSCODE%TYPE := :NEW.REMOTENOTPBSCODE;
  new$USECHECK_CARD ORGANIZATIONS.USECHECK_CARD%TYPE := :NEW.USECHECK_CARD;
  new$EXTROOTID ORGANIZATIONS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION ORGANIZATIONS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE ORGANIZATIONS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$RECORDOWNERORGREF ORGANIZATIONS.RECORDOWNERORGREF%TYPE := :NEW.RECORDOWNERORGREF;
  new$REJECTCAUSE ORGANIZATIONS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  CNT$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (tr_Organizations_bi)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$FUID is null) then
    new$FUID := new$id;
  END IF;
  if (new$GOSNI is null) then
    new$GOSNI := 0;
  END IF;
  if (new$Name is null) then
    new$Name := '  ';
  END IF;
  if (new$City is null) then
    GetVarcharConst(-1,7,new$City);
  END IF;
  if (new$COUNTRY is null) then
    new$COUNTRY := '';
  END IF;
  if (new$CountryCode is null) then
    new$CountryCode := 643;
  END IF;
  if (new$ORG_CLS is NULL) then
    new$ORG_CLS:= 0;
  END IF;
  if (new$SubINN is null) then
    new$SubINN:= 0;
  END IF;
  if (new$INN20 is null) then
    new$INN20:= '';
  END IF;
  if (new$RCOrg is null) then
    new$RCOrg := 0;
  END IF;
  if (new$RegionCls is null) then
    new$RegionCls := 0;
  END IF;
  if (new$OKATO is null) then
    new$OKATO := 0;
  END IF;
  if (new$KVSR is null) then
    new$KVSR := 0;
  END IF;
  if (new$OKFS is null) then
    new$OKFS := 0;
  END IF;
  if (new$OKOPF is null) then
    new$OKOPF := 0;
  END IF;
  if (new$FederalRegionCode is null) then
    GetIntConst(-1, 27,new$FederalRegionCode);
  END IF;
  if (new$FederalRegionCode is null) then
    new$FederalRegionCode := 0;
  END IF;
  if (new$BudgetRef is null) then
    new$BudgetRef := 0;
  END IF;
  /*    - */
  if (new$org_type is null) then
    new$org_type := 20000;
  END IF;
  /*        */
  if ((new$generalorg_ref is null) or (new$org_type < 10000) or (new$org_type >= 20000)) then
    new$generalorg_ref := new$id;
  END IF;
  /*    10 ,      */
  if ((new$INN > 9999999999.9) and (new$INN20 <> '') and (new$INN20 is not null)) then
    RaiseException('EX_WRONGKPP');
  END IF;
  check_unique_organization(new$inn,  new$inn20);
  if (new$CostAuthority is null) then
    new$CostAuthority:= 0;
  END IF;
  if (new$IncomeAuthority is null) then
    new$IncomeAuthority := 0;
  END IF;
  if (new$DebtAuthority is null) then
    new$DebtAuthority := 0;
  END IF;
  if (new$SVRAuthority is null) then
    new$SVRAuthority := 0;
  END IF;
  /*        */
  if (new$Org_Type is not null)
  then
    if (new$Org_Type between 10100 and 10299) then
      new$CostAuthority:= 1;
    END IF;
    if (new$Org_Type between 10300 and 10399) then
      new$CostAuthority:= 2;
    END IF;
    if (new$Org_Type between 10400 and 10499) then
      new$CostAuthority:= 4;
    END IF;
    if (((new$Org_Type between 10500 and 10599) and (new$CostAuthority<>16)) or
    (((new$Org_Type between 10000 and 10099) or (new$Org_Type between 10600 and 10799))
    and (new$CostAuthority=0))) then
      new$CostAuthority:= 8;

    END IF;
  END IF;
  if (new$UseCheck_Card is null) then
    new$UseCheck_Card := 0;
  END IF;
  if (new$RecordOwnerOrgRef is null) then
    new$RecordOwnerOrgRef := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_ORGANIZATIONS_BI_10)
-- Last update 19.10.2006
-- - - - - - - - - - - - -

  if (new$FacialAcc is not null) then
    select count(id) into cnt$ from Organizations where (FacialAcc = new$FacialAcc) AND (ROWNUM = 1);
    if (cnt$ <> 0) then RaiseException('ex_DublicateFacialAcc'); end if;
  end if;

-- - - - - - - - - - - - -
-- BI_200 (TR_ORGANIZATIONS_BI_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

  if (new$id <> new$GeneralOrg_Ref) then
    select count(*) into cnt$
    from Organizations o where (o.id = new$GeneralOrg_Ref) AND (ROWNUM = 1);

    if cnt$ = 0 then
      RaiseException('ex_GeneralOrgNotFound');
    end if;

    /*       ,     */
    if (new$KVSR = 0) then
      select o.KVSR into new$KVSR
      from Organizations o
      where o.id = new$GeneralOrg_Ref;
    end if;
  end if;

-- - - - - - - - - - - - -
-- BI_500 (TR_ORGANIZATIONS_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_ORGANIZATIONS (
    ID,
    NAME,
    GOSNI,
    CITY,
    COUNTRY,
    PHONE,
    ADDRESS,
    ORG_CLS,
    INN20,
    SUBINN,
    FACIALACC,
    REGIONCLS,
    DIRNAME,
    BUGNAME,
    DIRPHONE,
    BUGPHONE,
    RCORG,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    INN,
    OKATO,
    EMAIL,
    WEBSITE,
    UFKCODE,
    ADDOKATO,
    SHORTNAME,
    RVERSION,
    SENDERID,
    KVSR,
    OKFS,
    OKOPF,
    OPENDATE,
    CLOSEDATE,
    CHANGEDATE,
    GENERALORG_REF,
    FEDERALREGIONCODE,
    ORG_TYPE,
    BUDGETREF,
    SUPPLIERSTATUS,
    COUNTRYCODE,
    DATECLOSE,
    ORGCODE,
    COSTAUTHORITY,
    INCOMEAUTHORITY,
    DEBTAUTHORITY,
    SVRAUTHORITY,
    CLIENTID,
    DATEOPEN,
    FUID,
    OKPO,
    OKTMO,
    DOCSTATEREF,
    CRYPTOSTATUS,
    OGRN,
    REJECT_CLS,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    REMOTEPBSCODE,
    REMOTENOTPBSCODE,
    USECHECK_CARD,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    RECORDOWNERORGREF,
    REJECTCAUSE
  ) VALUES (
    new$ID,
    new$NAME,
    new$GOSNI,
    new$CITY,
    new$COUNTRY,
    new$PHONE,
    new$ADDRESS,
    new$ORG_CLS,
    new$INN20,
    new$SUBINN,
    new$FACIALACC,
    new$REGIONCLS,
    new$DIRNAME,
    new$BUGNAME,
    new$DIRPHONE,
    new$BUGPHONE,
    new$RCORG,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$INN,
    new$OKATO,
    new$EMAIL,
    new$WEBSITE,
    new$UFKCODE,
    new$ADDOKATO,
    new$SHORTNAME,
    new$RVERSION,
    new$SENDERID,
    new$KVSR,
    new$OKFS,
    new$OKOPF,
    new$OPENDATE,
    new$CLOSEDATE,
    new$CHANGEDATE,
    new$GENERALORG_REF,
    new$FEDERALREGIONCODE,
    new$ORG_TYPE,
    new$BUDGETREF,
    new$SUPPLIERSTATUS,
    new$COUNTRYCODE,
    new$DATECLOSE,
    new$ORGCODE,
    new$COSTAUTHORITY,
    new$INCOMEAUTHORITY,
    new$DEBTAUTHORITY,
    new$SVRAUTHORITY,
    new$CLIENTID,
    new$DATEOPEN,
    new$FUID,
    new$OKPO,
    new$OKTMO,
    new$DOCSTATEREF,
    new$CRYPTOSTATUS,
    new$OGRN,
    new$REJECT_CLS,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$REMOTEPBSCODE,
    new$REMOTENOTPBSCODE,
    new$USECHECK_CARD,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$RECORDOWNERORGREF,
    new$REJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_ORGANIZATIONS_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 27) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_IU
  INSTEAD OF UPDATE
  ON ORGANIZATIONS
  FOR EACH ROW
DECLARE
  new$ID ORGANIZATIONS.ID%TYPE := :NEW.ID;
  new$NAME ORGANIZATIONS.NAME%TYPE := :NEW.NAME;
  new$GOSNI ORGANIZATIONS.GOSNI%TYPE := :NEW.GOSNI;
  new$CITY ORGANIZATIONS.CITY%TYPE := :NEW.CITY;
  new$COUNTRY ORGANIZATIONS.COUNTRY%TYPE := :NEW.COUNTRY;
  new$PHONE ORGANIZATIONS.PHONE%TYPE := :NEW.PHONE;
  new$ADDRESS ORGANIZATIONS.ADDRESS%TYPE := :NEW.ADDRESS;
  new$ORG_CLS ORGANIZATIONS.ORG_CLS%TYPE := :NEW.ORG_CLS;
  new$INN20 ORGANIZATIONS.INN20%TYPE := :NEW.INN20;
  new$SUBINN ORGANIZATIONS.SUBINN%TYPE := :NEW.SUBINN;
  new$FACIALACC ORGANIZATIONS.FACIALACC%TYPE := :NEW.FACIALACC;
  new$REGIONCLS ORGANIZATIONS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$DIRNAME ORGANIZATIONS.DIRNAME%TYPE := :NEW.DIRNAME;
  new$BUGNAME ORGANIZATIONS.BUGNAME%TYPE := :NEW.BUGNAME;
  new$DIRPHONE ORGANIZATIONS.DIRPHONE%TYPE := :NEW.DIRPHONE;
  new$BUGPHONE ORGANIZATIONS.BUGPHONE%TYPE := :NEW.BUGPHONE;
  new$RCORG ORGANIZATIONS.RCORG%TYPE := :NEW.RCORG;
  new$CREATERUSER ORGANIZATIONS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ORGANIZATIONS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ORGANIZATIONS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ORGANIZATIONS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$INN ORGANIZATIONS.INN%TYPE := :NEW.INN;
  new$OKATO ORGANIZATIONS.OKATO%TYPE := :NEW.OKATO;
  new$EMAIL ORGANIZATIONS.EMAIL%TYPE := :NEW.EMAIL;
  new$WEBSITE ORGANIZATIONS.WEBSITE%TYPE := :NEW.WEBSITE;
  new$UFKCODE ORGANIZATIONS.UFKCODE%TYPE := :NEW.UFKCODE;
  new$ADDOKATO ORGANIZATIONS.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$SHORTNAME ORGANIZATIONS.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$RVERSION ORGANIZATIONS.RVERSION%TYPE := :NEW.RVERSION;
  new$SENDERID ORGANIZATIONS.SENDERID%TYPE := :NEW.SENDERID;
  new$KVSR ORGANIZATIONS.KVSR%TYPE := :NEW.KVSR;
  new$OKFS ORGANIZATIONS.OKFS%TYPE := :NEW.OKFS;
  new$OKOPF ORGANIZATIONS.OKOPF%TYPE := :NEW.OKOPF;
  new$OPENDATE ORGANIZATIONS.OPENDATE%TYPE := :NEW.OPENDATE;
  new$CLOSEDATE ORGANIZATIONS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$CHANGEDATE ORGANIZATIONS.CHANGEDATE%TYPE := :NEW.CHANGEDATE;
  new$GENERALORG_REF ORGANIZATIONS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$FEDERALREGIONCODE ORGANIZATIONS.FEDERALREGIONCODE%TYPE := :NEW.FEDERALREGIONCODE;
  new$ORG_TYPE ORGANIZATIONS.ORG_TYPE%TYPE := :NEW.ORG_TYPE;
  new$BUDGETREF ORGANIZATIONS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUPPLIERSTATUS ORGANIZATIONS.SUPPLIERSTATUS%TYPE := :NEW.SUPPLIERSTATUS;
  new$COUNTRYCODE ORGANIZATIONS.COUNTRYCODE%TYPE := :NEW.COUNTRYCODE;
  new$DATECLOSE ORGANIZATIONS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$ORGCODE ORGANIZATIONS.ORGCODE%TYPE := :NEW.ORGCODE;
  new$COSTAUTHORITY ORGANIZATIONS.COSTAUTHORITY%TYPE := :NEW.COSTAUTHORITY;
  new$INCOMEAUTHORITY ORGANIZATIONS.INCOMEAUTHORITY%TYPE := :NEW.INCOMEAUTHORITY;
  new$DEBTAUTHORITY ORGANIZATIONS.DEBTAUTHORITY%TYPE := :NEW.DEBTAUTHORITY;
  new$SVRAUTHORITY ORGANIZATIONS.SVRAUTHORITY%TYPE := :NEW.SVRAUTHORITY;
  new$CLIENTID ORGANIZATIONS.CLIENTID%TYPE := :NEW.CLIENTID;
  new$DATEOPEN ORGANIZATIONS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$FUID ORGANIZATIONS.FUID%TYPE := :NEW.FUID;
  new$OKPO ORGANIZATIONS.OKPO%TYPE := :NEW.OKPO;
  new$OKTMO ORGANIZATIONS.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCSTATEREF ORGANIZATIONS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ORGANIZATIONS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$OGRN ORGANIZATIONS.OGRN%TYPE := :NEW.OGRN;
  new$REJECT_CLS ORGANIZATIONS.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$EXTID ORGANIZATIONS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER ORGANIZATIONS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE ORGANIZATIONS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$REMOTEPBSCODE ORGANIZATIONS.REMOTEPBSCODE%TYPE := :NEW.REMOTEPBSCODE;
  new$REMOTENOTPBSCODE ORGANIZATIONS.REMOTENOTPBSCODE%TYPE := :NEW.REMOTENOTPBSCODE;
  new$USECHECK_CARD ORGANIZATIONS.USECHECK_CARD%TYPE := :NEW.USECHECK_CARD;
  new$EXTROOTID ORGANIZATIONS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION ORGANIZATIONS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE ORGANIZATIONS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$RECORDOWNERORGREF ORGANIZATIONS.RECORDOWNERORGREF%TYPE := :NEW.RECORDOWNERORGREF;
  new$REJECTCAUSE ORGANIZATIONS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  CNT$ NUMBER(10);
  c1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (tr_organizations_bu)
-- Version 11.30.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$gosni is null) then
--     new$gosni := 0;
--   END IF;
--   if (new$city is null) then
--     getvarcharconst(-1,7,new$city);
--   END IF;
--   if (new$country is null) then
--     new$country := '';
--   END IF;
--   if (new$countrycode is null) then
--     new$countrycode := 643;
--   END IF;
--   if (new$org_cls is null) then
--     new$org_cls:= 0;
--   END IF;
--   if (new$inn20 is null) then
--     new$inn20:= '';
--   END IF;
--   if (new$rcorg is null) then
--     new$rcorg := 0;
--   END IF;
--   if (new$regioncls is null) then
--     new$regioncls := 0;
--   END IF;
--   if (new$okato is null) then
--     new$okato := 0;
--   END IF;
--   if (new$kvsr is null) then
--     new$kvsr := 0;
--   END IF;
--   if (new$okfs is null) then
--     new$okfs := 0;
--   END IF;
--   if (new$okopf is null) then
--     new$okopf := 0;
--   END IF;
--   if (new$federalregioncode is null) then
--     getintconst(-1, 27,new$federalregioncode);
--   END IF;
--   if (new$federalregioncode is null) then
--     new$federalregioncode := 0;
--   END IF;
--   if (new$budgetref is null) then
--     new$budgetref := 0;
--   END IF;
--   /*    - */
--   if (new$org_type is null) then
--     new$org_type := 20000;
--   END IF;
--   /*        */
--   if ((new$generalorg_ref is null) or (new$org_type < 10000) or (new$org_type >= 20000)) then
--     new$generalorg_ref := new$id;
--   END IF;
-- 
--   /*    10 ,      */
--   if ((new$inn <> :old.inn) or ((:old.inn is null) and (new$inn is not null))) then
--     if ((new$inn > 9999999999.9) and (new$inn20 <> '')) then
--       RaiseException('ex_wrongkpp');
--     END IF;
--   END IF;
--   if ( ((new$inn <> :old.inn) or ((:old.inn is null) and (new$inn is not null)))
--   or ( (new$inn20 <> :old.inn20) or ((:old.inn20 is null) and (new$inn20 is not null))) )
--   then
--     check_unique_organization(new$inn,  new$inn20);
--   END IF;
-- 
--   if (new$regioncls <> :old.regioncls) then
--     update dfaccountsbuhtable set
--     regioncls = new$regioncls
--     where id = any (select id from org_accounts where org_ref = new$id);
--   END IF;
--   /*      */
--   if (:old.id = 0) then
--     RaiseException('ex_cantmodifyunknownorg');
--   END IF;
--   /*        */
--   if ((new$org_type<>:old.org_type) or (new$costauthority<>:old.costauthority))
--   then
--     c1$ := new$costauthority;
--     if (new$org_type between 10100 and 10299) then
--       new$costauthority:= 1;
--     END IF;
--     if (new$org_type between 10300 and 10399) then
--       new$costauthority:= 2;
--     END IF;
--     if (new$org_type between 10400 and 10499) then
--       new$costauthority:= 4;
--     END IF;
--     if (((new$org_type between 10500 and 10599) and (new$costauthority<>16)) or
--     (((new$org_type between 10000 and 10099) or (new$org_type between 10600 and 10799))
--     and (new$costauthority=0))) then
--       new$costauthority:= 8;
--     END IF;
--     if ((new$org_type=:old.org_type) and (c1$<>new$costauthority)) then
--       RaiseException('ex_wrongcostauthority');
--     END IF;
--   END IF;
--   /*    RegionCls  ,  
--          */
--   if (new$regioncls <> :old.regioncls) then
--     update facialacc_cls fac set
--     fac.regioncls = new$regioncls
--     where
--     new$id = fac.org_ref;
-- 
--   END IF;
--   if (new$UseCheck_Card is null) then
--     new$UseCheck_Card := 0;
--   END IF;
--   if (new$RecordOwnerOrgRef is null) then
--     new$RecordOwnerOrgRef := 0;
--   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_ORGANIZATIONS_BU_10)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$FacialAcc <> :old.FacialAcc) then
    select count(id) into CNT$ from Organizations
      where (FacialAcc = new$FacialAcc) and (id <> new$id) AND (ROWNUM = 1);
    if (CNT$ <> 0) then
      RaiseException('ex_DublicateFacialAcc');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_100 (TR_ORGANIZATIONS_BU_100)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*   */
  if ((new$DateClose is not null) and (:old.DateClose is null)) then
    /*        */
    update Org_Accounts set
    DateClose = new$DateClose,
    CloseCode = CloseCode + 10
    where Org_Ref = new$Id;

  END IF;
  /*  /      */
  if (((new$DateClose is not null) and (:old.DateClose is null)) or (new$DateClose <> :old.DateClose)) then
    /*     / */
    update FacialAcc_Cls set
    DateClose = new$DateClose,
    CloseCode = CloseCode + 10
    where Org_ref = new$Id;
  END IF;
  /*   */
  if ((new$DateClose is null) and (:old.DateClose is not null)) then
    update Org_Accounts set
    CloseCode = CloseCode - 10
    where Org_Ref = new$Id;

    /*     / */
    update FacialAcc_Cls set
    DateClose = new$DateClose,
    CloseCode = CloseCode - 10
    where Org_ref = new$Id;

  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_ORGANIZATIONS_BU_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

  if (new$id <> new$GeneralOrg_Ref) then
    select count(*) into cnt$
    from Organizations o where (o.id = new$GeneralOrg_Ref) AND (ROWNUM = 1);

    if cnt$ = 0 then
      RaiseException('ex_GeneralOrgNotFound');
    end if;
  end if;

  if (new$GeneralOrg_Ref <> :old.GeneralOrg_Ref) then
    update FacialAcc_CLS set
      GeneralOrg_Ref = new$GeneralOrg_Ref
    where
      Org_Ref = new$id;
  end if;

-- - - - - - - - - - - - -
-- BU_210 (TR_ORGANIZATIONS_BU_210)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$DOCSTATEREF <> :old.DOCSTATEREF) then
    insert into StateJumpHistory(DocID, BeginStateRef, EndStateRef)
    values(new$id, :old.DOCSTATEREF, new$DOCSTATEREF);
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_ORGANIZATIONS_BU_700)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  IF (new$RVersion IS NULL) THEN
    new$RVersion := 1;
  ELSIF ( (new$RVersion = -1) AND (:OLD.RVersion <> -1) ) THEN
    new$RVersion := :OLD.RVersion;
  ELSE
    new$RVersion := :OLD.RVersion + 1;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_ORGANIZATIONS SET
    ID = new$ID,
    NAME = new$NAME,
    GOSNI = new$GOSNI,
    CITY = new$CITY,
    COUNTRY = new$COUNTRY,
    PHONE = new$PHONE,
    ADDRESS = new$ADDRESS,
    ORG_CLS = new$ORG_CLS,
    INN20 = new$INN20,
    SUBINN = new$SUBINN,
    FACIALACC = new$FACIALACC,
    REGIONCLS = new$REGIONCLS,
    DIRNAME = new$DIRNAME,
    BUGNAME = new$BUGNAME,
    DIRPHONE = new$DIRPHONE,
    BUGPHONE = new$BUGPHONE,
    RCORG = new$RCORG,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    INN = new$INN,
    OKATO = new$OKATO,
    EMAIL = new$EMAIL,
    WEBSITE = new$WEBSITE,
    UFKCODE = new$UFKCODE,
    ADDOKATO = new$ADDOKATO,
    SHORTNAME = new$SHORTNAME,
    RVERSION = new$RVERSION,
    SENDERID = new$SENDERID,
    KVSR = new$KVSR,
    OKFS = new$OKFS,
    OKOPF = new$OKOPF,
    OPENDATE = new$OPENDATE,
    CLOSEDATE = new$CLOSEDATE,
    CHANGEDATE = new$CHANGEDATE,
    GENERALORG_REF = new$GENERALORG_REF,
    FEDERALREGIONCODE = new$FEDERALREGIONCODE,
    ORG_TYPE = new$ORG_TYPE,
    BUDGETREF = new$BUDGETREF,
    SUPPLIERSTATUS = new$SUPPLIERSTATUS,
    COUNTRYCODE = new$COUNTRYCODE,
    DATECLOSE = new$DATECLOSE,
    ORGCODE = new$ORGCODE,
    COSTAUTHORITY = new$COSTAUTHORITY,
    INCOMEAUTHORITY = new$INCOMEAUTHORITY,
    DEBTAUTHORITY = new$DEBTAUTHORITY,
    SVRAUTHORITY = new$SVRAUTHORITY,
    CLIENTID = new$CLIENTID,
    DATEOPEN = new$DATEOPEN,
    FUID = new$FUID,
    OKPO = new$OKPO,
    OKTMO = new$OKTMO,
    DOCSTATEREF = new$DOCSTATEREF,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    OGRN = new$OGRN,
    REJECT_CLS = new$REJECT_CLS,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    REMOTEPBSCODE = new$REMOTEPBSCODE,
    REMOTENOTPBSCODE = new$REMOTENOTPBSCODE,
    USECHECK_CARD = new$USECHECK_CARD,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    RECORDOWNERORGREF = new$RECORDOWNERORGREF,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AU_100 (TR_ORGANIZATIONS_AU_100)
-- Create 27.07.2007
-- - - - - - - - - - - - -

-- Comment   / 


  /*    */
  if ((new$DateClose is not null) and (:old.DateClose is null)) then
    update Banks set DateClose = new$DateClose where (id = new$ID) and (DateClose is null);
  end if;

  /*    */
  if ((new$DateClose is null) and (:old.DateClose is not null)) then
    update Banks set DateClose = null where (id = new$ID) and (DateClose is not null);
  end if;

-- - - - - - - - - - - - -
-- AU_200 (TR_ORGANIZATIONS_AU_200)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$BudgetRef <> :old.BudgetRef) then
    update FacialAcc_CLS set
    BudgetRef = new$BudgetRef
    where
    (ORG_REF = new$id)and((BudgetRef = :old.BudgetRef)or(BudgetRef<>0));
  END IF;
  /*     ,    */
  if ((new$KVSR <> :old.KVSR)and(new$Org_Type >= 10100)and(new$Org_Type <= 10299)) then
    update KVSR set
    Org_Ref = new$id
    where
    id = new$KVSR;
  END IF;
  if (new$KVSR <> :old.KVSR) then
    update FacialAcc_CLS set
    KVSR = new$KVSR
    where
    (ORG_REF = new$id) and (KVSR = :old.KVSR);
  END IF;
  if (new$BudgetRef <> :old.BudgetRef) then
    update organizations set
    BudgetRef = new$BudgetRef
    where
    (generalorg_ref = new$id) and (id <> new$id);
  END IF;
  if (new$KVSR <> :old.KVSR) then
    update organizations set
    KVSR = new$KVSR
    where
    (generalorg_ref = new$id) and (id <> new$id);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_ORGANIZATIONS_AU_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (27, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=27) and (RecordId=new$ID);
  end if;

END;
/
ALTER TRIGGER TR_ORGANIZATIONS_BU_500 ENABLE
/
-- ALTER TRIGGER TR_ORGANIZATIONS_BU
CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_IU
  INSTEAD OF UPDATE
  ON ORGANIZATIONS
  FOR EACH ROW
DECLARE
  new$ID ORGANIZATIONS.ID%TYPE := :NEW.ID;
  new$NAME ORGANIZATIONS.NAME%TYPE := :NEW.NAME;
  new$GOSNI ORGANIZATIONS.GOSNI%TYPE := :NEW.GOSNI;
  new$CITY ORGANIZATIONS.CITY%TYPE := :NEW.CITY;
  new$COUNTRY ORGANIZATIONS.COUNTRY%TYPE := :NEW.COUNTRY;
  new$PHONE ORGANIZATIONS.PHONE%TYPE := :NEW.PHONE;
  new$ADDRESS ORGANIZATIONS.ADDRESS%TYPE := :NEW.ADDRESS;
  new$ORG_CLS ORGANIZATIONS.ORG_CLS%TYPE := :NEW.ORG_CLS;
  new$INN20 ORGANIZATIONS.INN20%TYPE := :NEW.INN20;
  new$SUBINN ORGANIZATIONS.SUBINN%TYPE := :NEW.SUBINN;
  new$FACIALACC ORGANIZATIONS.FACIALACC%TYPE := :NEW.FACIALACC;
  new$REGIONCLS ORGANIZATIONS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$DIRNAME ORGANIZATIONS.DIRNAME%TYPE := :NEW.DIRNAME;
  new$BUGNAME ORGANIZATIONS.BUGNAME%TYPE := :NEW.BUGNAME;
  new$DIRPHONE ORGANIZATIONS.DIRPHONE%TYPE := :NEW.DIRPHONE;
  new$BUGPHONE ORGANIZATIONS.BUGPHONE%TYPE := :NEW.BUGPHONE;
  new$RCORG ORGANIZATIONS.RCORG%TYPE := :NEW.RCORG;
  new$CREATERUSER ORGANIZATIONS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ORGANIZATIONS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ORGANIZATIONS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ORGANIZATIONS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$INN ORGANIZATIONS.INN%TYPE := :NEW.INN;
  new$OKATO ORGANIZATIONS.OKATO%TYPE := :NEW.OKATO;
  new$EMAIL ORGANIZATIONS.EMAIL%TYPE := :NEW.EMAIL;
  new$WEBSITE ORGANIZATIONS.WEBSITE%TYPE := :NEW.WEBSITE;
  new$UFKCODE ORGANIZATIONS.UFKCODE%TYPE := :NEW.UFKCODE;
  new$ADDOKATO ORGANIZATIONS.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$SHORTNAME ORGANIZATIONS.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$RVERSION ORGANIZATIONS.RVERSION%TYPE := :NEW.RVERSION;
  new$SENDERID ORGANIZATIONS.SENDERID%TYPE := :NEW.SENDERID;
  new$KVSR ORGANIZATIONS.KVSR%TYPE := :NEW.KVSR;
  new$OKFS ORGANIZATIONS.OKFS%TYPE := :NEW.OKFS;
  new$OKOPF ORGANIZATIONS.OKOPF%TYPE := :NEW.OKOPF;
  new$OPENDATE ORGANIZATIONS.OPENDATE%TYPE := :NEW.OPENDATE;
  new$CLOSEDATE ORGANIZATIONS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$CHANGEDATE ORGANIZATIONS.CHANGEDATE%TYPE := :NEW.CHANGEDATE;
  new$GENERALORG_REF ORGANIZATIONS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$FEDERALREGIONCODE ORGANIZATIONS.FEDERALREGIONCODE%TYPE := :NEW.FEDERALREGIONCODE;
  new$ORG_TYPE ORGANIZATIONS.ORG_TYPE%TYPE := :NEW.ORG_TYPE;
  new$BUDGETREF ORGANIZATIONS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUPPLIERSTATUS ORGANIZATIONS.SUPPLIERSTATUS%TYPE := :NEW.SUPPLIERSTATUS;
  new$COUNTRYCODE ORGANIZATIONS.COUNTRYCODE%TYPE := :NEW.COUNTRYCODE;
  new$DATECLOSE ORGANIZATIONS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$ORGCODE ORGANIZATIONS.ORGCODE%TYPE := :NEW.ORGCODE;
  new$COSTAUTHORITY ORGANIZATIONS.COSTAUTHORITY%TYPE := :NEW.COSTAUTHORITY;
  new$INCOMEAUTHORITY ORGANIZATIONS.INCOMEAUTHORITY%TYPE := :NEW.INCOMEAUTHORITY;
  new$DEBTAUTHORITY ORGANIZATIONS.DEBTAUTHORITY%TYPE := :NEW.DEBTAUTHORITY;
  new$SVRAUTHORITY ORGANIZATIONS.SVRAUTHORITY%TYPE := :NEW.SVRAUTHORITY;
  new$CLIENTID ORGANIZATIONS.CLIENTID%TYPE := :NEW.CLIENTID;
  new$DATEOPEN ORGANIZATIONS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$FUID ORGANIZATIONS.FUID%TYPE := :NEW.FUID;
  new$OKPO ORGANIZATIONS.OKPO%TYPE := :NEW.OKPO;
  new$OKTMO ORGANIZATIONS.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCSTATEREF ORGANIZATIONS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ORGANIZATIONS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$OGRN ORGANIZATIONS.OGRN%TYPE := :NEW.OGRN;
  new$REJECT_CLS ORGANIZATIONS.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$EXTID ORGANIZATIONS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER ORGANIZATIONS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE ORGANIZATIONS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$REMOTEPBSCODE ORGANIZATIONS.REMOTEPBSCODE%TYPE := :NEW.REMOTEPBSCODE;
  new$REMOTENOTPBSCODE ORGANIZATIONS.REMOTENOTPBSCODE%TYPE := :NEW.REMOTENOTPBSCODE;
  new$USECHECK_CARD ORGANIZATIONS.USECHECK_CARD%TYPE := :NEW.USECHECK_CARD;
  new$EXTROOTID ORGANIZATIONS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION ORGANIZATIONS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE ORGANIZATIONS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$RECORDOWNERORGREF ORGANIZATIONS.RECORDOWNERORGREF%TYPE := :NEW.RECORDOWNERORGREF;
  new$REJECTCAUSE ORGANIZATIONS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  CNT$ NUMBER(10);
  c1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (tr_organizations_bu)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (new$gosni is null) then
    new$gosni := 0;
  END IF;
  if (new$city is null) then
    getvarcharconst(-1,7,new$city);
  END IF;
  if (new$country is null) then
    new$country := '';
  END IF;
  if (new$countrycode is null) then
    new$countrycode := 643;
  END IF;
  if (new$org_cls is null) then
    new$org_cls:= 0;
  END IF;
  if (new$inn20 is null) then
    new$inn20:= '';
  END IF;
  if (new$rcorg is null) then
    new$rcorg := 0;
  END IF;
  if (new$regioncls is null) then
    new$regioncls := 0;
  END IF;
  if (new$okato is null) then
    new$okato := 0;
  END IF;
  if (new$kvsr is null) then
    new$kvsr := 0;
  END IF;
  if (new$okfs is null) then
    new$okfs := 0;
  END IF;
  if (new$okopf is null) then
    new$okopf := 0;
  END IF;
  if (new$federalregioncode is null) then
    getintconst(-1, 27,new$federalregioncode);
  END IF;
  if (new$federalregioncode is null) then
    new$federalregioncode := 0;
  END IF;
  if (new$budgetref is null) then
    new$budgetref := 0;
  END IF;
  /*    - */
  if (new$org_type is null) then
    new$org_type := 20000;
  END IF;
  /*        */
  if ((new$generalorg_ref is null) or (new$org_type < 10000) or (new$org_type >= 20000)) then
    new$generalorg_ref := new$id;
  END IF;

  /*    10 ,      */
  if ((new$inn <> :old.inn) or ((:old.inn is null) and (new$inn is not null))) then
    if ((new$inn > 9999999999.9) and (new$inn20 <> '')) then
      RaiseException('ex_wrongkpp');
    END IF;
  END IF;
  if ( ((new$inn <> :old.inn) or ((:old.inn is null) and (new$inn is not null)))
  or ( (new$inn20 <> :old.inn20) or ((:old.inn20 is null) and (new$inn20 is not null))) )
  then
    check_unique_organization(new$inn,  new$inn20);
  END IF;

  if (new$regioncls <> :old.regioncls) then
    update dfaccountsbuhtable set
    regioncls = new$regioncls
    where id = any (select id from org_accounts where org_ref = new$id);
  END IF;
  /*      */
  if (:old.id = 0) then
    RaiseException('ex_cantmodifyunknownorg');
  END IF;
  /*        */
  if ((new$org_type<>:old.org_type) or (new$costauthority<>:old.costauthority))
  then
    c1$ := new$costauthority;
    if (new$org_type between 10100 and 10299) then
      new$costauthority:= 1;
    END IF;
    if (new$org_type between 10300 and 10399) then
      new$costauthority:= 2;
    END IF;
    if (new$org_type between 10400 and 10499) then
      new$costauthority:= 4;
    END IF;
    if (((new$org_type between 10500 and 10599) and (new$costauthority<>16)) or
    (((new$org_type between 10000 and 10099) or (new$org_type between 10600 and 10799))
    and (new$costauthority=0))) then
      new$costauthority:= 8;
    END IF;
    if ((new$org_type=:old.org_type) and (c1$<>new$costauthority)) then
      RaiseException('ex_wrongcostauthority');
    END IF;
  END IF;
  /*    RegionCls  ,  
         */
  if (new$regioncls <> :old.regioncls) then
    update facialacc_cls fac set
    fac.regioncls = new$regioncls
    where
    new$id = fac.org_ref;

  END IF;
  if (new$UseCheck_Card is null) then
    new$UseCheck_Card := 0;
  END IF;
  if (new$RecordOwnerOrgRef is null) then
    new$RecordOwnerOrgRef := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_ORGANIZATIONS_BU_10)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$FacialAcc <> :old.FacialAcc) then
    select count(id) into CNT$ from Organizations
      where (FacialAcc = new$FacialAcc) and (id <> new$id) AND (ROWNUM = 1);
    if (CNT$ <> 0) then
      RaiseException('ex_DublicateFacialAcc');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_100 (TR_ORGANIZATIONS_BU_100)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*   */
  if ((new$DateClose is not null) and (:old.DateClose is null)) then
    /*        */
    update Org_Accounts set
    DateClose = new$DateClose,
    CloseCode = CloseCode + 10
    where Org_Ref = new$Id;

  END IF;
  /*  /      */
  if (((new$DateClose is not null) and (:old.DateClose is null)) or (new$DateClose <> :old.DateClose)) then
    /*     / */
    update FacialAcc_Cls set
    DateClose = new$DateClose,
    CloseCode = CloseCode + 10
    where Org_ref = new$Id;
  END IF;
  /*   */
  if ((new$DateClose is null) and (:old.DateClose is not null)) then
    update Org_Accounts set
    CloseCode = CloseCode - 10
    where Org_Ref = new$Id;

    /*     / */
    update FacialAcc_Cls set
    DateClose = new$DateClose,
    CloseCode = CloseCode - 10
    where Org_ref = new$Id;

  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_ORGANIZATIONS_BU_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

  if (new$id <> new$GeneralOrg_Ref) then
    select count(*) into cnt$
    from Organizations o where (o.id = new$GeneralOrg_Ref) AND (ROWNUM = 1);

    if cnt$ = 0 then
      RaiseException('ex_GeneralOrgNotFound');
    end if;
  end if;

  if (new$GeneralOrg_Ref <> :old.GeneralOrg_Ref) then
    update FacialAcc_CLS set
      GeneralOrg_Ref = new$GeneralOrg_Ref
    where
      Org_Ref = new$id;
  end if;

-- - - - - - - - - - - - -
-- BU_210 (TR_ORGANIZATIONS_BU_210)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$DOCSTATEREF <> :old.DOCSTATEREF) then
    insert into StateJumpHistory(DocID, BeginStateRef, EndStateRef)
    values(new$id, :old.DOCSTATEREF, new$DOCSTATEREF);
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_ORGANIZATIONS_BU_700)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  IF (new$RVersion IS NULL) THEN
    new$RVersion := 1;
  ELSIF ( (new$RVersion = -1) AND (:OLD.RVersion <> -1) ) THEN
    new$RVersion := :OLD.RVersion;
  ELSE
    new$RVersion := :OLD.RVersion + 1;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_ORGANIZATIONS SET
    ID = new$ID,
    NAME = new$NAME,
    GOSNI = new$GOSNI,
    CITY = new$CITY,
    COUNTRY = new$COUNTRY,
    PHONE = new$PHONE,
    ADDRESS = new$ADDRESS,
    ORG_CLS = new$ORG_CLS,
    INN20 = new$INN20,
    SUBINN = new$SUBINN,
    FACIALACC = new$FACIALACC,
    REGIONCLS = new$REGIONCLS,
    DIRNAME = new$DIRNAME,
    BUGNAME = new$BUGNAME,
    DIRPHONE = new$DIRPHONE,
    BUGPHONE = new$BUGPHONE,
    RCORG = new$RCORG,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    INN = new$INN,
    OKATO = new$OKATO,
    EMAIL = new$EMAIL,
    WEBSITE = new$WEBSITE,
    UFKCODE = new$UFKCODE,
    ADDOKATO = new$ADDOKATO,
    SHORTNAME = new$SHORTNAME,
    RVERSION = new$RVERSION,
    SENDERID = new$SENDERID,
    KVSR = new$KVSR,
    OKFS = new$OKFS,
    OKOPF = new$OKOPF,
    OPENDATE = new$OPENDATE,
    CLOSEDATE = new$CLOSEDATE,
    CHANGEDATE = new$CHANGEDATE,
    GENERALORG_REF = new$GENERALORG_REF,
    FEDERALREGIONCODE = new$FEDERALREGIONCODE,
    ORG_TYPE = new$ORG_TYPE,
    BUDGETREF = new$BUDGETREF,
    SUPPLIERSTATUS = new$SUPPLIERSTATUS,
    COUNTRYCODE = new$COUNTRYCODE,
    DATECLOSE = new$DATECLOSE,
    ORGCODE = new$ORGCODE,
    COSTAUTHORITY = new$COSTAUTHORITY,
    INCOMEAUTHORITY = new$INCOMEAUTHORITY,
    DEBTAUTHORITY = new$DEBTAUTHORITY,
    SVRAUTHORITY = new$SVRAUTHORITY,
    CLIENTID = new$CLIENTID,
    DATEOPEN = new$DATEOPEN,
    FUID = new$FUID,
    OKPO = new$OKPO,
    OKTMO = new$OKTMO,
    DOCSTATEREF = new$DOCSTATEREF,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    OGRN = new$OGRN,
    REJECT_CLS = new$REJECT_CLS,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    REMOTEPBSCODE = new$REMOTEPBSCODE,
    REMOTENOTPBSCODE = new$REMOTENOTPBSCODE,
    USECHECK_CARD = new$USECHECK_CARD,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    RECORDOWNERORGREF = new$RECORDOWNERORGREF,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AU_100 (TR_ORGANIZATIONS_AU_100)
-- Create 27.07.2007
-- - - - - - - - - - - - -

-- Comment   / 


  /*    */
  if ((new$DateClose is not null) and (:old.DateClose is null)) then
    update Banks set DateClose = new$DateClose where (id = new$ID) and (DateClose is null);
  end if;

  /*    */
  if ((new$DateClose is null) and (:old.DateClose is not null)) then
    update Banks set DateClose = null where (id = new$ID) and (DateClose is not null);
  end if;

-- - - - - - - - - - - - -
-- AU_200 (TR_ORGANIZATIONS_AU_200)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$BudgetRef <> :old.BudgetRef) then
    update FacialAcc_CLS set
    BudgetRef = new$BudgetRef
    where
    (ORG_REF = new$id)and((BudgetRef = :old.BudgetRef)or(BudgetRef<>0));
  END IF;
  /*     ,    */
  if ((new$KVSR <> :old.KVSR)and(new$Org_Type >= 10100)and(new$Org_Type <= 10299)) then
    update KVSR set
    Org_Ref = new$id
    where
    id = new$KVSR;
  END IF;
  if (new$KVSR <> :old.KVSR) then
    update FacialAcc_CLS set
    KVSR = new$KVSR
    where
    (ORG_REF = new$id) and (KVSR = :old.KVSR);
  END IF;
  if (new$BudgetRef <> :old.BudgetRef) then
    update organizations set
    BudgetRef = new$BudgetRef
    where
    (generalorg_ref = new$id) and (id <> new$id);
  END IF;
  if (new$KVSR <> :old.KVSR) then
    update organizations set
    KVSR = new$KVSR
    where
    (generalorg_ref = new$id) and (id <> new$id);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_ORGANIZATIONS_AU_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (27, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=27) and (RecordId=new$ID);
  end if;

END;
/
commit work 
/

-- #########################################################
-- #########################################################
-- Alter_Tab_PayDocEx_Note_to_NOTE1024.sql
-- #########################################################
-- #########################################################

/*     Note 
  PAYDOCEXCHANGE  1024 */
ALTER TABLE PAYDOCEXCHANGE ADD (
  NOTENew VARCHAR2(1024)
)
/
ALTER TRIGGER TR_PAYDOCEXCHANGE_BU_500 DISABLE
/
update PAYDOCEXCHANGE set NOTENew = SUBSTR(NOTE ,1 ,1024)
/
ALTER TRIGGER TR_PAYDOCEXCHANGE_BU_500 ENABLE
/
ALTER TABLE PAYDOCEXCHANGE DROP (NOTE)
/
ALTER TABLE PAYDOCEXCHANGE RENAME COLUMN NOTENew TO NOTE
/
COMMIT WORK
/


-- #########################################################
-- #########################################################
-- Fill_TargetCls.sql
-- #########################################################
-- #########################################################

/* >Add_ContractCostsCls.sql *//* 
    ,         "  " (32, 41). 
  ,                  
  . 
*/
/*         "  " (32, 41) */
CREATE OR REPLACE procedure GetTargetCls(OldTransfertCls$ NUMBER,NewTransfertCls$ NUMBER,
    OldMeansType$ NUMBER,  NewMeansType$ NUMBER,NewTargetCls$ NUMBER,  TargetCls$ out NUMBER)
AS
  const$ NUMBER(10);
BEGIN
  getintconst(32, 41,const$);
  if (((const$ = 0) and (((OldMeansType$  is null) and (NewMeansType$  is not null)) or
  ((OldMeansType$  is not null) and (NewMeansType$  is null)) or ((OldMeansType$  is not null) and 
  (NewMeansType$  is not null) and (OldMeansType$  <> NewMeansType$)))) or ((const$ = 2) and (NewTargetCls$ is null))) then
    BEGIN
      /*       */
      select
      TargetCls
      into
      TargetCls$     from
      MeansType
      where
      (id = NewMeansType$)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  else 
    if (((const$ = 1) and (((OldTransfertCls$  is null) and (NewTransfertCls$  is not null)) or
    ((OldTransfertCls$  is not null) and (NewTransfertCls$  is null)) or ((OldTransfertCls$  is not null) and 
    (NewTransfertCls$  is not null) and (OldTransfertCls$  <> NewTransfertCls$)))) or ((const$ = 3) and (NewTargetCls$ is null))) then
      BEGIN
        /*        */
        select
        TargetCls
        into
        TargetCls$       from
        TransfertCls
        where
        (id = NewTransfertCls$)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    else 
      /*          */      
      TargetCls$ := NewTargetCls$;
    END IF;
  END IF;
END;
/
grant execute on GetTargetCls to BUDGET_USERS
/
-- ALTER TRIGGER tr_FacialFinDetail_bi_110
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_II
  INSTEAD OF INSERT
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
--
  SourceFacialAcc_CLS$ NUMBER(10);
  DestFacialAcc_CLS$ NUMBER(10);
  CapBuhOperationCLS$ NUMBER(10);
  CapClsType$ NUMBER(10);
  CapAcceptDate$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  PromiseAcceptDate$ NUMBER;
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  BPInnerNum1$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  Promise_Count1$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  PromiseAccepted1$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALFINDETAIL_BI_0)
-- Last update 15.12.2002
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_FacialFinDetail_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;
        
  else
    new$SenderIDKey := new$SenderID;
  END IF;
      
  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;
        
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_FACIALFINDETAIL_BI_100)
-- Last update 12.01.2009
-- - - - - - - - - - - - -

 /*  ,    */
   BEGIN

     select
       ffc.BudgetRef, ffc.BuhOperationCls, ffc.ClsType, ffc.AcceptDate,
       ffc.IsBlocked, ffc.BlockedCause, ffc.UnBlockedDate, ffc.UnBlockedCause
     into new$BudgetRef, CapBuhOperationCls$, CapClsType$, CapAcceptDate$,
       new$IsBlocked, new$BlockedCause, new$UnBlockedDate, new$UnBlockedCause
     from
       FacialFinCaption ffc
     where
       ffc.id = new$RecordIndex;
     
   EXCEPTION
     WHEN NO_DATA_FOUND THEN
       new$BudgetRef := NULL;
       CapBuhOperationCls$ := NULL;
       CapClsType$ := NULL;
       CapAcceptDate$ := NULL;
   END;

   /*      */
   if (new$BuhOperationCls is null) then new$BuhOperationCls := CapBuhOperationCls$; end if;

   /*      */
   if (new$ClsType is null) then new$ClsType := CapClsType$; end if;

   if (new$DestClsType is null) then new$DestClsType := new$ClsType; end if;
   
   /*      */
   if (new$AcceptDate is null) then new$AcceptDate := CapAcceptDate$; end if;

   /*      */
   if ((new$SourceFacialAcc_CLS is null) or (new$DestFacialAcc_CLS is null)) then
     BEGIN
       select SourceFacialAcc_CLS, DestFacialAcc_CLS
         into SourceFacialAcc_CLS$, DestFacialAcc_CLS$
       from FacialFinCaption
       where new$RecordIndex = id;
     EXCEPTION
       WHEN NO_DATA_FOUND THEN
         SourceFacialAcc_CLS$ := NULL;
         DestFacialAcc_CLS$ := NULL;
     END;

     if (new$SourceFacialAcc_CLS is null) then new$SourceFacialAcc_CLS := SourceFacialAcc_CLS$; end if;
     if (new$DestFacialAcc_CLS is null) then new$DestFacialAcc_CLS := DestFacialAcc_CLS$; end if;
   end if;

-- - - - - - - - - - - - -
-- BI_110 (TR_FACIALFINDETAIL_BI_110)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL OR (new$Sourcefintype=0)) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;
     
  END IF;
  IF (new$DestFintype IS NULL OR (new$Destfintype=0)) THEN 
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 1000;
  END IF;
  IF (new$SourceIFS IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 1000;
  END IF;
  IF (new$DestIFS IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*   Promise null,    */
  IF ((new$Promise IS NULL) AND
  ((new$SourcePromise IS NOT NULL) OR
  (new$DestPromise IS NOT NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND(new$DestPromise IS NOT NULL)AND
        (new$SourcePromise=new$DestPromise)) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*    ,  ,       */
  ELSE
    IF ((new$Promise IS NOT NULL) AND
    (new$SourcePromise IS NULL) AND
    (new$DestPromise IS NULL)) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  BEGIN

    /*     \   */
    SELECT org.Org_Type  INTO new$SourceFAOrg_Type FROM Organizations org
    INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$SourceFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  BEGIN

    SELECT org.Org_Type  INTO new$DestFAOrg_Type FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$DestFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*       */
  GETTARGETCLS(null, new$sourcetransfertcls, null, new$sourcemeanstype,
  new$sourcetargetcls,new$sourcetargetcls);
  GETTARGETCLS(null, new$desttransfertcls, null, new$destmeanstype,
  new$desttargetcls,new$desttargetcls);

-- - - - - - - - - - - - -
-- BI_120 (TR_FACIALFINDETAIL_BI_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*  60 :  '   .'; source
          61 :  '      '; dest
          62 :  '   ';dest
          63 :  '    '; source
          64 :  '   '; source
          65 :  ' , ';dest
          66 :  '  ,  - '; source dest
          67 :  '   ';source
          68 :  '  \ ';dest
          69 :  '   \ '; dest
          70 :  '  \ ';source
          71 :  '   \ '; dest */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if ((new$DestClsType is NULL) and
  (
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71))) or (new$ProgIndex = 60)
  )) then
    new$DestClsType := 1; /*       ClsType */
      
  else
    if ((new$DestClsType is NULL) and
    ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    ) then
      new$DestClsType := 2; /*        ClsType */
          
    else
      if (new$DestClsType is null) then
        new$DestClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_FACIALFINDETAIL_BI_200)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode1$);
  /*     */
  if (((new$SourcePromise is not null) or (new$DestPromise is not null)) and (PromiseMode1$ <> 1)) then
    if (new$SourcePromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$         from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    if (new$DestPromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$         from
      promise_detail pr
      where
      (pr.registrnumber = new$DESTPROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;    
    END IF;
  END IF;
  if (PromiseMode1$ = 1) then
    /* source  .    */
    if ((new$SourcePromise is not null) and (new$SourceBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum1$           from PaymentSchedule 
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum1$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* dest  .    */
    if ((new$DestPromise is not null) and (new$DestBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum1$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$DestBudgetPromise := BPInnerNum1$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* source    ,   ,   */
    if ((new$SourceBudgetPromise is not null) and (new$SourcePromise is null)) then
      BEGIN
        select ANumber 
        into BPInnerNum1$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$SourcePromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;
            
    END IF;
    /* dest */
    if ((new$DestBudgetPromise is not null) and (new$DestPromise is null)) then
      BEGIN
        select ANumber 
        into BPInnerNum1$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$DestPromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;
            
    END IF;
    /*     */
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$1
      from PaymentSchedule where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls1$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$2
      from PaymentSchedule where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls1$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_FACIALFINDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$SourceExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*    ,   ,  */
    else 
      if (new$SourceExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$DestExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*    ,   ,  */
    else 
      if (new$DestExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALFINDETAIL_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update facialfincaption set
  DocChangeDate = new$UpdateDate,
  RVersion=-1
  where id=new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALFINDETAIL (
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    NOTE,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS,
    DESTTARGETCLS
  ) VALUES (
    new$ID,
    new$SOURCEFACIALACC_CLS,
    new$SOURCEKVR,
    new$SOURCEKESR,
    new$DESTFACIALACC_CLS,
    new$DESTKVR,
    new$DESTKESR,
    new$BUDGETREF,
    new$CREDIT,
    new$PAYSYMBOLCLS,
    new$MEMORDERNUM,
    new$NOTE,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$SOURCEKVSR,
    new$SOURCEKCSR,
    new$SOURCEKFSR,
    new$SOURCESUBKESR,
    new$SOURCEFACT,
    new$SOURCEMEANSTYPE,
    new$SOURCEFINSOURCE,
    new$SOURCEFINTYPE,
    new$DESTKVSR,
    new$DESTKCSR,
    new$DESTKFSR,
    new$DESTSUBKESR,
    new$DESTFACT,
    new$DESTMEANSTYPE,
    new$DESTFINSOURCE,
    new$DESTFINTYPE,
    new$REQUESTSINDEX,
    new$SENDERID,
    new$SENDERRECORDID,
    new$PROMISE,
    new$SOURCEDOCTYPE,
    new$DESTDOCTYPE,
    new$SOURCEPROMISE,
    new$DESTPROMISE,
    new$RECORDINDEX2,
    new$SOURCEBUDGETPROMISE,
    new$DESTBUDGETPROMISE,
    new$SUBPROGINDEX,
    new$STIMATEID,
    new$RVERSION,
    new$SOURCEDIRECTIONCLS,
    new$DESTDIRECTIONCLS,
    new$SOURCEDOCBASE,
    new$DESTDOCBASE,
    new$SOURCEEXECDOC,
    new$DESTEXECDOC,
    new$BUHOPERATIONCLS,
    new$SOURCEIFS,
    new$DESTIFS,
    new$CLSTYPE,
    new$UNIONNOTIFYREF,
    new$ACCEPTDATE,
    new$SOURCEKD,
    new$DESTKD,
    new$SOURCEREGIONCLS,
    new$DESTREGIONCLS,
    new$DESTFUNDSSOURCE,
    new$SOURCEFUNDSSOURCE,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SOURCETRANSFERTCLS,
    new$DESTTRANSFERTCLS,
    new$DESTCLSTYPE,
    new$SOURCEASSIGNMENTKIND,
    new$DESTASSIGNMENTKIND,
    new$SOURCEEXECINNERNUMBER,
    new$DESTEXECINNERNUMBER,
    new$SOURCESUBSIDYCLS,
    new$DESTSUBSIDYCLS,
    new$SOURCEFAORG_TYPE,
    new$DESTFAORG_TYPE,
    new$SOURCEBUDALLOCATIONCLS,
    new$SOURCEPAYPROMISECLS,
    new$DESTBUDALLOCATIONCLS,
    new$DESTPAYPROMISECLS,
    new$SOURCEINVESTOBJECT,
    new$DESTINVESTOBJECT,
    new$TRANSFERTORG_REF,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$STOREDPAYMENTCONTENT,
    new$SOURCECONTRACTCOSTSCLS,
    new$DESTCONTRACTCOSTSCLS,
    new$SOURCETARGETCLS,
    new$DESTTARGETCLS);

-- - - - - - - - - - - - -
-- AI_100 (TR_FACIALFINDETAIL_AI_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  update FacialFinCaption set
  ClsType = new$ClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(ClsType <> new$ClsType);
  update FacialFinCaption set
  DestClsType = new$DestClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(DestClsType <> new$DestClsType);

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALFINDETAIL_AI_500)
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID =22 ) and (RecordID = new$ID);

END;
/
-- ALTER TRIGGER tr_FacialFinDetail_bu_110
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;
     
  END IF;
  IF (new$DestFintype IS NULL) THEN 
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*       */
  GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
  new$Sourcetargetcls,new$Sourcetargetcls);
  GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
  new$Desttargetcls,new$Desttargetcls);     

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*  60 :  '   .'; source
          61 :  '      '; dest
          62 :  '   ';dest
          63 :  '    '; source
          64 :  '   '; source
          65 :  ' , ';dest
          66 :  '  ,  - '; source dest
          67 :  '   ';source
          68 :  '  \ ';dest
          69 :  '   \ '; dest
          70 :  '  \ ';source
          71 :  '   \ '; dest */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  /*     */
  if (PromiseMode$ <> 1) then
    /*          */
    if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /*          */
    if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$DestPromise)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
        
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /*     */
  if (PromiseMode$ = 1) then
    /* source  .    */
    if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
    (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule 
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* dest  .     */
    if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
    (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
          
    /*         NULL,    */
    /* source */
    if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
    (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /* dest */
    if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
    (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /*    ,     */
    if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
      new$SourcePromise := null;
      new$Promise := null;
            
    END IF;
    if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
      new$DestPromise := null;
      new$Promise := null;
            
    END IF;
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$1
      from PaymentSchedule
      where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$2
      from PaymentSchedule
      where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$SourcePromise is not null and (
    (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
    (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$SourceExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null and (
    (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
    (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$DestExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select c.AcceptDate into CapAcceptDate$
      from facialfincaption c
      where c.id = new$RecordIndex;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        CapAcceptDate$ := NULL;
    END;

    if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
      new$AcceptDate := new$AcceptDate;
    else
      RaiseException('ex_wrongacceptdate');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
commit work 
/
-- ALTER TRIGGER tr_budgetdata_bi
CREATE OR REPLACE TRIGGER TR_BUDGETDATA_BI
  BEFORE INSERT
  ON BUDGETDATA
  FOR EACH ROW
DECLARE
  AutoKvrCorr$ NUMBER(10);
  OrgRefByAcc1$ NUMBER(10);
  CapClsType1$ NUMBER(10);
  doubleUse1$ NUMBER(10);
  BALBOFlag1$ NUMBER(10);
  AllowDivideBA1$ NUMBER(10);
  StimateKind1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_BUDGETDATA_BI)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (:new.id IS NULL) THEN 
    select g_shared.nextval into :new.id from dual;
  END IF;
  IF (:new.KFSR IS NULL) THEN  
    :new.KFSR := 0;
  END IF;
  IF (:new.KVSR IS NULL) THEN  
    :new.KVSR := 0;
  END IF;
  IF (:new.KVR IS NULL) THEN  
    :new.KVR := 0;
  END IF;
  IF (:new.KCSR IS NULL) THEN  
    :new.KCSR := 0;
  END IF;
  IF (:new.KESR IS NULL) THEN  
    :new.KESR := 0;
  END IF;
  IF (:new.SubKESR IS NULL) THEN  
    :new.SubKESR := 0;
  END IF;
  IF (:new.RegionCLS IS NULL) THEN  
    :new.RegionCLS := 0;
  END IF;
  IF (:new.DirectionCls IS NULL) THEN 
    :new.DirectionCls := 0;
  END IF;
  IF (:new.FundsSource IS NULL) THEN 
    :new.FundsSource := 0;
  END IF;
  IF (:new.KD IS NULL) THEN 
    :new.KD := 0;
  END IF;
  IF (:new.subkd IS NULL) THEN 
    :new.subkd := 0;
  END IF;
  IF (:new.Fact IS NULL) THEN  
    :new.Fact := 0;
  END IF;
  IF (:new.FacialAcc_Cls IS NULL) THEN 
    :new.FacialAcc_Cls := 0;
  END IF;
  IF (:new.KVRCorr IS NULL) THEN 
    :new.KVRCorr := 0;
  END IF;
  IF (:new.KESRCorr IS NULL) THEN 
    :new.KESRCorr := 0;
  END IF;
  IF (:new.AssignmentKind IS NULL) THEN 
    :new.AssignmentKind := 0;
  END IF;
  IF (:new.Quarter1 IS NULL) THEN  
    :new.Quarter1 := 0;
  END IF;
  IF (:new.Quarter2 IS NULL) THEN  
    :new.Quarter2 := 0;
  END IF;
  IF (:new.Quarter3 IS NULL) THEN  
    :new.Quarter3 := 0;
  END IF;
  IF (:new.Quarter4 IS NULL) THEN  
    :new.Quarter4 := 0;
  END IF;
  IF (:new.DayPlanSumma IS NULL) THEN 
    :new.DayPlanSumma := 0;
  END IF;
  IF (:new.FinType IS NULL) THEN  
    :new.FinType := 0;
  END IF;
  IF (:new.MeansType IS NULL) THEN 
    :new.MeansType := 0;
  END IF;
  IF (:new.DepartmentCls IS NULL) THEN 
    :new.DepartmentCls := 0;
  END IF;
  /*   .      */
  IF (:new.IFS IS NULL) THEN 
    :new.IFS := 0;
  END IF;
  IF (:new.BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,:new.BuhOperationCLS);
  END IF;
  BEGIN

    /*  .   */
    SELECT bn.BudgetRef      INTO :new.BudgetRef FROM BudNotify bn
    WHERE bn.id = :new.RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  IF (:new.Month01 IS NULL) THEN  
    :new.Month01 := 0;
  END IF;
  IF (:new.Month02 IS NULL) THEN  
    :new.Month02 := 0;
  END IF;
  IF (:new.Month03 IS NULL) THEN  
    :new.Month03 := 0;
  END IF;
  IF (:new.Month04 IS NULL) THEN  
    :new.Month04 := 0;
  END IF;
  IF (:new.Month05 IS NULL) THEN  
    :new.Month05 := 0;
  END IF;
  IF (:new.Month06 IS NULL) THEN  
    :new.Month06 := 0;
  END IF;
  IF (:new.Month07 IS NULL) THEN  
    :new.Month07 := 0;
  END IF;
  IF (:new.Month08 IS NULL) THEN  
    :new.Month08 := 0;
  END IF;
  IF (:new.Month09 IS NULL) THEN  
    :new.Month09 := 0;
  END IF;
  IF (:new.Month10 IS NULL) THEN  
    :new.Month10 := 0;
  END IF;
  IF (:new.Month11 IS NULL) THEN  
    :new.Month11 := 0;
  END IF;
  IF (:new.Month12 IS NULL) THEN  
    :new.Month12 := 0;
  END IF;
  IF (:new.SummaYear1 IS NULL) THEN  
    :new.SummaYear1 := 0;
  END IF;
  IF (:new.SummaYear2 IS NULL) THEN  
    :new.SummaYear2 := 0;
  END IF;
  IF (:new.SummaYear3 IS NULL) THEN  
    :new.SummaYear3 := 0;
  END IF;
  IF (:new.SummaYear4 IS NULL) THEN  
    :new.SummaYear4 := 0;
  END IF;
  IF (:new.SummaOtherYears IS NULL) THEN  
    :new.SummaOtherYears := 0; 
  END IF;
  BEGIN

    SELECT
    c.BA_LBO_FLAG
    INTO
    BALBOFlag1$  FROM
    BudNotify c
    WHERE
    c.id = :new.RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*   */
  IF (:new.ProgIndex = 262) THEN
    GetIntConst(32, 43,StimateKind1$);
    IF ((StimateKind1$  = 0) OR (StimateKind1$  IS NULL)) THEN
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
         
    ELSE
      IF (StimateKind1$  = 1) THEN
        :new.Quarter1 := :new.SummaYear1;
             
      ELSE
        :new.Quarter1 := :new.Month01 + :new.Month02 +:new.Month03;
        :new.Quarter2 := :new.Month04 + :new.Month05 +:new.Month06;
        :new.Quarter3 := :new.Month07 + :new.Month08 +:new.Month09;
        :new.Quarter4 := :new.Month10 + :new.Month11 +:new.Month12;
        :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
             
      END IF; 
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 260) THEN
    GetIntConst(32, 30,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 264) THEN
    GetIntConst(32, 34,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 32) THEN
    GetIntConst(32, 31,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*          ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 215) THEN
    GetIntConst(32, 35,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*         ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /* 
   IF ((NEW.TransfertOrg_Ref IS NULL) AND (NEW.REGIONCLS <> 0)) THEN
      SELECT Organizations FROM REGIONCLS
        WHERE NEW.REGIONCLS = ID
      INTO NEW.TransfertOrg_Ref;
  *//*    */
  GETTARGETCLS(null, :new.transfertcls, null, :new.meanstype,
  :new.targetcls,:new.targetcls);

-- - - - - - - - - - - - -
-- BI_10 (tr_BudgetData_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (:new.SenderID is null) then
    :new.SenderIDKey := -1;
        
  else
    :new.SenderIDKey := :new.SenderID;
  END IF;
      
  if (:new.SenderRecordID is null) then
    :new.SenderRecordIDKey := :new.ID;
        
  else
    :new.SenderRecordIDKey := :new.SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_BUDGETDATA_BI_100)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if (:new.ClsType is NULL) then
    BEGIN
      select
      bn.ClsType
      into
      CapClsType1$     from
      BudNotify bn
      where
      bn.id = :new.RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (CapClsType1$  = 3) then
      if (:new.IFS <> 0) then
        :new.ClsType := 1; /*       ClsType */
            
      else
        if (:new.KD <> 0) then
          :new.ClsType := 2; /* */
                
        else
          :new.ClsType := 0; /* */
        END IF;    
      END IF;
    else
      :new.ClsType := CapClsType1$;
      
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND ((:new.IFS <> 0)or(:new.KD <> 0))) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0)
  )) THEN
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  if (((:new.ClsType = 1)and(:new.KD <> 0))or((:new.ClsType = 2)and(:new.IFS <> 0))) then
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 1) AND (:new.ClsType <> 2)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;
  IF (:new.ACC_REF IS NOT NULL) THEN /*    / */
    BEGIN
      SELECT oa.ORG_REF
      INTO OrgRefByAcc1$     FROM ORG_ACCOUNTS oa
      WHERE (oa.ID = :new.ACC_REF)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (:new.FacialAcc_CLS = 0) then 
      :new.Org_Ref := OrgRefByAcc1$;
      
    END IF;
  END IF;
  /*  \ ,       \    \,  \ */
  if (:new.FacialAcc_CLS <> 0) then
    BEGIN
      SELECT
      fac.ORG_REF
      INTO :new.Org_Ref     FROM
      FacialACC_CLS fac
      WHERE
      (fac.ID = :new.FacialAcc_CLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (OrgRefByAcc1$<>:new.Org_Ref) then 
      :new.ACC_REF := null;
      
    END IF;
  END IF;
  if ((:new.ProgIndex in (252, 253))and(:new.FacialAcc_CLS = 0)) then
    BEGIN
      SELECT
      bn.FacialAccCLS
      INTO :new.FacialAcc_CLS     FROM
      BudNotify bn
      WHERE
      (bn.ID = :new.RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_BUDGETDATA_BI_200)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*       32-, 260-, 261-, 262-  , 263-, 268-  , 252-. */
  if (:new.ProgIndex in (32, 252, 260, 261, 262, 263, 268)) then
    /*     (32  ()) 
             :
           =0     ,
           =1  ,
           =2   0  .*//*     260 ()
             :
           =2   0  .*/
    GetIntConst(32, 25,AutoKvrCorr$);
    if (:new.ProgIndex = 32) then /*  ()*/
      if (AutoKvrCorr$  = 0) then
        :new.KvrCorr := :new.Kvr;
              
      else
        if (AutoKvrCorr$  = 2) then
          :new.KvrCorr := 0;
        END IF;
      END IF;
      /* KESR   */
      if (AutoKvrCorr$  = 0) then
        :new.KesrCorr := :new.Kesr;
              
      else
        if (AutoKvrCorr$  = 2) then
          :new.KesrCorr := 0;
        END IF;    
      END IF;
    else 
      if ((:new.ProgIndex = 260)and (AutoKvrCorr$  = 2)) then  /* ()*/
        :new.KvrCorr := 0;
        --   ,    new.Kvr = 0;
        /* KESR   */        
                
        :new.KesrCorr := 0;
        :new.Kesr := 0;     
              
      else 
        :new.KvrCorr := :new.Kvr; /*         */
        /* KESR   */        
        :new.KesrCorr := :new.Kesr;
              
      END IF;  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_BUDGETDATA_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

  Update BudNotify set
  DocChangeDate = :new.UpdateDate,
  RVersion = -1
  where id = :new.recordindex;

END;
/
-- ALTER TRIGGER tr_budgetdata_bu
CREATE OR REPLACE TRIGGER TR_BUDGETDATA_BU
  BEFORE UPDATE
  ON BUDGETDATA
  FOR EACH ROW
DECLARE
  AutoKvrCorr$ NUMBER(10);
  OrgRefByAcc1$ NUMBER(10);
  CapClsType1$ NUMBER(10);
  doubleUse1$ NUMBER(10);
  BALBOFlag1$ NUMBER(10);
  AllowDivideBA1$ NUMBER(10);
  StimateKind1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_BUDGETDATA_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (:new.KFSR IS NULL) THEN  
    :new.KFSR := 0;
  END IF;
  IF (:new.KVSR IS NULL) THEN  
    :new.KVSR := 0;
  END IF;
  IF (:new.KVR IS NULL) THEN  
    :new.KVR := 0;
  END IF;
  IF (:new.KCSR IS NULL) THEN  
    :new.KCSR := 0;
  END IF;
  IF (:new.KESR IS NULL) THEN  
    :new.KESR := 0;
  END IF;
  IF (:new.SubKESR IS NULL) THEN  
    :new.SubKESR := 0;
  END IF;
  IF (:new.RegionCLS IS NULL) THEN  
    :new.RegionCLS := 0;
  END IF;
  IF (:new.DirectionCls IS NULL) THEN 
    :new.DirectionCls := 0;
  END IF;
  IF (:new.FundsSource IS NULL) THEN 
    :new.FundsSource := 0;
  END IF;
  IF (:new.KD IS NULL) THEN 
    :new.KD := 0;
  END IF;
  IF (:new.subkd IS NULL) THEN 
    :new.subkd := 0;
  END IF;
  IF (:new.Fact IS NULL) THEN  
    :new.Fact := 0;
  END IF;
  IF (:new.FacialAcc_Cls IS NULL) THEN 
    :new.FacialAcc_Cls := 0;
  END IF;
  IF (:new.KVRCorr IS NULL) THEN 
    :new.KVRCorr := 0;
  END IF;
  IF (:new.KesrCorr IS NULL) THEN 
    :new.KesrCorr := 0;
  END IF;
  IF (:new.AssignmentKind IS NULL) THEN 
    :new.AssignmentKind := 0;
  END IF;
  IF (:new.Quarter1 IS NULL) THEN  
    :new.Quarter1 := 0;
  END IF;
  IF (:new.Quarter2 IS NULL) THEN  
    :new.Quarter2 := 0;
  END IF;
  IF (:new.Quarter3 IS NULL) THEN  
    :new.Quarter3 := 0;
  END IF;
  IF (:new.Quarter4 IS NULL) THEN  
    :new.Quarter4 := 0;
  END IF;
  IF (:new.FinType IS NULL) THEN  
    :new.FinType := 0;
  END IF;
  IF (:new.MeansType IS NULL) THEN  
    :new.MeansType := 0;
  END IF;
  IF (:new.DepartmentCls IS NULL) THEN 
    :new.DepartmentCls := 0;
  END IF;
  /*   .        */
  IF (:new.IFS IS NULL) THEN 
    :new.IFS := 0;
  END IF;
  IF (:new.BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,:new.BuhOperationCLS);
  END IF;
  IF (:new.Month01 IS NULL) THEN  
    :new.Month01 := 0;
  END IF;
  IF (:new.Month02 IS NULL) THEN  
    :new.Month02 := 0;
  END IF;
  IF (:new.Month03 IS NULL) THEN  
    :new.Month03 := 0;
  END IF;
  IF (:new.Month04 IS NULL) THEN  
    :new.Month04 := 0;
  END IF;
  IF (:new.Month05 IS NULL) THEN  
    :new.Month05 := 0;
  END IF;
  IF (:new.Month06 IS NULL) THEN  
    :new.Month06 := 0;
  END IF;
  IF (:new.Month07 IS NULL) THEN  
    :new.Month07 := 0;
  END IF;
  IF (:new.Month08 IS NULL) THEN  
    :new.Month08 := 0;
  END IF;
  IF (:new.Month09 IS NULL) THEN  
    :new.Month09 := 0;
  END IF;
  IF (:new.Month10 IS NULL) THEN  
    :new.Month10 := 0;
  END IF;
  IF (:new.Month11 IS NULL) THEN  
    :new.Month11 := 0;
  END IF;
  IF (:new.Month12 IS NULL) THEN  
    :new.Month12 := 0;
  END IF;
  IF (:new.SummaYear1 IS NULL) THEN  
    :new.SummaYear1 := 0;
  END IF;
  IF (:new.SummaYear2 IS NULL) THEN  
    :new.SummaYear2 := 0;
  END IF;
  IF (:new.SummaYear3 IS NULL) THEN  
    :new.SummaYear3 := 0;
  END IF;
  IF (:new.SummaYear4 IS NULL) THEN  
    :new.SummaYear4 := 0;
  END IF;
  IF (:new.SummaOtherYears IS NULL) THEN  
    :new.SummaOtherYears := 0; 
  END IF;
  IF (:new.DayPlanSumma IS NULL) THEN 
    :new.DayPlanSumma := 0;
  END IF;
  /*     */
  IF (:new.BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((:new.BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN
      RaiseException('Ex_CantModufyBudget');
    END IF;
  END IF;
  BEGIN

    SELECT
    c.BA_LBO_FLAG
    INTO
    BALBOFlag1$  FROM
    BudNotify c
    WHERE
    c.id = :new.RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*   */
  IF (:new.ProgIndex = 262) THEN
    GetIntConst(32, 43,StimateKind1$);
    IF ((StimateKind1$  = 0) OR (StimateKind1$  IS NULL)) THEN
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
         
    ELSE
      IF (StimateKind1$  = 1) THEN
        :new.Quarter1 := :new.SummaYear1;
             
      ELSE
        :new.Quarter1 := :new.Month01 + :new.Month02 +:new.Month03;
        :new.Quarter2 := :new.Month04 + :new.Month05 +:new.Month06;
        :new.Quarter3 := :new.Month07 + :new.Month08 +:new.Month09;
        :new.Quarter4 := :new.Month10 + :new.Month11 +:new.Month12;
        :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
             
      END IF; 
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 260) THEN
    GetIntConst(32, 30,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 264) THEN
    GetIntConst(32, 34,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 32) THEN
    GetIntConst(32, 31,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*          ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 215) THEN
    GetIntConst(32, 35,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*         ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /* 
   IF ((NEW.TransfertOrg_Ref IS NULL) AND (NEW.REGIONCLS <> 0)) THEN
       SELECT Organizations FROM REGIONCLS
         WHERE NEW.REGIONCLS = ID
       INTO NEW.TransfertOrg_Ref;
  *//*    */
  GETTARGETCLS(:old.transfertcls, :new.transfertcls, :old.meanstype, :new.meanstype,
  :new.targetcls,:new.targetcls);

-- - - - - - - - - - - - -
-- BU_100 (TR_BUDGETDATA_BU_100)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if (:new.ClsType is NULL) then
    BEGIN
      select
      bn.ClsType
      into
      CapClsType1$     from
      BudNotify bn
      where
      bn.id = :new.RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (CapClsType1$  = 3) then
      if (:new.IFS <> 0) then
        :new.ClsType := 1; /*       ClsType */
            
      else
        if (:new.KD <> 0) then
          :new.ClsType := 2; /* */
                
        else
          :new.ClsType := 0; /* */
        END IF;    
      END IF;
    else
      :new.ClsType := CapClsType1$;
      
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND ((:new.IFS <> 0)or(:new.KD <> 0))) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0)
  )) THEN
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  if (((:new.ClsType = 1)and(:new.KD <> 0))or((:new.ClsType = 2)and(:new.IFS <> 0))) then
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 1) AND (:new.ClsType <> 2)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;
  IF (:new.ACC_REF IS NOT NULL) THEN /*    / */
    BEGIN
      SELECT oa.ORG_REF
      INTO OrgRefByAcc1$     FROM ORG_ACCOUNTS oa
      WHERE (oa.ID = :new.ACC_REF)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (:new.FacialAcc_CLS = 0) then 
      :new.Org_Ref := OrgRefByAcc1$;
      
    END IF;
  END IF;
  /*  \ ,       \    \,  \ */
  if (:new.FacialAcc_CLS <> 0) then
    BEGIN
      SELECT
      fac.ORG_REF
      INTO :new.Org_Ref     FROM
      FacialACC_CLS fac
      WHERE
      (fac.ID = :new.FacialAcc_CLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (OrgRefByAcc1$<>:new.Org_Ref) then 
      :new.ACC_REF := null;
      
    END IF;
  END IF;
  if ((:new.ProgIndex in (252, 253))and(:new.FacialAcc_CLS = 0)) then
    BEGIN
      SELECT
      bn.FacialAccCLS
      INTO :new.FacialAcc_CLS     FROM
      BudNotify bn
      WHERE
      (bn.ID = :new.RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_BUDGETDATA_BU_200)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*       32-, 260-, 261-, 262-  , 263-, 268-  , 252-. */
  if (:new.ProgIndex in (32, 252, 260, 261, 262, 263, 268)) then
    /*     (32  ()) 
             :
           =0     ,
           =1  ,
           =2   0  .*//*     260 ()
             :
           =2   0  .*/
    GetIntConst(32, 25,AutoKvrCorr$);
    if (:new.ProgIndex = 32) then /*  ()*/
      if (AutoKvrCorr$  = 0) then
        :new.KvrCorr := :new.Kvr;
              
      else
        if (AutoKvrCorr$  = 2) then
          :new.KvrCorr := 0;
        END IF;
      END IF;
      /* KESR   */
      if (AutoKvrCorr$  = 0) then
        :new.KesrCorr := :new.Kesr;
              
      else
        if (AutoKvrCorr$  = 2) then
          :new.KesrCorr := 0;
        END IF;    
      END IF;
    else 
      if ((:new.ProgIndex = 260)and (AutoKvrCorr$  = 2)) then  /* ()*/
        :new.KvrCorr := 0;
        --   ,    new.Kvr = 0;
        /* KESR   */        
                
        :new.KesrCorr := 0;
        :new.Kesr := 0;     
              
      else
        :new.KvrCorr := :new.Kvr; /*         */
        /* KESR   */        
        :new.KesrCorr := :new.Kesr;
              
      END IF;  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_BUDGETDATA_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

  IF (:NEW.RVersion IS NULL) THEN
     :NEW.RVersion := 1;
  ELSIF ((:NEW.RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
     :NEW.RVersion := :OLD.RVersion;
  ELSE
     :NEW.RVersion := :OLD.RVersion + 1;
  END IF;

END;
/
commit work
/
-- ALTER TRIGGER tr_incomes32_bi
CREATE OR REPLACE TRIGGER TR_INCOMES32_II
  INSTEAD OF INSERT
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  CapDocNumber VARCHAR2(20);
  unkKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  Kd_Master NUMBER(10);
  idKD$ NUMBER(10);
  unkVKD$ VARCHAR2(20);
  val_DocCount$ NUMBER(10);
  val_DocType$ NUMBER(10);
  val_Org_Ref$ NUMBER(10);
  val_AccountIndex$ NUMBER(10);
  val_SubKD$ NUMBER(10);
  val_RegionCLS$ NUMBER(10);
  val_GosNI$ NUMBER(10);
  val_IncAccount$ NUMBER(10);
  val_BudgetRef$ NUMBER(10);
  val_MEANSTYPE$ NUMBER(10);
  val_FACIALACC_CLS$ NUMBER(10);
  val_TransfertCls$ NUMBER(10);
  CapAcceptDate$ NUMBER;
  CapReestrNumber$ VARCHAR2(20);
  CapProgIndex1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_INCOMES32_BI)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN 
    select g_shared.nextval into new$id from dual;
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN 
    new$FACIALACC_CLS := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN 
    new$Gosni := 0;
  END IF;
  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN 
    new$DocBase := 0;
  END IF;
  /* 3 -    */
  IF (new$KD IS NULL) THEN 
    new$KD := 0;
  END IF;
  IF (new$ProgIndex IS NULL) THEN 
    new$ProgIndex := 3;
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN 
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN 
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN 
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN 
    new$AccountIndex := 0;
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN 
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN 
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN 
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN 
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN 
    new$DirectionCLS := 0;
  END IF;
  IF (new$FinType is null) then 
    new$FinType := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  /*   .        */
  IF (new$IFS IS NULL) THEN 
    new$IFS := 0;
  END IF;
  IF (new$IFS_CORR IS NULL) THEN 
    new$Ifs_Corr := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
   
  /*  ,    */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0)) THEN
    BEGIN
      SELECT qt.BudgetRef      INTO new$BudgetRef FROM QuotesTitle qt
      WHERE qt.Id = new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    0,     */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0)) THEN
    BEGIN
      SELECT fa.BudgetRef      INTO new$BudgetRef FROM FacialAcc_Cls fa
      WHERE fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    0,    */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0))
  THEN 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
   
  IF (new$ProgIndex = 45) 
  THEN 
    IF (new$IncAccount IS NULL) THEN
      GetDefDFAccRefForBudget(new$BudgetRef,new$IncAccount);
    END IF;
    BEGIN

      /*     */
      SELECT qt.ProgIndex, qt.AcceptDate, qt.IncAccount, qt.ReestrNumber 
      INTO CapProgIndex1$, CapAcceptDate$, new$IncAccount, CapReestrNumber$       FROM QuotesTitle qt
      WHERE 
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*           / */
    /*  /   after insert */
    IF (CapProgIndex1$ <> 145) THEN 
      new$iDate := CapAcceptDate$;
    END IF;
    IF ((CapProgIndex1$ = 145)AND (NOT ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0)OR (new$Credit<0)))) )
    THEN 
      new$Idate := CapAcceptDate$;      
    END IF;
    /*   -    () */
    IF ((CapProgIndex1$ = 45) AND (CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN 
      /*        , *//*    */            
                  
      new$FederalFundsRef := new$ID;
      /* if-then */  
    END IF;/* if-then*/
  END IF;
  BEGIN
    /*     \*/
    SELECT org.Org_Type   INTO new$FAOrgType FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$FacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*    */
  GETTARGETCLS(null, new$transfertcls, null, new$meanstype,
  new$targetcls,new$targetcls);  

-- - - - - - - - - - - - -
-- BI_5 (TR_INCOMES_BI_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BI_9 (TR_INCOMES32_BI_VZ)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   IF (new$ProgIndex = 9) THEN
      /*   */
      GetIntConst (9, 1, new$IncAccount);

      BEGIN
        /*      */
        SELECT ACCEPTDATE, BUDGETREF
          INTO new$IDate, new$BudgetRef
          FROM VZ_OFFSET
         WHERE ID = new$RecordIndex;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_INCOMES32_BI_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   BEGIN
      SELECT Inn
        INTO new$Inn
        FROM Organizations o
       WHERE (o.ID = new$Org_Ref);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

/*  .    ,    */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      BEGIN
         SELECT c.BudgetRef
           INTO new$budgetref
           FROM QuotesTitle c
          WHERE c.ID = NEW$RecordIndex;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

   /*  .  ,     */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      BEGIN
         SELECT fa.BudgetRef
           INTO new$budgetref
           FROM FacialAcc_Cls fa
          WHERE fa.ID = NEW$FacialAcc_Cls;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

   /*  ,    */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      GetIntConst (-1, 3, new$budgetref);
   END IF;

-- - - - - - - - - - - - -
-- BI_30 (TR_INCOMES32_BI_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then 
    BEGIN
      select q.BuildDate 
      into 
      new$DocDate        from QuotesTitle q 
      where q.id = new$RecordIndex 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_70 (TR_INCOMES32_BI_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
               */
         new$FederalFundsRef := new$ID;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_INCOMES32_BI_100)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if ((not (newKD$  like unkKD$)) and
    (not (newKD$  like unkVKD$))) then
      /*   (    
            ) ,  
         ,   */

      /*       */
      if (new$Debit <> 0) then 
        RaiseException('ex_UnknownRedirect');
      END IF;
      BEGIN

        /*      */
        select KD,DocCount,DocType,
        Org_Ref,AccountIndex,SubKD,RegionCLS,GosNI,
        IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,
        TransfertCls
        into
        idKD$,
        val_DocCount$,
        val_DocType$,
        val_Org_Ref$,
        val_AccountIndex$,
        val_SubKD$,
        val_RegionCLS$,
        val_GosNI$,
        val_IncAccount$,
        val_BudgetRef$,
        val_MEANSTYPE$  ,
        val_FACIALACC_CLS$,
        val_TransfertCls$         from incomes32 where id=new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
         
      if (not idKD$ is null) then
        insert into
        /* KD=   (      )
              Debit=0
              redit=-new.credit
              ProgIndex=43
              RecordIndex=new.id
              id    Incomes32*/
        Incomes32(CreaterUser, DocNum,DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS, TransfertCls)
        Values(new$CreaterUser, new$DocNum, val_DocCount$, new$iDate, new$DOCDATE, 0, -new$Credit, val_DocType$,
        val_Org_Ref$, val_AccountIndex$, idKD$, val_SubKD$, val_RegionCLS$, val_GosNI$,
        43,new$Id, val_IncAccount$, val_BudgetRef$, new$Note,val_MEANSTYPE$,val_FACIALACC_CLS$,val_TransfertCls$);
        
      END IF; 
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_110 (TR_INCOMES32_BI_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       /*       ClsType */
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                /*  -  */
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_INCOMES32_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update QuotesTitle set
  DocChangeDate = new$UpdateDate,
  RVersion = -1
  where id = new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_INCOMES32 (
    ID,
    DOCNUMBER,
    DOCCOUNT,
    IDATE,
    DEBIT,
    CREDIT,
    DOCTYPE,
    INN,
    ORG_REF,
    ACCOUNTINDEX,
    KD,
    SUBKD,
    REGIONCLS,
    GOSNI,
    INCACCOUNT,
    PROGINDEX,
    RECORDINDEX,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    NOTE,
    RECORDINDEX2,
    ELNUM,
    NOTEEX,
    BUHPAYMENTCLS,
    ACCOUNTREF,
    ELPACKETNUM,
    FACIALACC_CLS,
    NDS,
    MEANSTYPE,
    RECORDDATE,
    TOTALREF,
    REQUESTSINDEX,
    KVSR,
    TAXNOTE,
    DOCNUM,
    REALPAYERORG_REF,
    DOCDATE,
    DOCBASE,
    FACT,
    RVERSION,
    KFSR,
    KESR,
    KVR,
    KCSR,
    SUMCOMPLETE,
    ELDOCREF,
    REQUESTSINDEX2,
    FEDERALFUNDSREF,
    BUHOPERATIONCLS,
    IFS,
    IFS_CORR,
    CLSTYPE,
    NDSNOTE,
    DOGNUM,
    SENDERID,
    SENDERRECORDID,
    OKATO,
    ADDOKATO,
    REJECTCLS,
    FUNDSSOURCE,
    DIRECTIONCLS,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    STIMATEID,
    TRANSFERTCLS,
    SUBSIDYCLS,
    FAORGTYPE,
    OKTMO,
    UINCODE,
    FINTYPE,
    INVESTOBJECT,
    CONTRACTCOSTSCLS,
    TARGETCLS,
    REJECTCAUSE
  ) VALUES (
    new$ID,
    new$DOCNUMBER,
    new$DOCCOUNT,
    new$IDATE,
    new$DEBIT,
    new$CREDIT,
    new$DOCTYPE,
    new$INN,
    new$ORG_REF,
    new$ACCOUNTINDEX,
    new$KD,
    new$SUBKD,
    new$REGIONCLS,
    new$GOSNI,
    new$INCACCOUNT,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$BUDGETREF,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$NOTE,
    new$RECORDINDEX2,
    new$ELNUM,
    new$NOTEEX,
    new$BUHPAYMENTCLS,
    new$ACCOUNTREF,
    new$ELPACKETNUM,
    new$FACIALACC_CLS,
    new$NDS,
    new$MEANSTYPE,
    new$RECORDDATE,
    new$TOTALREF,
    new$REQUESTSINDEX,
    new$KVSR,
    new$TAXNOTE,
    new$DOCNUM,
    new$REALPAYERORG_REF,
    new$DOCDATE,
    new$DOCBASE,
    new$FACT,
    new$RVERSION,
    new$KFSR,
    new$KESR,
    new$KVR,
    new$KCSR,
    new$SUMCOMPLETE,
    new$ELDOCREF,
    new$REQUESTSINDEX2,
    new$FEDERALFUNDSREF,
    new$BUHOPERATIONCLS,
    new$IFS,
    new$IFS_CORR,
    new$CLSTYPE,
    new$NDSNOTE,
    new$DOGNUM,
    new$SENDERID,
    new$SENDERRECORDID,
    new$OKATO,
    new$ADDOKATO,
    new$REJECTCLS,
    new$FUNDSSOURCE,
    new$DIRECTIONCLS,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$STIMATEID,
    new$TRANSFERTCLS,
    new$SUBSIDYCLS,
    new$FAORGTYPE,
    new$OKTMO,
    new$UINCODE,
    new$FINTYPE,
    new$INVESTOBJECT,
    new$CONTRACTCOSTSCLS,
    new$TARGETCLS,
    new$REJECTCAUSE);

-- - - - - - - - - - - - -
-- AI_20 (T_INCOMES32_AI_20)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   --     
   if (new$ProgIndex <> 42) then
     BEGIN
       SELECT ProgIndex, DocNumber, AcceptDate
        INTO CapProgIndex, CapDocNumber, CapAcceptDate
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
     EXCEPTION
       WHEN NO_DATA_FOUND THEN NULL;
     END;
   end if;

   --   - ,  
   IF ((CapProgIndex = 145) or (new$ProgIndex=42)) THEN

      If ((new$ProgIndex=42) and (new$DocType between 1010 and 1019) and
         (new$Debit>0) and (new$DOCDATE is not null))
      then
        BEGIN
          select kd into Kd_Master
    From Incomes32 inc
          where inc.id = new$RecordIndex;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;

        if (Kd_Master = new$Kd) then
          CapAcceptDate := new$DOCDATE;
          CapProgIndex  := new$ProgIndex;
          CapDocNumber  := new$DocNum;
        end if;
      end if; --       (         )

      --             
      IF ((CapAcceptDate IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit > 0) OR (new$Credit < 0))) THEN
         --    ( RealPayerOrg_Ref(PayDoc32)=new$RealPayerOrg_Ref(Incomes32))
         INSERT INTO PayDoc32
            (BudgetRef, AccountRef, PayerAttrRef, InputDate,
             Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref, FACIALACC_CLS)
         VALUES (new$BudgetRef, new$AccountRef, new$IncAccount, CapAcceptDate,
             (new$Debit - new$Credit), new$Note, new$ProgIndex, new$id, CapDocNumber, new$TaxNote,
             new$RealPayerOrg_Ref,new$FACIALACC_CLS);
      -- (new$Debit - new$Credit) --- ..      ,    ,
      --             
      END IF;

   END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_INCOMES32_AI_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 161) AND (RecordID = NEW$ID);

END;
/
-- ALTER TRIGGER tr_incomes32_bu
CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN 
    new$DocBase := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN 
    new$Gosni := 0;
  END IF;
  /* 3 -    */
  IF (new$ProgIndex IS NULL) THEN 
    new$ProgIndex := 3; 
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0; 
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN 
    new$FACIALACC_CLS := 0; 
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN 
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN 
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN 
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN 
    new$AccountIndex := 0; 
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN 
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN 
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN 
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN 
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN 
    new$DirectionCLS := 0;
  END IF;
  IF (new$FinType is null) then 
    new$FinType := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  /*   .        */
  IF (new$IFS_CORR IS NULL) THEN 
    new$Ifs_Corr := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$Ifs := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  BEGIN

    /*     */
    /*   after   ,*/ 
    /*      */
    SELECT ProgIndex, AcceptDate, ReestrNumber
    INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
    WHERE
    (qt.ID = new$RecordIndex)
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*              
           (  , , ) */
  /*   -    () */
  IF (CapProgIndex2$ = 45)
  THEN 
    IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN 
      /*        ,
                     */            
      new$FederalFundsRef := new$ID;
      /* if-then*/
    ELSE 
      new$FederalFundsRef := NULL;
      /* if-else*/  
    END IF;/* if (CapProgIndex=45) */
  END IF;
  /*     */
  IF (new$BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
      IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
        RaiseException('Ex_CantModufyBudget');
      END IF;
      IF (new$Progindex = 41) THEN
        SELECT COUNT(inc.id ) INTO CNT$1
        FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
        IF ((CNT$1<> 0)) THEN
          RaiseException('Ex_CantModufyBudget');
        END IF;   
      END IF;
    END IF;
  END IF;
  /*     \*/
  IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
  ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
  new$targetcls,new$targetcls);  

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

  BEGIN
    SELECT Inn
     INTO new$Inn
     FROM Organizations o
    WHERE (o.ID = new$Org_Ref);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*      */
  IF (new$ProgIndex <> 42) THEN
    BEGIN
      SELECT ProgIndex, DocNumber, AcceptDate
      INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
      WHERE
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*   -  ,   */
  IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
  THEN 
    IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
    (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
    THEN 
      BEGIN
        SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
        WHERE inc.id = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (Kd_Master$ = new$Kd) THEN 
        CapAcceptDate$ := new$DOCDATE;
        CapProgIndex$  := new$ProgIndex;
        CapDocNumber$  := new$DocNum;
        /*  */        
      END IF;/*       (         )*/
    END IF;
    IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
    THEN 

      /*      */
      /* /      Incomes32, ..      ,     */

      /*     /   */
      SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
      INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
      ;
      /*            ,  .*/
      /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
                      ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
                     ) THEN
                    EXCEPTION EX_CANNOTUPDATENUMBER;*/
                 
                
      IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
      then
        if ((new$DocType <> :old.DocType )
        or (new$Debit <> :old.Debit )
        or (new$Credit <> :old.Credit)
        or (new$org_ref <> :old.org_ref)
        or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
        or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
        )
        then
          RaiseException('EX_CANNOTUPDATENUMBER');
        END IF;
      END IF;
                


      /*           */
      IF (PayDocCount$ = 0)
      THEN 
        /*       */
        GetIntConst(11, 2,ConstPayQueue$);
        /*       */
        GetIntConst(11, 1,ConstSendBy$);

        /*    */
        INSERT INTO PayDoc32
        (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
        Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
        VALUES
        (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
        new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
        /* (new.Debit - new.Credit) --- ..      ,    ,
                                     */

        /* if-then */
      ELSE 
        /*     */
        IF (((new$AccountRef = :old.AccountRef) OR
        ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
        AND (new$IncAccount = :old.IncAccount)
        AND (new$BudgetRef = :old.BudgetRef)
        AND ((new$Note = :old.Note) OR
        ((new$Note IS NULL) AND (:old.Note IS NULL)))
        AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
        ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
        AND ((new$TaxNote = :old.TaxNote) OR
        ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
        )  THEN
          new$AccountRef := new$AccountRef;
                          
        ELSE

          UPDATE PayDoc32 pd
          SET
          pd.AccountRef = new$AccountRef,
          pd.PayerAttrRef = new$IncAccount,
          pd.AcceptorAttrRef = new$AccountRef,
          pd.TextNote = new$Note,
          pd.TaxNote = new$TaxNote,
          pd.BudgetRef = new$BudgetRef,
          pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
          pd.InputDate = CapAcceptDate$,
          pd.SourceDocNumber = CapDocNumber$,
          pd.FACIALACC_CLS = new$FACIALACC_CLS
          WHERE
          (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
        END IF;
        IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
        OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
        THEN  
          IF (Divided$ > 0)
          THEN
            /*  ,      */
            RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
          ELSE
            UPDATE PayDoc32 pd
            SET
            pd.Credit = new$Debit - new$Credit
            WHERE
            (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
          END IF;/* if-then*/            
        END IF;/* if-else*/
      END IF;
      /*     / */
      /*   :     ,     */
      /*  ,     */
      SELECT MAX(pd.AcceptDate)
      INTO Date_Pd$           FROM PayDoc32 pd
      WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
      ;
      new$Idate := Date_Pd$;
      /* if-then*/
    ELSE 
      /*       
                          -
                    . */
      DELETE FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex = new$ProgIndex)
      AND (pd.RecordIndex = new$id);
      /* if-else*/  
    END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then 
    BEGIN
      select q.BuildDate 
      into 
      new$DocDate        from QuotesTitle q 
      where q.id = new$RecordIndex 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
            */
         new$FederalFundsRef := new$ID;
      ELSE
         new$FederalFundsRef := NULL;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN
      select KDValue   into oldKD$ from kd where Id=:old.kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN

      /*     */
      select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
      IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
      into
      idKD1$,
      val_DocCount1$,
      val_DocType1$,
      val_Org_Ref1$,
      val_AccountIndex1$,
      val_SubKD1$,
      val_RegionCLS1$,
      val_GosNI1$,
      val_IncAccount1$,
      val_BudgetRef1$,
      val_MEANSTYPE1$  , 
      val_FACIALACC_CLS1$,
      val_TransfertCls1$         from incomes32 where id=new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not idKD1$ is null) then
      if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
      (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
        /*   ,    */
        delete
        from Incomes32
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      (new$Debit<>0))
      /*       */
      then 
        RaiseException('ex_UnknownRedirect');
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
        /*   ,   ,   */
        insert into
        Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
        Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
        val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
        val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
        new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
      END IF;
      if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
      and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
        /*      ,   */
        update Incomes32
        set
        DocNum = new$DocNum,
        DocCount = val_DocCount1$,
        iDate = new$iDate,
        DOCDATE = new$DOCDATE,
        Debit = 0,
        Credit = -new$Credit,
        DocType = val_DocType1$,
        Org_Ref = val_Org_Ref1$,
        AccountIndex = val_AccountIndex1$,
        KD = idKD1$,
        SubKD = val_SubKD1$,
        RegionCLS = val_RegionCLS1$,
        GosNI = val_GosNI1$,
        ProgIndex = 43,
        RecordIndex = new$Id,
        IncAccount = val_IncAccount1$,
        BudgetRef = val_BudgetRef1$,
        Note = new$Note,
        MEANSTYPE = val_MEANSTYPE1$,
        FACIALACC_CLS = val_FACIALACC_CLS1$,
        TransfertCls = val_TransfertCls1$,
        RVersion = -1
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
         
      END IF; 
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 41)    /*   () */
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    /*       */
    FOR REC$1 IN (SELECT inc.id
     AS val_ID42    FROM Incomes32 inc
    LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
    WHERE (inc.ProgIndex =  42) and
    (inc.RecordIndex =  new$id) and
    (inc.debit = 0) and
    (not(kd.kdvalue like unkKD$)) and
    (not(kd.kdvalue like unkVKD$))
    )
    LOOP
      BEGIN
        /*       */
        select inc.id
        into val_ID431$         FROM Incomes32 inc
        WHERE (inc.ProgIndex =  43) and
        (inc.RecordIndex =  REC$1.val_ID42)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      /*     ,   Credit, ProgIndex, RecordIndex */
      update Incomes32
      set
      DocNum = new$DocNum,
      DocCount = new$DocCount,       
      DOCDATE = new$DOCDATE,
      Debit = 0,
      DocType = new$DocType,
      Org_Ref = new$Org_Ref,
      AccountIndex = new$AccountIndex,
      KD = new$Kd,
      SubKD = new$SubKD,
      RegionCLS = new$RegionCLS,
      GosNI = new$GosNI,
      IncAccount = new$IncAccount,
      BudgetRef = new$BudgetRef,
      Note = new$Note,
      MEANSTYPE = new$MEANSTYPE,
      FACIALACC_CLS = new$FACIALACC_CLS,
      FACT = new$FACT,
      TransfertCls = new$TransfertCls,
      DirectionCls = new$DirectionCls,
      rversion = -1
      where id = val_ID431$;

        
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       --       ClsType
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                --  - 
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      --   
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   IF (NEW$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (161, :OLD.ID, SYSDATE);
      DELETE FROM DelRecIndexes
        WHERE (TableID = 161) AND (RecordId = NEW$ID);
   END IF;

END;
/
commit work
/
-- CREATE TRIGGER TR_PAYMENTSCHEDULE_BU
CREATE OR REPLACE TRIGGER TR_PAYMENTSCHEDULE_IU
  INSTEAD OF UPDATE
  ON PAYMENTSCHEDULE
  FOR EACH ROW
DECLARE
  new$ID PAYMENTSCHEDULE.ID%TYPE := :NEW.ID;
  new$ANUMBER PAYMENTSCHEDULE.ANUMBER%TYPE := :NEW.ANUMBER;
  new$PARENTNUMBER PAYMENTSCHEDULE.PARENTNUMBER%TYPE := :NEW.PARENTNUMBER;
  new$KFSR PAYMENTSCHEDULE.KFSR%TYPE := :NEW.KFSR;
  new$KESR PAYMENTSCHEDULE.KESR%TYPE := :NEW.KESR;
  new$KVSR PAYMENTSCHEDULE.KVSR%TYPE := :NEW.KVSR;
  new$KCSR PAYMENTSCHEDULE.KCSR%TYPE := :NEW.KCSR;
  new$KVR PAYMENTSCHEDULE.KVR%TYPE := :NEW.KVR;
  new$MONTH01 PAYMENTSCHEDULE.MONTH01%TYPE := :NEW.MONTH01;
  new$MONTH02 PAYMENTSCHEDULE.MONTH02%TYPE := :NEW.MONTH02;
  new$MONTH03 PAYMENTSCHEDULE.MONTH03%TYPE := :NEW.MONTH03;
  new$MONTH04 PAYMENTSCHEDULE.MONTH04%TYPE := :NEW.MONTH04;
  new$MONTH05 PAYMENTSCHEDULE.MONTH05%TYPE := :NEW.MONTH05;
  new$MONTH06 PAYMENTSCHEDULE.MONTH06%TYPE := :NEW.MONTH06;
  new$MONTH07 PAYMENTSCHEDULE.MONTH07%TYPE := :NEW.MONTH07;
  new$MONTH08 PAYMENTSCHEDULE.MONTH08%TYPE := :NEW.MONTH08;
  new$MONTH09 PAYMENTSCHEDULE.MONTH09%TYPE := :NEW.MONTH09;
  new$MONTH10 PAYMENTSCHEDULE.MONTH10%TYPE := :NEW.MONTH10;
  new$MONTH11 PAYMENTSCHEDULE.MONTH11%TYPE := :NEW.MONTH11;
  new$MONTH12 PAYMENTSCHEDULE.MONTH12%TYPE := :NEW.MONTH12;
  new$SUMMA PAYMENTSCHEDULE.SUMMA%TYPE := :NEW.SUMMA;
  new$REGION PAYMENTSCHEDULE.REGION%TYPE := :NEW.REGION;
  new$SUBKESR PAYMENTSCHEDULE.SUBKESR%TYPE := :NEW.SUBKESR;
  new$MEANSTYPE PAYMENTSCHEDULE.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FINSOURCE PAYMENTSCHEDULE.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE PAYMENTSCHEDULE.FINTYPE%TYPE := :NEW.FINTYPE;
  new$FACT PAYMENTSCHEDULE.FACT%TYPE := :NEW.FACT;
  new$FACIALACC_CLS PAYMENTSCHEDULE.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$CREATERUSER PAYMENTSCHEDULE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYMENTSCHEDULE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PAYMENTSCHEDULE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PAYMENTSCHEDULE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF PAYMENTSCHEDULE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$ACCEPTDATE PAYMENTSCHEDULE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$LASTADJUSTMENT PAYMENTSCHEDULE.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$ACCEPTED PAYMENTSCHEDULE.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED PAYMENTSCHEDULE.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$PROMISETYPE PAYMENTSCHEDULE.PROMISETYPE%TYPE := :NEW.PROMISETYPE;
  new$ADJUSTMENTREF PAYMENTSCHEDULE.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$OLDNUMBER PAYMENTSCHEDULE.OLDNUMBER%TYPE := :NEW.OLDNUMBER;
  new$SUMMAPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAPREVIOUSYEAR%TYPE := :NEW.SUMMAPREVIOUSYEAR;
  new$SUMMAFINPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAFINPREVIOUSYEAR%TYPE := :NEW.SUMMAFINPREVIOUSYEAR;
  new$QUARTER1 PAYMENTSCHEDULE.QUARTER1%TYPE := :NEW.QUARTER1;
  new$QUARTER2 PAYMENTSCHEDULE.QUARTER2%TYPE := :NEW.QUARTER2;
  new$QUARTER3 PAYMENTSCHEDULE.QUARTER3%TYPE := :NEW.QUARTER3;
  new$QUARTER4 PAYMENTSCHEDULE.QUARTER4%TYPE := :NEW.QUARTER4;
  new$RECORDINDEX PAYMENTSCHEDULE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CRYPTOSTATUS PAYMENTSCHEDULE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID PAYMENTSCHEDULE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PAYMENTSCHEDULE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DIRECTIONCLS PAYMENTSCHEDULE.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$RVERSION PAYMENTSCHEDULE.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYMENTSCHEDULE.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MONTH01DELTA PAYMENTSCHEDULE.MONTH01DELTA%TYPE := :NEW.MONTH01DELTA;
  new$MONTH02DELTA PAYMENTSCHEDULE.MONTH02DELTA%TYPE := :NEW.MONTH02DELTA;
  new$MONTH03DELTA PAYMENTSCHEDULE.MONTH03DELTA%TYPE := :NEW.MONTH03DELTA;
  new$MONTH04DELTA PAYMENTSCHEDULE.MONTH04DELTA%TYPE := :NEW.MONTH04DELTA;
  new$MONTH05DELTA PAYMENTSCHEDULE.MONTH05DELTA%TYPE := :NEW.MONTH05DELTA;
  new$MONTH06DELTA PAYMENTSCHEDULE.MONTH06DELTA%TYPE := :NEW.MONTH06DELTA;
  new$MONTH07DELTA PAYMENTSCHEDULE.MONTH07DELTA%TYPE := :NEW.MONTH07DELTA;
  new$MONTH08DELTA PAYMENTSCHEDULE.MONTH08DELTA%TYPE := :NEW.MONTH08DELTA;
  new$MONTH09DELTA PAYMENTSCHEDULE.MONTH09DELTA%TYPE := :NEW.MONTH09DELTA;
  new$MONTH10DELTA PAYMENTSCHEDULE.MONTH10DELTA%TYPE := :NEW.MONTH10DELTA;
  new$MONTH11DELTA PAYMENTSCHEDULE.MONTH11DELTA%TYPE := :NEW.MONTH11DELTA;
  new$MONTH12DELTA PAYMENTSCHEDULE.MONTH12DELTA%TYPE := :NEW.MONTH12DELTA;
  new$QUARTER1DELTA PAYMENTSCHEDULE.QUARTER1DELTA%TYPE := :NEW.QUARTER1DELTA;
  new$QUARTER2DELTA PAYMENTSCHEDULE.QUARTER2DELTA%TYPE := :NEW.QUARTER2DELTA;
  new$QUARTER3DELTA PAYMENTSCHEDULE.QUARTER3DELTA%TYPE := :NEW.QUARTER3DELTA;
  new$QUARTER4DELTA PAYMENTSCHEDULE.QUARTER4DELTA%TYPE := :NEW.QUARTER4DELTA;
  new$SUMMADELTA PAYMENTSCHEDULE.SUMMADELTA%TYPE := :NEW.SUMMADELTA;
  new$NOTE PAYMENTSCHEDULE.NOTE%TYPE := :NEW.NOTE;
  new$FINYEAR PAYMENTSCHEDULE.FINYEAR%TYPE := :NEW.FINYEAR;
  new$SUMMAYEAR1 PAYMENTSCHEDULE.SUMMAYEAR1%TYPE := :NEW.SUMMAYEAR1;
  new$SUMMAYEAR2 PAYMENTSCHEDULE.SUMMAYEAR2%TYPE := :NEW.SUMMAYEAR2;
  new$SUMMAYEAR3 PAYMENTSCHEDULE.SUMMAYEAR3%TYPE := :NEW.SUMMAYEAR3;
  new$SUMMAYEAR1DELTA PAYMENTSCHEDULE.SUMMAYEAR1DELTA%TYPE := :NEW.SUMMAYEAR1DELTA;
  new$SUMMAYEAR2DELTA PAYMENTSCHEDULE.SUMMAYEAR2DELTA%TYPE := :NEW.SUMMAYEAR2DELTA;
  new$SUMMAYEAR3DELTA PAYMENTSCHEDULE.SUMMAYEAR3DELTA%TYPE := :NEW.SUMMAYEAR3DELTA;
  new$ASSIGNMENTKIND PAYMENTSCHEDULE.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$TRANSFERTCLS PAYMENTSCHEDULE.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SENDERIDKEY PAYMENTSCHEDULE.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY PAYMENTSCHEDULE.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXECUTIONREF PAYMENTSCHEDULE.EXECUTIONREF%TYPE := :NEW.EXECUTIONREF;
  new$INNERPROMISENUM PAYMENTSCHEDULE.INNERPROMISENUM%TYPE := :NEW.INNERPROMISENUM;
  new$ADJUSTMENTNUMBER PAYMENTSCHEDULE.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$PROMISENUMBER PAYMENTSCHEDULE.PROMISENUMBER%TYPE := :NEW.PROMISENUMBER;
  new$SUBSIDYCLS PAYMENTSCHEDULE.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$AGREEMENTREF PAYMENTSCHEDULE.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$BUDALLOCATIONCLS PAYMENTSCHEDULE.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS PAYMENTSCHEDULE.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$PROGINDEX PAYMENTSCHEDULE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$INVESTOBJECT PAYMENTSCHEDULE.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$SUMMAYEAR4 PAYMENTSCHEDULE.SUMMAYEAR4%TYPE := :NEW.SUMMAYEAR4;
  new$SUMMAOTHERYEARS PAYMENTSCHEDULE.SUMMAOTHERYEARS%TYPE := :NEW.SUMMAOTHERYEARS;
  new$SUMMAYEAR4DELTA PAYMENTSCHEDULE.SUMMAYEAR4DELTA%TYPE := :NEW.SUMMAYEAR4DELTA;
  new$SUMMAOTHERYEARSDELTA PAYMENTSCHEDULE.SUMMAOTHERYEARSDELTA%TYPE := :NEW.SUMMAOTHERYEARSDELTA;
  new$CONTRACTCOSTSCLS PAYMENTSCHEDULE.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS PAYMENTSCHEDULE.TARGETCLS%TYPE := :NEW.TARGETCLS;
--
  M01$ NUMBER;
  M02$ NUMBER;
  M03$ NUMBER;
  M04$ NUMBER;
  M05$ NUMBER;
  M06$ NUMBER;
  M07$ NUMBER;
  M08$ NUMBER;
  M09$ NUMBER;
  M10$ NUMBER;
  M11$ NUMBER;
  M12$ NUMBER;
  Q1$ NUMBER;
  Q2$ NUMBER;
  Q3$ NUMBER;
  Q4$ NUMBER;
  S$ NUMBER;
  S1$ NUMBER;
  S2$ NUMBER;
  S3$ NUMBER;
  MaxNumber1$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  S4$ NUMBER;
  SOther$ NUMBER;
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_PAYMENTSCHEDULE_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*   2.4*/
  /*    -*/
  if (new$Accepted is null) then 
    new$Accepted := 1;
  END IF;
  if (new$PromiseType is null) then 
    new$PromiseType := 0;
  END IF;
  if (new$KFSR is null) then 
    new$KFSR := 0;
  END IF;
  if (new$KESR is null) then 
    new$KESR := 0;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$KCSR is null) then 
    new$KCSR := 0;
  END IF;
  if (new$KVR is null) then 
    new$KVR := 0;
  END IF;
  if (new$SubKESR is null) then 
    new$SubKESR := 0;
  END IF;
  if (new$AssignmentKind is null) then 
    new$AssignmentKind := 0;
  END IF;
   
  if (new$DirectionCls is null) then 
    new$DirectionCls := 0;
  END IF;
   
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Region is null) then 
    new$Region := 0;
  END IF;
  if (new$MeansType is null) then 
    new$MeansType := 0;
  END IF;
  if (new$FinSource is null) then 
    new$FinSource := 0;
  END IF;
  if (new$FinType is null) then 
    new$FinType := 0;
  END IF;
  if (new$Fact is null) then 
    new$Fact := 0;
  END IF;
  if (new$BuhOperationCLS is null) then 
    GetIntConst(60, 15,new$BuhOperationCLS); 
  END IF;
  if (new$Month01 is null) then 
    new$Month01 := 0;
  END IF;
  if (new$Month02 is null) then 
    new$Month02 := 0;
  END IF;
  if (new$Month03 is null) then 
    new$Month03 := 0;
  END IF;
  if (new$Month04 is null) then 
    new$Month04 := 0;
  END IF;
  if (new$Month05 is null) then 
    new$Month05 := 0;
  END IF;
  if (new$Month06 is null) then 
    new$Month06 := 0;
  END IF;
  if (new$Month07 is null) then 
    new$Month07 := 0;
  END IF;
  if (new$Month08 is null) then 
    new$Month08 := 0;
  END IF;
  if (new$Month09 is null) then 
    new$Month09 := 0;
  END IF;
  if (new$Month10 is null) then 
    new$Month10 := 0;
  END IF;
  if (new$Month11 is null) then 
    new$Month11 := 0;
  END IF;
  if (new$Month12 is null) then 
    new$Month12 := 0;
  END IF;
  if (new$Quarter1 is null) then 
    new$Quarter1 := 0;
  END IF;
  if (new$Quarter2 is null) then 
    new$Quarter2 := 0;
  END IF;
  if (new$Quarter3 is null) then 
    new$Quarter3 := 0;
  END IF;
  if (new$Quarter4 is null) then 
    new$Quarter4 := 0;
  END IF;
  if (new$Summa is null) then 
    new$Summa := 0;
  END IF;
  if (new$Month01Delta is null) then 
    new$Month01Delta := 0;
  END IF;
  if (new$Month02Delta is null) then 
    new$Month02Delta := 0;
  END IF;
  if (new$Month03Delta is null) then 
    new$Month03Delta := 0;
  END IF;
  if (new$Month04Delta is null) then 
    new$Month04Delta := 0;
  END IF;
  if (new$Month05Delta is null) then 
    new$Month05Delta := 0;
  END IF;
  if (new$Month06Delta is null) then 
    new$Month06Delta := 0;
  END IF;
  if (new$Month07Delta is null) then 
    new$Month07Delta := 0;
  END IF;
  if (new$Month08Delta is null) then 
    new$Month08Delta := 0;
  END IF;
  if (new$Month09Delta is null) then 
    new$Month09Delta := 0;
  END IF;
  if (new$Month10Delta is null) then 
    new$Month10Delta := 0;
  END IF;
  if (new$Month11Delta is null) then 
    new$Month11Delta := 0;
  END IF;
  if (new$Month12Delta is null) then 
    new$Month12Delta := 0;
  END IF;
  if (new$Quarter1Delta is null) then 
    new$Quarter1Delta := 0;
  END IF;
  if (new$Quarter2Delta is null) then 
    new$Quarter2Delta := 0;
  END IF;
  if (new$Quarter3Delta is null) then 
    new$Quarter3Delta := 0;
  END IF;
  if (new$Quarter4Delta is null) then 
    new$Quarter4Delta := 0;
  END IF;
  if (new$SummaDelta is null) then 
    new$SummaDelta := 0; 
  END IF;
  if (new$SummaPreviousYear is null) then 
    new$SummaPreviousYear := 0;
  END IF;
  if (new$SummaFinPreviousYear is null) then 
    new$SummaFinPreviousYear := 0;
  END IF;
   
  if (new$SummaYear1 is null) then 
    new$SummaYear1 := 0;
  END IF;
  if (new$SummaYear2 is null) then 
    new$SummaYear2 := 0;
  END IF;
  if (new$SummaYear3 is null) then 
    new$SummaYear3 := 0;
  END IF;
  if (new$SummaYear4 is null) then 
    new$SummaYear4 := 0;
  END IF;
  if (new$SummaOtherYears is null) then 
    new$SummaOtherYears := 0;
  END IF;
   
  if (new$SummaYear1Delta is null) then 
    new$SummaYear1Delta := 0;
  END IF;
  if (new$SummaYear2Delta is null) then 
    new$SummaYear2Delta := 0;
  END IF;
  if (new$SummaYear3Delta is null) then 
    new$SummaYear3Delta := 0;
  END IF;
  if (new$SummaYear4Delta is null) then 
    new$SummaYear4Delta := 0;
  END IF;
  if (new$SummaOtherYearsDelta is null) then 
    new$SummaOtherYearsDelta := 0;
  END IF;
   
  /*   ,        */
  if (new$ProgIndex = 304 and new$RecordIndex is not null and (:old.RecordIndex is null or :old.RecordIndex <> new$RecordIndex)) then
    SELECT COUNT(*) INTO CNT$1
    from AgreementSteps s where (s.Id = new$RecordIndex and s.RecordIndex = new$AgreementRef) AND (ROWNUM = 1);
    if (not (CNT$1<> 0)) then
      RaiseException('Ex_WrongStep');
    END IF;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      RaiseException('Ex_CantModufyBudget');
    END IF;
  END IF;
  if ((:old.ANumber is null) and (new$ANumber is not Null)) then
    SELECT COUNT(                    id
    ) INTO CNT$2
    from
    PaymentSchedule ps
    where
    (                    (ps.ANumber = new$ANumber)
    and
    (ps.BudgetRef = new$BudgetRef)) AND (ROWNUM = 1);
    if ((CNT$2<> 0)) then
      RaiseException('ex_Promise_NumUQ');
    END IF;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
  new$targetcls,new$targetcls); 

-- - - - - - - - - - - - -
-- BU_1 (TR_PAYMENTSCHEDULE_BU_1)
-- Create 05.03.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  /*   1.0*/
    if (new$Quarter1 = 0) then new$Quarter1 := new$Month01 + new$Month02 + new$Month03; end if;
    if (new$Quarter2 = 0) then new$Quarter2 := new$Month04 + new$Month05 + new$Month06; end if;
    if (new$Quarter3 = 0) then new$Quarter3 := new$Month07 + new$Month08 + new$Month09; end if;
    if (new$Quarter4 = 0) then new$Quarter4 := new$Month10 + new$Month11 + new$Month12; end if;
    new$SummaYear1 := new$Quarter1 + new$Quarter2 + new$Quarter3 + new$Quarter4;

-- - - - - - - - - - - - -
-- BU_3 (TR_PAYMENTSCHEDULE_BU_3)
-- Create 03.12.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

    /*            */
    new$AdjustmentRef := :old.AdjustmentRef;

-- - - - - - - - - - - - -
-- BU_10 (TR_PAYMENTSCHEDULE_BU_10)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*   5.0*/
  /* ,      ,   */
  if ((new$ANumber <> :old.ANumber) or
  (new$InnerPromiseNum <> :old.InnerPromiseNum) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber)) then
    RaiseException('EX_AGR_ChangeInnerNums');
  END IF;
      
  /*   !!!*/
  if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and 
  ((new$Accepted = 1) or (new$AcceptDate is null))) then
    RaiseException('EX_RollbackCancel');
  END IF;
  /*   ,     LastAccepted*/
  if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) or 
  ((:old.Accepted = 0) and (new$Accepted = 1) and (new$AcceptDate is not null))) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;
              
    else
      RaiseException('EX_BP_ChangeStateAdjust');    
    END IF;
  END IF;
      
  /*    ,     LastAccepted*/
  if (((:old.AcceptDate is not null) and (:old.Accepted = 1)) and
  ((new$Accepted = 0) or (new$AcceptDate is null))) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 0;
              
    else
      RaiseException('EX_BP_ChangeStateAdjust');    
    END IF;
  END IF;
      
  /*   ,     LastAdjustment*/
  if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 0)) or 
  ((:old.Accepted = 1) and (new$Accepted = 0) and (new$AcceptDate is not null))) then
    if (new$LastAdjustment = 1) then
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
              
    else
      RaiseException('EX_AGR_ChangeStateAdjust');
    END IF;

    select max(AdjustmentNumber) into MaxNumber1$ from PaymentSchedule 
    where (InnerPromiseNum = new$InnerPromiseNum) ;
    /*    ,     */
    if ((new$adjustmentNumber=0) and (MaxNumber1$<>0))
    then 
      RaiseException('EX_BP_PrimaryBPHasNotify');    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_PAYMENTSCHEDULE_BU_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*           */  
  if (new$AdjustmentNumber > 0) then
    BEGIN
      select 
      Month01, Month02, Month03, Month04, Month05, Month06,
      Month07, Month08, Month09, Month10, Month11, Month12,
      Quarter1, Quarter2, Quarter3, Quarter4, Summa,
      SummaYear1, SummaYear2, SummaYear3, SummaYear4, SummaOtherYears
      into
      M01$, M02$, M03$, M04$, M05$, M06$, M07$, M08$, M09$, M10$, M11$, M12$, 
      Q1$, Q2$, Q3$, Q4$, S$, S1$, S2$, S3$, S4$, SOther$         from 
      PaymentSchedule
      where
      ID = new$AdjustmentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
          
    new$Month01Delta := new$Month01 - M01$;
    new$Month02Delta := new$Month02 - M02$;
    new$Month03Delta := new$Month03 - M03$;
    new$Month04Delta := new$Month04 - M04$;
    new$Month05Delta := new$Month05 - M05$;
    new$Month06Delta := new$Month06 - M06$;
    new$Month07Delta := new$Month07 - M07$;
    new$Month08Delta := new$Month08 - M08$;
    new$Month09Delta := new$Month09 - M09$;
    new$Month10Delta := new$Month10 - M10$;
    new$Month11Delta := new$Month11 - M11$;
    new$Month12Delta := new$Month12 - M12$;
    new$Quarter1Delta := new$Quarter1 - Q1$;
    new$Quarter2Delta := new$Quarter2 - Q2$;
    new$Quarter3Delta := new$Quarter3 - Q3$;
    new$Quarter4Delta := new$Quarter4 - Q4$;
    new$SummaDelta := new$Summa - S$;
    new$SummaYear1Delta := new$SummaYear1 - S1$;
    new$SummaYear2Delta := new$SummaYear2 - S2$;
    new$SummaYear3Delta := new$SummaYear3 - S3$;
    new$SummaYear4Delta := new$SummaYear4 - S4$;
    new$SummaOtherYearsDelta := new$SummaOtherYears - SOther$;
        
  else /*        */  
    new$Month01Delta := new$Month01;
    new$Month02Delta := new$Month02;
    new$Month03Delta := new$Month03;
    new$Month04Delta := new$Month04;
    new$Month05Delta := new$Month05;
    new$Month06Delta := new$Month06;
    new$Month07Delta := new$Month07;
    new$Month08Delta := new$Month08;
    new$Month09Delta := new$Month09;
    new$Month10Delta := new$Month10;
    new$Month11Delta := new$Month11;
    new$Month12Delta := new$Month12;
    new$Quarter1Delta := new$Quarter1;
    new$Quarter2Delta := new$Quarter2;
    new$Quarter3Delta := new$Quarter3;
    new$Quarter4Delta := new$Quarter4;
    new$SummaDelta := new$Summa;
    new$SummaYear1Delta := new$SummaYear1;
    new$SummaYear2Delta := new$SummaYear2;
    new$SummaYear3Delta := new$SummaYear3;
    new$SummaYear4Delta := new$SummaYear4;
    new$SummaOtherYearsDelta := new$SummaOtherYears;        
        
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_PAYMENTSCHEDULE_BU_200)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*    */
  if (new$Accepted = 0 and new$AcceptDate is not null and :old.Accepted = 1) then
    /*   ,     
         *    ,      */
    FOR REC$1 IN (      select ffc.Reject_Cls  AS DocumentRejectCls from FacialFinDetail ffd
    left join FacialFinCaption ffc on (ffc.ID = ffd.RecordIndex)
    where SourcePromise = new$ANumber and SourceBudgetPromise = new$InnerPromiseNum
    or DestPromise = new$ANumber and DestBudgetPromise = new$InnerPromiseNum
    )
    LOOP
      if (REC$1.DocumentRejectCls is null) then
        RaiseException('Ex_BP_CannotReject');    
      END IF;
    END LOOP;
    /* ,         */
    FOR REC$1 IN (      SELECT Count(ps_in.ID)  AS AdjCount FROM PaymentSchedule ps_in
    WHERE (ps_in.InnerPromiseNum = new$InnerPromiseNum)and(ps_in.AdjustmentNumber > new$AdjustmentNumber)
    and (ps_in.Accepted<>0) 
    )
    LOOP
      if (REC$1.AdjCount > 0) then
        RaiseException('EX_BP_AdjustmentedCANNOTREJECT');    
      END IF;
    END LOOP;
  END IF;
  /*   .       */
  if (new$Accepted = 1 and new$AcceptDate is null and :old.Accepted = 1 and :old.AcceptDate is not null) then
    SELECT COUNT(ffc.Reject_Cls ) INTO CNT$1
    from FacialFinDetail ffd
    left join FacialFinCaption ffc on (ffc.ID = ffd.RecordIndex)
    where ((SourcePromise = new$ANumber and SourceBudgetPromise = new$InnerPromiseNum
    or DestPromise = new$ANumber and DestBudgetPromise = new$InnerPromiseNum)
    and ffc.acceptdate is not null and ffc.Reject_cls is null) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_BP_NOTACCEPTED');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (tr_PaymentSchedule_BU_400)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$AgreementRef <> :old.AgreementRef or new$ExecutionRef <> :old.ExecutionRef) then
    RaiseException('EX_CANTCHANGECAPTIONREF');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_PAYMENTSCHEDULE_BU_700)
-- Create 14.10.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$RVersion is null) then
    new$RVersion := 1;
  elsif ((new$RVersion = -1) and (:Old.RVersion <> -1)) then
    new$RVersion := :Old.RVersion;
  else
    new$RVersion := :Old.RVersion + 1;
  end if;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_PAYMENTSCHEDULE SET
    ID = new$ID,
    ANUMBER = new$ANUMBER,
    PARENTNUMBER = new$PARENTNUMBER,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVSR = new$KVSR,
    KCSR = new$KCSR,
    KVR = new$KVR,
    MONTH01 = new$MONTH01,
    MONTH02 = new$MONTH02,
    MONTH03 = new$MONTH03,
    MONTH04 = new$MONTH04,
    MONTH05 = new$MONTH05,
    MONTH06 = new$MONTH06,
    MONTH07 = new$MONTH07,
    MONTH08 = new$MONTH08,
    MONTH09 = new$MONTH09,
    MONTH10 = new$MONTH10,
    MONTH11 = new$MONTH11,
    MONTH12 = new$MONTH12,
    SUMMA = new$SUMMA,
    REGION = new$REGION,
    SUBKESR = new$SUBKESR,
    MEANSTYPE = new$MEANSTYPE,
    FINSOURCE = new$FINSOURCE,
    FINTYPE = new$FINTYPE,
    FACT = new$FACT,
    FACIALACC_CLS = new$FACIALACC_CLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    ACCEPTDATE = new$ACCEPTDATE,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    ACCEPTED = new$ACCEPTED,
    LASTACCEPTED = new$LASTACCEPTED,
    PROMISETYPE = new$PROMISETYPE,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    OLDNUMBER = new$OLDNUMBER,
    SUMMAPREVIOUSYEAR = new$SUMMAPREVIOUSYEAR,
    SUMMAFINPREVIOUSYEAR = new$SUMMAFINPREVIOUSYEAR,
    QUARTER1 = new$QUARTER1,
    QUARTER2 = new$QUARTER2,
    QUARTER3 = new$QUARTER3,
    QUARTER4 = new$QUARTER4,
    RECORDINDEX = new$RECORDINDEX,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DIRECTIONCLS = new$DIRECTIONCLS,
    RVERSION = new$RVERSION,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    MONTH01DELTA = new$MONTH01DELTA,
    MONTH02DELTA = new$MONTH02DELTA,
    MONTH03DELTA = new$MONTH03DELTA,
    MONTH04DELTA = new$MONTH04DELTA,
    MONTH05DELTA = new$MONTH05DELTA,
    MONTH06DELTA = new$MONTH06DELTA,
    MONTH07DELTA = new$MONTH07DELTA,
    MONTH08DELTA = new$MONTH08DELTA,
    MONTH09DELTA = new$MONTH09DELTA,
    MONTH10DELTA = new$MONTH10DELTA,
    MONTH11DELTA = new$MONTH11DELTA,
    MONTH12DELTA = new$MONTH12DELTA,
    QUARTER1DELTA = new$QUARTER1DELTA,
    QUARTER2DELTA = new$QUARTER2DELTA,
    QUARTER3DELTA = new$QUARTER3DELTA,
    QUARTER4DELTA = new$QUARTER4DELTA,
    SUMMADELTA = new$SUMMADELTA,
    NOTE = new$NOTE,
    FINYEAR = new$FINYEAR,
    SUMMAYEAR1 = new$SUMMAYEAR1,
    SUMMAYEAR2 = new$SUMMAYEAR2,
    SUMMAYEAR3 = new$SUMMAYEAR3,
    SUMMAYEAR1DELTA = new$SUMMAYEAR1DELTA,
    SUMMAYEAR2DELTA = new$SUMMAYEAR2DELTA,
    SUMMAYEAR3DELTA = new$SUMMAYEAR3DELTA,
    ASSIGNMENTKIND = new$ASSIGNMENTKIND,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    EXECUTIONREF = new$EXECUTIONREF,
    INNERPROMISENUM = new$INNERPROMISENUM,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    PROMISENUMBER = new$PROMISENUMBER,
    SUBSIDYCLS = new$SUBSIDYCLS,
    AGREEMENTREF = new$AGREEMENTREF,
    BUDALLOCATIONCLS = new$BUDALLOCATIONCLS,
    PAYPROMISECLS = new$PAYPROMISECLS,
    PROGINDEX = new$PROGINDEX,
    INVESTOBJECT = new$INVESTOBJECT,
    SUMMAYEAR4 = new$SUMMAYEAR4,
    SUMMAOTHERYEARS = new$SUMMAOTHERYEARS,
    SUMMAYEAR4DELTA = new$SUMMAYEAR4DELTA,
    SUMMAOTHERYEARSDELTA = new$SUMMAOTHERYEARSDELTA,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_10 (TR_PAYMENTSCHEDULE_AU_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/

  /*      */
  /*     ,       */
  if ((new$AdjustmentNumber > 0) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update PaymentSchedule set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment    */
  if ((new$AdjustmentNumber > 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and 
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update PaymentSchedule set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_PAYMENTSCHEDULE_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (113, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=113) and (RecordId=new$ID);
  end if;

END;
/
-- CREATE TRIGGER TR_PAYMENTSCHEDULE_BI
CREATE OR REPLACE TRIGGER TR_PAYMENTSCHEDULE_II
  INSTEAD OF INSERT
  ON PAYMENTSCHEDULE
  FOR EACH ROW
DECLARE
  new$ID PAYMENTSCHEDULE.ID%TYPE := :NEW.ID;
  new$ANUMBER PAYMENTSCHEDULE.ANUMBER%TYPE := :NEW.ANUMBER;
  new$PARENTNUMBER PAYMENTSCHEDULE.PARENTNUMBER%TYPE := :NEW.PARENTNUMBER;
  new$KFSR PAYMENTSCHEDULE.KFSR%TYPE := :NEW.KFSR;
  new$KESR PAYMENTSCHEDULE.KESR%TYPE := :NEW.KESR;
  new$KVSR PAYMENTSCHEDULE.KVSR%TYPE := :NEW.KVSR;
  new$KCSR PAYMENTSCHEDULE.KCSR%TYPE := :NEW.KCSR;
  new$KVR PAYMENTSCHEDULE.KVR%TYPE := :NEW.KVR;
  new$MONTH01 PAYMENTSCHEDULE.MONTH01%TYPE := :NEW.MONTH01;
  new$MONTH02 PAYMENTSCHEDULE.MONTH02%TYPE := :NEW.MONTH02;
  new$MONTH03 PAYMENTSCHEDULE.MONTH03%TYPE := :NEW.MONTH03;
  new$MONTH04 PAYMENTSCHEDULE.MONTH04%TYPE := :NEW.MONTH04;
  new$MONTH05 PAYMENTSCHEDULE.MONTH05%TYPE := :NEW.MONTH05;
  new$MONTH06 PAYMENTSCHEDULE.MONTH06%TYPE := :NEW.MONTH06;
  new$MONTH07 PAYMENTSCHEDULE.MONTH07%TYPE := :NEW.MONTH07;
  new$MONTH08 PAYMENTSCHEDULE.MONTH08%TYPE := :NEW.MONTH08;
  new$MONTH09 PAYMENTSCHEDULE.MONTH09%TYPE := :NEW.MONTH09;
  new$MONTH10 PAYMENTSCHEDULE.MONTH10%TYPE := :NEW.MONTH10;
  new$MONTH11 PAYMENTSCHEDULE.MONTH11%TYPE := :NEW.MONTH11;
  new$MONTH12 PAYMENTSCHEDULE.MONTH12%TYPE := :NEW.MONTH12;
  new$SUMMA PAYMENTSCHEDULE.SUMMA%TYPE := :NEW.SUMMA;
  new$REGION PAYMENTSCHEDULE.REGION%TYPE := :NEW.REGION;
  new$SUBKESR PAYMENTSCHEDULE.SUBKESR%TYPE := :NEW.SUBKESR;
  new$MEANSTYPE PAYMENTSCHEDULE.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FINSOURCE PAYMENTSCHEDULE.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE PAYMENTSCHEDULE.FINTYPE%TYPE := :NEW.FINTYPE;
  new$FACT PAYMENTSCHEDULE.FACT%TYPE := :NEW.FACT;
  new$FACIALACC_CLS PAYMENTSCHEDULE.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$CREATERUSER PAYMENTSCHEDULE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYMENTSCHEDULE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PAYMENTSCHEDULE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PAYMENTSCHEDULE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF PAYMENTSCHEDULE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$ACCEPTDATE PAYMENTSCHEDULE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$LASTADJUSTMENT PAYMENTSCHEDULE.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$ACCEPTED PAYMENTSCHEDULE.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED PAYMENTSCHEDULE.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$PROMISETYPE PAYMENTSCHEDULE.PROMISETYPE%TYPE := :NEW.PROMISETYPE;
  new$ADJUSTMENTREF PAYMENTSCHEDULE.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$OLDNUMBER PAYMENTSCHEDULE.OLDNUMBER%TYPE := :NEW.OLDNUMBER;
  new$SUMMAPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAPREVIOUSYEAR%TYPE := :NEW.SUMMAPREVIOUSYEAR;
  new$SUMMAFINPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAFINPREVIOUSYEAR%TYPE := :NEW.SUMMAFINPREVIOUSYEAR;
  new$QUARTER1 PAYMENTSCHEDULE.QUARTER1%TYPE := :NEW.QUARTER1;
  new$QUARTER2 PAYMENTSCHEDULE.QUARTER2%TYPE := :NEW.QUARTER2;
  new$QUARTER3 PAYMENTSCHEDULE.QUARTER3%TYPE := :NEW.QUARTER3;
  new$QUARTER4 PAYMENTSCHEDULE.QUARTER4%TYPE := :NEW.QUARTER4;
  new$RECORDINDEX PAYMENTSCHEDULE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CRYPTOSTATUS PAYMENTSCHEDULE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID PAYMENTSCHEDULE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PAYMENTSCHEDULE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DIRECTIONCLS PAYMENTSCHEDULE.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$RVERSION PAYMENTSCHEDULE.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYMENTSCHEDULE.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MONTH01DELTA PAYMENTSCHEDULE.MONTH01DELTA%TYPE := :NEW.MONTH01DELTA;
  new$MONTH02DELTA PAYMENTSCHEDULE.MONTH02DELTA%TYPE := :NEW.MONTH02DELTA;
  new$MONTH03DELTA PAYMENTSCHEDULE.MONTH03DELTA%TYPE := :NEW.MONTH03DELTA;
  new$MONTH04DELTA PAYMENTSCHEDULE.MONTH04DELTA%TYPE := :NEW.MONTH04DELTA;
  new$MONTH05DELTA PAYMENTSCHEDULE.MONTH05DELTA%TYPE := :NEW.MONTH05DELTA;
  new$MONTH06DELTA PAYMENTSCHEDULE.MONTH06DELTA%TYPE := :NEW.MONTH06DELTA;
  new$MONTH07DELTA PAYMENTSCHEDULE.MONTH07DELTA%TYPE := :NEW.MONTH07DELTA;
  new$MONTH08DELTA PAYMENTSCHEDULE.MONTH08DELTA%TYPE := :NEW.MONTH08DELTA;
  new$MONTH09DELTA PAYMENTSCHEDULE.MONTH09DELTA%TYPE := :NEW.MONTH09DELTA;
  new$MONTH10DELTA PAYMENTSCHEDULE.MONTH10DELTA%TYPE := :NEW.MONTH10DELTA;
  new$MONTH11DELTA PAYMENTSCHEDULE.MONTH11DELTA%TYPE := :NEW.MONTH11DELTA;
  new$MONTH12DELTA PAYMENTSCHEDULE.MONTH12DELTA%TYPE := :NEW.MONTH12DELTA;
  new$QUARTER1DELTA PAYMENTSCHEDULE.QUARTER1DELTA%TYPE := :NEW.QUARTER1DELTA;
  new$QUARTER2DELTA PAYMENTSCHEDULE.QUARTER2DELTA%TYPE := :NEW.QUARTER2DELTA;
  new$QUARTER3DELTA PAYMENTSCHEDULE.QUARTER3DELTA%TYPE := :NEW.QUARTER3DELTA;
  new$QUARTER4DELTA PAYMENTSCHEDULE.QUARTER4DELTA%TYPE := :NEW.QUARTER4DELTA;
  new$SUMMADELTA PAYMENTSCHEDULE.SUMMADELTA%TYPE := :NEW.SUMMADELTA;
  new$NOTE PAYMENTSCHEDULE.NOTE%TYPE := :NEW.NOTE;
  new$FINYEAR PAYMENTSCHEDULE.FINYEAR%TYPE := :NEW.FINYEAR;
  new$SUMMAYEAR1 PAYMENTSCHEDULE.SUMMAYEAR1%TYPE := :NEW.SUMMAYEAR1;
  new$SUMMAYEAR2 PAYMENTSCHEDULE.SUMMAYEAR2%TYPE := :NEW.SUMMAYEAR2;
  new$SUMMAYEAR3 PAYMENTSCHEDULE.SUMMAYEAR3%TYPE := :NEW.SUMMAYEAR3;
  new$SUMMAYEAR1DELTA PAYMENTSCHEDULE.SUMMAYEAR1DELTA%TYPE := :NEW.SUMMAYEAR1DELTA;
  new$SUMMAYEAR2DELTA PAYMENTSCHEDULE.SUMMAYEAR2DELTA%TYPE := :NEW.SUMMAYEAR2DELTA;
  new$SUMMAYEAR3DELTA PAYMENTSCHEDULE.SUMMAYEAR3DELTA%TYPE := :NEW.SUMMAYEAR3DELTA;
  new$ASSIGNMENTKIND PAYMENTSCHEDULE.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$TRANSFERTCLS PAYMENTSCHEDULE.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SENDERIDKEY PAYMENTSCHEDULE.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY PAYMENTSCHEDULE.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXECUTIONREF PAYMENTSCHEDULE.EXECUTIONREF%TYPE := :NEW.EXECUTIONREF;
  new$INNERPROMISENUM PAYMENTSCHEDULE.INNERPROMISENUM%TYPE := :NEW.INNERPROMISENUM;
  new$ADJUSTMENTNUMBER PAYMENTSCHEDULE.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$PROMISENUMBER PAYMENTSCHEDULE.PROMISENUMBER%TYPE := :NEW.PROMISENUMBER;
  new$SUBSIDYCLS PAYMENTSCHEDULE.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$AGREEMENTREF PAYMENTSCHEDULE.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$BUDALLOCATIONCLS PAYMENTSCHEDULE.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS PAYMENTSCHEDULE.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$PROGINDEX PAYMENTSCHEDULE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$INVESTOBJECT PAYMENTSCHEDULE.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$SUMMAYEAR4 PAYMENTSCHEDULE.SUMMAYEAR4%TYPE := :NEW.SUMMAYEAR4;
  new$SUMMAOTHERYEARS PAYMENTSCHEDULE.SUMMAOTHERYEARS%TYPE := :NEW.SUMMAOTHERYEARS;
  new$SUMMAYEAR4DELTA PAYMENTSCHEDULE.SUMMAYEAR4DELTA%TYPE := :NEW.SUMMAYEAR4DELTA;
  new$SUMMAOTHERYEARSDELTA PAYMENTSCHEDULE.SUMMAOTHERYEARSDELTA%TYPE := :NEW.SUMMAOTHERYEARSDELTA;
  new$CONTRACTCOSTSCLS PAYMENTSCHEDULE.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS PAYMENTSCHEDULE.TARGETCLS%TYPE := :NEW.TARGETCLS;
--
  M01$ NUMBER;
  M02$ NUMBER;
  M03$ NUMBER;
  M04$ NUMBER;
  M05$ NUMBER;
  M06$ NUMBER;
  M07$ NUMBER;
  M08$ NUMBER;
  M09$ NUMBER;
  M10$ NUMBER;
  M11$ NUMBER;
  M12$ NUMBER;
  Q1$ NUMBER;
  Q2$ NUMBER;
  Q3$ NUMBER;
  Q4$ NUMBER;
  S$ NUMBER;
  S1$ NUMBER;
  S2$ NUMBER;
  S3$ NUMBER;
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  Tmp$ NUMBER(10);
  AdjID$ NUMBER(10);
  AdjDocNum$ NUMBER(10);
  InnerNumber_parent$ NUMBER(10);
  InnerNumber_child$ NUMBER(10);
  S4$ NUMBER;
  SOther$ NUMBER;
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_PAYMENTSCHEDULE_BI)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$Accepted is null) then 
    new$Accepted := 1;
  END IF;
  if (new$PromiseType is null) then 
    new$PromiseType := 0;
  END IF;
  if (new$KFSR is null) then 
    new$KFSR := 0;
  END IF;
  if (new$KESR is null) then 
    new$KESR := 0;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$KCSR is null) then 
    new$KCSR := 0;
  END IF;
  if (new$KVR is null) then 
    new$KVR := 0;
  END IF;
  if (new$SubKESR is null) then 
    new$SubKESR := 0;
  END IF;
  if (new$AssignmentKind is null) then 
    new$AssignmentKind := 0;
  END IF;
  if (new$DirectionCls is null) then 
    new$DirectionCls := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Region is null) then 
    new$Region := 0;
  END IF;
  if (new$MeansType is null) then 
    new$MeansType := 0;
  END IF;
  if (new$FinSource is null) then 
    new$FinSource := 0;
  END IF;
  if (new$FinType is null) then 
    new$FinType := 0;
  END IF;
  if (new$Fact is null) then 
    new$Fact := 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$Month01 is null) then 
    new$Month01 := 0;
  END IF;
  if (new$Month02 is null) then 
    new$Month02 := 0;
  END IF;
  if (new$Month03 is null) then 
    new$Month03 := 0;
  END IF;
  if (new$Month04 is null) then 
    new$Month04 := 0;
  END IF;
  if (new$Month05 is null) then 
    new$Month05 := 0;
  END IF;
  if (new$Month06 is null) then 
    new$Month06 := 0;
  END IF;
  if (new$Month07 is null) then 
    new$Month07 := 0;
  END IF;
  if (new$Month08 is null) then 
    new$Month08 := 0;
  END IF;
  if (new$Month09 is null) then 
    new$Month09 := 0;
  END IF;
  if (new$Month10 is null) then 
    new$Month10 := 0;
  END IF;
  if (new$Month11 is null) then 
    new$Month11 := 0;
  END IF;
  if (new$Month12 is null) then 
    new$Month12 := 0;
  END IF;
  if (new$Quarter1 is null) then 
    new$Quarter1 := 0;
  END IF;
  if (new$Quarter2 is null) then 
    new$Quarter2 := 0;
  END IF;
  if (new$Quarter3 is null) then 
    new$Quarter3 := 0;
  END IF;
  if (new$Quarter4 is null) then 
    new$Quarter4 := 0;
  END IF;
  if (new$Summa is null) then 
    new$Summa := 0;
  END IF;
  if (new$Month01Delta is null) then 
    new$Month01Delta := 0;
  END IF;
  if (new$Month02Delta is null) then 
    new$Month02Delta := 0;
  END IF;
  if (new$Month03Delta is null) then 
    new$Month03Delta := 0;
  END IF;
  if (new$Month04Delta is null) then 
    new$Month04Delta := 0;
  END IF;
  if (new$Month05Delta is null) then 
    new$Month05Delta := 0;
  END IF;
  if (new$Month06Delta is null) then 
    new$Month06Delta := 0;
  END IF;
  if (new$Month07Delta is null) then 
    new$Month07Delta := 0;
  END IF;
  if (new$Month08Delta is null) then 
    new$Month08Delta := 0;
  END IF;
  if (new$Month09Delta is null) then 
    new$Month09Delta := 0;
  END IF;
  if (new$Month10Delta is null) then 
    new$Month10Delta := 0;
  END IF;
  if (new$Month11Delta is null) then 
    new$Month11Delta := 0;
  END IF;
  if (new$Month12Delta is null) then 
    new$Month12Delta := 0;
  END IF;
  if (new$Quarter1Delta is null) then 
    new$Quarter1Delta := 0;
  END IF;
  if (new$Quarter2Delta is null) then 
    new$Quarter2Delta := 0;
  END IF;
  if (new$Quarter3Delta is null) then 
    new$Quarter3Delta := 0;
  END IF;
  if (new$Quarter4Delta is null) then 
    new$Quarter4Delta := 0;
  END IF;
  if (new$SummaDelta is null) then 
    new$SummaDelta := 0;
  END IF;
  if (new$SummaPreviousYear is null) then 
    new$SummaPreviousYear := 0;
  END IF;
  if (new$SummaFinPreviousYear is null) then 
    new$SummaFinPreviousYear := 0;
  END IF;
  if (new$SummaYear1 is null) then 
    new$SummaYear1 := 0;
  END IF;
  if (new$SummaYear2 is null) then 
    new$SummaYear2 := 0;
  END IF;
  if (new$SummaYear3 is null) then 
    new$SummaYear3 := 0;
  END IF;
  if (new$SummaYear4 is null) then 
    new$SummaYear4 := 0;
  END IF;
  if (new$SummaOtherYears is null) then 
    new$SummaOtherYears := 0;
  END IF;
  if (new$SummaYear1Delta is null) then 
    new$SummaYear1Delta := 0;
  END IF;
  if (new$SummaYear2Delta is null) then 
    new$SummaYear2Delta := 0;
  END IF;
  if (new$SummaYear3Delta is null) then 
    new$SummaYear3Delta := 0;
  END IF;
  if (new$SummaYear4Delta is null) then 
    new$SummaYear4Delta := 0;
  END IF;
  if (new$SummaOtherYearsDelta is null) then 
    new$SummaOtherYearsDelta := 0;
  END IF;
  /*   ,        */
  if (new$ProgIndex = 304 and new$RecordIndex is not null) then
    SELECT COUNT(*) INTO CNT$1
    from AgreementSteps s where (s.Id = new$RecordIndex and s.RecordIndex = new$AgreementRef) AND (ROWNUM = 1);
    if (not (CNT$1<> 0)) then
      RaiseException('Ex_WrongStep');
    END IF;
  END IF;
  /*       */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    if (new$ProgIndex in (304,314,317,318)) then
      BEGIN
        select a.BudgetRef       into new$BudgetRef from Agreements a
        where a.ID = new$AgreementRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    else 
      if (new$ProgIndex = 308) then
        BEGIN
          select e.BudgetRef
          into new$BudgetRef       from ExecutionDocumentsCaption e
          where e.ID = new$ExecutionRef
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
      END IF;
    END IF;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$ANumber is not null) then
    SELECT COUNT(                    id
    ) INTO CNT$2
    from
    PaymentSchedule ps
    where
    (                    (ps.ANumber = new$ANumber)
    and
    (ps.BudgetRef = new$BudgetRef)) AND (ROWNUM = 1);
    if ((CNT$2<> 0)) then
      RaiseException('ex_Promise_NumUQ');
    END IF;
  END IF;
  /*    */
  GETTARGETCLS(null, new$transfertcls, null, new$meanstype,
  new$targetcls,new$targetcls);     

-- - - - - - - - - - - - -
-- BI_1 (TR_PAYMENTSCHEDULE_BI_1)
-- Create 05.03.2004
-- Last update 29.12.2007
-- - - - - - - - - - - - -

/*   1.0*/
    if (new$Quarter1 = 0) then new$Quarter1 := new$Month01 + new$Month02 + new$Month03; end if;
    if (new$Quarter2 = 0) then new$Quarter2 := new$Month04 + new$Month05 + new$Month06; end if;
    if (new$Quarter3 = 0) then new$Quarter3 := new$Month07 + new$Month08 + new$Month09; end if;
    if (new$Quarter4 = 0) then new$Quarter4 := new$Month10 + new$Month11 + new$Month12; end if;
    new$SummaYear1 := new$Quarter1 + new$Quarter2 + new$Quarter3 + new$Quarter4;

-- - - - - - - - - - - - -
-- BI_10 (TR_PAYMENTSCHEDULE_BI_10)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   5.0*/
     
  /*    .*/
  if (new$InnerPromiseNum is null) then
    RaiseException('EX_BP_InnerNumsIsNull');
  END IF;
      
  /*    */
  select max(AdjustmentNumber)
  into Tmp$         from PaymentSchedule 
  where (InnerPromiseNum = new$InnerPromiseNum)
  ;
  /*      ,   0*/
  if (Tmp$ is null) then
    new$AdjustmentNumber := 0;
        
  else
    new$AdjustmentNumber := Tmp$ + 1;
  END IF;
      
  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;
        
  else
    new$LastAdjustment := 1;
  END IF;
      
  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then 
    new$LastAccepted := 1;
        
  else
    new$LastAccepted := 0;
  END IF;
  /*    */
  if (new$AdjustmentNumber > 0) then
    /*      -    */
    select count(ID), max(ID), max(ANumber)
    into Tmp$, AdjID$, AdjDocNum$             from PaymentSchedule
    where (InnerPromiseNum = new$InnerPromiseNum) and (LastAccepted = 1)
    ;
    /*   ,  */
    if (Tmp$ <> 1) then 
      RaiseException('EX_BP_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID) 
    into Tmp$             from PaymentSchedule
    where (InnerPromiseNum = new$InnerPromiseNum) and (AcceptDate is null)
    ;
    if (Tmp$ > 0) then 
      RaiseException('EX_BP_AdjustDuplicate');
    END IF;
    /* ,    ,    */        
    new$AdjustmentRef := AdjID$;
    new$ParentNumber := AdjDocNum$;
    /*   - ,  ,       */
    if (new$ProgIndex in (304, 314)) then
      BEGIN
        /*     */        
        select a.InnerNumber
        into InnerNumber_child$             from Agreements a
        where a.ID = new$AgreementRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN
        /*       */
        select a.InnerNumber
        into InnerNumber_parent$             from PaymentSchedule ps
        left join Agreements a on (a.Id = ps.AgreementRef)
        where (ps.Id = new$AdjustmentRef)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*      */
      if (InnerNumber_parent$ <> InnerNumber_child$) then
        RaiseException('EX_PROMISE_ADJ_INCORRECT');        
      END IF;
    else 
      if (new$ProgIndex = 308) then
        BEGIN
          /*     */        
          select edc.InnerNumber
          into InnerNumber_child$             from ExecutionDocumentsCaption edc
          where edc.ID = new$ExecutionRef
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        BEGIN
          /*       */
          select edc.InnerNumber
          into InnerNumber_parent$             from PaymentSchedule ps
          left join ExecutionDocumentsCaption edc on (edc.id=ps.ExecutionRef)
          where (ps.Id = new$AdjustmentRef)
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        /*      */
        if (InnerNumber_parent$ <> InnerNumber_child$) then
          RaiseException('EX_PROMISE_ADJ_INCORRECT');        
        END IF;
      END IF;    
    END IF;
  else /*     */
    /*       (    )*/        
    new$AdjustmentRef := null;
    new$ParentNumber := null;
        
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_PAYMENTSCHEDULE_BI_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*           */
  if (new$AdjustmentNumber > 0) then
    BEGIN
      select 
      Month01, Month02, Month03, Month04, Month05, Month06,
      Month07, Month08, Month09, Month10, Month11, Month12,
      Quarter1, Quarter2, Quarter3, Quarter4, Summa, 
      SummaYear1, SummaYear2, SummaYear3, SummaYear4, SummaOtherYears
      into
      M01$, M02$, M03$, M04$, M05$, M06$, M07$, M08$, M09$, M10$, M11$, M12$, 
      Q1$, Q2$, Q3$, Q4$, S$, S1$, S2$, S3$, S4$, SOther$         from 
      PaymentSchedule
      where
      ID = new$AdjustmentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
          
    new$Month01Delta := new$Month01 - M01$;
    new$Month02Delta := new$Month02 - M02$;
    new$Month03Delta := new$Month03 - M03$;
    new$Month04Delta := new$Month04 - M04$;
    new$Month05Delta := new$Month05 - M05$;
    new$Month06Delta := new$Month06 - M06$;
    new$Month07Delta := new$Month07 - M07$;
    new$Month08Delta := new$Month08 - M08$;
    new$Month09Delta := new$Month09 - M09$;
    new$Month10Delta := new$Month10 - M10$;
    new$Month11Delta := new$Month11 - M11$;
    new$Month12Delta := new$Month12 - M12$;
    new$Quarter1Delta := new$Quarter1 - Q1$;
    new$Quarter2Delta := new$Quarter2 - Q2$;
    new$Quarter3Delta := new$Quarter3 - Q3$;
    new$Quarter4Delta := new$Quarter4 - Q4$;
    new$SummaDelta := new$Summa - S$;
    new$SummaYear1Delta := new$SummaYear1 - S1$;
    new$SummaYear2Delta := new$SummaYear2 - S2$;
    new$SummaYear3Delta := new$SummaYear3 - S3$;
    new$SummaYear4Delta := new$SummaYear4 - S4$;
    new$SummaOtherYearsDelta := new$SummaOtherYears - SOther$;        
        
  else    /*        */  
    new$Month01Delta := new$Month01;
    new$Month02Delta := new$Month02;
    new$Month03Delta := new$Month03;
    new$Month04Delta := new$Month04;
    new$Month05Delta := new$Month05;
    new$Month06Delta := new$Month06;
    new$Month07Delta := new$Month07;
    new$Month08Delta := new$Month08;
    new$Month09Delta := new$Month09;
    new$Month10Delta := new$Month10;
    new$Month11Delta := new$Month11;
    new$Month12Delta := new$Month12;
    new$Quarter1Delta := new$Quarter1;
    new$Quarter2Delta := new$Quarter2;
    new$Quarter3Delta := new$Quarter3;
    new$Quarter4Delta := new$Quarter4;
    new$SummaDelta := new$Summa;
    new$SummaYear1Delta := new$SummaYear1;
    new$SummaYear2Delta := new$SummaYear2;
    new$SummaYear3Delta := new$SummaYear3;
    new$SummaYear4Delta := new$SummaYear4;
    new$SummaOtherYearsDelta := new$SummaOtherYears;        
        
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_PAYMENTSCHEDULE_BI_200)
-- Create 06.08.2010
-- - - - - - - - - - - - -

  /*      */
  if (new$senderId is null) then 
    new$senderIdKey := -1;
  else
    new$senderIdKey := new$senderId;
  end if;

  if (new$SenderRecordID is null)then
    new$SenderRecordIDKey := new$ID;
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  end if;       

-- - - - - - - - - - - - -
-- BI_500 (TR_PAYMENTSCHEDULE_BI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_PAYMENTSCHEDULE (
    ID,
    ANUMBER,
    PARENTNUMBER,
    KFSR,
    KESR,
    KVSR,
    KCSR,
    KVR,
    MONTH01,
    MONTH02,
    MONTH03,
    MONTH04,
    MONTH05,
    MONTH06,
    MONTH07,
    MONTH08,
    MONTH09,
    MONTH10,
    MONTH11,
    MONTH12,
    SUMMA,
    REGION,
    SUBKESR,
    MEANSTYPE,
    FINSOURCE,
    FINTYPE,
    FACT,
    FACIALACC_CLS,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    ACCEPTDATE,
    LASTADJUSTMENT,
    ACCEPTED,
    LASTACCEPTED,
    PROMISETYPE,
    ADJUSTMENTREF,
    OLDNUMBER,
    SUMMAPREVIOUSYEAR,
    SUMMAFINPREVIOUSYEAR,
    QUARTER1,
    QUARTER2,
    QUARTER3,
    QUARTER4,
    RECORDINDEX,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DIRECTIONCLS,
    RVERSION,
    BUHOPERATIONCLS,
    MONTH01DELTA,
    MONTH02DELTA,
    MONTH03DELTA,
    MONTH04DELTA,
    MONTH05DELTA,
    MONTH06DELTA,
    MONTH07DELTA,
    MONTH08DELTA,
    MONTH09DELTA,
    MONTH10DELTA,
    MONTH11DELTA,
    MONTH12DELTA,
    QUARTER1DELTA,
    QUARTER2DELTA,
    QUARTER3DELTA,
    QUARTER4DELTA,
    SUMMADELTA,
    NOTE,
    FINYEAR,
    SUMMAYEAR1,
    SUMMAYEAR2,
    SUMMAYEAR3,
    SUMMAYEAR1DELTA,
    SUMMAYEAR2DELTA,
    SUMMAYEAR3DELTA,
    ASSIGNMENTKIND,
    TRANSFERTCLS,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    EXECUTIONREF,
    INNERPROMISENUM,
    ADJUSTMENTNUMBER,
    PROMISENUMBER,
    SUBSIDYCLS,
    AGREEMENTREF,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    PROGINDEX,
    INVESTOBJECT,
    SUMMAYEAR4,
    SUMMAOTHERYEARS,
    SUMMAYEAR4DELTA,
    SUMMAOTHERYEARSDELTA,
    CONTRACTCOSTSCLS,
    TARGETCLS
  ) VALUES (
    new$ID,
    new$ANUMBER,
    new$PARENTNUMBER,
    new$KFSR,
    new$KESR,
    new$KVSR,
    new$KCSR,
    new$KVR,
    new$MONTH01,
    new$MONTH02,
    new$MONTH03,
    new$MONTH04,
    new$MONTH05,
    new$MONTH06,
    new$MONTH07,
    new$MONTH08,
    new$MONTH09,
    new$MONTH10,
    new$MONTH11,
    new$MONTH12,
    new$SUMMA,
    new$REGION,
    new$SUBKESR,
    new$MEANSTYPE,
    new$FINSOURCE,
    new$FINTYPE,
    new$FACT,
    new$FACIALACC_CLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$ACCEPTDATE,
    new$LASTADJUSTMENT,
    new$ACCEPTED,
    new$LASTACCEPTED,
    new$PROMISETYPE,
    new$ADJUSTMENTREF,
    new$OLDNUMBER,
    new$SUMMAPREVIOUSYEAR,
    new$SUMMAFINPREVIOUSYEAR,
    new$QUARTER1,
    new$QUARTER2,
    new$QUARTER3,
    new$QUARTER4,
    new$RECORDINDEX,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$DIRECTIONCLS,
    new$RVERSION,
    new$BUHOPERATIONCLS,
    new$MONTH01DELTA,
    new$MONTH02DELTA,
    new$MONTH03DELTA,
    new$MONTH04DELTA,
    new$MONTH05DELTA,
    new$MONTH06DELTA,
    new$MONTH07DELTA,
    new$MONTH08DELTA,
    new$MONTH09DELTA,
    new$MONTH10DELTA,
    new$MONTH11DELTA,
    new$MONTH12DELTA,
    new$QUARTER1DELTA,
    new$QUARTER2DELTA,
    new$QUARTER3DELTA,
    new$QUARTER4DELTA,
    new$SUMMADELTA,
    new$NOTE,
    new$FINYEAR,
    new$SUMMAYEAR1,
    new$SUMMAYEAR2,
    new$SUMMAYEAR3,
    new$SUMMAYEAR1DELTA,
    new$SUMMAYEAR2DELTA,
    new$SUMMAYEAR3DELTA,
    new$ASSIGNMENTKIND,
    new$TRANSFERTCLS,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$EXECUTIONREF,
    new$INNERPROMISENUM,
    new$ADJUSTMENTNUMBER,
    new$PROMISENUMBER,
    new$SUBSIDYCLS,
    new$AGREEMENTREF,
    new$BUDALLOCATIONCLS,
    new$PAYPROMISECLS,
    new$PROGINDEX,
    new$INVESTOBJECT,
    new$SUMMAYEAR4,
    new$SUMMAOTHERYEARS,
    new$SUMMAYEAR4DELTA,
    new$SUMMAOTHERYEARSDELTA,
    new$CONTRACTCOSTSCLS,
    new$TARGETCLS);

-- - - - - - - - - - - - -
-- AI_10 (TR_PAYMENTSCHEDULE_AI_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/
  /*      */
  if ((new$AdjustmentNumber > 0) and (new$LastAdjustment = 1)) then
    update PaymentSchedule set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);            
    if (new$LastAccepted = 1) then
      update PaymentSchedule set
      LastAccepted = 0,
      RVersion = -1
      where (ID = new$AdjustmentRef);
        
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_PAYMENTSCHEDULE_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 113) and (RecordID = new$ID);

END;
/
commit work
/
-- ALTER TRIGGER TR_WRITEXECUTIONDETAIL_BI
CREATE OR REPLACE TRIGGER TR_WRITEXECUTIONDETAIL_BI
  BEFORE INSERT
  ON WRITEXECUTIONDETAIL
  FOR EACH ROW
DECLARE
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  ConstCheck$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  ScheduleRef$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_WRITEXECUTIONDETAIL_BI)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  if (:new.BudgetRef is null) then
    BEGIN
      select 
      writ_c.BudgetRef 
      into :new.BudgetRef     from 
      WritExecutionCaption writ_c
      where 
      writ_c.id = :new.RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
    
  if (:new.Progindex is null) then 
    :new.Progindex := 556;  
  END IF;
  if (:new.FacialAcc_Cls is null) then 
    :new.FacialAcc_Cls := 0;
  END IF;
  if (:new.KVSR is null) then 
    :new.KVSR := 0;
  END IF;
  if (:new.KFSR is null) then 
    :new.KFSR := 0;
  END IF;
  if (:new.KESR is null) then 
    :new.KESR := 0;
  END IF;
  if (:new.KVR is null) then 
    :new.KVR := 0;
  END IF;
  if (:new.KCSR is null) then 
    :new.KCSR := 0;
  END IF;
  if (:new.MeansType is null) then 
    :new.MeansType := 0;
  END IF;
  if (:new.Fact is null) then 
    :new.Fact := 0;
  END IF;
  if (:new.DirectionCls is null) then 
    :new.DirectionCls := 0;
  END IF;
  if (:new.RegionCLS is null) then 
    :new.RegionCLS := 0;
  END IF;
  if (:new.Finsource is null) then 
    :new.Finsource := 0;
  END IF;
  if (:new.FinType is null) then 
    :new.FinType := 0;
  END IF;
  if (:new.DocType is null) then 
    :new.DocType := 0;
  END IF;
  if (:new.SubKesr is null) then 
    :new.SubKesr := 0;
  END IF;
    
  if (:new.Month01 IS NULL) then  
    :new.Month01 := 0;
  END IF;
  if (:new.Month02 IS NULL) then  
    :new.Month02 := 0;
  END IF;
  if (:new.Month03 IS NULL) then  
    :new.Month03 := 0;
  END IF;
  if (:new.Month04 IS NULL) then  
    :new.Month04 := 0;
  END IF;
  if (:new.Month05 IS NULL) then  
    :new.Month05 := 0;
  END IF;
  if (:new.Month06 IS NULL) then  
    :new.Month06 := 0;
  END IF;
  if (:new.Month07 IS NULL) then  
    :new.Month07 := 0;
  END IF;
  if (:new.Month08 IS NULL) then  
    :new.Month08 := 0;
  END IF;
  if (:new.Month09 IS NULL) then  
    :new.Month09 := 0;
  END IF;
  if (:new.Month10 IS NULL) then  
    :new.Month10 := 0;
  END IF;
  if (:new.Month11 IS NULL) then  
    :new.Month11 := 0;
  END IF;
  if (:new.Month12 IS NULL) then  
    :new.Month12 := 0;
  END IF;
    
  if (:new.Quarter1 IS NULL) then  
    :new.Quarter1 := 0;
  END IF;
  if (:new.Quarter2 IS NULL) then  
    :new.Quarter2 := 0;
  END IF;
  if (:new.Quarter3 IS NULL) then  
    :new.Quarter3 := 0;
  END IF;
  if (:new.Quarter4 IS NULL) then  
    :new.Quarter4 := 0;
  END IF;
    
  if (:new.WritExecutionSumma is Null) then 
    :new.WritExecutionSumma := 0; 
  END IF;
  if ((not :new.PROMISE is null) and (not :new.BUDGETPROMISE is null)) then
    BEGIN
      select ps.id     into ScheduleRef$ from PaymentSchedule ps
      where (ps.InnerPromiseNum = :new.BUDGETPROMISE) and
      (ps.ANumber = :new.PROMISE)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (ScheduleRef$ <> 0) then
    :new.PScheduleRef := ScheduleRef$;
      
  else
    :new.PScheduleRef := null;
  END IF;
  /*    */
  GETTARGETCLS(null, :new.transfertcls, null, :new.meanstype,
  :new.targetcls,:new.targetcls); 

-- - - - - - - - - - - - -
-- BI_110 (TR_WritExecutionDetail_BI_110)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if (:new.KD is NULL) then 
    :new.KD := 0;
  END IF;
    
  if (:new.ClsType is NULL) then
    if (:new.KD <> 0) then
      :new.ClsType := 2; /*       ClsType */
          
    else
      :new.ClsType := 0;    
      
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND (:new.KD <> 0)) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0)
  )) THEN
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 2)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_WRITEXECUTIONDETAIL_BI_200)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  getintconst(30, 35,ConstCheck$);
  /* ( )      ,    */
  if ((PromiseMode$ <> 1) and (ConstCheck$ = 1)) then
    if (:new.Promise is not null) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$        from
      promise_detail pr
      where
      (pr.registrnumber = :new.PROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');    
      END IF;  
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /* ( )      ,    */
  /*         */
  if (PromiseMode$ = 1) then
    if ((:new.Promise is not null) and (:new.BudgetPromise is null)) then
      select 
      max(InnerPromiseNum) 
      into BPInnerNum$       from 
      PaymentSchedule 
      where 
      (ANumber = :new.Promise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        :new.BudgetPromise := BPInnerNum$;
              
      else
        RaiseException('EX_BP_NotExist');    
      END IF;
    END IF;
    /*    ,   ,   */
    if ((:new.BudgetPromise is not null) and (:new.Promise is null)) then
      BEGIN
        select 
        ANumber 
        into BPInnerNum$       from 
        PaymentSchedule
        where 
        (InnerPromiseNum = :new.BudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
            
      :new.Promise := BPInnerNum$;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_WRITEXECUTIONDETAIL_BI_210)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (:new.Promise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = :new.Promise and ps.InnerPromiseNum = :new.BudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_WRITEXECUTIONDETAIL_BI_500)
-- Create 02.04.2010
-- Last update 02.04.2010
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER TR_WRITEXECUTIONDETAIL_BU
CREATE OR REPLACE TRIGGER TR_WRITEXECUTIONDETAIL_BU
  BEFORE UPDATE
  ON WRITEXECUTIONDETAIL
  FOR EACH ROW
DECLARE
  BPInnerNum1$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  Promise_Count1$ NUMBER(10);
  ConstCheck1$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  ScheduleRef$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_WRITEXECUTIONDETAIL_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if (:new.BudgetRef is null) then
    BEGIN
      select 
      writ_c.BudgetRef 
      into :new.BudgetRef     from 
      WritExecutionCaption writ_c
      where 
      writ_c.id = :new.RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (:new.Progindex is null) then 
    :new.Progindex := 556;    
  END IF;
  if (:new.FacialAcc_Cls is null) then 
    :new.FacialAcc_Cls := 0;
  END IF;
  if (:new.KVSR is null) then 
    :new.KVSR := 0;
  END IF;
  if (:new.KFSR is null) then 
    :new.KFSR := 0;
  END IF;
  if (:new.KESR is null) then 
    :new.KESR := 0;
  END IF;
  if (:new.KVR is null) then 
    :new.KVR := 0;
  END IF;
  if (:new.KCSR is null) then 
    :new.KCSR := 0;
  END IF;
  if (:new.MeansType is null) then 
    :new.MeansType := 0;
  END IF;
  if (:new.Fact is null) then 
    :new.Fact := 0;
  END IF;
  if (:new.DirectionCls is null) then 
    :new.DirectionCls := 0;
  END IF;
  if (:new.RegionCLS is null) then 
    :new.RegionCLS := 0;
  END IF;
  if (:new.Finsource is null) then 
    :new.Finsource := 0;
  END IF;
  if (:new.FinType is null) then 
    :new.FinType := 0;
  END IF;
  if (:new.DocType is null) then 
    :new.DocType := 0;
  END IF;
  if (:new.SubKesr is null) then 
    :new.SubKesr := 0;
  END IF;
    
  if (:new.Month01 IS NULL) then  
    :new.Month01 := 0;
  END IF;
  if (:new.Month02 IS NULL) then  
    :new.Month02 := 0;
  END IF;
  if (:new.Month03 IS NULL) then  
    :new.Month03 := 0;
  END IF;
  if (:new.Month04 IS NULL) then  
    :new.Month04 := 0;
  END IF;
  if (:new.Month05 IS NULL) then  
    :new.Month05 := 0;
  END IF;
  if (:new.Month06 IS NULL) then  
    :new.Month06 := 0;
  END IF;
  if (:new.Month07 IS NULL) then  
    :new.Month07 := 0;
  END IF;
  if (:new.Month08 IS NULL) then  
    :new.Month08 := 0;
  END IF;
  if (:new.Month09 IS NULL) then  
    :new.Month09 := 0;
  END IF;
  if (:new.Month10 IS NULL) then  
    :new.Month10 := 0;
  END IF;
  if (:new.Month11 IS NULL) then  
    :new.Month11 := 0;
  END IF;
  if (:new.Month12 IS NULL) then  
    :new.Month12 := 0;
  END IF;
    
  if (:new.Quarter1 IS NULL) then  
    :new.Quarter1 := 0;
  END IF;
  if (:new.Quarter2 IS NULL) then  
    :new.Quarter2 := 0;
  END IF;
  if (:new.Quarter3 IS NULL) then  
    :new.Quarter3 := 0;
  END IF;
  if (:new.Quarter4 IS NULL) then  
    :new.Quarter4 := 0;
  END IF;
    
  if (:new.WritExecutionSumma is Null) then 
    :new.WritExecutionSumma := 0; 
  END IF;
  if ((not :new.PROMISE is null) and (not :new.BUDGETPROMISE is null)) then
    BEGIN
      select ps.id     into ScheduleRef$ from PaymentSchedule ps
      where (ps.InnerPromiseNum = :new.BUDGETPROMISE) and
      (ps.ANumber = :new.PROMISE)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (ScheduleRef$ <> 0) then
    :new.PScheduleRef := ScheduleRef$;
      
  else
    :new.PScheduleRef := null;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, :new.transfertcls, :old.meanstype, :new.meanstype,
  :new.targetcls,:new.targetcls); 

-- - - - - - - - - - - - -
-- BU_110 (TR_WritExecutionDetail_BU_110)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if (:new.KD is NULL) then 
    :new.KD := 0;
  END IF;
  if (:new.ClsType is NULL) then
    if (:new.KD <> 0) then
      :new.ClsType := 2; /*       ClsType */
          
    else
      :new.ClsType := 0;    
      
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND (:new.KD <> 0)) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0)
  )) THEN
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 2)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_WRITEXECUTIONDETAIL_BU_200)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode1$);
  getintconst(30, 35,ConstCheck1$);
  /* ( )      ,    */
  if ((PromiseMode1$ <> 1) and (ConstCheck1$ = 1)) then
    if ((:new.Promise is not null)and((:old.Promise is null)or(:old.Promise <> :new.Promise ))) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$        from
      promise_detail pr
      where
      (pr.registrnumber = :new.PROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');    
      END IF;  
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /* ( )      ,    */
  /*         */
  if (PromiseMode1$ = 1) then
    if ((:new.Promise is not null)and((:old.Promise is null)or(:old.Promise <> :new.Promise )) and 
    (:new.BudgetPromise is null) and (:old.BudgetPromise is null)) then
      select 
      max(InnerPromiseNum) 
      into BPInnerNum1$       from 
      PaymentSchedule 
      where 
      (ANumber = :new.Promise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        :new.BudgetPromise := BPInnerNum1$;
              
      else
        RaiseException('EX_BP_NotExist');    
      END IF;
    END IF;
        
    /*         NULL,    */
    if (:new.Promise is null and ((:new.BudgetPromise is not null and :old.BudgetPromise is null) or
    (:new.BudgetPromise <> :old.BudgetPromise))) then
      BEGIN
        select 
        ANumber 
        into BPInnerNum1$       from 
        PaymentSchedule
        where 
        (InnerPromiseNum = :new.BudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
            
      :new.Promise := BPInnerNum1$;
          
    END IF;
        
    /*    ,     */
    if ((:new.BudgetPromise is null) and (:old.BudgetPromise is not null)) then
      :new.Promise := null;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_WRITEXECUTIONDETAIL_BU_210)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (:new.Promise is not null and (
    (:old.Promise is null or :old.Promise <> :new.Promise) or
    (:old.ExecDoc is null or :new.ExecDoc is null or :old.ExecDoc <> :new.ExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = :new.Promise and ps.InnerPromiseNum = :new.BudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_WRITEXECUTIONDETAIL_BU_700)
-- Create 02.04.2010
-- Last update 02.04.2010
-- - - - - - - - - - - - -

  if (:new.RVersion is null) then
    :new.RVersion := 1;
  elsif ((:new.RVersion = -1) and (:old.RVersion <> -1)) then
    :new.RVersion := :old.RVersion;
  else
    :new.RVersion := :old.RVersion + 1;
  end if;

END;
/
commit work 
/
-- ALTER TRIGGER TR_RepClsDetailInfo_BI
CREATE OR REPLACE TRIGGER TR_REPLACEMENTCLSDETAILINFO_BI
  BEFORE INSERT
  ON REPLACEMENTCLSDETAILINFO
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_RepClsDetailInfo_BI)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  /*    */
  GETTARGETCLS(null, :new.transfertcls, null, :new.meanstype,
  :new.targetcls,:new.targetcls);

-- - - - - - - - - - - - -
-- BI_10 (TR_REPCLSDETINFO_BI_10)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  BEGIN
    select 
    rep_c.BudgetRef
    into
    :new.BudgetRef   from 
    ReplacementClsCaption rep_c
    where
    rep_c.id = :new.RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BI_120 (TR_REPLCLSDETINFO_BI_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((:new.ClsType is NULL) and (:new.IFS <> 0)) then
    :new.ClsType := 1; 
      
  else
    if ((:new.ClsType is NULL) and (:new.KD <> 0)) then
      :new.ClsType := 2; 
          
    else
      if (:new.ClsType is null) then
        :new.ClsType := 0; 
      END IF;
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND ((:new.IFS <> 0) or (:new.KD <> 0)))THEN 
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ( (:new.ClsType = 1) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0) OR
  (:new.KD <> 0)
  )) 
  THEN 
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType = 2) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0) OR
  (:new.IFS <> 0)
  )) 
  THEN 
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_RepClsDetailInfo_BI_500)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER TR_RepClsDetailInfo_BU
CREATE OR REPLACE TRIGGER TR_REPLACEMENTCLSDETAILINFO_BU
  BEFORE UPDATE
  ON REPLACEMENTCLSDETAILINFO
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_RepClsDetailInfo_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, :new.transfertcls, :old.meanstype, :new.meanstype,
  :new.targetcls,:new.targetcls); 

-- - - - - - - - - - - - -
-- BU_120 (TR_REPLCLSDETINFO_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((:new.ClsType is NULL) and (:new.IFS <> 0)) then
    :new.ClsType := 1; 
      
  else
    if ((:new.ClsType is NULL) and (:new.KD <> 0)) then
      :new.ClsType := 2; 
          
    else
      if (:new.ClsType is null) then
        :new.ClsType := 0;
      END IF;
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND ((:new.IFS <> 0) or (:new.KD <> 0)))THEN
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ( (:new.ClsType = 1) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0) OR
  (:new.KD <> 0)
  )) 
  THEN 
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType = 2) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0) OR
  (:new.IFS <> 0)
  )) 
  THEN 
    RaiseException('EX_WRONGBUDCLS');
  END IF;

END;
/
commit work 
/
-- CREATE TRIGGER tr_correctiondetail_bi
CREATE OR REPLACE TRIGGER TR_CORRECTIONDETAIL_II
  INSTEAD OF INSERT
  ON CORRECTIONDETAIL
  FOR EACH ROW
DECLARE
  new$ID CORRECTIONDETAIL.ID%TYPE := :NEW.ID;
  new$PARENTID CORRECTIONDETAIL.PARENTID%TYPE := :NEW.PARENTID;
  new$BUDGETREF CORRECTIONDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUMMA CORRECTIONDETAIL.SUMMA%TYPE := :NEW.SUMMA;
  new$CLSTYPE CORRECTIONDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$FACIALACC_CLS CORRECTIONDETAIL.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$KVSR CORRECTIONDETAIL.KVSR%TYPE := :NEW.KVSR;
  new$KFSR CORRECTIONDETAIL.KFSR%TYPE := :NEW.KFSR;
  new$KCSR CORRECTIONDETAIL.KCSR%TYPE := :NEW.KCSR;
  new$KVR CORRECTIONDETAIL.KVR%TYPE := :NEW.KVR;
  new$KESR CORRECTIONDETAIL.KESR%TYPE := :NEW.KESR;
  new$DIRECTIONCLS CORRECTIONDETAIL.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$MEANSTYPE CORRECTIONDETAIL.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FACT CORRECTIONDETAIL.FACT%TYPE := :NEW.FACT;
  new$REGIONCLS CORRECTIONDETAIL.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$FINSOURCE CORRECTIONDETAIL.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE CORRECTIONDETAIL.FINTYPE%TYPE := :NEW.FINTYPE;
  new$DOCTYPE CORRECTIONDETAIL.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SUBKESR CORRECTIONDETAIL.SUBKESR%TYPE := :NEW.SUBKESR;
  new$FUNDSSOURCE CORRECTIONDETAIL.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$KD CORRECTIONDETAIL.KD%TYPE := :NEW.KD;
  new$IFS CORRECTIONDETAIL.IFS%TYPE := :NEW.IFS;
  new$BUHOPERATIONCLS CORRECTIONDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CHANGEACC_REF CORRECTIONDETAIL.CHANGEACC_REF%TYPE := :NEW.CHANGEACC_REF;
  new$CHANGEACC CORRECTIONDETAIL.CHANGEACC%TYPE := :NEW.CHANGEACC;
  new$CHANGEORGINN CORRECTIONDETAIL.CHANGEORGINN%TYPE := :NEW.CHANGEORGINN;
  new$CHANGEORGINN20 CORRECTIONDETAIL.CHANGEORGINN20%TYPE := :NEW.CHANGEORGINN20;
  new$PROGINDEX CORRECTIONDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX CORRECTIONDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$DOCUMENTPROGINDEX CORRECTIONDETAIL.DOCUMENTPROGINDEX%TYPE := :NEW.DOCUMENTPROGINDEX;
  new$DOCUMENTRECORDINDEX CORRECTIONDETAIL.DOCUMENTRECORDINDEX%TYPE := :NEW.DOCUMENTRECORDINDEX;
  new$ISBLOCKED CORRECTIONDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE CORRECTIONDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE CORRECTIONDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE CORRECTIONDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SENDERID CORRECTIONDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID CORRECTIONDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$RVERSION CORRECTIONDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$CREATERUSER CORRECTIONDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE CORRECTIONDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER CORRECTIONDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE CORRECTIONDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$NOTE CORRECTIONDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$ISCLSCHANGED CORRECTIONDETAIL.ISCLSCHANGED%TYPE := :NEW.ISCLSCHANGED;
  new$PROMISE CORRECTIONDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$BUDGETPROMISE CORRECTIONDETAIL.BUDGETPROMISE%TYPE := :NEW.BUDGETPROMISE;
  new$EXECDOC CORRECTIONDETAIL.EXECDOC%TYPE := :NEW.EXECDOC;
  new$OKATO CORRECTIONDETAIL.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO CORRECTIONDETAIL.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$TRANSFERTCLS CORRECTIONDETAIL.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$ORIGINALCLSSUMMA CORRECTIONDETAIL.ORIGINALCLSSUMMA%TYPE := :NEW.ORIGINALCLSSUMMA;
  new$NOTECLS CORRECTIONDETAIL.NOTECLS%TYPE := :NEW.NOTECLS;
  new$OPERATIONTYPE CORRECTIONDETAIL.OPERATIONTYPE%TYPE := :NEW.OPERATIONTYPE;
  new$REVERSEFLAG CORRECTIONDETAIL.REVERSEFLAG%TYPE := :NEW.REVERSEFLAG;
  new$EXECINNERNUMBER CORRECTIONDETAIL.EXECINNERNUMBER%TYPE := :NEW.EXECINNERNUMBER;
  new$CLSFIELFCHANGED CORRECTIONDETAIL.CLSFIELFCHANGED%TYPE := :NEW.CLSFIELFCHANGED;
  new$FAORGTYPE CORRECTIONDETAIL.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$SUBSIDYCLS CORRECTIONDETAIL.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$BUDALLOCATIONCLS CORRECTIONDETAIL.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS CORRECTIONDETAIL.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$NOTEQUALEX CORRECTIONDETAIL.NOTEQUALEX%TYPE := :NEW.NOTEQUALEX;
  new$OKTMO CORRECTIONDETAIL.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE CORRECTIONDETAIL.UINCODE%TYPE := :NEW.UINCODE;
  new$INVESTOBJECT CORRECTIONDETAIL.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CHANGEORGNAME CORRECTIONDETAIL.CHANGEORGNAME%TYPE := :NEW.CHANGEORGNAME;
  new$CONTRACTCOSTSCLS CORRECTIONDETAIL.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS CORRECTIONDETAIL.TARGETCLS%TYPE := :NEW.TARGETCLS;
--
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  ConstCheck$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  vOperationTypeS$ NUMBER(10);
  vOperationTypeD$ NUMBER(10);
  vOperationType$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_CORRECTIONDETAIL_BI)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN 
    select g_shared.nextval into new$id from dual;
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$IFS := 0;
  END IF;
  IF (new$FacialAcc_Cls IS NULL) THEN 
    new$FacialAcc_Cls := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DirectionCls IS NULL) THEN 
    new$DirectionCls := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$Finsource IS NULL) THEN 
    new$Finsource := 0;
  END IF;
  IF (new$FinType IS NULL) THEN 
    new$FinType := 0;
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;  
  END IF;
  IF (new$SubKesr IS NULL) THEN 
    new$SubKesr := 0;
  END IF;
  IF (new$buhoperationCls IS NULL) THEN 
    new$buhoperationCls := 0;
  END IF;
  IF (new$ReverseFlag IS NULL) THEN 
    new$ReverseFlag := 1;
  END IF;
  IF (new$OperationType IS NULL) THEN 
    BEGIN
      SELECT CorCap.SourceType, CorCap.DestType
      INTO
      vOperationTypeS$, vOperationTypeD$       FROM correctioncaption CorCap
      WHERE
      (CorCap.id = new$recordindex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    IF (new$ProgIndex = 315) THEN 
      vOperationType$ := vOperationTypeS$;
          
    ELSE 
      vOperationType$ := vOperationTypeD$;
    END IF;
    new$OperationType := vOperationType$;
      
  END IF;
  BEGIN

    SELECT org.Org_Type   INTO new$FAOrgType FROM Organizations org
    INNER JOIN FacialAcc_Cls fac  ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$FacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*    */
  GETTARGETCLS(null, new$transfertcls, null, new$meanstype,
  new$targetcls,new$targetcls); 

-- - - - - - - - - - - - -
-- BI_100 (tr_correctiondetail_bi_100)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$progindex = 316) then
    update correctiondetail set
    buhoperationcls = new$buhoperationcls
    where ID = new$parentid;
  END IF;

-- - - - - - - - - - - - -
-- BI_120 (TR_CORRECTIONDETAIL_BI_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((new$ClsType is NULL) and (new$IFS <> 0)) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$KD <> 0)) then
      new$ClsType := 2; /*        ClsType */
            
    else
      if (new$ClsType is null)
      then 
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND ((new$IFS <> 0) or (new$KD <> 0)))THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ( (new$ClsType = 1) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0) OR
  (new$KD <> 0)
  ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0) OR
  (new$IFS <> 0)
  ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_CORRECTIONDETAIL_BI_200)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  getintconst(30, 35,ConstCheck$);
  /* ( )      ,    */
  if ((PromiseMode$ <> 1) and (ConstCheck$ = 1)) then
    if (new$Promise is not null) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$        from
      promise_detail pr
      where
      (pr.registrnumber = new$PROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');    
      END IF;  
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /* ( )      ,    */
  /*         */
  if (PromiseMode$ = 1) then
    if ((new$Promise is not null) and (new$BudgetPromise is null)) then
      select 
      max(InnerPromiseNum) 
      into BPInnerNum$       from 
      PaymentSchedule 
      where 
      (ANumber = new$Promise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$BudgetPromise := BPInnerNum$;
              
      else
        RaiseException('EX_BP_NotExist');    
      END IF;
    END IF;
    /*    ,   ,   */
    if ((new$BudgetPromise is not null) and (new$Promise is null)) then
      BEGIN
        select 
        ANumber 
        into BPInnerNum$       from 
        PaymentSchedule
        where 
        (InnerPromiseNum = new$BudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
            
      new$Promise := BPInnerNum$;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_CORRECTIONDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$Promise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$Promise and ps.InnerPromiseNum = new$BudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$ExecDoc := ExecID$;
        new$ExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$ExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$ExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$ExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*    ,   ,  */
    else 
      if (new$ExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$ExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$ExecInnerNumber := ExecInnerNumber$;
            
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_CORRECTIONDETAIL_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update CorrectionCaption set
  DocChangeDate = new$UpdateDate,
  RVersion = -1
  where id = new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_CORRECTIONDETAIL (
    ID,
    PARENTID,
    BUDGETREF,
    SUMMA,
    CLSTYPE,
    FACIALACC_CLS,
    KVSR,
    KFSR,
    KCSR,
    KVR,
    KESR,
    DIRECTIONCLS,
    MEANSTYPE,
    FACT,
    REGIONCLS,
    FINSOURCE,
    FINTYPE,
    DOCTYPE,
    SUBKESR,
    FUNDSSOURCE,
    KD,
    IFS,
    BUHOPERATIONCLS,
    CHANGEACC_REF,
    CHANGEACC,
    CHANGEORGINN,
    CHANGEORGINN20,
    PROGINDEX,
    RECORDINDEX,
    DOCUMENTPROGINDEX,
    DOCUMENTRECORDINDEX,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SENDERID,
    SENDERRECORDID,
    RVERSION,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    NOTE,
    ISCLSCHANGED,
    PROMISE,
    BUDGETPROMISE,
    EXECDOC,
    OKATO,
    ADDOKATO,
    TRANSFERTCLS,
    ORIGINALCLSSUMMA,
    NOTECLS,
    OPERATIONTYPE,
    REVERSEFLAG,
    EXECINNERNUMBER,
    CLSFIELFCHANGED,
    FAORGTYPE,
    SUBSIDYCLS,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    NOTEQUALEX,
    OKTMO,
    UINCODE,
    INVESTOBJECT,
    CHANGEORGNAME,
    CONTRACTCOSTSCLS,
    TARGETCLS
  ) VALUES (
    new$ID,
    new$PARENTID,
    new$BUDGETREF,
    new$SUMMA,
    new$CLSTYPE,
    new$FACIALACC_CLS,
    new$KVSR,
    new$KFSR,
    new$KCSR,
    new$KVR,
    new$KESR,
    new$DIRECTIONCLS,
    new$MEANSTYPE,
    new$FACT,
    new$REGIONCLS,
    new$FINSOURCE,
    new$FINTYPE,
    new$DOCTYPE,
    new$SUBKESR,
    new$FUNDSSOURCE,
    new$KD,
    new$IFS,
    new$BUHOPERATIONCLS,
    new$CHANGEACC_REF,
    new$CHANGEACC,
    new$CHANGEORGINN,
    new$CHANGEORGINN20,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$DOCUMENTPROGINDEX,
    new$DOCUMENTRECORDINDEX,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SENDERID,
    new$SENDERRECORDID,
    new$RVERSION,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$NOTE,
    new$ISCLSCHANGED,
    new$PROMISE,
    new$BUDGETPROMISE,
    new$EXECDOC,
    new$OKATO,
    new$ADDOKATO,
    new$TRANSFERTCLS,
    new$ORIGINALCLSSUMMA,
    new$NOTECLS,
    new$OPERATIONTYPE,
    new$REVERSEFLAG,
    new$EXECINNERNUMBER,
    new$CLSFIELFCHANGED,
    new$FAORGTYPE,
    new$SUBSIDYCLS,
    new$BUDALLOCATIONCLS,
    new$PAYPROMISECLS,
    new$NOTEQUALEX,
    new$OKTMO,
    new$UINCODE,
    new$INVESTOBJECT,
    new$CHANGEORGNAME,
    new$CONTRACTCOSTSCLS,
    new$TARGETCLS);

-- - - - - - - - - - - - -
-- AI_500 (TR_CORRECTIONDETAIL_AI_500)
-- Create 29.12.2009
-- - - - - - - - - - - - -

 delete from DelRecIndexes where (TableID =5504 ) and (RecordID = new$ID);

END;
/
-- CREATE TRIGGER tr_correctiondetail_bu
CREATE OR REPLACE TRIGGER TR_CORRECTIONDETAIL_IU
  INSTEAD OF UPDATE
  ON CORRECTIONDETAIL
  FOR EACH ROW
DECLARE
  new$ID CORRECTIONDETAIL.ID%TYPE := :NEW.ID;
  new$PARENTID CORRECTIONDETAIL.PARENTID%TYPE := :NEW.PARENTID;
  new$BUDGETREF CORRECTIONDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUMMA CORRECTIONDETAIL.SUMMA%TYPE := :NEW.SUMMA;
  new$CLSTYPE CORRECTIONDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$FACIALACC_CLS CORRECTIONDETAIL.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$KVSR CORRECTIONDETAIL.KVSR%TYPE := :NEW.KVSR;
  new$KFSR CORRECTIONDETAIL.KFSR%TYPE := :NEW.KFSR;
  new$KCSR CORRECTIONDETAIL.KCSR%TYPE := :NEW.KCSR;
  new$KVR CORRECTIONDETAIL.KVR%TYPE := :NEW.KVR;
  new$KESR CORRECTIONDETAIL.KESR%TYPE := :NEW.KESR;
  new$DIRECTIONCLS CORRECTIONDETAIL.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$MEANSTYPE CORRECTIONDETAIL.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FACT CORRECTIONDETAIL.FACT%TYPE := :NEW.FACT;
  new$REGIONCLS CORRECTIONDETAIL.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$FINSOURCE CORRECTIONDETAIL.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE CORRECTIONDETAIL.FINTYPE%TYPE := :NEW.FINTYPE;
  new$DOCTYPE CORRECTIONDETAIL.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SUBKESR CORRECTIONDETAIL.SUBKESR%TYPE := :NEW.SUBKESR;
  new$FUNDSSOURCE CORRECTIONDETAIL.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$KD CORRECTIONDETAIL.KD%TYPE := :NEW.KD;
  new$IFS CORRECTIONDETAIL.IFS%TYPE := :NEW.IFS;
  new$BUHOPERATIONCLS CORRECTIONDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CHANGEACC_REF CORRECTIONDETAIL.CHANGEACC_REF%TYPE := :NEW.CHANGEACC_REF;
  new$CHANGEACC CORRECTIONDETAIL.CHANGEACC%TYPE := :NEW.CHANGEACC;
  new$CHANGEORGINN CORRECTIONDETAIL.CHANGEORGINN%TYPE := :NEW.CHANGEORGINN;
  new$CHANGEORGINN20 CORRECTIONDETAIL.CHANGEORGINN20%TYPE := :NEW.CHANGEORGINN20;
  new$PROGINDEX CORRECTIONDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX CORRECTIONDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$DOCUMENTPROGINDEX CORRECTIONDETAIL.DOCUMENTPROGINDEX%TYPE := :NEW.DOCUMENTPROGINDEX;
  new$DOCUMENTRECORDINDEX CORRECTIONDETAIL.DOCUMENTRECORDINDEX%TYPE := :NEW.DOCUMENTRECORDINDEX;
  new$ISBLOCKED CORRECTIONDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE CORRECTIONDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE CORRECTIONDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE CORRECTIONDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SENDERID CORRECTIONDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID CORRECTIONDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$RVERSION CORRECTIONDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$CREATERUSER CORRECTIONDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE CORRECTIONDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER CORRECTIONDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE CORRECTIONDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$NOTE CORRECTIONDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$ISCLSCHANGED CORRECTIONDETAIL.ISCLSCHANGED%TYPE := :NEW.ISCLSCHANGED;
  new$PROMISE CORRECTIONDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$BUDGETPROMISE CORRECTIONDETAIL.BUDGETPROMISE%TYPE := :NEW.BUDGETPROMISE;
  new$EXECDOC CORRECTIONDETAIL.EXECDOC%TYPE := :NEW.EXECDOC;
  new$OKATO CORRECTIONDETAIL.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO CORRECTIONDETAIL.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$TRANSFERTCLS CORRECTIONDETAIL.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$ORIGINALCLSSUMMA CORRECTIONDETAIL.ORIGINALCLSSUMMA%TYPE := :NEW.ORIGINALCLSSUMMA;
  new$NOTECLS CORRECTIONDETAIL.NOTECLS%TYPE := :NEW.NOTECLS;
  new$OPERATIONTYPE CORRECTIONDETAIL.OPERATIONTYPE%TYPE := :NEW.OPERATIONTYPE;
  new$REVERSEFLAG CORRECTIONDETAIL.REVERSEFLAG%TYPE := :NEW.REVERSEFLAG;
  new$EXECINNERNUMBER CORRECTIONDETAIL.EXECINNERNUMBER%TYPE := :NEW.EXECINNERNUMBER;
  new$CLSFIELFCHANGED CORRECTIONDETAIL.CLSFIELFCHANGED%TYPE := :NEW.CLSFIELFCHANGED;
  new$FAORGTYPE CORRECTIONDETAIL.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$SUBSIDYCLS CORRECTIONDETAIL.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$BUDALLOCATIONCLS CORRECTIONDETAIL.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS CORRECTIONDETAIL.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$NOTEQUALEX CORRECTIONDETAIL.NOTEQUALEX%TYPE := :NEW.NOTEQUALEX;
  new$OKTMO CORRECTIONDETAIL.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE CORRECTIONDETAIL.UINCODE%TYPE := :NEW.UINCODE;
  new$INVESTOBJECT CORRECTIONDETAIL.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CHANGEORGNAME CORRECTIONDETAIL.CHANGEORGNAME%TYPE := :NEW.CHANGEORGNAME;
  new$CONTRACTCOSTSCLS CORRECTIONDETAIL.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS CORRECTIONDETAIL.TARGETCLS%TYPE := :NEW.TARGETCLS;
--
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  ConstCheck$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  vOperationTypeS1$ NUMBER(10);
  vOperationTypeD1$ NUMBER(10);
  vOperationType1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_CORRECTIONDETAIL_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN 
    select g_shared.nextval into new$id from dual;
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$IFS := 0;
  END IF;
  IF (new$FacialAcc_Cls IS NULL) THEN 
    new$FacialAcc_Cls := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DirectionCls IS NULL) THEN 
    new$DirectionCls := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$Finsource IS NULL) THEN 
    new$Finsource := 0;
  END IF;
  IF (new$FinType IS NULL) THEN 
    new$FinType := 0;
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKesr IS NULL) THEN 
    new$SubKesr := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$buhoperationCls IS NULL) THEN 
    new$buhoperationCls := 0;
  END IF;
  IF (new$ReverseFlag IS NULL) THEN 
    new$ReverseFlag := 1;
  END IF;
  IF (new$OperationType IS NULL) THEN 
    BEGIN
      SELECT CorCap.SourceType, CorCap.DestType
      INTO
      vOperationTypeS1$, vOperationTypeD1$       FROM correctioncaption CorCap
      WHERE
      (CorCap.id = new$recordindex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    IF (new$ProgIndex = 315) THEN 
      vOperationType1$ := vOperationTypeS1$;
          
    ELSE 
      vOperationType1$ := vOperationTypeD1$;
    END IF;
    new$OperationType := vOperationType1$;
      
  END IF;
  /*     \*/
  IF ((new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType IS NULL)) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  ON (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
  new$targetcls,new$targetcls);    

-- - - - - - - - - - - - -
-- BU_100 (tr_correctiondetail_bu_100)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$buhoperationcls <> :old.buhoperationcls) and (new$progindex = 316)) then
    update correctiondetail set
    buhoperationcls = new$buhoperationcls
    where ID = new$parentid;
  END IF;

-- - - - - - - - - - - - -
-- BU_120 (TR_CORRECTIONDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((new$ClsType is NULL) and (new$IFS <> 0)) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$KD <> 0)) then
      new$ClsType := 2; /*        ClsType */
            
    else
      if (new$ClsType is null)
      then 
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND ((new$IFS <> 0) or (new$KD <> 0)))THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ( (new$ClsType = 1) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0) OR
  (new$KD <> 0)
  ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0) OR
  (new$IFS <> 0)
  ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_CORRECTIONDETAIL_BU_200)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  getintconst(30, 35,ConstCheck$);
  /* ( )      ,    */
  if ((PromiseMode$ <> 1) and (ConstCheck$ = 1)) then
    if ((new$Promise is not null)and((:old.Promise is null)or(:old.Promise <> new$Promise ))) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$        from
      promise_detail pr
      where
      (pr.registrnumber = new$PROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');    
      END IF;  
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /* ( )      ,    */
  /*         */
  if (PromiseMode$ = 1) then
    if ((new$Promise is not null)and((:old.Promise is null)or(:old.Promise <> new$Promise )) and 
    (new$BudgetPromise is null) and (:old.BudgetPromise is null)) then
      select 
      max(InnerPromiseNum) 
      into BPInnerNum$       from 
      PaymentSchedule 
      where 
      (ANumber = new$Promise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$BudgetPromise := BPInnerNum$;
              
      else
        RaiseException('EX_BP_NotExist');    
      END IF;
    END IF;
        
    /*    ,   */
    if (((new$BudgetPromise is not null) and (:old.BudgetPromise is null)) or 
    (new$BudgetPromise <> :old.BudgetPromise)) then
      BEGIN
        select 
        ANumber 
        into BPInnerNum$       from 
        PaymentSchedule
        where 
        (InnerPromiseNum = new$BudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
            
      new$Promise := BPInnerNum$;
          
    END IF;
        
    /*    ,     */
    if ((new$BudgetPromise is null) and (:old.BudgetPromise is not null)) then
      new$Promise := null;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_CORRECTIONDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$Promise is not null and (
    (:old.Promise is null or :old.Promise <> new$Promise) or
    (:old.ExecDoc is null or new$ExecDoc is null or :old.ExecDoc <> new$ExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$Promise and ps.InnerPromiseNum = new$BudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$ExecDoc := ExecID$;
        new$ExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$ExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$ExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$ExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$ExecDoc is null or :old.ExecDoc is null or new$ExecDoc <> :old.ExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$ExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$ExecInnerNumber := ExecInnerNumber$;
            
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_CORRECTIONDETAIL_BU_700)
-- Create 13.08.2007
-- - - - - - - - - - - - -

 if (new$RVersion is null) then
   new$RVersion:=1;
 else
   if ((new$RVersion = -1) and (:Old.RVersion <> -1)) then
     new$RVersion:=:Old.RVersion;
   else
     new$RVersion:=:Old.RVersion+1;
   end if;
 end if;  

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_CORRECTIONDETAIL SET
    ID = new$ID,
    PARENTID = new$PARENTID,
    BUDGETREF = new$BUDGETREF,
    SUMMA = new$SUMMA,
    CLSTYPE = new$CLSTYPE,
    FACIALACC_CLS = new$FACIALACC_CLS,
    KVSR = new$KVSR,
    KFSR = new$KFSR,
    KCSR = new$KCSR,
    KVR = new$KVR,
    KESR = new$KESR,
    DIRECTIONCLS = new$DIRECTIONCLS,
    MEANSTYPE = new$MEANSTYPE,
    FACT = new$FACT,
    REGIONCLS = new$REGIONCLS,
    FINSOURCE = new$FINSOURCE,
    FINTYPE = new$FINTYPE,
    DOCTYPE = new$DOCTYPE,
    SUBKESR = new$SUBKESR,
    FUNDSSOURCE = new$FUNDSSOURCE,
    KD = new$KD,
    IFS = new$IFS,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    CHANGEACC_REF = new$CHANGEACC_REF,
    CHANGEACC = new$CHANGEACC,
    CHANGEORGINN = new$CHANGEORGINN,
    CHANGEORGINN20 = new$CHANGEORGINN20,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    DOCUMENTPROGINDEX = new$DOCUMENTPROGINDEX,
    DOCUMENTRECORDINDEX = new$DOCUMENTRECORDINDEX,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    RVERSION = new$RVERSION,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    NOTE = new$NOTE,
    ISCLSCHANGED = new$ISCLSCHANGED,
    PROMISE = new$PROMISE,
    BUDGETPROMISE = new$BUDGETPROMISE,
    EXECDOC = new$EXECDOC,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    TRANSFERTCLS = new$TRANSFERTCLS,
    ORIGINALCLSSUMMA = new$ORIGINALCLSSUMMA,
    NOTECLS = new$NOTECLS,
    OPERATIONTYPE = new$OPERATIONTYPE,
    REVERSEFLAG = new$REVERSEFLAG,
    EXECINNERNUMBER = new$EXECINNERNUMBER,
    CLSFIELFCHANGED = new$CLSFIELFCHANGED,
    FAORGTYPE = new$FAORGTYPE,
    SUBSIDYCLS = new$SUBSIDYCLS,
    BUDALLOCATIONCLS = new$BUDALLOCATIONCLS,
    PAYPROMISECLS = new$PAYPROMISECLS,
    NOTEQUALEX = new$NOTEQUALEX,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    INVESTOBJECT = new$INVESTOBJECT,
    CHANGEORGNAME = new$CHANGEORGNAME,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_CORRECTIONDETAIL_AU_500)
-- Create 29.12.2009
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (5504, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=5504) and (RecordId=new$ID);
  end if;

END;
/
Commit work 
/
-- ALTER TRIGGER TR_LIMITFINDETAIL_BI
CREATE OR REPLACE TRIGGER TR_LIMITFINDETAIL_BI
  BEFORE INSERT
  ON LIMITFINDETAIL
  FOR EACH ROW
DECLARE
  DFAcc$ NUMBER(10);
  SFacialAcc$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_LIMITFINDETAIL_BI)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*  (   ) */
  if ((:new.ProgIndex = 56) and ((:new.DFAccount is null) or (:new.SourceFacialAcc is null))) then
    BEGIN
      select
      DFAccount, SourceFacialAcc
      into
      DFAcc$, SFacialAcc$     from
      RequestFinCaption
      where
      (id = :new.RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (:new.DFAccount is null) then 
      :new.DFAccount := DFAcc$;
    END IF;
    if (:new.SourceFacialAcc is null) then 
      :new.SourceFacialAcc := SFacialAcc$;
      
    END IF;
  END IF;
  /*     */
  if ((:new.ProgIndex = 57) and ((:new.DFAccount is null) or (:new.SourceFacialAcc is null))) then
    BEGIN
      select
      DFAccount, SourceFacialAcc
      into
      DFAcc$, SFacialAcc$     from
      LimitNotifyCaption
      where
      (id = :new.RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (:new.DFAccount is null) then 
      :new.DFAccount := DFAcc$;
    END IF;
    if (:new.SourceFacialAcc is null) then 
      :new.SourceFacialAcc := SFacialAcc$;
      
    END IF;
  END IF;
  BEGIN
    /*        , */
    select
    AcceptDate
    into
    :new.AcceptDate   from
    LimitNotifyCaption
    where
    (id = :new.RecordIndex)
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /* 1 - ., 2 - ., 3 -  . */
  if (:new.RequestFlag is null) then 
    :new.RequestFlag := 3;
  END IF;
  if (:new.Summa is null) then 
    :new.Summa := 0;
  END IF;
  if (:new.AcceptSumma is null) then 
    :new.AcceptSumma := 0;
  END IF;
      
  if (:new.AcceptDate is not null)
  then 
    if((:new.RequestFlag=3)and(:new.AcceptSumma=0))then 
      :new.AcceptSumma:= :new.Summa;
    END IF;
    if(:new.RequestFlag=3)then 
      :new.RequestFlag:= 2; 
     
    END IF;
  END IF;
   
  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  if (:new.KVSR is null) then 
    :new.KVSR := 0;
  END IF;
  if (:new.KCSR is null) then 
    :new.KCSR := 0;
  END IF;
  if (:new.KFSR is null) then 
    :new.KFSR := 0;
  END IF;
  if (:new.KVR is null) then 
    :new.KVR := 0;
  END IF;
  if (:new.KESR is null) then 
    :new.KESR := 0;
  END IF;
  if (:new.SubKESR is null) then 
    :new.SubKESR := 0;
  END IF;
  if (:new.DirectionCls is null) then 
    :new.DirectionCls := 0;
  END IF;
  /*     */
  IF (:new.FundsSource IS NULL) THEN 
    :new.FundsSource := 0;
  END IF;
  if (:new.FacialAcc is null) then 
    :new.FacialAcc := 0;
  END IF;
  if (:new.RegionCLS is null) then
    BEGIN
      select fac.RegionCLS       into :new.regioncls from facialacc_cls fac
      where fac.id = :new.facialacc
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (:new.FinSource is null) then 
    :new.FinSource := 0;
  END IF;
  if (:new.FinType is null) then 
    :new.FinType := 0;
  END IF;
  if (:new.Fact is null) then  
    :new.Fact := 0;
  END IF;
  if (:new.DocTypes is null) then 
    :new.DocTypes := 0;
  END IF;
  if (:new.MeansType is null) then 
    :new.MeansType := 0;
  END IF;
  if (:new.SourceFacialAcc is null) then 
    :new.SourceFacialAcc := 0;
  END IF;
  /*   .     */
  if (:new.IFS is null) then 
    :new.IFS := 0;
  END IF;
  if (:new.BuhOperationCLS is null)
  then 
    GetIntConst(60, 15,:new.BuhOperationCLS);
  END IF;
    
  /*  .    ,    */
  if ((:new.BudgetRef is null) or (:new.BudgetRef = 0)) then
    BEGIN
      select lim.BudgetRef         into :new.BudgetRef from LimitFinCaption lim
      where lim.id = :new.RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,     */
  if ((:new.BudgetRef is null) or (:new.BudgetRef = 0)) then
    BEGIN
      select fa.BudgetRef       into :new.BudgetRef from FacialAcc_Cls fa
      where fa.Id = :new.FacialAcc
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*  ,    */
  if ((:new.BudgetRef is null) or (:new.BudgetRef = 0))
  then 
    GetIntConst(-1, 3,:new.BudgetRef);
  END IF;
  /*    */
  GETTARGETCLS(null, :new.transfertcls, null, :new.meanstype,
  :new.targetcls,:new.targetcls); 

-- - - - - - - - - - - - -
-- BI_100 (TR_LIMITFINDETAIL_BI_100)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((:new.ClsType is NULL) and (:new.IFS <> 0)) then
    :new.ClsType := 1; /*       ClsType */
      
  else
    if (:new.ClsType is null) then
      :new.ClsType := 0; /*  -  */
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND (:new.IFS <> 0)) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType = 1) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0)
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 1)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_LIMITFINDETAIL_BI_500)
-- Last update 29.06.2005
-- - - - - - - - - - - - -

  :NEW.CreateDate := SYSDATE;
  :NEW.UpdateDate := :NEW.CreateDate;
  :NEW.CreaterUser := USER;
  :NEW.UpdaterUser := USER;

END;
/
-- ALTER TRIGGER TR_LIMITFINDETAIL_BU
CREATE OR REPLACE TRIGGER TR_LIMITFINDETAIL_BU
  BEFORE UPDATE
  ON LIMITFINDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_LIMITFINDETAIL_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if (:new.KVSR is null) then 
    :new.KVSR := 0;
  END IF;
  if (:new.KCSR is null) then 
    :new.KCSR := 0;
  END IF;
  if (:new.KFSR is null) then 
    :new.KFSR := 0;
  END IF;
  if (:new.KVR is null) then 
    :new.KVR := 0;
  END IF;
  if (:new.KESR is null) then 
    :new.KESR := 0;
  END IF;
  if (:new.SubKESR is null) then  
    :new.SubKESR := 0;
  END IF;
  if (:new.DirectionCls is null) then 
    :new.DirectionCls := 0;
  END IF;
  /*     */
  IF (:new.FundsSource IS NULL) THEN 
    :new.FundsSource := 0;
  END IF;

  if (:new.Summa is null) then 
    :new.Summa := 0;
  END IF;
  if (:new.AcceptSumma is null) then 
    :new.AcceptSumma := 0;
  END IF;
  if (:new.RequestFlag is null) then 
    :new.RequestFlag := 3; /* 1 - ., 2 - ., 3 -  . */
  END IF;
  if (:new.FacialAcc is null) then 
    :new.FacialAcc := 0;
  END IF;
  if (:new.RegionCLS is null) then
    BEGIN
      select fac.RegionCLS       into :new.regioncls from facialacc_cls fac
      where fac.id = :new.facialacc
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (:new.FINSOURCE is null) then 
    :new.FINSOURCE := 0;
  END IF;
  if (:new.FINType is null) then 
    :new.FINType := 0;
  END IF;
  if (:new.Fact is null) then  
    :new.Fact := 0;
  END IF;
  if (:new.DocTypes is null) then 
    :new.DocTypes := 0;
  END IF;
  if (:new.MeansType is null) then 
    :new.MeansType := 0;
  END IF;
  if (:new.SourceFacialAcc is null) then 
    :new.SourceFacialAcc := 0;
  END IF;
   
  /* ----*/
  /*   .     */
  if (:new.IFS is null) then 
    :new.IFS := 0;
  END IF;
  if (:new.BuhOperationCLS is null)
  then 
    GetIntConst(60, 15,:new.BuhOperationCLS);
  END IF;
  /*     */
  if (:new.BudgetRef <> :old.BudgetRef) then
    if ( not((:new.BudgetRef is null) and (:old.BudgetRef is null)) ) then
      RaiseException('Ex_CantModufyBudget');
    END IF;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, :new.transfertcls, :old.meanstype, :new.meanstype,
  :new.targetcls,:new.targetcls);    

-- - - - - - - - - - - - -
-- BU_10 (TR_LIMITFINDETAIL_BU_10)
-- Last update 14.02.2006
-- - - - - - - - - - - - -

  if ((:new.AcceptDate is null) and (:old.AcceptDate is not null)) then
    if ((:new.RequestFlag=2) and (:new.AcceptSumma = :new.Summa)) then :new.AcceptSumma := 0; end if;
    if (:new.RequestFlag=2) then :new.RequestFlag := 3; end if;
  end if;

  if ((:new.AcceptDate is not null) and (:new.RequestFlag = 3)) then
    :new.RequestFlag := 2;
  end if;
  if ((:new.AcceptDate is not null) and (:new.RequestFlag = 2) and (:new.AcceptSumma = 0)) then
     :new.AcceptSumma := :new.Summa;
  end if;

-- - - - - - - - - - - - -
-- BU_100 (TR_LIMITFINDETAIL_BU_100)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((:new.ClsType is NULL) and (:new.IFS <> 0)) then
    :new.ClsType := 1; /*       ClsType */
      
  else
    if (:new.ClsType is null) then
      :new.ClsType := 0; /*  -  */
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND (:new.IFS <> 0)) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType = 1) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0)
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 1)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_LIMITFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (:NEW.RVersion IS NULL) THEN
      :NEW.RVersion := 1;
   ELSIF ((:NEW.RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      :NEW.RVersion := :OLD.RVersion;
   ELSE
      :NEW.RVersion := :OLD.RVersion + 1;
   END IF;

END;
/
COMMIT WORK
/
-- CREATE TRIGGER TR_TENDERPRODUCT_BI
CREATE OR REPLACE TRIGGER TR_TENDERPRODUCT_BI
  BEFORE INSERT
  ON TENDERPRODUCT
  FOR EACH ROW
DECLARE
  PosNumber$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_TENDERPRODUCT_BI)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  if (:new.SubKESR is null) then 
    :new.SubKESR := 0;
  END IF;
  if (:new.KFSR is null) then 
    :new.KFSR := 0;
  END IF;
  if (:new.KVSR is null) then 
    :new.KVSR := 0;
  END IF;
  if (:new.KESR is null) then 
    :new.KESR := 0;
  END IF;
  if (:new.KVR is null) then 
    :new.KVR := 0;
  END IF;
  if (:new.KCSR is null) then 
    :new.KCSR := 0;
  END IF;
  if (:new.FinSourceCls is null) then 
    :new.FinSourceCls := 0;
  END IF;
  if (:new.FinType is null) then 
    :new.FinType := 0;
  END IF;
  if (:new.TenderObjectCls is null) then 
    :new.TenderObjectCls := 0;
  END IF;
  if (:new.FactCls is null) then 
    :new.FactCls := 0;
  END IF;
  if (:new.OKATO is null) then 
    :new.OKATO := 0;
  END IF;
  if (:new.MeansTypeCls is null) then 
    :new.MeansTypeCls := 0;
  END IF;
  if (:new.DirectionCls is null) then 
    :new.DirectionCls := 0;
  END IF;
  if (:new.AcceptPrice is null) then 
    :new.AcceptPrice := 0;
  END IF;
  if (:new.PriceVAT is null) then 
    :new.PriceVAT := 0;
  END IF;
  if (:new.AcceptAmount is null) then 
    :new.AcceptAmount := 0;
  END IF;
  if (:new.AcceptMonth01 is null) then 
    :new.AcceptMonth01 := 0;
  END IF;
  if (:new.AcceptMonth02 is null) then 
    :new.AcceptMonth02 := 0;
  END IF;
  if (:new.AcceptMonth03 is null) then 
    :new.AcceptMonth03 := 0;
  END IF;
  if (:new.AcceptMonth04 is null) then 
    :new.AcceptMonth04 := 0;
  END IF;
  if (:new.AcceptMonth05 is null) then 
    :new.AcceptMonth05 := 0;
  END IF;
  if (:new.AcceptMonth06 is null) then 
    :new.AcceptMonth06 := 0;
  END IF;
  if (:new.AcceptMonth07 is null) then 
    :new.AcceptMonth07 := 0;
  END IF;
  if (:new.AcceptMonth08 is null) then 
    :new.AcceptMonth08 := 0;
  END IF;
  if (:new.AcceptMonth09 is null) then 
    :new.AcceptMonth09 := 0;
  END IF;
  if (:new.AcceptMonth10 is null) then 
    :new.AcceptMonth10 := 0;
  END IF;
  if (:new.AcceptMonth11 is null) then 
    :new.AcceptMonth11 := 0;
  END IF;
  if (:new.AcceptMonth12 is null) then 
    :new.AcceptMonth12 := 0;
  END IF;
  if (:new.AcceptQuarter1 is null) then 
    :new.AcceptQuarter1 := 0;
  END IF;
  if (:new.AcceptQuarter2 is null) then 
    :new.AcceptQuarter2 := 0;
  END IF;
  if (:new.AcceptQuarter3 is null) then 
    :new.AcceptQuarter3 := 0;
  END IF;
  if (:new.AcceptQuarter4 is null) then 
    :new.AcceptQuarter4 := 0;
  END IF;
  if (:new.AcceptSumma is null) then 
    :new.AcceptSumma := 0;
  END IF;
  if (:new.DeliverySpec is null) then 
    :new.DeliverySpec := 0;
  END IF;
  if (:new.DeliveryPeriod is null) then 
    :new.DeliveryPeriod := 0;
  END IF;
  if (:new.DeliveryAmount is null) then 
    :new.DeliveryAmount := 0;
  END IF;
  if (:new.VatPercent is null) then 
    :new.VatPercent := 0;
  END IF;
  if (:new.AcceptVatSumma is null) then 
    :new.AcceptVatSumma := 0;
  END IF;
  if (:new.AcceptCost is null) then 
    :new.AcceptCost := 0;
  END IF;
  if (:new.AcceptTotalSumma is null) then 
    :new.AcceptTotalSumma := 0;
  END IF;
  if (:new.Equivalent is null) then 
    :new.Equivalent := 0;
  END IF;
  if (:new.SummaYear2 is null) then 
    :new.SummaYear2 := 0;
  END IF;
  if (:new.SummaYear3 is null) then 
    :new.SummaYear3 := 0;
  END IF;
  if (:new.SummaOtherYears is null) then 
    :new.SummaOtherYears := 0;
  END IF;
  /*    */
  GETTARGETCLS(null, :new.transfertcls, null, :new.MEANSTYPECLS,
  :new.targetcls,:new.targetcls); 

-- - - - - - - - - - - - -
-- BI_10 (TR_TENDERPRODUCT_BI_10)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

    /*   1.2 */
   IF (:NEW.FacialAccCls IS NULL) THEN :NEW.FacialAccCls := 0; END IF;

   /*  .  ,     */
   IF ((:NEW.BudgetRef IS NULL) OR (:NEW.BudgetRef = 0)) THEN
      BEGIN
         SELECT fa.BudgetRef
           INTO :NEW.BudgetRef
           FROM FacialAcc_Cls fa
          WHERE fa.ID = :NEW.FacialAccCls;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            :NEW.BudgetRef := NULL;
      END;
   END IF;

   /*  ,    */
   IF ((:NEW.BudgetRef IS NULL) OR (:NEW.BudgetRef = 0)) THEN
      GetIntConst (-1, 3, :NEW.BudgetRef);
   END IF;

-- - - - - - - - - - - - -
-- BI_20 (TR_TENDERPRODUCT_BI_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (:new.PositionNumber is null) then
    select Max(PositionNumber)     INTO PosNumber$ from TenderProduct
    where (RecordIndex = :new.RecordIndex) and (ProgIndex = :new.ProgIndex)
    ;
    if (PosNumber$ is null) then
      PosNumber$ := 0;
    END IF;
    :new.PositionNumber := PosNumber$ + 1;

  END IF;

-- - - - - - - - - - - - -
-- BI_40 (TR_TENDERPRODUCT_BI_40)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (:new.senderId is null) then
    :new.senderIdKey := -1;

  else
    :new.senderIdKey := :new.senderId;
  END IF;
  if (:new.SenderRecordID is null) then
    :new.SenderRecordIDKey := :new.ID;

  else
    :new.SenderRecordIDKey := :new.SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_410 (TR_TENDERPRODUCT_BI_410)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  FOR REC$1 IN (SELECT tl.ID  AS lotref FROM TenderLot tl WHERE (tl.ID = :new.LotRef) AND (tl.RecordIndex = :new.RecordIndex)   )
  LOOP
    if (not ((REC$1.lotref  = :new.LotRef) or (:new.lotref is null))) then
      RaiseException('EX_TEN_UNKNOWNLOT');
    END IF;
  END LOOP;

-- - - - - - - - - - - - -
-- BI_500 (TR_TENDERPRODUCT_BI_500)
-- Last update 18.04.2006
-- - - - - - - - - - - - -

  :NEW.CreateDate := SYSDATE;
  :NEW.UpdateDate := :NEW.CreateDate;
  :NEW.CreaterUser := USER;
  :NEW.UpdaterUser := USER;

END;
/
-- CREATE TRIGGER TR_TENDERPRODUCT_BU_0
CREATE OR REPLACE TRIGGER TR_TENDERPRODUCT_BU
  BEFORE UPDATE
  ON TENDERPRODUCT
  FOR EACH ROW
DECLARE
  PosNumber$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_TENDERPRODUCT_BU_0)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if (:new.FacialAccCls is null) then 
    :new.FacialAccCls := 0;
  END IF;
  if (:new.SubKESR is null) then 
    :new.SubKESR := 0;
  END IF;
  if (:new.KFSR is null) then 
    :new.KFSR := 0;
  END IF;
  if (:new.KVSR is null) then 
    :new.KVSR := 0;
  END IF;
  if (:new.KESR is null) then 
    :new.KESR := 0;
  END IF;
  if (:new.KVR is null) then 
    :new.KVR := 0;
  END IF;
  if (:new.KCSR is null) then 
    :new.KCSR := 0;
  END IF;
  if (:new.FinSourceCls is null) then 
    :new.FinSourceCls := 0;
  END IF;
  if (:new.FinType is null) then 
    :new.FinType := 0;
  END IF;
  if (:new.TenderObjectCls is null) then 
    :new.TenderObjectCls := 0;
  END IF;
  if (:new.FactCls is null) then 
    :new.FactCls := 0;
  END IF;
  if (:new.OKATO is null) then 
    :new.OKATO := 0;
  END IF;
  if (:new.MeansTypeCls is null) then 
    :new.MeansTypeCls := 0;
  END IF;
  if (:new.DirectionCls is null) then 
    :new.DirectionCls := 0;
  END IF;
  if (:new.AcceptPrice is null) then 
    :new.AcceptPrice := 0;
  END IF;
  if (:new.PriceVAT is null) then 
    :new.PriceVAT := 0;
  END IF;
  if (:new.AcceptAmount is null) then 
    :new.AcceptAmount := 0;
  END IF;
  if (:new.AcceptMonth01 is null) then 
    :new.AcceptMonth01 := 0;
  END IF;
  if (:new.AcceptMonth02 is null) then 
    :new.AcceptMonth02 := 0;
  END IF;
  if (:new.AcceptMonth03 is null) then 
    :new.AcceptMonth03 := 0;
  END IF;
  if (:new.AcceptMonth04 is null) then 
    :new.AcceptMonth04 := 0;
  END IF;
  if (:new.AcceptMonth05 is null) then 
    :new.AcceptMonth05 := 0;
  END IF;
  if (:new.AcceptMonth06 is null) then 
    :new.AcceptMonth06 := 0;
  END IF;
  if (:new.AcceptMonth07 is null) then 
    :new.AcceptMonth07 := 0;
  END IF;
  if (:new.AcceptMonth08 is null) then 
    :new.AcceptMonth08 := 0;
  END IF;
  if (:new.AcceptMonth09 is null) then 
    :new.AcceptMonth09 := 0;
  END IF;
  if (:new.AcceptMonth10 is null) then 
    :new.AcceptMonth10 := 0;
  END IF;
  if (:new.AcceptMonth11 is null) then 
    :new.AcceptMonth11 := 0;
  END IF;
  if (:new.AcceptMonth12 is null) then 
    :new.AcceptMonth12 := 0;
  END IF;
  if (:new.AcceptQuarter1 is null) then 
    :new.AcceptQuarter1 := 0;
  END IF;
  if (:new.AcceptQuarter2 is null) then 
    :new.AcceptQuarter2 := 0;
  END IF;
  if (:new.AcceptQuarter3 is null) then 
    :new.AcceptQuarter3 := 0;
  END IF;
  if (:new.AcceptQuarter4 is null) then 
    :new.AcceptQuarter4 := 0;
  END IF;
  if (:new.AcceptSumma is null) then 
    :new.AcceptSumma := 0;
  END IF;
  if (:new.DeliverySpec is null) then 
    :new.DeliverySpec := 0;
  END IF;
  if (:new.DeliveryPeriod is null) then 
    :new.DeliveryPeriod := 0;
  END IF;
  if (:new.DeliveryAmount is null) then 
    :new.DeliveryAmount := 0;
  END IF;
  if (:new.VatPercent is null) then 
    :new.VatPercent := 0;
  END IF;
  if (:new.AcceptVatSumma is null) then 
    :new.AcceptVatSumma := 0;
  END IF;
  if (:new.AcceptCost is null) then 
    :new.AcceptCost := 0;
  END IF;
  if (:new.AcceptTotalSumma is null) then 
    :new.AcceptTotalSumma := 0;
  END IF;
  if (:new.Equivalent is null) then 
    :new.Equivalent := 0;    
  END IF;
  if (:new.SummaYear2 is null) then 
    :new.SummaYear2 := 0;
  END IF;
  if (:new.SummaYear3 is null) then 
    :new.SummaYear3 := 0;
  END IF;
  if (:new.SummaOtherYears is null) then 
    :new.SummaOtherYears := 0;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, :new.transfertcls, :old.MEANSTYPECLS, :new.MEANSTYPECLS,
  :new.targetcls,:new.targetcls);   

-- - - - - - - - - - - - -
-- BU_20 (TR_TENDERPRODUCT_BU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (:new.PositionNumber is null) then
    select Max(PositionNumber)     INTO PosNumber$ from TenderProduct
    where (RecordIndex = :new.RecordIndex) and (ProgIndex = :new.ProgIndex)
    ;
    if (PosNumber$ is null) then
      PosNumber$ := 0;
    END IF;
    :new.PositionNumber := PosNumber$ + 1;

  END IF;

-- - - - - - - - - - - - -
-- BU_400 (tr_TenderProduct_BU_400)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (:new.RecordIndex <> :old.RecordIndex) then
    RaiseException('EX_CANTCHANGECAPTIONREF');
  END IF;

-- - - - - - - - - - - - -
-- BU_410 (TR_TENDERPRODUCT_BU_410)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  FOR REC$1 IN (SELECT tl.ID  AS lotref FROM TenderLot tl WHERE (tl.ID = :new.LotRef) AND (tl.RecordIndex = :new.RecordIndex)   )
  LOOP
    if (not ((REC$1.lotref  = :new.LotRef) or (:new.lotref is null))) then
      RaiseException('EX_TEN_UNKNOWNLOT');
    END IF;
  END LOOP;

-- - - - - - - - - - - - -
-- BU_700 (TR_TENDERPRODUCT_BU_700)
-- Create 14.10.2004
-- - - - - - - - - - - - -

  if (:New.RVersion is null) then
    :New.RVersion := 1;
  elsif ((:New.RVersion = -1) and (:Old.RVersion <> -1)) then
    :New.RVersion := :Old.RVersion;
  else
    :New.RVersion := :Old.RVersion + 1;
  end if;

END;
/
commit work 
/
/*       */
CREATE OR REPLACE procedure FillTargetCls
AS
  const$ NUMBER(10);
BEGIN
  getintconst(32, 41,const$);
  if (const$ = 0) then
    /*       */
    update BUDGETDATA d
    set d.TargetCls = (select TargetCls from MeansType where MeansType.id=d.MeansType);
    update CORRECTIONDETAIL d
    set d.TargetCls = (select TargetCls from MeansType where MeansType.id=d.MeansType);
    update FACIALFINDETAIL d
    set d.SourceTargetCls = (select TargetCls from MeansType where MeansType.id=d.SourceMeansType),
    d.DestTargetCls = (select TargetCls from MeansType where MeansType.id=d.DestMeansType);
    update INCOMES32 d
    set d.TargetCls = (select TargetCls from MeansType where MeansType.id=d.MeansType);
    update LIMITFINDETAIL d
    set d.TargetCls = (select TargetCls from MeansType where MeansType.id=d.MeansType);
    update PAYMENTSCHEDULE d
    set d.TargetCls = (select TargetCls from MeansType where MeansType.id=d.MeansType);
    update REPLACEMENTCLSDETAILINFO d
    set d.TargetCls = (select TargetCls from MeansType where MeansType.id=d.MeansType);
    update TENDERPRODUCT d
    set d.TargetCls = (select TargetCls from MeansType where MeansType.id=d.MeansTypeCls);
    update WRITEXECUTIONDETAIL d
    set d.TargetCls = (select TargetCls from MeansType where MeansType.id=d.MeansType);
      
  else 
    if (const$ = 1) then
      /*        */
      update BUDGETDATA d
      set d.TargetCls = (select TargetCls from TransfertCls where TransfertCls.id=d.TransfertCls);
      update CORRECTIONDETAIL d
      set d.TargetCls = (select TargetCls from TransfertCls where TransfertCls.id=d.TransfertCls);
      update FACIALFINDETAIL d
      set d.SourceTargetCls = (select TargetCls from TransfertCls where TransfertCls.id=d.SourceTransfertCls),
      d.DestTargetCls = (select TargetCls from TransfertCls where TransfertCls.id=d.DestTransfertCls);
      update INCOMES32 d
      set d.TargetCls = (select TargetCls from TransfertCls where TransfertCls.id=d.TransfertCls);
      update LIMITFINDETAIL d
      set d.TargetCls = (select TargetCls from TransfertCls where TransfertCls.id=d.TransfertCls);
      update PAYMENTSCHEDULE d
      set d.TargetCls = (select TargetCls from TransfertCls where TransfertCls.id=d.TransfertCls);
      update REPLACEMENTCLSDETAILINFO d
      set d.TargetCls = (select TargetCls from TransfertCls where TransfertCls.id=d.TransfertCls);
      update TENDERPRODUCT d
      set d.TargetCls = (select TargetCls from TransfertCls where TransfertCls.id=d.TransfertCls);
      update WRITEXECUTIONDETAIL d
      set d.TargetCls = (select TargetCls from TransfertCls where TransfertCls.id=d.TransfertCls);
          
    END IF;
  END IF;
END;
/
grant execute on FillTargetCls to BUDGET_USERS
/
ALTER TRIGGER TR_BUDGETDATA_BU_500 DISABLE
/
-- ALTER TRIGGER tr_BudgetData_bu
CREATE OR REPLACE TRIGGER TR_BUDGETDATA_BU
  BEFORE UPDATE
  ON BUDGETDATA
  FOR EACH ROW
DECLARE
  AutoKvrCorr$ NUMBER(10);
  OrgRefByAcc1$ NUMBER(10);
  CapClsType1$ NUMBER(10);
  doubleUse1$ NUMBER(10);
  BALBOFlag1$ NUMBER(10);
  AllowDivideBA1$ NUMBER(10);
  StimateKind1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_BUDGETDATA_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   IF (:new.KFSR IS NULL) THEN  
--     :new.KFSR := 0;
--   END IF;
--   IF (:new.KVSR IS NULL) THEN  
--     :new.KVSR := 0;
--   END IF;
--   IF (:new.KVR IS NULL) THEN  
--     :new.KVR := 0;
--   END IF;
--   IF (:new.KCSR IS NULL) THEN  
--     :new.KCSR := 0;
--   END IF;
--   IF (:new.KESR IS NULL) THEN  
--     :new.KESR := 0;
--   END IF;
--   IF (:new.SubKESR IS NULL) THEN  
--     :new.SubKESR := 0;
--   END IF;
--   IF (:new.RegionCLS IS NULL) THEN  
--     :new.RegionCLS := 0;
--   END IF;
--   IF (:new.DirectionCls IS NULL) THEN 
--     :new.DirectionCls := 0;
--   END IF;
--   IF (:new.FundsSource IS NULL) THEN 
--     :new.FundsSource := 0;
--   END IF;
--   IF (:new.KD IS NULL) THEN 
--     :new.KD := 0;
--   END IF;
--   IF (:new.subkd IS NULL) THEN 
--     :new.subkd := 0;
--   END IF;
--   IF (:new.Fact IS NULL) THEN  
--     :new.Fact := 0;
--   END IF;
--   IF (:new.FacialAcc_Cls IS NULL) THEN 
--     :new.FacialAcc_Cls := 0;
--   END IF;
--   IF (:new.KVRCorr IS NULL) THEN 
--     :new.KVRCorr := 0;
--   END IF;
--   IF (:new.KesrCorr IS NULL) THEN 
--     :new.KesrCorr := 0;
--   END IF;
--   IF (:new.AssignmentKind IS NULL) THEN 
--     :new.AssignmentKind := 0;
--   END IF;
--   IF (:new.Quarter1 IS NULL) THEN  
--     :new.Quarter1 := 0;
--   END IF;
--   IF (:new.Quarter2 IS NULL) THEN  
--     :new.Quarter2 := 0;
--   END IF;
--   IF (:new.Quarter3 IS NULL) THEN  
--     :new.Quarter3 := 0;
--   END IF;
--   IF (:new.Quarter4 IS NULL) THEN  
--     :new.Quarter4 := 0;
--   END IF;
--   IF (:new.FinType IS NULL) THEN  
--     :new.FinType := 0;
--   END IF;
--   IF (:new.MeansType IS NULL) THEN  
--     :new.MeansType := 0;
--   END IF;
--   IF (:new.DepartmentCls IS NULL) THEN 
--     :new.DepartmentCls := 0;
--   END IF;
--   /*   .        */
--   IF (:new.IFS IS NULL) THEN 
--     :new.IFS := 0;
--   END IF;
--   IF (:new.BuhOperationCLS IS NULL)
--   THEN 
--     GetIntConst(60, 15,:new.BuhOperationCLS);
--   END IF;
--   IF (:new.Month01 IS NULL) THEN  
--     :new.Month01 := 0;
--   END IF;
--   IF (:new.Month02 IS NULL) THEN  
--     :new.Month02 := 0;
--   END IF;
--   IF (:new.Month03 IS NULL) THEN  
--     :new.Month03 := 0;
--   END IF;
--   IF (:new.Month04 IS NULL) THEN  
--     :new.Month04 := 0;
--   END IF;
--   IF (:new.Month05 IS NULL) THEN  
--     :new.Month05 := 0;
--   END IF;
--   IF (:new.Month06 IS NULL) THEN  
--     :new.Month06 := 0;
--   END IF;
--   IF (:new.Month07 IS NULL) THEN  
--     :new.Month07 := 0;
--   END IF;
--   IF (:new.Month08 IS NULL) THEN  
--     :new.Month08 := 0;
--   END IF;
--   IF (:new.Month09 IS NULL) THEN  
--     :new.Month09 := 0;
--   END IF;
--   IF (:new.Month10 IS NULL) THEN  
--     :new.Month10 := 0;
--   END IF;
--   IF (:new.Month11 IS NULL) THEN  
--     :new.Month11 := 0;
--   END IF;
--   IF (:new.Month12 IS NULL) THEN  
--     :new.Month12 := 0;
--   END IF;
--   IF (:new.SummaYear1 IS NULL) THEN  
--     :new.SummaYear1 := 0;
--   END IF;
--   IF (:new.SummaYear2 IS NULL) THEN  
--     :new.SummaYear2 := 0;
--   END IF;
--   IF (:new.SummaYear3 IS NULL) THEN  
--     :new.SummaYear3 := 0;
--   END IF;
--   IF (:new.SummaYear4 IS NULL) THEN  
--     :new.SummaYear4 := 0;
--   END IF;
--   IF (:new.SummaOtherYears IS NULL) THEN  
--     :new.SummaOtherYears := 0; 
--   END IF;
--   IF (:new.DayPlanSumma IS NULL) THEN 
--     :new.DayPlanSumma := 0;
--   END IF;
--   /*     */
--   IF (:new.BudgetRef <> :old.BudgetRef) THEN
--     IF ( NOT((:new.BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN
--       RaiseException('Ex_CantModufyBudget');
--     END IF;
--   END IF;
--   BEGIN
-- 
--     SELECT
--     c.BA_LBO_FLAG
--     INTO
--     BALBOFlag1$  FROM
--     BudNotify c
--     WHERE
--     c.id = :new.RecordIndex
--     ;
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;
--   /*   */
--   IF (:new.ProgIndex = 262) THEN
--     GetIntConst(32, 43,StimateKind1$);
--     IF ((StimateKind1$  = 0) OR (StimateKind1$  IS NULL)) THEN
--       :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
--          
--     ELSE
--       IF (StimateKind1$  = 1) THEN
--         :new.Quarter1 := :new.SummaYear1;
--              
--       ELSE
--         :new.Quarter1 := :new.Month01 + :new.Month02 +:new.Month03;
--         :new.Quarter2 := :new.Month04 + :new.Month05 +:new.Month06;
--         :new.Quarter3 := :new.Month07 + :new.Month08 +:new.Month09;
--         :new.Quarter4 := :new.Month10 + :new.Month11 +:new.Month12;
--         :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
--              
--       END IF; 
--     END IF;
--   END IF;
--   /* ()*/
--   IF (:new.ProgIndex = 260) THEN
--     GetIntConst(32, 30,doubleUse1$);
--     GetIntConst(32, 40,AllowDivideBA1$);
--     IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*       ,     */
--       :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
--      
--     END IF;
--   END IF;
--   /* ()*/
--   IF (:new.ProgIndex = 264) THEN
--     GetIntConst(32, 34,doubleUse1$);
--     GetIntConst(32, 40,AllowDivideBA1$);
--     IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*       ,     */
--       :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
--      
--     END IF;
--   END IF;
--   /*  ()*/
--   IF (:new.ProgIndex = 32) THEN
--     GetIntConst(32, 31,doubleUse1$);
--     GetIntConst(32, 40,AllowDivideBA1$);
--     IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*          ,     */
--       :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
--      
--     END IF;
--   END IF;
--   /*  ()*/
--   IF (:new.ProgIndex = 215) THEN
--     GetIntConst(32, 35,doubleUse1$);
--     GetIntConst(32, 40,AllowDivideBA1$);
--     IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*         ,     */
--       :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
--      
--     END IF;
--   END IF;
--   /* 
--    IF ((NEW.TransfertOrg_Ref IS NULL) AND (NEW.REGIONCLS <> 0)) THEN
--        SELECT Organizations FROM REGIONCLS
--          WHERE NEW.REGIONCLS = ID
--        INTO NEW.TransfertOrg_Ref;
--   *//*    */
--   GETTARGETCLS(:old.transfertcls, :new.transfertcls, :old.meanstype, :new.meanstype,
--   :new.targetcls,:new.targetcls);

-- - - - - - - - - - - - -
-- BU_100 (TR_BUDGETDATA_BU_100)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if (:new.ClsType is NULL) then
    BEGIN
      select
      bn.ClsType
      into
      CapClsType1$     from
      BudNotify bn
      where
      bn.id = :new.RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (CapClsType1$  = 3) then
      if (:new.IFS <> 0) then
        :new.ClsType := 1; /*       ClsType */
            
      else
        if (:new.KD <> 0) then
          :new.ClsType := 2; /* */
                
        else
          :new.ClsType := 0; /* */
        END IF;    
      END IF;
    else
      :new.ClsType := CapClsType1$;
      
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND ((:new.IFS <> 0)or(:new.KD <> 0))) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0)
  )) THEN
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  if (((:new.ClsType = 1)and(:new.KD <> 0))or((:new.ClsType = 2)and(:new.IFS <> 0))) then
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 1) AND (:new.ClsType <> 2)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;
  IF (:new.ACC_REF IS NOT NULL) THEN /*    / */
    BEGIN
      SELECT oa.ORG_REF
      INTO OrgRefByAcc1$     FROM ORG_ACCOUNTS oa
      WHERE (oa.ID = :new.ACC_REF)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (:new.FacialAcc_CLS = 0) then 
      :new.Org_Ref := OrgRefByAcc1$;
      
    END IF;
  END IF;
  /*  \ ,       \    \,  \ */
  if (:new.FacialAcc_CLS <> 0) then
    BEGIN
      SELECT
      fac.ORG_REF
      INTO :new.Org_Ref     FROM
      FacialACC_CLS fac
      WHERE
      (fac.ID = :new.FacialAcc_CLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (OrgRefByAcc1$<>:new.Org_Ref) then 
      :new.ACC_REF := null;
      
    END IF;
  END IF;
  if ((:new.ProgIndex in (252, 253))and(:new.FacialAcc_CLS = 0)) then
    BEGIN
      SELECT
      bn.FacialAccCLS
      INTO :new.FacialAcc_CLS     FROM
      BudNotify bn
      WHERE
      (bn.ID = :new.RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_BUDGETDATA_BU_200)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*       32-, 260-, 261-, 262-  , 263-, 268-  , 252-. */
  if (:new.ProgIndex in (32, 252, 260, 261, 262, 263, 268)) then
    /*     (32  ()) 
             :
           =0     ,
           =1  ,
           =2   0  .*//*     260 ()
             :
           =2   0  .*/
    GetIntConst(32, 25,AutoKvrCorr$);
    if (:new.ProgIndex = 32) then /*  ()*/
      if (AutoKvrCorr$  = 0) then
        :new.KvrCorr := :new.Kvr;
              
      else
        if (AutoKvrCorr$  = 2) then
          :new.KvrCorr := 0;
        END IF;
      END IF;
      /* KESR   */
      if (AutoKvrCorr$  = 0) then
        :new.KesrCorr := :new.Kesr;
              
      else
        if (AutoKvrCorr$  = 2) then
          :new.KesrCorr := 0;
        END IF;    
      END IF;
    else 
      if ((:new.ProgIndex = 260)and (AutoKvrCorr$  = 2)) then  /* ()*/
        :new.KvrCorr := 0;
        --   ,    new.Kvr = 0;
        /* KESR   */        
                
        :new.KesrCorr := 0;
        :new.Kesr := 0;     
              
      else
        :new.KvrCorr := :new.Kvr; /*         */
        /* KESR   */        
        :new.KesrCorr := :new.Kesr;
              
      END IF;  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_BUDGETDATA_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

  IF (:NEW.RVersion IS NULL) THEN
     :NEW.RVersion := 1;
  ELSIF ((:NEW.RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
     :NEW.RVersion := :OLD.RVersion;
  ELSE
     :NEW.RVersion := :OLD.RVersion + 1;
  END IF;

END;
/
-- ALTER TRIGGER TR_BudgetData_BU_700
CREATE OR REPLACE TRIGGER TR_BUDGETDATA_BU
  BEFORE UPDATE
  ON BUDGETDATA
  FOR EACH ROW
DECLARE
  AutoKvrCorr$ NUMBER(10);
  OrgRefByAcc1$ NUMBER(10);
  CapClsType1$ NUMBER(10);
  doubleUse1$ NUMBER(10);
  BALBOFlag1$ NUMBER(10);
  AllowDivideBA1$ NUMBER(10);
  StimateKind1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_BUDGETDATA_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   IF (:new.KFSR IS NULL) THEN  
--     :new.KFSR := 0;
--   END IF;
--   IF (:new.KVSR IS NULL) THEN  
--     :new.KVSR := 0;
--   END IF;
--   IF (:new.KVR IS NULL) THEN  
--     :new.KVR := 0;
--   END IF;
--   IF (:new.KCSR IS NULL) THEN  
--     :new.KCSR := 0;
--   END IF;
--   IF (:new.KESR IS NULL) THEN  
--     :new.KESR := 0;
--   END IF;
--   IF (:new.SubKESR IS NULL) THEN  
--     :new.SubKESR := 0;
--   END IF;
--   IF (:new.RegionCLS IS NULL) THEN  
--     :new.RegionCLS := 0;
--   END IF;
--   IF (:new.DirectionCls IS NULL) THEN 
--     :new.DirectionCls := 0;
--   END IF;
--   IF (:new.FundsSource IS NULL) THEN 
--     :new.FundsSource := 0;
--   END IF;
--   IF (:new.KD IS NULL) THEN 
--     :new.KD := 0;
--   END IF;
--   IF (:new.subkd IS NULL) THEN 
--     :new.subkd := 0;
--   END IF;
--   IF (:new.Fact IS NULL) THEN  
--     :new.Fact := 0;
--   END IF;
--   IF (:new.FacialAcc_Cls IS NULL) THEN 
--     :new.FacialAcc_Cls := 0;
--   END IF;
--   IF (:new.KVRCorr IS NULL) THEN 
--     :new.KVRCorr := 0;
--   END IF;
--   IF (:new.KesrCorr IS NULL) THEN 
--     :new.KesrCorr := 0;
--   END IF;
--   IF (:new.AssignmentKind IS NULL) THEN 
--     :new.AssignmentKind := 0;
--   END IF;
--   IF (:new.Quarter1 IS NULL) THEN  
--     :new.Quarter1 := 0;
--   END IF;
--   IF (:new.Quarter2 IS NULL) THEN  
--     :new.Quarter2 := 0;
--   END IF;
--   IF (:new.Quarter3 IS NULL) THEN  
--     :new.Quarter3 := 0;
--   END IF;
--   IF (:new.Quarter4 IS NULL) THEN  
--     :new.Quarter4 := 0;
--   END IF;
--   IF (:new.FinType IS NULL) THEN  
--     :new.FinType := 0;
--   END IF;
--   IF (:new.MeansType IS NULL) THEN  
--     :new.MeansType := 0;
--   END IF;
--   IF (:new.DepartmentCls IS NULL) THEN 
--     :new.DepartmentCls := 0;
--   END IF;
--   /*   .        */
--   IF (:new.IFS IS NULL) THEN 
--     :new.IFS := 0;
--   END IF;
--   IF (:new.BuhOperationCLS IS NULL)
--   THEN 
--     GetIntConst(60, 15,:new.BuhOperationCLS);
--   END IF;
--   IF (:new.Month01 IS NULL) THEN  
--     :new.Month01 := 0;
--   END IF;
--   IF (:new.Month02 IS NULL) THEN  
--     :new.Month02 := 0;
--   END IF;
--   IF (:new.Month03 IS NULL) THEN  
--     :new.Month03 := 0;
--   END IF;
--   IF (:new.Month04 IS NULL) THEN  
--     :new.Month04 := 0;
--   END IF;
--   IF (:new.Month05 IS NULL) THEN  
--     :new.Month05 := 0;
--   END IF;
--   IF (:new.Month06 IS NULL) THEN  
--     :new.Month06 := 0;
--   END IF;
--   IF (:new.Month07 IS NULL) THEN  
--     :new.Month07 := 0;
--   END IF;
--   IF (:new.Month08 IS NULL) THEN  
--     :new.Month08 := 0;
--   END IF;
--   IF (:new.Month09 IS NULL) THEN  
--     :new.Month09 := 0;
--   END IF;
--   IF (:new.Month10 IS NULL) THEN  
--     :new.Month10 := 0;
--   END IF;
--   IF (:new.Month11 IS NULL) THEN  
--     :new.Month11 := 0;
--   END IF;
--   IF (:new.Month12 IS NULL) THEN  
--     :new.Month12 := 0;
--   END IF;
--   IF (:new.SummaYear1 IS NULL) THEN  
--     :new.SummaYear1 := 0;
--   END IF;
--   IF (:new.SummaYear2 IS NULL) THEN  
--     :new.SummaYear2 := 0;
--   END IF;
--   IF (:new.SummaYear3 IS NULL) THEN  
--     :new.SummaYear3 := 0;
--   END IF;
--   IF (:new.SummaYear4 IS NULL) THEN  
--     :new.SummaYear4 := 0;
--   END IF;
--   IF (:new.SummaOtherYears IS NULL) THEN  
--     :new.SummaOtherYears := 0; 
--   END IF;
--   IF (:new.DayPlanSumma IS NULL) THEN 
--     :new.DayPlanSumma := 0;
--   END IF;
--   /*     */
--   IF (:new.BudgetRef <> :old.BudgetRef) THEN
--     IF ( NOT((:new.BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN
--       RaiseException('Ex_CantModufyBudget');
--     END IF;
--   END IF;
--   BEGIN
-- 
--     SELECT
--     c.BA_LBO_FLAG
--     INTO
--     BALBOFlag1$  FROM
--     BudNotify c
--     WHERE
--     c.id = :new.RecordIndex
--     ;
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;
--   /*   */
--   IF (:new.ProgIndex = 262) THEN
--     GetIntConst(32, 43,StimateKind1$);
--     IF ((StimateKind1$  = 0) OR (StimateKind1$  IS NULL)) THEN
--       :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
--          
--     ELSE
--       IF (StimateKind1$  = 1) THEN
--         :new.Quarter1 := :new.SummaYear1;
--              
--       ELSE
--         :new.Quarter1 := :new.Month01 + :new.Month02 +:new.Month03;
--         :new.Quarter2 := :new.Month04 + :new.Month05 +:new.Month06;
--         :new.Quarter3 := :new.Month07 + :new.Month08 +:new.Month09;
--         :new.Quarter4 := :new.Month10 + :new.Month11 +:new.Month12;
--         :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
--              
--       END IF; 
--     END IF;
--   END IF;
--   /* ()*/
--   IF (:new.ProgIndex = 260) THEN
--     GetIntConst(32, 30,doubleUse1$);
--     GetIntConst(32, 40,AllowDivideBA1$);
--     IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*       ,     */
--       :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
--      
--     END IF;
--   END IF;
--   /* ()*/
--   IF (:new.ProgIndex = 264) THEN
--     GetIntConst(32, 34,doubleUse1$);
--     GetIntConst(32, 40,AllowDivideBA1$);
--     IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*       ,     */
--       :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
--      
--     END IF;
--   END IF;
--   /*  ()*/
--   IF (:new.ProgIndex = 32) THEN
--     GetIntConst(32, 31,doubleUse1$);
--     GetIntConst(32, 40,AllowDivideBA1$);
--     IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*          ,     */
--       :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
--      
--     END IF;
--   END IF;
--   /*  ()*/
--   IF (:new.ProgIndex = 215) THEN
--     GetIntConst(32, 35,doubleUse1$);
--     GetIntConst(32, 40,AllowDivideBA1$);
--     IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*         ,     */
--       :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
--      
--     END IF;
--   END IF;
--   /* 
--    IF ((NEW.TransfertOrg_Ref IS NULL) AND (NEW.REGIONCLS <> 0)) THEN
--        SELECT Organizations FROM REGIONCLS
--          WHERE NEW.REGIONCLS = ID
--        INTO NEW.TransfertOrg_Ref;
--   *//*    */
--   GETTARGETCLS(:old.transfertcls, :new.transfertcls, :old.meanstype, :new.meanstype,
--   :new.targetcls,:new.targetcls);

-- - - - - - - - - - - - -
-- BU_100 (TR_BUDGETDATA_BU_100)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if (:new.ClsType is NULL) then
    BEGIN
      select
      bn.ClsType
      into
      CapClsType1$     from
      BudNotify bn
      where
      bn.id = :new.RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (CapClsType1$  = 3) then
      if (:new.IFS <> 0) then
        :new.ClsType := 1; /*       ClsType */
            
      else
        if (:new.KD <> 0) then
          :new.ClsType := 2; /* */
                
        else
          :new.ClsType := 0; /* */
        END IF;    
      END IF;
    else
      :new.ClsType := CapClsType1$;
      
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND ((:new.IFS <> 0)or(:new.KD <> 0))) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0)
  )) THEN
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  if (((:new.ClsType = 1)and(:new.KD <> 0))or((:new.ClsType = 2)and(:new.IFS <> 0))) then
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 1) AND (:new.ClsType <> 2)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;
  IF (:new.ACC_REF IS NOT NULL) THEN /*    / */
    BEGIN
      SELECT oa.ORG_REF
      INTO OrgRefByAcc1$     FROM ORG_ACCOUNTS oa
      WHERE (oa.ID = :new.ACC_REF)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (:new.FacialAcc_CLS = 0) then 
      :new.Org_Ref := OrgRefByAcc1$;
      
    END IF;
  END IF;
  /*  \ ,       \    \,  \ */
  if (:new.FacialAcc_CLS <> 0) then
    BEGIN
      SELECT
      fac.ORG_REF
      INTO :new.Org_Ref     FROM
      FacialACC_CLS fac
      WHERE
      (fac.ID = :new.FacialAcc_CLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (OrgRefByAcc1$<>:new.Org_Ref) then 
      :new.ACC_REF := null;
      
    END IF;
  END IF;
  if ((:new.ProgIndex in (252, 253))and(:new.FacialAcc_CLS = 0)) then
    BEGIN
      SELECT
      bn.FacialAccCLS
      INTO :new.FacialAcc_CLS     FROM
      BudNotify bn
      WHERE
      (bn.ID = :new.RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_BUDGETDATA_BU_200)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*       32-, 260-, 261-, 262-  , 263-, 268-  , 252-. */
  if (:new.ProgIndex in (32, 252, 260, 261, 262, 263, 268)) then
    /*     (32  ()) 
             :
           =0     ,
           =1  ,
           =2   0  .*//*     260 ()
             :
           =2   0  .*/
    GetIntConst(32, 25,AutoKvrCorr$);
    if (:new.ProgIndex = 32) then /*  ()*/
      if (AutoKvrCorr$  = 0) then
        :new.KvrCorr := :new.Kvr;
              
      else
        if (AutoKvrCorr$  = 2) then
          :new.KvrCorr := 0;
        END IF;
      END IF;
      /* KESR   */
      if (AutoKvrCorr$  = 0) then
        :new.KesrCorr := :new.Kesr;
              
      else
        if (AutoKvrCorr$  = 2) then
          :new.KesrCorr := 0;
        END IF;    
      END IF;
    else 
      if ((:new.ProgIndex = 260)and (AutoKvrCorr$  = 2)) then  /* ()*/
        :new.KvrCorr := 0;
        --   ,    new.Kvr = 0;
        /* KESR   */        
                
        :new.KesrCorr := 0;
        :new.Kesr := 0;     
              
      else
        :new.KvrCorr := :new.Kvr; /*         */
        /* KESR   */        
        :new.KesrCorr := :new.Kesr;
              
      END IF;  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_BUDGETDATA_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -
  NULL;
--   IF (:NEW.RVersion IS NULL) THEN
--      :NEW.RVersion := 1;
--   ELSIF ((:NEW.RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
--      :NEW.RVersion := :OLD.RVersion;
--   ELSE
--      :NEW.RVersion := :OLD.RVersion + 1;
--   END IF;

END;
/
-- ALTER TRIGGER TR_BUDGETDATA_BU_100
CREATE OR REPLACE TRIGGER TR_BUDGETDATA_BU
  BEFORE UPDATE
  ON BUDGETDATA
  FOR EACH ROW
DECLARE
  AutoKvrCorr$ NUMBER(10);
  OrgRefByAcc1$ NUMBER(10);
  CapClsType1$ NUMBER(10);
  doubleUse1$ NUMBER(10);
  BALBOFlag1$ NUMBER(10);
  AllowDivideBA1$ NUMBER(10);
  StimateKind1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_BUDGETDATA_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   IF (:new.KFSR IS NULL) THEN  
--     :new.KFSR := 0;
--   END IF;
--   IF (:new.KVSR IS NULL) THEN  
--     :new.KVSR := 0;
--   END IF;
--   IF (:new.KVR IS NULL) THEN  
--     :new.KVR := 0;
--   END IF;
--   IF (:new.KCSR IS NULL) THEN  
--     :new.KCSR := 0;
--   END IF;
--   IF (:new.KESR IS NULL) THEN  
--     :new.KESR := 0;
--   END IF;
--   IF (:new.SubKESR IS NULL) THEN  
--     :new.SubKESR := 0;
--   END IF;
--   IF (:new.RegionCLS IS NULL) THEN  
--     :new.RegionCLS := 0;
--   END IF;
--   IF (:new.DirectionCls IS NULL) THEN 
--     :new.DirectionCls := 0;
--   END IF;
--   IF (:new.FundsSource IS NULL) THEN 
--     :new.FundsSource := 0;
--   END IF;
--   IF (:new.KD IS NULL) THEN 
--     :new.KD := 0;
--   END IF;
--   IF (:new.subkd IS NULL) THEN 
--     :new.subkd := 0;
--   END IF;
--   IF (:new.Fact IS NULL) THEN  
--     :new.Fact := 0;
--   END IF;
--   IF (:new.FacialAcc_Cls IS NULL) THEN 
--     :new.FacialAcc_Cls := 0;
--   END IF;
--   IF (:new.KVRCorr IS NULL) THEN 
--     :new.KVRCorr := 0;
--   END IF;
--   IF (:new.KesrCorr IS NULL) THEN 
--     :new.KesrCorr := 0;
--   END IF;
--   IF (:new.AssignmentKind IS NULL) THEN 
--     :new.AssignmentKind := 0;
--   END IF;
--   IF (:new.Quarter1 IS NULL) THEN  
--     :new.Quarter1 := 0;
--   END IF;
--   IF (:new.Quarter2 IS NULL) THEN  
--     :new.Quarter2 := 0;
--   END IF;
--   IF (:new.Quarter3 IS NULL) THEN  
--     :new.Quarter3 := 0;
--   END IF;
--   IF (:new.Quarter4 IS NULL) THEN  
--     :new.Quarter4 := 0;
--   END IF;
--   IF (:new.FinType IS NULL) THEN  
--     :new.FinType := 0;
--   END IF;
--   IF (:new.MeansType IS NULL) THEN  
--     :new.MeansType := 0;
--   END IF;
--   IF (:new.DepartmentCls IS NULL) THEN 
--     :new.DepartmentCls := 0;
--   END IF;
--   /*   .        */
--   IF (:new.IFS IS NULL) THEN 
--     :new.IFS := 0;
--   END IF;
--   IF (:new.BuhOperationCLS IS NULL)
--   THEN 
--     GetIntConst(60, 15,:new.BuhOperationCLS);
--   END IF;
--   IF (:new.Month01 IS NULL) THEN  
--     :new.Month01 := 0;
--   END IF;
--   IF (:new.Month02 IS NULL) THEN  
--     :new.Month02 := 0;
--   END IF;
--   IF (:new.Month03 IS NULL) THEN  
--     :new.Month03 := 0;
--   END IF;
--   IF (:new.Month04 IS NULL) THEN  
--     :new.Month04 := 0;
--   END IF;
--   IF (:new.Month05 IS NULL) THEN  
--     :new.Month05 := 0;
--   END IF;
--   IF (:new.Month06 IS NULL) THEN  
--     :new.Month06 := 0;
--   END IF;
--   IF (:new.Month07 IS NULL) THEN  
--     :new.Month07 := 0;
--   END IF;
--   IF (:new.Month08 IS NULL) THEN  
--     :new.Month08 := 0;
--   END IF;
--   IF (:new.Month09 IS NULL) THEN  
--     :new.Month09 := 0;
--   END IF;
--   IF (:new.Month10 IS NULL) THEN  
--     :new.Month10 := 0;
--   END IF;
--   IF (:new.Month11 IS NULL) THEN  
--     :new.Month11 := 0;
--   END IF;
--   IF (:new.Month12 IS NULL) THEN  
--     :new.Month12 := 0;
--   END IF;
--   IF (:new.SummaYear1 IS NULL) THEN  
--     :new.SummaYear1 := 0;
--   END IF;
--   IF (:new.SummaYear2 IS NULL) THEN  
--     :new.SummaYear2 := 0;
--   END IF;
--   IF (:new.SummaYear3 IS NULL) THEN  
--     :new.SummaYear3 := 0;
--   END IF;
--   IF (:new.SummaYear4 IS NULL) THEN  
--     :new.SummaYear4 := 0;
--   END IF;
--   IF (:new.SummaOtherYears IS NULL) THEN  
--     :new.SummaOtherYears := 0; 
--   END IF;
--   IF (:new.DayPlanSumma IS NULL) THEN 
--     :new.DayPlanSumma := 0;
--   END IF;
--   /*     */
--   IF (:new.BudgetRef <> :old.BudgetRef) THEN
--     IF ( NOT((:new.BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN
--       RaiseException('Ex_CantModufyBudget');
--     END IF;
--   END IF;
--   BEGIN
-- 
--     SELECT
--     c.BA_LBO_FLAG
--     INTO
--     BALBOFlag1$  FROM
--     BudNotify c
--     WHERE
--     c.id = :new.RecordIndex
--     ;
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;
--   /*   */
--   IF (:new.ProgIndex = 262) THEN
--     GetIntConst(32, 43,StimateKind1$);
--     IF ((StimateKind1$  = 0) OR (StimateKind1$  IS NULL)) THEN
--       :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
--          
--     ELSE
--       IF (StimateKind1$  = 1) THEN
--         :new.Quarter1 := :new.SummaYear1;
--              
--       ELSE
--         :new.Quarter1 := :new.Month01 + :new.Month02 +:new.Month03;
--         :new.Quarter2 := :new.Month04 + :new.Month05 +:new.Month06;
--         :new.Quarter3 := :new.Month07 + :new.Month08 +:new.Month09;
--         :new.Quarter4 := :new.Month10 + :new.Month11 +:new.Month12;
--         :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
--              
--       END IF; 
--     END IF;
--   END IF;
--   /* ()*/
--   IF (:new.ProgIndex = 260) THEN
--     GetIntConst(32, 30,doubleUse1$);
--     GetIntConst(32, 40,AllowDivideBA1$);
--     IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*       ,     */
--       :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
--      
--     END IF;
--   END IF;
--   /* ()*/
--   IF (:new.ProgIndex = 264) THEN
--     GetIntConst(32, 34,doubleUse1$);
--     GetIntConst(32, 40,AllowDivideBA1$);
--     IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*       ,     */
--       :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
--      
--     END IF;
--   END IF;
--   /*  ()*/
--   IF (:new.ProgIndex = 32) THEN
--     GetIntConst(32, 31,doubleUse1$);
--     GetIntConst(32, 40,AllowDivideBA1$);
--     IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*          ,     */
--       :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
--      
--     END IF;
--   END IF;
--   /*  ()*/
--   IF (:new.ProgIndex = 215) THEN
--     GetIntConst(32, 35,doubleUse1$);
--     GetIntConst(32, 40,AllowDivideBA1$);
--     IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*         ,     */
--       :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
--      
--     END IF;
--   END IF;
--   /* 
--    IF ((NEW.TransfertOrg_Ref IS NULL) AND (NEW.REGIONCLS <> 0)) THEN
--        SELECT Organizations FROM REGIONCLS
--          WHERE NEW.REGIONCLS = ID
--        INTO NEW.TransfertOrg_Ref;
--   *//*    */
--   GETTARGETCLS(:old.transfertcls, :new.transfertcls, :old.meanstype, :new.meanstype,
--   :new.targetcls,:new.targetcls);

-- - - - - - - - - - - - -
-- BU_100 (TR_BUDGETDATA_BU_100)
-- Version 11.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (:new.ClsType is NULL) then
--     BEGIN
--       select
--       bn.ClsType
--       into
--       CapClsType1$     from
--       BudNotify bn
--       where
--       bn.id = :new.RecordIndex
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     if (CapClsType1$  = 3) then
--       if (:new.IFS <> 0) then
--         :new.ClsType := 1; /*       ClsType */
--             
--       else
--         if (:new.KD <> 0) then
--           :new.ClsType := 2; /* */
--                 
--         else
--           :new.ClsType := 0; /* */
--         END IF;    
--       END IF;
--     else
--       :new.ClsType := CapClsType1$;
--       
--     END IF;
--   END IF;
--   IF ((:new.ClsType = 0) AND ((:new.IFS <> 0)or(:new.KD <> 0))) THEN  /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((:new.ClsType <> 0) AND (
--   (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
--   (:new.KCSR <> 0) OR (:new.KVR <> 0)
--   )) THEN
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   if (((:new.ClsType = 1)and(:new.KD <> 0))or((:new.ClsType = 2)and(:new.IFS <> 0))) then
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((:new.ClsType <> 0) AND (:new.ClsType <> 1) AND (:new.ClsType <> 2)) THEN /*   */
--     RaiseException('EX_WRONGBUDCLSTYPE');
--   END IF;
--   IF (:new.ACC_REF IS NOT NULL) THEN /*    / */
--     BEGIN
--       SELECT oa.ORG_REF
--       INTO OrgRefByAcc1$     FROM ORG_ACCOUNTS oa
--       WHERE (oa.ID = :new.ACC_REF)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     if (:new.FacialAcc_CLS = 0) then 
--       :new.Org_Ref := OrgRefByAcc1$;
--       
--     END IF;
--   END IF;
--   /*  \ ,       \    \,  \ */
--   if (:new.FacialAcc_CLS <> 0) then
--     BEGIN
--       SELECT
--       fac.ORG_REF
--       INTO :new.Org_Ref     FROM
--       FacialACC_CLS fac
--       WHERE
--       (fac.ID = :new.FacialAcc_CLS)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     if (OrgRefByAcc1$<>:new.Org_Ref) then 
--       :new.ACC_REF := null;
--       
--     END IF;
--   END IF;
--   if ((:new.ProgIndex in (252, 253))and(:new.FacialAcc_CLS = 0)) then
--     BEGIN
--       SELECT
--       bn.FacialAccCLS
--       INTO :new.FacialAcc_CLS     FROM
--       BudNotify bn
--       WHERE
--       (bn.ID = :new.RecordIndex)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_BUDGETDATA_BU_200)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*       32-, 260-, 261-, 262-  , 263-, 268-  , 252-. */
  if (:new.ProgIndex in (32, 252, 260, 261, 262, 263, 268)) then
    /*     (32  ()) 
             :
           =0     ,
           =1  ,
           =2   0  .*//*     260 ()
             :
           =2   0  .*/
    GetIntConst(32, 25,AutoKvrCorr$);
    if (:new.ProgIndex = 32) then /*  ()*/
      if (AutoKvrCorr$  = 0) then
        :new.KvrCorr := :new.Kvr;
              
      else
        if (AutoKvrCorr$  = 2) then
          :new.KvrCorr := 0;
        END IF;
      END IF;
      /* KESR   */
      if (AutoKvrCorr$  = 0) then
        :new.KesrCorr := :new.Kesr;
              
      else
        if (AutoKvrCorr$  = 2) then
          :new.KesrCorr := 0;
        END IF;    
      END IF;
    else 
      if ((:new.ProgIndex = 260)and (AutoKvrCorr$  = 2)) then  /* ()*/
        :new.KvrCorr := 0;
        --   ,    new.Kvr = 0;
        /* KESR   */        
                
        :new.KesrCorr := 0;
        :new.Kesr := 0;     
              
      else
        :new.KvrCorr := :new.Kvr; /*         */
        /* KESR   */        
        :new.KesrCorr := :new.Kesr;
              
      END IF;  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_BUDGETDATA_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -
  NULL;
--   IF (:NEW.RVersion IS NULL) THEN
--      :NEW.RVersion := 1;
--   ELSIF ((:NEW.RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
--      :NEW.RVersion := :OLD.RVersion;
--   ELSE
--      :NEW.RVersion := :OLD.RVersion + 1;
--   END IF;

END;
/
-- ALTER TRIGGER Tr_BudgetData_AU_500
CREATE OR REPLACE TRIGGER TR_BUDGETDATA_AU
  AFTER UPDATE
  ON BUDGETDATA
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- AU_500 (TR_BUDGETDATA_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -
  NULL;
--   if (:new.ID<>:old.ID) then
--     insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (26, :old.ID, SYSDATE);
--     delete from DelRecIndexes where (TableID=26) and (RecordId=:new.ID);
--   end if;

END;
/
-- ALTER TRIGGER TR_BUDGETDATA_BU_200
CREATE OR REPLACE TRIGGER TR_BUDGETDATA_BU
  BEFORE UPDATE
  ON BUDGETDATA
  FOR EACH ROW
DECLARE
  AutoKvrCorr$ NUMBER(10);
  OrgRefByAcc1$ NUMBER(10);
  CapClsType1$ NUMBER(10);
  doubleUse1$ NUMBER(10);
  BALBOFlag1$ NUMBER(10);
  AllowDivideBA1$ NUMBER(10);
  StimateKind1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_BUDGETDATA_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   IF (:new.KFSR IS NULL) THEN  
--     :new.KFSR := 0;
--   END IF;
--   IF (:new.KVSR IS NULL) THEN  
--     :new.KVSR := 0;
--   END IF;
--   IF (:new.KVR IS NULL) THEN  
--     :new.KVR := 0;
--   END IF;
--   IF (:new.KCSR IS NULL) THEN  
--     :new.KCSR := 0;
--   END IF;
--   IF (:new.KESR IS NULL) THEN  
--     :new.KESR := 0;
--   END IF;
--   IF (:new.SubKESR IS NULL) THEN  
--     :new.SubKESR := 0;
--   END IF;
--   IF (:new.RegionCLS IS NULL) THEN  
--     :new.RegionCLS := 0;
--   END IF;
--   IF (:new.DirectionCls IS NULL) THEN 
--     :new.DirectionCls := 0;
--   END IF;
--   IF (:new.FundsSource IS NULL) THEN 
--     :new.FundsSource := 0;
--   END IF;
--   IF (:new.KD IS NULL) THEN 
--     :new.KD := 0;
--   END IF;
--   IF (:new.subkd IS NULL) THEN 
--     :new.subkd := 0;
--   END IF;
--   IF (:new.Fact IS NULL) THEN  
--     :new.Fact := 0;
--   END IF;
--   IF (:new.FacialAcc_Cls IS NULL) THEN 
--     :new.FacialAcc_Cls := 0;
--   END IF;
--   IF (:new.KVRCorr IS NULL) THEN 
--     :new.KVRCorr := 0;
--   END IF;
--   IF (:new.KesrCorr IS NULL) THEN 
--     :new.KesrCorr := 0;
--   END IF;
--   IF (:new.AssignmentKind IS NULL) THEN 
--     :new.AssignmentKind := 0;
--   END IF;
--   IF (:new.Quarter1 IS NULL) THEN  
--     :new.Quarter1 := 0;
--   END IF;
--   IF (:new.Quarter2 IS NULL) THEN  
--     :new.Quarter2 := 0;
--   END IF;
--   IF (:new.Quarter3 IS NULL) THEN  
--     :new.Quarter3 := 0;
--   END IF;
--   IF (:new.Quarter4 IS NULL) THEN  
--     :new.Quarter4 := 0;
--   END IF;
--   IF (:new.FinType IS NULL) THEN  
--     :new.FinType := 0;
--   END IF;
--   IF (:new.MeansType IS NULL) THEN  
--     :new.MeansType := 0;
--   END IF;
--   IF (:new.DepartmentCls IS NULL) THEN 
--     :new.DepartmentCls := 0;
--   END IF;
--   /*   .        */
--   IF (:new.IFS IS NULL) THEN 
--     :new.IFS := 0;
--   END IF;
--   IF (:new.BuhOperationCLS IS NULL)
--   THEN 
--     GetIntConst(60, 15,:new.BuhOperationCLS);
--   END IF;
--   IF (:new.Month01 IS NULL) THEN  
--     :new.Month01 := 0;
--   END IF;
--   IF (:new.Month02 IS NULL) THEN  
--     :new.Month02 := 0;
--   END IF;
--   IF (:new.Month03 IS NULL) THEN  
--     :new.Month03 := 0;
--   END IF;
--   IF (:new.Month04 IS NULL) THEN  
--     :new.Month04 := 0;
--   END IF;
--   IF (:new.Month05 IS NULL) THEN  
--     :new.Month05 := 0;
--   END IF;
--   IF (:new.Month06 IS NULL) THEN  
--     :new.Month06 := 0;
--   END IF;
--   IF (:new.Month07 IS NULL) THEN  
--     :new.Month07 := 0;
--   END IF;
--   IF (:new.Month08 IS NULL) THEN  
--     :new.Month08 := 0;
--   END IF;
--   IF (:new.Month09 IS NULL) THEN  
--     :new.Month09 := 0;
--   END IF;
--   IF (:new.Month10 IS NULL) THEN  
--     :new.Month10 := 0;
--   END IF;
--   IF (:new.Month11 IS NULL) THEN  
--     :new.Month11 := 0;
--   END IF;
--   IF (:new.Month12 IS NULL) THEN  
--     :new.Month12 := 0;
--   END IF;
--   IF (:new.SummaYear1 IS NULL) THEN  
--     :new.SummaYear1 := 0;
--   END IF;
--   IF (:new.SummaYear2 IS NULL) THEN  
--     :new.SummaYear2 := 0;
--   END IF;
--   IF (:new.SummaYear3 IS NULL) THEN  
--     :new.SummaYear3 := 0;
--   END IF;
--   IF (:new.SummaYear4 IS NULL) THEN  
--     :new.SummaYear4 := 0;
--   END IF;
--   IF (:new.SummaOtherYears IS NULL) THEN  
--     :new.SummaOtherYears := 0; 
--   END IF;
--   IF (:new.DayPlanSumma IS NULL) THEN 
--     :new.DayPlanSumma := 0;
--   END IF;
--   /*     */
--   IF (:new.BudgetRef <> :old.BudgetRef) THEN
--     IF ( NOT((:new.BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN
--       RaiseException('Ex_CantModufyBudget');
--     END IF;
--   END IF;
--   BEGIN
-- 
--     SELECT
--     c.BA_LBO_FLAG
--     INTO
--     BALBOFlag1$  FROM
--     BudNotify c
--     WHERE
--     c.id = :new.RecordIndex
--     ;
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;
--   /*   */
--   IF (:new.ProgIndex = 262) THEN
--     GetIntConst(32, 43,StimateKind1$);
--     IF ((StimateKind1$  = 0) OR (StimateKind1$  IS NULL)) THEN
--       :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
--          
--     ELSE
--       IF (StimateKind1$  = 1) THEN
--         :new.Quarter1 := :new.SummaYear1;
--              
--       ELSE
--         :new.Quarter1 := :new.Month01 + :new.Month02 +:new.Month03;
--         :new.Quarter2 := :new.Month04 + :new.Month05 +:new.Month06;
--         :new.Quarter3 := :new.Month07 + :new.Month08 +:new.Month09;
--         :new.Quarter4 := :new.Month10 + :new.Month11 +:new.Month12;
--         :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
--              
--       END IF; 
--     END IF;
--   END IF;
--   /* ()*/
--   IF (:new.ProgIndex = 260) THEN
--     GetIntConst(32, 30,doubleUse1$);
--     GetIntConst(32, 40,AllowDivideBA1$);
--     IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*       ,     */
--       :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
--      
--     END IF;
--   END IF;
--   /* ()*/
--   IF (:new.ProgIndex = 264) THEN
--     GetIntConst(32, 34,doubleUse1$);
--     GetIntConst(32, 40,AllowDivideBA1$);
--     IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*       ,     */
--       :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
--      
--     END IF;
--   END IF;
--   /*  ()*/
--   IF (:new.ProgIndex = 32) THEN
--     GetIntConst(32, 31,doubleUse1$);
--     GetIntConst(32, 40,AllowDivideBA1$);
--     IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*          ,     */
--       :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
--      
--     END IF;
--   END IF;
--   /*  ()*/
--   IF (:new.ProgIndex = 215) THEN
--     GetIntConst(32, 35,doubleUse1$);
--     GetIntConst(32, 40,AllowDivideBA1$);
--     IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*         ,     */
--       :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
--      
--     END IF;
--   END IF;
--   /* 
--    IF ((NEW.TransfertOrg_Ref IS NULL) AND (NEW.REGIONCLS <> 0)) THEN
--        SELECT Organizations FROM REGIONCLS
--          WHERE NEW.REGIONCLS = ID
--        INTO NEW.TransfertOrg_Ref;
--   *//*    */
--   GETTARGETCLS(:old.transfertcls, :new.transfertcls, :old.meanstype, :new.meanstype,
--   :new.targetcls,:new.targetcls);

-- - - - - - - - - - - - -
-- BU_100 (TR_BUDGETDATA_BU_100)
-- Version 11.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (:new.ClsType is NULL) then
--     BEGIN
--       select
--       bn.ClsType
--       into
--       CapClsType1$     from
--       BudNotify bn
--       where
--       bn.id = :new.RecordIndex
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     if (CapClsType1$  = 3) then
--       if (:new.IFS <> 0) then
--         :new.ClsType := 1; /*       ClsType */
--             
--       else
--         if (:new.KD <> 0) then
--           :new.ClsType := 2; /* */
--                 
--         else
--           :new.ClsType := 0; /* */
--         END IF;    
--       END IF;
--     else
--       :new.ClsType := CapClsType1$;
--       
--     END IF;
--   END IF;
--   IF ((:new.ClsType = 0) AND ((:new.IFS <> 0)or(:new.KD <> 0))) THEN  /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((:new.ClsType <> 0) AND (
--   (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
--   (:new.KCSR <> 0) OR (:new.KVR <> 0)
--   )) THEN
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   if (((:new.ClsType = 1)and(:new.KD <> 0))or((:new.ClsType = 2)and(:new.IFS <> 0))) then
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((:new.ClsType <> 0) AND (:new.ClsType <> 1) AND (:new.ClsType <> 2)) THEN /*   */
--     RaiseException('EX_WRONGBUDCLSTYPE');
--   END IF;
--   IF (:new.ACC_REF IS NOT NULL) THEN /*    / */
--     BEGIN
--       SELECT oa.ORG_REF
--       INTO OrgRefByAcc1$     FROM ORG_ACCOUNTS oa
--       WHERE (oa.ID = :new.ACC_REF)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     if (:new.FacialAcc_CLS = 0) then 
--       :new.Org_Ref := OrgRefByAcc1$;
--       
--     END IF;
--   END IF;
--   /*  \ ,       \    \,  \ */
--   if (:new.FacialAcc_CLS <> 0) then
--     BEGIN
--       SELECT
--       fac.ORG_REF
--       INTO :new.Org_Ref     FROM
--       FacialACC_CLS fac
--       WHERE
--       (fac.ID = :new.FacialAcc_CLS)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     if (OrgRefByAcc1$<>:new.Org_Ref) then 
--       :new.ACC_REF := null;
--       
--     END IF;
--   END IF;
--   if ((:new.ProgIndex in (252, 253))and(:new.FacialAcc_CLS = 0)) then
--     BEGIN
--       SELECT
--       bn.FacialAccCLS
--       INTO :new.FacialAcc_CLS     FROM
--       BudNotify bn
--       WHERE
--       (bn.ID = :new.RecordIndex)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_BUDGETDATA_BU_200)
-- Version 10.30.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*       32-, 260-, 261-, 262-  , 263-, 268-  , 252-. */
--   if (:new.ProgIndex in (32, 252, 260, 261, 262, 263, 268)) then
--     /*     (32  ()) 
--              :
--            =0     ,
--            =1  ,
--            =2   0  .*//*     260 ()
--              :
--            =2   0  .*/
--     GetIntConst(32, 25,AutoKvrCorr$);
--     if (:new.ProgIndex = 32) then /*  ()*/
--       if (AutoKvrCorr$  = 0) then
--         :new.KvrCorr := :new.Kvr;
--               
--       else
--         if (AutoKvrCorr$  = 2) then
--           :new.KvrCorr := 0;
--         END IF;
--       END IF;
--       /* KESR   */
--       if (AutoKvrCorr$  = 0) then
--         :new.KesrCorr := :new.Kesr;
--               
--       else
--         if (AutoKvrCorr$  = 2) then
--           :new.KesrCorr := 0;
--         END IF;    
--       END IF;
--     else 
--       if ((:new.ProgIndex = 260)and (AutoKvrCorr$  = 2)) then  /* ()*/
--         :new.KvrCorr := 0;
--         --   ,    new.Kvr = 0;
--         /* KESR   */        
--                 
--         :new.KesrCorr := 0;
--         :new.Kesr := 0;     
--               
--       else
--         :new.KvrCorr := :new.Kvr; /*         */
--         /* KESR   */        
--         :new.KesrCorr := :new.Kesr;
--               
--       END IF;  
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_BUDGETDATA_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -
  NULL;
--   IF (:NEW.RVersion IS NULL) THEN
--      :NEW.RVersion := 1;
--   ELSIF ((:NEW.RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
--      :NEW.RVersion := :OLD.RVersion;
--   ELSE
--      :NEW.RVersion := :OLD.RVersion + 1;
--   END IF;

END;
/
ALTER TRIGGER TR_CORRECTIONDETAIL_BU_500 DISABLE
/
ALTER TRIGGER TR_FACIALFINDETAIL_BU_500 DISABLE
/
-- ALTER TRIGGER tr_FacialFinDetail_bu_0
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;
-- 
--    /*     */
--    IF     (new$BudgetRef <> :OLD.BudgetRef)
--       AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
--       raiseException ('Ex_CantModufyBudget');
--    END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;
     
  END IF;
  IF (new$DestFintype IS NULL) THEN 
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*       */
  GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
  new$Sourcetargetcls,new$Sourcetargetcls);
  GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
  new$Desttargetcls,new$Desttargetcls);     

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*  60 :  '   .'; source
          61 :  '      '; dest
          62 :  '   ';dest
          63 :  '    '; source
          64 :  '   '; source
          65 :  ' , ';dest
          66 :  '  ,  - '; source dest
          67 :  '   ';source
          68 :  '  \ ';dest
          69 :  '   \ '; dest
          70 :  '  \ ';source
          71 :  '   \ '; dest */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  /*     */
  if (PromiseMode$ <> 1) then
    /*          */
    if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /*          */
    if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$DestPromise)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
        
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /*     */
  if (PromiseMode$ = 1) then
    /* source  .    */
    if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
    (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule 
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* dest  .     */
    if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
    (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
          
    /*         NULL,    */
    /* source */
    if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
    (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /* dest */
    if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
    (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /*    ,     */
    if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
      new$SourcePromise := null;
      new$Promise := null;
            
    END IF;
    if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
      new$DestPromise := null;
      new$Promise := null;
            
    END IF;
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$1
      from PaymentSchedule
      where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$2
      from PaymentSchedule
      where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$SourcePromise is not null and (
    (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
    (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$SourceExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null and (
    (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
    (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$DestExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select c.AcceptDate into CapAcceptDate$
      from facialfincaption c
      where c.id = new$RecordIndex;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        CapAcceptDate$ := NULL;
    END;

    if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
      new$AcceptDate := new$AcceptDate;
    else
      RaiseException('ex_wrongacceptdate');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
-- ALTER TRIGGER tr_FacialFinDetail_bu_110
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;
-- 
--    /*     */
--    IF     (new$BudgetRef <> :OLD.BudgetRef)
--       AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
--       raiseException ('Ex_CantModufyBudget');
--    END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 12.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*     ,      */ 
--   i_fintype$ := -1 ;
--   IF (new$SourceFintype IS NULL) THEN 
--     BEGIN
--       SELECT constvalue INTO i_fintype$   FROM intconst
--       WHERE (progindex=30) AND (constindex=10) ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     new$SourceFintype := i_fintype$  ;
--      
--   END IF;
--   IF (new$DestFintype IS NULL) THEN 
--     IF (i_fintype$ = -1) THEN
--       BEGIN
--         SELECT constvalue INTO i_fintype$   FROM intconst
--         WHERE (progindex=30) AND (constindex=10) ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--     END IF;
--     new$DestFintype := i_fintype$  ;
--      
--   END IF;
--   IF (new$SourceFacialAcc_CLS IS NULL) THEN 
--     new$SourceFacialAcc_CLS := 0;
--   END IF;
--   /*   */
--   IF (new$SourceKVR IS NULL) THEN 
--     new$SourceKVR := 0;
--   END IF;
--   IF (new$SourceKESR IS NULL) THEN 
--     new$SourceKESR := 0;
--   END IF;
--   IF (new$SourceKVSR IS NULL) THEN 
--     new$SourceKVSR := 0;
--   END IF;
--   IF (new$SourceKFSR IS NULL) THEN 
--     new$SourceKFSR := 0;
--   END IF;
--   IF (new$SourceKCSR IS NULL) THEN 
--     new$SourceKCSR := 0;
--   END IF;
--   IF (new$SourceSubKESR IS NULL) THEN 
--     new$SourceSubKESR := 0;
--   END IF;
--   IF (new$SourceDirectionCls IS NULL) THEN 
--     new$SourceDirectionCls := 0;
--   END IF;
--   IF (new$SourceFact IS NULL) THEN 
--     new$SourceFact := 0;
--   END IF;
--   IF (new$SourceMeansType IS NULL) THEN 
--     new$SourceMeansType := 0;
--   END IF;
--   IF (new$SourceFinSource IS NULL) THEN 
--     new$SourceFinSource := 0;
--   END IF;
--   IF (new$SourceFinType IS NULL) THEN 
--     new$SourceFinType := 0;
--   END IF;
--   IF (new$SourceDocType IS NULL) THEN 
--     new$SourceDocType := 0;
--   END IF;
--   IF (new$Sourceifs IS NULL) THEN 
--     new$Sourceifs := 0;
--   END IF;
--   IF (new$SourceKD IS NULL) THEN 
--     new$SourceKD := 0;
--   END IF;
--   IF (new$SourceFundsSource IS NULL) THEN 
--     new$SourceFundsSource := 0;
--   END IF;
--   IF (new$SourceAssignmentKind IS NULL) THEN 
--     new$SourceAssignmentKind := 0;
--   END IF;
--   IF (new$SourceRegionCLS IS NULL) THEN 
--     new$SourceRegionCLS := 0;
--   END IF;
--   IF (new$DestFacialAcc_CLS IS NULL) THEN 
--     new$DestFacialAcc_CLS := 0;
--   END IF;
--   /*   */
--   IF (new$DestKVR IS NULL) THEN 
--     new$DestKVR := 0;
--   END IF;
--   IF (new$DestKESR IS NULL) THEN 
--     new$DestKESR := 0;
--   END IF;
--   IF (new$DestKVSR IS NULL) THEN 
--     new$DestKVSR := 0;
--   END IF;
--   IF (new$DestKFSR IS NULL) THEN 
--     new$DestKFSR := 0;
--   END IF;
--   IF (new$DestKCSR IS NULL) THEN 
--     new$DestKCSR := 0;
--   END IF;
--   IF (new$DestSubKESR IS NULL) THEN 
--     new$DestSubKESR := 0;
--   END IF;
--   IF (new$DestDirectionCls IS NULL) THEN 
--     new$DestDirectionCls := 0;
--   END IF;
--   IF (new$DestFact IS NULL) THEN 
--     new$DestFact := 0;
--   END IF;
--   IF (new$DestMeansType IS NULL) THEN 
--     new$DestMeansType := 0;
--   END IF;
--   IF (new$DestFinSource IS NULL) THEN 
--     new$DestFinSource := 0;
--   END IF;
--   IF (new$DestFinType IS NULL) THEN 
--     new$DestFinType := 0;
--   END IF;
--   IF (new$DestDocType IS NULL) THEN 
--     new$DestDocType := 0;
--   END IF;
--   IF (new$Destifs IS NULL) THEN 
--     new$Destifs := 0;
--   END IF;
--   IF (new$DestKD IS NULL) THEN 
--     new$DestKD := 0;
--   END IF;
--   IF (new$DestFundsSource IS NULL) THEN 
--     new$DestFundsSource := 0;
--   END IF;
--   IF (new$DestAssignmentKind IS NULL) THEN 
--     new$DestAssignmentKind := 0;
--   END IF;
--   IF (new$DestRegionCLS IS NULL) THEN 
--     new$DestRegionCLS := 0;
--   END IF;
--   /*   :       */
--   if (new$progindex=76) then
--     new$SourceKVR := new$DestKVR;
--     new$SourceKESR := new$DestKESR;
--     new$SourceKVSR := new$DestKVSR;
--     new$SourceKFSR := new$DestKFSR;
--     new$SourceKCSR := new$DestKCSR;
--     new$SourceSubKESR := new$DestSubKESR;
--     new$SourceDirectionCls := new$DestDirectionCls;
--     new$SourceFact := new$DestFact;
--     new$SourceMeansType := new$DestMeansType;
--     new$SourceFinSource := new$DestFinSource;
--     new$SourceFinType := new$DestFinType;
--     new$SourceDocType := new$DestDocType;
--     new$SourceIFS := new$DestIFS;
--     new$SourceKD := new$DestKD;
--     new$SourceRegionCls := new$DestRegionCls;
--     new$SourceDocBase := new$DestDocBase;
--     new$SourceAssignmentKind := new$DestAssignmentKind;
--     new$SourceSubsidyCls := new$DestSubsidyCls;
--     new$SourceTransfertCLS := new$DestTransfertCLS;
--     new$SourceBudAllocationCls := new$DestBudAllocationCls;
--     new$SourcePayPromiseCls := new$DestPayPromiseCls;
--      
--   END IF;
--   IF (new$BuhOperationCLS IS NULL)
--   THEN 
--     GetIntConst(60, 15,new$BuhOperationCLS);
--   END IF;
--   /*    */
--   IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
--   AND (new$SourcePromise <> :old.SourcePromise)
--   OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
--   OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
--   OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
--   AND (new$DestPromise <> :old.DestPromise)
--   OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
--   OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
--     IF (new$progindex IN (63, 64, 73)) THEN
--       new$Promise := new$SourcePromise;
--          
--     ELSE 
--       IF (new$progindex IN (61, 62, 65, 75)) THEN
--         new$Promise := new$DestPromise;
--            
--       ELSE 
--         IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
--         ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
--           new$Promise := new$DestPromise;
--         END IF;
--       END IF; 
--     END IF;/*     */
--   ELSE
--     IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
--     AND (new$Promise <> :old.Promise)
--     OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
--     OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
--       IF (new$progindex IN (63, 64, 73)) THEN
--         new$SourcePromise := new$Promise;
--            
--       ELSE 
--         IF (new$progindex IN (61, 62, 65, 75)) THEN
--           new$DestPromise := new$Promise;
--              
--         ELSE 
--           IF (new$progindex in (66, 67, 76)) THEN
--             new$SourcePromise := new$Promise;
--             new$DestPromise := new$Promise;
--                
--           END IF;
--         END IF; 
--       END IF;
--     END IF;
--   END IF;
--   /*     \   */
--   IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
--   ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
--       INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
--       WHERE (fac.ID = new$SourceFacialAcc_Cls)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
--   ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
--       INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
--       WHERE (fac.ID = new$DestFacialAcc_Cls)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*       */
--   GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
--   new$Sourcetargetcls,new$Sourcetargetcls);
--   GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
--   new$Desttargetcls,new$Desttargetcls);     

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*  60 :  '   .'; source
          61 :  '      '; dest
          62 :  '   ';dest
          63 :  '    '; source
          64 :  '   '; source
          65 :  ' , ';dest
          66 :  '  ,  - '; source dest
          67 :  '   ';source
          68 :  '  \ ';dest
          69 :  '   \ '; dest
          70 :  '  \ ';source
          71 :  '   \ '; dest */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  /*     */
  if (PromiseMode$ <> 1) then
    /*          */
    if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /*          */
    if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$DestPromise)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
        
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /*     */
  if (PromiseMode$ = 1) then
    /* source  .    */
    if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
    (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule 
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* dest  .     */
    if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
    (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
          
    /*         NULL,    */
    /* source */
    if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
    (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /* dest */
    if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
    (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /*    ,     */
    if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
      new$SourcePromise := null;
      new$Promise := null;
            
    END IF;
    if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
      new$DestPromise := null;
      new$Promise := null;
            
    END IF;
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$1
      from PaymentSchedule
      where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$2
      from PaymentSchedule
      where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$SourcePromise is not null and (
    (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
    (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$SourceExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null and (
    (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
    (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$DestExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select c.AcceptDate into CapAcceptDate$
      from facialfincaption c
      where c.id = new$RecordIndex;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        CapAcceptDate$ := NULL;
    END;

    if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
      new$AcceptDate := new$AcceptDate;
    else
      RaiseException('ex_wrongacceptdate');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
-- ALTER TRIGGER TR_FACIALFINDETAIL_BU_120
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;
-- 
--    /*     */
--    IF     (new$BudgetRef <> :OLD.BudgetRef)
--       AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
--       raiseException ('Ex_CantModufyBudget');
--    END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 12.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*     ,      */ 
--   i_fintype$ := -1 ;
--   IF (new$SourceFintype IS NULL) THEN 
--     BEGIN
--       SELECT constvalue INTO i_fintype$   FROM intconst
--       WHERE (progindex=30) AND (constindex=10) ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     new$SourceFintype := i_fintype$  ;
--      
--   END IF;
--   IF (new$DestFintype IS NULL) THEN 
--     IF (i_fintype$ = -1) THEN
--       BEGIN
--         SELECT constvalue INTO i_fintype$   FROM intconst
--         WHERE (progindex=30) AND (constindex=10) ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--     END IF;
--     new$DestFintype := i_fintype$  ;
--      
--   END IF;
--   IF (new$SourceFacialAcc_CLS IS NULL) THEN 
--     new$SourceFacialAcc_CLS := 0;
--   END IF;
--   /*   */
--   IF (new$SourceKVR IS NULL) THEN 
--     new$SourceKVR := 0;
--   END IF;
--   IF (new$SourceKESR IS NULL) THEN 
--     new$SourceKESR := 0;
--   END IF;
--   IF (new$SourceKVSR IS NULL) THEN 
--     new$SourceKVSR := 0;
--   END IF;
--   IF (new$SourceKFSR IS NULL) THEN 
--     new$SourceKFSR := 0;
--   END IF;
--   IF (new$SourceKCSR IS NULL) THEN 
--     new$SourceKCSR := 0;
--   END IF;
--   IF (new$SourceSubKESR IS NULL) THEN 
--     new$SourceSubKESR := 0;
--   END IF;
--   IF (new$SourceDirectionCls IS NULL) THEN 
--     new$SourceDirectionCls := 0;
--   END IF;
--   IF (new$SourceFact IS NULL) THEN 
--     new$SourceFact := 0;
--   END IF;
--   IF (new$SourceMeansType IS NULL) THEN 
--     new$SourceMeansType := 0;
--   END IF;
--   IF (new$SourceFinSource IS NULL) THEN 
--     new$SourceFinSource := 0;
--   END IF;
--   IF (new$SourceFinType IS NULL) THEN 
--     new$SourceFinType := 0;
--   END IF;
--   IF (new$SourceDocType IS NULL) THEN 
--     new$SourceDocType := 0;
--   END IF;
--   IF (new$Sourceifs IS NULL) THEN 
--     new$Sourceifs := 0;
--   END IF;
--   IF (new$SourceKD IS NULL) THEN 
--     new$SourceKD := 0;
--   END IF;
--   IF (new$SourceFundsSource IS NULL) THEN 
--     new$SourceFundsSource := 0;
--   END IF;
--   IF (new$SourceAssignmentKind IS NULL) THEN 
--     new$SourceAssignmentKind := 0;
--   END IF;
--   IF (new$SourceRegionCLS IS NULL) THEN 
--     new$SourceRegionCLS := 0;
--   END IF;
--   IF (new$DestFacialAcc_CLS IS NULL) THEN 
--     new$DestFacialAcc_CLS := 0;
--   END IF;
--   /*   */
--   IF (new$DestKVR IS NULL) THEN 
--     new$DestKVR := 0;
--   END IF;
--   IF (new$DestKESR IS NULL) THEN 
--     new$DestKESR := 0;
--   END IF;
--   IF (new$DestKVSR IS NULL) THEN 
--     new$DestKVSR := 0;
--   END IF;
--   IF (new$DestKFSR IS NULL) THEN 
--     new$DestKFSR := 0;
--   END IF;
--   IF (new$DestKCSR IS NULL) THEN 
--     new$DestKCSR := 0;
--   END IF;
--   IF (new$DestSubKESR IS NULL) THEN 
--     new$DestSubKESR := 0;
--   END IF;
--   IF (new$DestDirectionCls IS NULL) THEN 
--     new$DestDirectionCls := 0;
--   END IF;
--   IF (new$DestFact IS NULL) THEN 
--     new$DestFact := 0;
--   END IF;
--   IF (new$DestMeansType IS NULL) THEN 
--     new$DestMeansType := 0;
--   END IF;
--   IF (new$DestFinSource IS NULL) THEN 
--     new$DestFinSource := 0;
--   END IF;
--   IF (new$DestFinType IS NULL) THEN 
--     new$DestFinType := 0;
--   END IF;
--   IF (new$DestDocType IS NULL) THEN 
--     new$DestDocType := 0;
--   END IF;
--   IF (new$Destifs IS NULL) THEN 
--     new$Destifs := 0;
--   END IF;
--   IF (new$DestKD IS NULL) THEN 
--     new$DestKD := 0;
--   END IF;
--   IF (new$DestFundsSource IS NULL) THEN 
--     new$DestFundsSource := 0;
--   END IF;
--   IF (new$DestAssignmentKind IS NULL) THEN 
--     new$DestAssignmentKind := 0;
--   END IF;
--   IF (new$DestRegionCLS IS NULL) THEN 
--     new$DestRegionCLS := 0;
--   END IF;
--   /*   :       */
--   if (new$progindex=76) then
--     new$SourceKVR := new$DestKVR;
--     new$SourceKESR := new$DestKESR;
--     new$SourceKVSR := new$DestKVSR;
--     new$SourceKFSR := new$DestKFSR;
--     new$SourceKCSR := new$DestKCSR;
--     new$SourceSubKESR := new$DestSubKESR;
--     new$SourceDirectionCls := new$DestDirectionCls;
--     new$SourceFact := new$DestFact;
--     new$SourceMeansType := new$DestMeansType;
--     new$SourceFinSource := new$DestFinSource;
--     new$SourceFinType := new$DestFinType;
--     new$SourceDocType := new$DestDocType;
--     new$SourceIFS := new$DestIFS;
--     new$SourceKD := new$DestKD;
--     new$SourceRegionCls := new$DestRegionCls;
--     new$SourceDocBase := new$DestDocBase;
--     new$SourceAssignmentKind := new$DestAssignmentKind;
--     new$SourceSubsidyCls := new$DestSubsidyCls;
--     new$SourceTransfertCLS := new$DestTransfertCLS;
--     new$SourceBudAllocationCls := new$DestBudAllocationCls;
--     new$SourcePayPromiseCls := new$DestPayPromiseCls;
--      
--   END IF;
--   IF (new$BuhOperationCLS IS NULL)
--   THEN 
--     GetIntConst(60, 15,new$BuhOperationCLS);
--   END IF;
--   /*    */
--   IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
--   AND (new$SourcePromise <> :old.SourcePromise)
--   OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
--   OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
--   OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
--   AND (new$DestPromise <> :old.DestPromise)
--   OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
--   OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
--     IF (new$progindex IN (63, 64, 73)) THEN
--       new$Promise := new$SourcePromise;
--          
--     ELSE 
--       IF (new$progindex IN (61, 62, 65, 75)) THEN
--         new$Promise := new$DestPromise;
--            
--       ELSE 
--         IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
--         ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
--           new$Promise := new$DestPromise;
--         END IF;
--       END IF; 
--     END IF;/*     */
--   ELSE
--     IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
--     AND (new$Promise <> :old.Promise)
--     OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
--     OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
--       IF (new$progindex IN (63, 64, 73)) THEN
--         new$SourcePromise := new$Promise;
--            
--       ELSE 
--         IF (new$progindex IN (61, 62, 65, 75)) THEN
--           new$DestPromise := new$Promise;
--              
--         ELSE 
--           IF (new$progindex in (66, 67, 76)) THEN
--             new$SourcePromise := new$Promise;
--             new$DestPromise := new$Promise;
--                
--           END IF;
--         END IF; 
--       END IF;
--     END IF;
--   END IF;
--   /*     \   */
--   IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
--   ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
--       INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
--       WHERE (fac.ID = new$SourceFacialAcc_Cls)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
--   ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
--       INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
--       WHERE (fac.ID = new$DestFacialAcc_Cls)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*       */
--   GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
--   new$Sourcetargetcls,new$Sourcetargetcls);
--   GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
--   new$Desttargetcls,new$Desttargetcls);     

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*  60 :  '   .'; source
--           61 :  '      '; dest
--           62 :  '   ';dest
--           63 :  '    '; source
--           64 :  '   '; source
--           65 :  ' , ';dest
--           66 :  '  ,  - '; source dest
--           67 :  '   ';source
--           68 :  '  \ ';dest
--           69 :  '   \ '; dest
--           70 :  '  \ ';source
--           71 :  '   \ '; dest */
-- 
--   /* ClsType*/
--   if ((new$ClsType is NULL) and
--   (
--   ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
--   (new$ProgIndex = 60)
--   )) then
--     new$ClsType := 1; /*       ClsType */
--       
--   else
--     if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
--     (new$ProgIndex in (63,64,66,67,68,70))) then
--       new$ClsType := 2; /*        ClsType */
--           
--     else
--       if (new$ClsType is null) then
--         new$ClsType := 0; /*  -  */
--       END IF;
--     END IF;
--   END IF;
--   IF ((new$ClsType = 0) AND
--   (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
--   (new$ProgIndex in (63,64,66,67,68,70)))
--   ) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$ClsType = 1) AND (
--   (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
--   (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
--   ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$ClsType = 2) AND (
--   (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
--   (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
--   ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   /* DestClsType*/
--   if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
--     new$DestClsType := new$ClsType;
--   END IF;
--   IF ((new$DestClsType = 0) AND
--   (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
--   (new$ProgIndex in (61,62,65,69,71)))
--   ) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$DestClsType = 1) AND (
--   (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
--   (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
--   ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$DestClsType = 2) AND (
--   (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
--   (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
--   ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  /*     */
  if (PromiseMode$ <> 1) then
    /*          */
    if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /*          */
    if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$DestPromise)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
        
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /*     */
  if (PromiseMode$ = 1) then
    /* source  .    */
    if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
    (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule 
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* dest  .     */
    if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
    (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
          
    /*         NULL,    */
    /* source */
    if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
    (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /* dest */
    if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
    (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /*    ,     */
    if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
      new$SourcePromise := null;
      new$Promise := null;
            
    END IF;
    if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
      new$DestPromise := null;
      new$Promise := null;
            
    END IF;
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$1
      from PaymentSchedule
      where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$2
      from PaymentSchedule
      where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$SourcePromise is not null and (
    (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
    (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$SourceExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null and (
    (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
    (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$DestExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select c.AcceptDate into CapAcceptDate$
      from facialfincaption c
      where c.id = new$RecordIndex;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        CapAcceptDate$ := NULL;
    END;

    if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
      new$AcceptDate := new$AcceptDate;
    else
      RaiseException('ex_wrongacceptdate');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
-- ALTER TRIGGER TR_FACIALFINDETAIL_AU_100
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;
-- 
--    /*     */
--    IF     (new$BudgetRef <> :OLD.BudgetRef)
--       AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
--       raiseException ('Ex_CantModufyBudget');
--    END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 12.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*     ,      */ 
--   i_fintype$ := -1 ;
--   IF (new$SourceFintype IS NULL) THEN 
--     BEGIN
--       SELECT constvalue INTO i_fintype$   FROM intconst
--       WHERE (progindex=30) AND (constindex=10) ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     new$SourceFintype := i_fintype$  ;
--      
--   END IF;
--   IF (new$DestFintype IS NULL) THEN 
--     IF (i_fintype$ = -1) THEN
--       BEGIN
--         SELECT constvalue INTO i_fintype$   FROM intconst
--         WHERE (progindex=30) AND (constindex=10) ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--     END IF;
--     new$DestFintype := i_fintype$  ;
--      
--   END IF;
--   IF (new$SourceFacialAcc_CLS IS NULL) THEN 
--     new$SourceFacialAcc_CLS := 0;
--   END IF;
--   /*   */
--   IF (new$SourceKVR IS NULL) THEN 
--     new$SourceKVR := 0;
--   END IF;
--   IF (new$SourceKESR IS NULL) THEN 
--     new$SourceKESR := 0;
--   END IF;
--   IF (new$SourceKVSR IS NULL) THEN 
--     new$SourceKVSR := 0;
--   END IF;
--   IF (new$SourceKFSR IS NULL) THEN 
--     new$SourceKFSR := 0;
--   END IF;
--   IF (new$SourceKCSR IS NULL) THEN 
--     new$SourceKCSR := 0;
--   END IF;
--   IF (new$SourceSubKESR IS NULL) THEN 
--     new$SourceSubKESR := 0;
--   END IF;
--   IF (new$SourceDirectionCls IS NULL) THEN 
--     new$SourceDirectionCls := 0;
--   END IF;
--   IF (new$SourceFact IS NULL) THEN 
--     new$SourceFact := 0;
--   END IF;
--   IF (new$SourceMeansType IS NULL) THEN 
--     new$SourceMeansType := 0;
--   END IF;
--   IF (new$SourceFinSource IS NULL) THEN 
--     new$SourceFinSource := 0;
--   END IF;
--   IF (new$SourceFinType IS NULL) THEN 
--     new$SourceFinType := 0;
--   END IF;
--   IF (new$SourceDocType IS NULL) THEN 
--     new$SourceDocType := 0;
--   END IF;
--   IF (new$Sourceifs IS NULL) THEN 
--     new$Sourceifs := 0;
--   END IF;
--   IF (new$SourceKD IS NULL) THEN 
--     new$SourceKD := 0;
--   END IF;
--   IF (new$SourceFundsSource IS NULL) THEN 
--     new$SourceFundsSource := 0;
--   END IF;
--   IF (new$SourceAssignmentKind IS NULL) THEN 
--     new$SourceAssignmentKind := 0;
--   END IF;
--   IF (new$SourceRegionCLS IS NULL) THEN 
--     new$SourceRegionCLS := 0;
--   END IF;
--   IF (new$DestFacialAcc_CLS IS NULL) THEN 
--     new$DestFacialAcc_CLS := 0;
--   END IF;
--   /*   */
--   IF (new$DestKVR IS NULL) THEN 
--     new$DestKVR := 0;
--   END IF;
--   IF (new$DestKESR IS NULL) THEN 
--     new$DestKESR := 0;
--   END IF;
--   IF (new$DestKVSR IS NULL) THEN 
--     new$DestKVSR := 0;
--   END IF;
--   IF (new$DestKFSR IS NULL) THEN 
--     new$DestKFSR := 0;
--   END IF;
--   IF (new$DestKCSR IS NULL) THEN 
--     new$DestKCSR := 0;
--   END IF;
--   IF (new$DestSubKESR IS NULL) THEN 
--     new$DestSubKESR := 0;
--   END IF;
--   IF (new$DestDirectionCls IS NULL) THEN 
--     new$DestDirectionCls := 0;
--   END IF;
--   IF (new$DestFact IS NULL) THEN 
--     new$DestFact := 0;
--   END IF;
--   IF (new$DestMeansType IS NULL) THEN 
--     new$DestMeansType := 0;
--   END IF;
--   IF (new$DestFinSource IS NULL) THEN 
--     new$DestFinSource := 0;
--   END IF;
--   IF (new$DestFinType IS NULL) THEN 
--     new$DestFinType := 0;
--   END IF;
--   IF (new$DestDocType IS NULL) THEN 
--     new$DestDocType := 0;
--   END IF;
--   IF (new$Destifs IS NULL) THEN 
--     new$Destifs := 0;
--   END IF;
--   IF (new$DestKD IS NULL) THEN 
--     new$DestKD := 0;
--   END IF;
--   IF (new$DestFundsSource IS NULL) THEN 
--     new$DestFundsSource := 0;
--   END IF;
--   IF (new$DestAssignmentKind IS NULL) THEN 
--     new$DestAssignmentKind := 0;
--   END IF;
--   IF (new$DestRegionCLS IS NULL) THEN 
--     new$DestRegionCLS := 0;
--   END IF;
--   /*   :       */
--   if (new$progindex=76) then
--     new$SourceKVR := new$DestKVR;
--     new$SourceKESR := new$DestKESR;
--     new$SourceKVSR := new$DestKVSR;
--     new$SourceKFSR := new$DestKFSR;
--     new$SourceKCSR := new$DestKCSR;
--     new$SourceSubKESR := new$DestSubKESR;
--     new$SourceDirectionCls := new$DestDirectionCls;
--     new$SourceFact := new$DestFact;
--     new$SourceMeansType := new$DestMeansType;
--     new$SourceFinSource := new$DestFinSource;
--     new$SourceFinType := new$DestFinType;
--     new$SourceDocType := new$DestDocType;
--     new$SourceIFS := new$DestIFS;
--     new$SourceKD := new$DestKD;
--     new$SourceRegionCls := new$DestRegionCls;
--     new$SourceDocBase := new$DestDocBase;
--     new$SourceAssignmentKind := new$DestAssignmentKind;
--     new$SourceSubsidyCls := new$DestSubsidyCls;
--     new$SourceTransfertCLS := new$DestTransfertCLS;
--     new$SourceBudAllocationCls := new$DestBudAllocationCls;
--     new$SourcePayPromiseCls := new$DestPayPromiseCls;
--      
--   END IF;
--   IF (new$BuhOperationCLS IS NULL)
--   THEN 
--     GetIntConst(60, 15,new$BuhOperationCLS);
--   END IF;
--   /*    */
--   IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
--   AND (new$SourcePromise <> :old.SourcePromise)
--   OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
--   OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
--   OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
--   AND (new$DestPromise <> :old.DestPromise)
--   OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
--   OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
--     IF (new$progindex IN (63, 64, 73)) THEN
--       new$Promise := new$SourcePromise;
--          
--     ELSE 
--       IF (new$progindex IN (61, 62, 65, 75)) THEN
--         new$Promise := new$DestPromise;
--            
--       ELSE 
--         IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
--         ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
--           new$Promise := new$DestPromise;
--         END IF;
--       END IF; 
--     END IF;/*     */
--   ELSE
--     IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
--     AND (new$Promise <> :old.Promise)
--     OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
--     OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
--       IF (new$progindex IN (63, 64, 73)) THEN
--         new$SourcePromise := new$Promise;
--            
--       ELSE 
--         IF (new$progindex IN (61, 62, 65, 75)) THEN
--           new$DestPromise := new$Promise;
--              
--         ELSE 
--           IF (new$progindex in (66, 67, 76)) THEN
--             new$SourcePromise := new$Promise;
--             new$DestPromise := new$Promise;
--                
--           END IF;
--         END IF; 
--       END IF;
--     END IF;
--   END IF;
--   /*     \   */
--   IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
--   ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
--       INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
--       WHERE (fac.ID = new$SourceFacialAcc_Cls)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
--   ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
--       INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
--       WHERE (fac.ID = new$DestFacialAcc_Cls)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*       */
--   GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
--   new$Sourcetargetcls,new$Sourcetargetcls);
--   GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
--   new$Desttargetcls,new$Desttargetcls);     

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*  60 :  '   .'; source
--           61 :  '      '; dest
--           62 :  '   ';dest
--           63 :  '    '; source
--           64 :  '   '; source
--           65 :  ' , ';dest
--           66 :  '  ,  - '; source dest
--           67 :  '   ';source
--           68 :  '  \ ';dest
--           69 :  '   \ '; dest
--           70 :  '  \ ';source
--           71 :  '   \ '; dest */
-- 
--   /* ClsType*/
--   if ((new$ClsType is NULL) and
--   (
--   ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
--   (new$ProgIndex = 60)
--   )) then
--     new$ClsType := 1; /*       ClsType */
--       
--   else
--     if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
--     (new$ProgIndex in (63,64,66,67,68,70))) then
--       new$ClsType := 2; /*        ClsType */
--           
--     else
--       if (new$ClsType is null) then
--         new$ClsType := 0; /*  -  */
--       END IF;
--     END IF;
--   END IF;
--   IF ((new$ClsType = 0) AND
--   (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
--   (new$ProgIndex in (63,64,66,67,68,70)))
--   ) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$ClsType = 1) AND (
--   (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
--   (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
--   ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$ClsType = 2) AND (
--   (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
--   (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
--   ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   /* DestClsType*/
--   if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
--     new$DestClsType := new$ClsType;
--   END IF;
--   IF ((new$DestClsType = 0) AND
--   (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
--   (new$ProgIndex in (61,62,65,69,71)))
--   ) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$DestClsType = 1) AND (
--   (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
--   (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
--   ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$DestClsType = 2) AND (
--   (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
--   (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
--   ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  /*     */
  if (PromiseMode$ <> 1) then
    /*          */
    if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /*          */
    if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$DestPromise)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
        
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /*     */
  if (PromiseMode$ = 1) then
    /* source  .    */
    if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
    (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule 
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* dest  .     */
    if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
    (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
          
    /*         NULL,    */
    /* source */
    if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
    (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /* dest */
    if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
    (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /*    ,     */
    if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
      new$SourcePromise := null;
      new$Promise := null;
            
    END IF;
    if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
      new$DestPromise := null;
      new$Promise := null;
            
    END IF;
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$1
      from PaymentSchedule
      where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$2
      from PaymentSchedule
      where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$SourcePromise is not null and (
    (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
    (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$SourceExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null and (
    (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
    (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$DestExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select c.AcceptDate into CapAcceptDate$
      from facialfincaption c
      where c.id = new$RecordIndex;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        CapAcceptDate$ := NULL;
    END;

    if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
      new$AcceptDate := new$AcceptDate;
    else
      RaiseException('ex_wrongacceptdate');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -
  NULL;
--   if (new$ClsType <> :old.ClsType) then
--     update FacialFinCaption set
--       ClsType = new$ClsType,
--       RVersion = -1
--     where
--       (id = new$RecordIndex)and(ClsType <> new$ClsType);
--   end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
-- ALTER TRIGGER TR_FACIALFINDETAIL_BU_700
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;
-- 
--    /*     */
--    IF     (new$BudgetRef <> :OLD.BudgetRef)
--       AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
--       raiseException ('Ex_CantModufyBudget');
--    END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 12.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*     ,      */ 
--   i_fintype$ := -1 ;
--   IF (new$SourceFintype IS NULL) THEN 
--     BEGIN
--       SELECT constvalue INTO i_fintype$   FROM intconst
--       WHERE (progindex=30) AND (constindex=10) ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     new$SourceFintype := i_fintype$  ;
--      
--   END IF;
--   IF (new$DestFintype IS NULL) THEN 
--     IF (i_fintype$ = -1) THEN
--       BEGIN
--         SELECT constvalue INTO i_fintype$   FROM intconst
--         WHERE (progindex=30) AND (constindex=10) ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--     END IF;
--     new$DestFintype := i_fintype$  ;
--      
--   END IF;
--   IF (new$SourceFacialAcc_CLS IS NULL) THEN 
--     new$SourceFacialAcc_CLS := 0;
--   END IF;
--   /*   */
--   IF (new$SourceKVR IS NULL) THEN 
--     new$SourceKVR := 0;
--   END IF;
--   IF (new$SourceKESR IS NULL) THEN 
--     new$SourceKESR := 0;
--   END IF;
--   IF (new$SourceKVSR IS NULL) THEN 
--     new$SourceKVSR := 0;
--   END IF;
--   IF (new$SourceKFSR IS NULL) THEN 
--     new$SourceKFSR := 0;
--   END IF;
--   IF (new$SourceKCSR IS NULL) THEN 
--     new$SourceKCSR := 0;
--   END IF;
--   IF (new$SourceSubKESR IS NULL) THEN 
--     new$SourceSubKESR := 0;
--   END IF;
--   IF (new$SourceDirectionCls IS NULL) THEN 
--     new$SourceDirectionCls := 0;
--   END IF;
--   IF (new$SourceFact IS NULL) THEN 
--     new$SourceFact := 0;
--   END IF;
--   IF (new$SourceMeansType IS NULL) THEN 
--     new$SourceMeansType := 0;
--   END IF;
--   IF (new$SourceFinSource IS NULL) THEN 
--     new$SourceFinSource := 0;
--   END IF;
--   IF (new$SourceFinType IS NULL) THEN 
--     new$SourceFinType := 0;
--   END IF;
--   IF (new$SourceDocType IS NULL) THEN 
--     new$SourceDocType := 0;
--   END IF;
--   IF (new$Sourceifs IS NULL) THEN 
--     new$Sourceifs := 0;
--   END IF;
--   IF (new$SourceKD IS NULL) THEN 
--     new$SourceKD := 0;
--   END IF;
--   IF (new$SourceFundsSource IS NULL) THEN 
--     new$SourceFundsSource := 0;
--   END IF;
--   IF (new$SourceAssignmentKind IS NULL) THEN 
--     new$SourceAssignmentKind := 0;
--   END IF;
--   IF (new$SourceRegionCLS IS NULL) THEN 
--     new$SourceRegionCLS := 0;
--   END IF;
--   IF (new$DestFacialAcc_CLS IS NULL) THEN 
--     new$DestFacialAcc_CLS := 0;
--   END IF;
--   /*   */
--   IF (new$DestKVR IS NULL) THEN 
--     new$DestKVR := 0;
--   END IF;
--   IF (new$DestKESR IS NULL) THEN 
--     new$DestKESR := 0;
--   END IF;
--   IF (new$DestKVSR IS NULL) THEN 
--     new$DestKVSR := 0;
--   END IF;
--   IF (new$DestKFSR IS NULL) THEN 
--     new$DestKFSR := 0;
--   END IF;
--   IF (new$DestKCSR IS NULL) THEN 
--     new$DestKCSR := 0;
--   END IF;
--   IF (new$DestSubKESR IS NULL) THEN 
--     new$DestSubKESR := 0;
--   END IF;
--   IF (new$DestDirectionCls IS NULL) THEN 
--     new$DestDirectionCls := 0;
--   END IF;
--   IF (new$DestFact IS NULL) THEN 
--     new$DestFact := 0;
--   END IF;
--   IF (new$DestMeansType IS NULL) THEN 
--     new$DestMeansType := 0;
--   END IF;
--   IF (new$DestFinSource IS NULL) THEN 
--     new$DestFinSource := 0;
--   END IF;
--   IF (new$DestFinType IS NULL) THEN 
--     new$DestFinType := 0;
--   END IF;
--   IF (new$DestDocType IS NULL) THEN 
--     new$DestDocType := 0;
--   END IF;
--   IF (new$Destifs IS NULL) THEN 
--     new$Destifs := 0;
--   END IF;
--   IF (new$DestKD IS NULL) THEN 
--     new$DestKD := 0;
--   END IF;
--   IF (new$DestFundsSource IS NULL) THEN 
--     new$DestFundsSource := 0;
--   END IF;
--   IF (new$DestAssignmentKind IS NULL) THEN 
--     new$DestAssignmentKind := 0;
--   END IF;
--   IF (new$DestRegionCLS IS NULL) THEN 
--     new$DestRegionCLS := 0;
--   END IF;
--   /*   :       */
--   if (new$progindex=76) then
--     new$SourceKVR := new$DestKVR;
--     new$SourceKESR := new$DestKESR;
--     new$SourceKVSR := new$DestKVSR;
--     new$SourceKFSR := new$DestKFSR;
--     new$SourceKCSR := new$DestKCSR;
--     new$SourceSubKESR := new$DestSubKESR;
--     new$SourceDirectionCls := new$DestDirectionCls;
--     new$SourceFact := new$DestFact;
--     new$SourceMeansType := new$DestMeansType;
--     new$SourceFinSource := new$DestFinSource;
--     new$SourceFinType := new$DestFinType;
--     new$SourceDocType := new$DestDocType;
--     new$SourceIFS := new$DestIFS;
--     new$SourceKD := new$DestKD;
--     new$SourceRegionCls := new$DestRegionCls;
--     new$SourceDocBase := new$DestDocBase;
--     new$SourceAssignmentKind := new$DestAssignmentKind;
--     new$SourceSubsidyCls := new$DestSubsidyCls;
--     new$SourceTransfertCLS := new$DestTransfertCLS;
--     new$SourceBudAllocationCls := new$DestBudAllocationCls;
--     new$SourcePayPromiseCls := new$DestPayPromiseCls;
--      
--   END IF;
--   IF (new$BuhOperationCLS IS NULL)
--   THEN 
--     GetIntConst(60, 15,new$BuhOperationCLS);
--   END IF;
--   /*    */
--   IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
--   AND (new$SourcePromise <> :old.SourcePromise)
--   OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
--   OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
--   OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
--   AND (new$DestPromise <> :old.DestPromise)
--   OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
--   OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
--     IF (new$progindex IN (63, 64, 73)) THEN
--       new$Promise := new$SourcePromise;
--          
--     ELSE 
--       IF (new$progindex IN (61, 62, 65, 75)) THEN
--         new$Promise := new$DestPromise;
--            
--       ELSE 
--         IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
--         ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
--           new$Promise := new$DestPromise;
--         END IF;
--       END IF; 
--     END IF;/*     */
--   ELSE
--     IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
--     AND (new$Promise <> :old.Promise)
--     OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
--     OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
--       IF (new$progindex IN (63, 64, 73)) THEN
--         new$SourcePromise := new$Promise;
--            
--       ELSE 
--         IF (new$progindex IN (61, 62, 65, 75)) THEN
--           new$DestPromise := new$Promise;
--              
--         ELSE 
--           IF (new$progindex in (66, 67, 76)) THEN
--             new$SourcePromise := new$Promise;
--             new$DestPromise := new$Promise;
--                
--           END IF;
--         END IF; 
--       END IF;
--     END IF;
--   END IF;
--   /*     \   */
--   IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
--   ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
--       INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
--       WHERE (fac.ID = new$SourceFacialAcc_Cls)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
--   ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
--       INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
--       WHERE (fac.ID = new$DestFacialAcc_Cls)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*       */
--   GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
--   new$Sourcetargetcls,new$Sourcetargetcls);
--   GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
--   new$Desttargetcls,new$Desttargetcls);     

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*  60 :  '   .'; source
--           61 :  '      '; dest
--           62 :  '   ';dest
--           63 :  '    '; source
--           64 :  '   '; source
--           65 :  ' , ';dest
--           66 :  '  ,  - '; source dest
--           67 :  '   ';source
--           68 :  '  \ ';dest
--           69 :  '   \ '; dest
--           70 :  '  \ ';source
--           71 :  '   \ '; dest */
-- 
--   /* ClsType*/
--   if ((new$ClsType is NULL) and
--   (
--   ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
--   (new$ProgIndex = 60)
--   )) then
--     new$ClsType := 1; /*       ClsType */
--       
--   else
--     if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
--     (new$ProgIndex in (63,64,66,67,68,70))) then
--       new$ClsType := 2; /*        ClsType */
--           
--     else
--       if (new$ClsType is null) then
--         new$ClsType := 0; /*  -  */
--       END IF;
--     END IF;
--   END IF;
--   IF ((new$ClsType = 0) AND
--   (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
--   (new$ProgIndex in (63,64,66,67,68,70)))
--   ) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$ClsType = 1) AND (
--   (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
--   (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
--   ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$ClsType = 2) AND (
--   (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
--   (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
--   ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   /* DestClsType*/
--   if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
--     new$DestClsType := new$ClsType;
--   END IF;
--   IF ((new$DestClsType = 0) AND
--   (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
--   (new$ProgIndex in (61,62,65,69,71)))
--   ) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$DestClsType = 1) AND (
--   (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
--   (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
--   ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$DestClsType = 2) AND (
--   (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
--   (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
--   ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  /*     */
  if (PromiseMode$ <> 1) then
    /*          */
    if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /*          */
    if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$DestPromise)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
        
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /*     */
  if (PromiseMode$ = 1) then
    /* source  .    */
    if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
    (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule 
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* dest  .     */
    if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
    (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
          
    /*         NULL,    */
    /* source */
    if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
    (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /* dest */
    if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
    (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /*    ,     */
    if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
      new$SourcePromise := null;
      new$Promise := null;
            
    END IF;
    if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
      new$DestPromise := null;
      new$Promise := null;
            
    END IF;
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$1
      from PaymentSchedule
      where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$2
      from PaymentSchedule
      where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$SourcePromise is not null and (
    (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
    (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$SourceExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null and (
    (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
    (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$DestExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select c.AcceptDate into CapAcceptDate$
      from facialfincaption c
      where c.id = new$RecordIndex;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        CapAcceptDate$ := NULL;
    END;

    if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
      new$AcceptDate := new$AcceptDate;
    else
      RaiseException('ex_wrongacceptdate');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -
  NULL;
--    IF (new$RVersion IS NULL) THEN
--       new$RVersion := 1;
--    ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
--       new$RVersion := :OLD.RVersion;
--    ELSE
--       new$RVersion := :OLD.RVersion + 1;
--    END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -
  NULL;
--   if (new$ClsType <> :old.ClsType) then
--     update FacialFinCaption set
--       ClsType = new$ClsType,
--       RVersion = -1
--     where
--       (id = new$RecordIndex)and(ClsType <> new$ClsType);
--   end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
-- ALTER TRIGGER TR_FACIALFINDETAIL_BU_200
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;
-- 
--    /*     */
--    IF     (new$BudgetRef <> :OLD.BudgetRef)
--       AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
--       raiseException ('Ex_CantModufyBudget');
--    END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 12.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*     ,      */ 
--   i_fintype$ := -1 ;
--   IF (new$SourceFintype IS NULL) THEN 
--     BEGIN
--       SELECT constvalue INTO i_fintype$   FROM intconst
--       WHERE (progindex=30) AND (constindex=10) ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     new$SourceFintype := i_fintype$  ;
--      
--   END IF;
--   IF (new$DestFintype IS NULL) THEN 
--     IF (i_fintype$ = -1) THEN
--       BEGIN
--         SELECT constvalue INTO i_fintype$   FROM intconst
--         WHERE (progindex=30) AND (constindex=10) ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--     END IF;
--     new$DestFintype := i_fintype$  ;
--      
--   END IF;
--   IF (new$SourceFacialAcc_CLS IS NULL) THEN 
--     new$SourceFacialAcc_CLS := 0;
--   END IF;
--   /*   */
--   IF (new$SourceKVR IS NULL) THEN 
--     new$SourceKVR := 0;
--   END IF;
--   IF (new$SourceKESR IS NULL) THEN 
--     new$SourceKESR := 0;
--   END IF;
--   IF (new$SourceKVSR IS NULL) THEN 
--     new$SourceKVSR := 0;
--   END IF;
--   IF (new$SourceKFSR IS NULL) THEN 
--     new$SourceKFSR := 0;
--   END IF;
--   IF (new$SourceKCSR IS NULL) THEN 
--     new$SourceKCSR := 0;
--   END IF;
--   IF (new$SourceSubKESR IS NULL) THEN 
--     new$SourceSubKESR := 0;
--   END IF;
--   IF (new$SourceDirectionCls IS NULL) THEN 
--     new$SourceDirectionCls := 0;
--   END IF;
--   IF (new$SourceFact IS NULL) THEN 
--     new$SourceFact := 0;
--   END IF;
--   IF (new$SourceMeansType IS NULL) THEN 
--     new$SourceMeansType := 0;
--   END IF;
--   IF (new$SourceFinSource IS NULL) THEN 
--     new$SourceFinSource := 0;
--   END IF;
--   IF (new$SourceFinType IS NULL) THEN 
--     new$SourceFinType := 0;
--   END IF;
--   IF (new$SourceDocType IS NULL) THEN 
--     new$SourceDocType := 0;
--   END IF;
--   IF (new$Sourceifs IS NULL) THEN 
--     new$Sourceifs := 0;
--   END IF;
--   IF (new$SourceKD IS NULL) THEN 
--     new$SourceKD := 0;
--   END IF;
--   IF (new$SourceFundsSource IS NULL) THEN 
--     new$SourceFundsSource := 0;
--   END IF;
--   IF (new$SourceAssignmentKind IS NULL) THEN 
--     new$SourceAssignmentKind := 0;
--   END IF;
--   IF (new$SourceRegionCLS IS NULL) THEN 
--     new$SourceRegionCLS := 0;
--   END IF;
--   IF (new$DestFacialAcc_CLS IS NULL) THEN 
--     new$DestFacialAcc_CLS := 0;
--   END IF;
--   /*   */
--   IF (new$DestKVR IS NULL) THEN 
--     new$DestKVR := 0;
--   END IF;
--   IF (new$DestKESR IS NULL) THEN 
--     new$DestKESR := 0;
--   END IF;
--   IF (new$DestKVSR IS NULL) THEN 
--     new$DestKVSR := 0;
--   END IF;
--   IF (new$DestKFSR IS NULL) THEN 
--     new$DestKFSR := 0;
--   END IF;
--   IF (new$DestKCSR IS NULL) THEN 
--     new$DestKCSR := 0;
--   END IF;
--   IF (new$DestSubKESR IS NULL) THEN 
--     new$DestSubKESR := 0;
--   END IF;
--   IF (new$DestDirectionCls IS NULL) THEN 
--     new$DestDirectionCls := 0;
--   END IF;
--   IF (new$DestFact IS NULL) THEN 
--     new$DestFact := 0;
--   END IF;
--   IF (new$DestMeansType IS NULL) THEN 
--     new$DestMeansType := 0;
--   END IF;
--   IF (new$DestFinSource IS NULL) THEN 
--     new$DestFinSource := 0;
--   END IF;
--   IF (new$DestFinType IS NULL) THEN 
--     new$DestFinType := 0;
--   END IF;
--   IF (new$DestDocType IS NULL) THEN 
--     new$DestDocType := 0;
--   END IF;
--   IF (new$Destifs IS NULL) THEN 
--     new$Destifs := 0;
--   END IF;
--   IF (new$DestKD IS NULL) THEN 
--     new$DestKD := 0;
--   END IF;
--   IF (new$DestFundsSource IS NULL) THEN 
--     new$DestFundsSource := 0;
--   END IF;
--   IF (new$DestAssignmentKind IS NULL) THEN 
--     new$DestAssignmentKind := 0;
--   END IF;
--   IF (new$DestRegionCLS IS NULL) THEN 
--     new$DestRegionCLS := 0;
--   END IF;
--   /*   :       */
--   if (new$progindex=76) then
--     new$SourceKVR := new$DestKVR;
--     new$SourceKESR := new$DestKESR;
--     new$SourceKVSR := new$DestKVSR;
--     new$SourceKFSR := new$DestKFSR;
--     new$SourceKCSR := new$DestKCSR;
--     new$SourceSubKESR := new$DestSubKESR;
--     new$SourceDirectionCls := new$DestDirectionCls;
--     new$SourceFact := new$DestFact;
--     new$SourceMeansType := new$DestMeansType;
--     new$SourceFinSource := new$DestFinSource;
--     new$SourceFinType := new$DestFinType;
--     new$SourceDocType := new$DestDocType;
--     new$SourceIFS := new$DestIFS;
--     new$SourceKD := new$DestKD;
--     new$SourceRegionCls := new$DestRegionCls;
--     new$SourceDocBase := new$DestDocBase;
--     new$SourceAssignmentKind := new$DestAssignmentKind;
--     new$SourceSubsidyCls := new$DestSubsidyCls;
--     new$SourceTransfertCLS := new$DestTransfertCLS;
--     new$SourceBudAllocationCls := new$DestBudAllocationCls;
--     new$SourcePayPromiseCls := new$DestPayPromiseCls;
--      
--   END IF;
--   IF (new$BuhOperationCLS IS NULL)
--   THEN 
--     GetIntConst(60, 15,new$BuhOperationCLS);
--   END IF;
--   /*    */
--   IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
--   AND (new$SourcePromise <> :old.SourcePromise)
--   OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
--   OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
--   OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
--   AND (new$DestPromise <> :old.DestPromise)
--   OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
--   OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
--     IF (new$progindex IN (63, 64, 73)) THEN
--       new$Promise := new$SourcePromise;
--          
--     ELSE 
--       IF (new$progindex IN (61, 62, 65, 75)) THEN
--         new$Promise := new$DestPromise;
--            
--       ELSE 
--         IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
--         ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
--           new$Promise := new$DestPromise;
--         END IF;
--       END IF; 
--     END IF;/*     */
--   ELSE
--     IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
--     AND (new$Promise <> :old.Promise)
--     OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
--     OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
--       IF (new$progindex IN (63, 64, 73)) THEN
--         new$SourcePromise := new$Promise;
--            
--       ELSE 
--         IF (new$progindex IN (61, 62, 65, 75)) THEN
--           new$DestPromise := new$Promise;
--              
--         ELSE 
--           IF (new$progindex in (66, 67, 76)) THEN
--             new$SourcePromise := new$Promise;
--             new$DestPromise := new$Promise;
--                
--           END IF;
--         END IF; 
--       END IF;
--     END IF;
--   END IF;
--   /*     \   */
--   IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
--   ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
--       INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
--       WHERE (fac.ID = new$SourceFacialAcc_Cls)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
--   ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
--       INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
--       WHERE (fac.ID = new$DestFacialAcc_Cls)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*       */
--   GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
--   new$Sourcetargetcls,new$Sourcetargetcls);
--   GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
--   new$Desttargetcls,new$Desttargetcls);     

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*  60 :  '   .'; source
--           61 :  '      '; dest
--           62 :  '   ';dest
--           63 :  '    '; source
--           64 :  '   '; source
--           65 :  ' , ';dest
--           66 :  '  ,  - '; source dest
--           67 :  '   ';source
--           68 :  '  \ ';dest
--           69 :  '   \ '; dest
--           70 :  '  \ ';source
--           71 :  '   \ '; dest */
-- 
--   /* ClsType*/
--   if ((new$ClsType is NULL) and
--   (
--   ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
--   (new$ProgIndex = 60)
--   )) then
--     new$ClsType := 1; /*       ClsType */
--       
--   else
--     if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
--     (new$ProgIndex in (63,64,66,67,68,70))) then
--       new$ClsType := 2; /*        ClsType */
--           
--     else
--       if (new$ClsType is null) then
--         new$ClsType := 0; /*  -  */
--       END IF;
--     END IF;
--   END IF;
--   IF ((new$ClsType = 0) AND
--   (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
--   (new$ProgIndex in (63,64,66,67,68,70)))
--   ) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$ClsType = 1) AND (
--   (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
--   (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
--   ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$ClsType = 2) AND (
--   (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
--   (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
--   ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   /* DestClsType*/
--   if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
--     new$DestClsType := new$ClsType;
--   END IF;
--   IF ((new$DestClsType = 0) AND
--   (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
--   (new$ProgIndex in (61,62,65,69,71)))
--   ) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$DestClsType = 1) AND (
--   (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
--   (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
--   ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$DestClsType = 2) AND (
--   (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
--   (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
--   ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -
  NULL;
--   /*       */
--   GetIntConst(30, 15,PromiseMode$);
--   /*     */
--   if (PromiseMode$ <> 1) then
--     /*          */
--     if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$SOURCEPROMISE)
--       ;
--       /*    ,  */
--       if (Promise_Count$ = 0) then
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--     /*          */
--     if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$DestPromise)
--       ;
--       /*    ,  */
--       if (Promise_Count$ = 0) then
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--         
--     END IF;/* end  PromiseMode <> 1*/
--   END IF;
--   /*     */
--   if (PromiseMode$ = 1) then
--     /* source  .    */
--     if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
--     (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
--       select max(InnerPromiseNum) 
--       into BPInnerNum$           from PaymentSchedule 
--       where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum$ <> 0) then
--         new$SourceBudgetPromise := BPInnerNum$;
--                 
--       else
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--     /* dest  .     */
--     if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
--     (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
--       select max(InnerPromiseNum) 
--       into BPInnerNum$           from PaymentSchedule
--       where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum$ <> 0) then
--         new$DestBudgetPromise := BPInnerNum$;
--                 
--       else
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--           
--     /*         NULL,    */
--     /* source */
--     if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
--     (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
--       BEGIN
--         select ANumber 
--         into BPInnerNum$           from PaymentSchedule
--         where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       new$SourcePromise := BPInnerNum$;
--       new$Promise := BPInnerNum$;
--             
--     END IF;
--     /* dest */
--     if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
--     (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
--       BEGIN
--         select ANumber 
--         into BPInnerNum$           from PaymentSchedule
--         where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       new$DestPromise := BPInnerNum$;
--       new$Promise := BPInnerNum$;
--             
--     END IF;
--     /*    ,     */
--     if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
--       new$SourcePromise := null;
--       new$Promise := null;
--             
--     END IF;
--     if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
--       new$DestPromise := null;
--       new$Promise := null;
--             
--     END IF;
--     if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$1
--       from PaymentSchedule
--       where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$1<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Source */
--         select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
--         where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');      
--       END IF;
--     END IF;
--     if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$2
--       from PaymentSchedule
--       where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$2<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Dest */
--         select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
--         where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');      
--       END IF;    
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$SourcePromise is not null and (
    (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
    (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$SourceExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null and (
    (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
    (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$DestExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select c.AcceptDate into CapAcceptDate$
      from facialfincaption c
      where c.id = new$RecordIndex;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        CapAcceptDate$ := NULL;
    END;

    if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
      new$AcceptDate := new$AcceptDate;
    else
      RaiseException('ex_wrongacceptdate');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -
  NULL;
--    IF (new$RVersion IS NULL) THEN
--       new$RVersion := 1;
--    ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
--       new$RVersion := :OLD.RVersion;
--    ELSE
--       new$RVersion := :OLD.RVersion + 1;
--    END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -
  NULL;
--   if (new$ClsType <> :old.ClsType) then
--     update FacialFinCaption set
--       ClsType = new$ClsType,
--       RVersion = -1
--     where
--       (id = new$RecordIndex)and(ClsType <> new$ClsType);
--   end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
-- ALTER TRIGGER TR_FACIALFINDETAIL_BU_300
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;
-- 
--    /*     */
--    IF     (new$BudgetRef <> :OLD.BudgetRef)
--       AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
--       raiseException ('Ex_CantModufyBudget');
--    END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 12.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*     ,      */ 
--   i_fintype$ := -1 ;
--   IF (new$SourceFintype IS NULL) THEN 
--     BEGIN
--       SELECT constvalue INTO i_fintype$   FROM intconst
--       WHERE (progindex=30) AND (constindex=10) ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     new$SourceFintype := i_fintype$  ;
--      
--   END IF;
--   IF (new$DestFintype IS NULL) THEN 
--     IF (i_fintype$ = -1) THEN
--       BEGIN
--         SELECT constvalue INTO i_fintype$   FROM intconst
--         WHERE (progindex=30) AND (constindex=10) ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--     END IF;
--     new$DestFintype := i_fintype$  ;
--      
--   END IF;
--   IF (new$SourceFacialAcc_CLS IS NULL) THEN 
--     new$SourceFacialAcc_CLS := 0;
--   END IF;
--   /*   */
--   IF (new$SourceKVR IS NULL) THEN 
--     new$SourceKVR := 0;
--   END IF;
--   IF (new$SourceKESR IS NULL) THEN 
--     new$SourceKESR := 0;
--   END IF;
--   IF (new$SourceKVSR IS NULL) THEN 
--     new$SourceKVSR := 0;
--   END IF;
--   IF (new$SourceKFSR IS NULL) THEN 
--     new$SourceKFSR := 0;
--   END IF;
--   IF (new$SourceKCSR IS NULL) THEN 
--     new$SourceKCSR := 0;
--   END IF;
--   IF (new$SourceSubKESR IS NULL) THEN 
--     new$SourceSubKESR := 0;
--   END IF;
--   IF (new$SourceDirectionCls IS NULL) THEN 
--     new$SourceDirectionCls := 0;
--   END IF;
--   IF (new$SourceFact IS NULL) THEN 
--     new$SourceFact := 0;
--   END IF;
--   IF (new$SourceMeansType IS NULL) THEN 
--     new$SourceMeansType := 0;
--   END IF;
--   IF (new$SourceFinSource IS NULL) THEN 
--     new$SourceFinSource := 0;
--   END IF;
--   IF (new$SourceFinType IS NULL) THEN 
--     new$SourceFinType := 0;
--   END IF;
--   IF (new$SourceDocType IS NULL) THEN 
--     new$SourceDocType := 0;
--   END IF;
--   IF (new$Sourceifs IS NULL) THEN 
--     new$Sourceifs := 0;
--   END IF;
--   IF (new$SourceKD IS NULL) THEN 
--     new$SourceKD := 0;
--   END IF;
--   IF (new$SourceFundsSource IS NULL) THEN 
--     new$SourceFundsSource := 0;
--   END IF;
--   IF (new$SourceAssignmentKind IS NULL) THEN 
--     new$SourceAssignmentKind := 0;
--   END IF;
--   IF (new$SourceRegionCLS IS NULL) THEN 
--     new$SourceRegionCLS := 0;
--   END IF;
--   IF (new$DestFacialAcc_CLS IS NULL) THEN 
--     new$DestFacialAcc_CLS := 0;
--   END IF;
--   /*   */
--   IF (new$DestKVR IS NULL) THEN 
--     new$DestKVR := 0;
--   END IF;
--   IF (new$DestKESR IS NULL) THEN 
--     new$DestKESR := 0;
--   END IF;
--   IF (new$DestKVSR IS NULL) THEN 
--     new$DestKVSR := 0;
--   END IF;
--   IF (new$DestKFSR IS NULL) THEN 
--     new$DestKFSR := 0;
--   END IF;
--   IF (new$DestKCSR IS NULL) THEN 
--     new$DestKCSR := 0;
--   END IF;
--   IF (new$DestSubKESR IS NULL) THEN 
--     new$DestSubKESR := 0;
--   END IF;
--   IF (new$DestDirectionCls IS NULL) THEN 
--     new$DestDirectionCls := 0;
--   END IF;
--   IF (new$DestFact IS NULL) THEN 
--     new$DestFact := 0;
--   END IF;
--   IF (new$DestMeansType IS NULL) THEN 
--     new$DestMeansType := 0;
--   END IF;
--   IF (new$DestFinSource IS NULL) THEN 
--     new$DestFinSource := 0;
--   END IF;
--   IF (new$DestFinType IS NULL) THEN 
--     new$DestFinType := 0;
--   END IF;
--   IF (new$DestDocType IS NULL) THEN 
--     new$DestDocType := 0;
--   END IF;
--   IF (new$Destifs IS NULL) THEN 
--     new$Destifs := 0;
--   END IF;
--   IF (new$DestKD IS NULL) THEN 
--     new$DestKD := 0;
--   END IF;
--   IF (new$DestFundsSource IS NULL) THEN 
--     new$DestFundsSource := 0;
--   END IF;
--   IF (new$DestAssignmentKind IS NULL) THEN 
--     new$DestAssignmentKind := 0;
--   END IF;
--   IF (new$DestRegionCLS IS NULL) THEN 
--     new$DestRegionCLS := 0;
--   END IF;
--   /*   :       */
--   if (new$progindex=76) then
--     new$SourceKVR := new$DestKVR;
--     new$SourceKESR := new$DestKESR;
--     new$SourceKVSR := new$DestKVSR;
--     new$SourceKFSR := new$DestKFSR;
--     new$SourceKCSR := new$DestKCSR;
--     new$SourceSubKESR := new$DestSubKESR;
--     new$SourceDirectionCls := new$DestDirectionCls;
--     new$SourceFact := new$DestFact;
--     new$SourceMeansType := new$DestMeansType;
--     new$SourceFinSource := new$DestFinSource;
--     new$SourceFinType := new$DestFinType;
--     new$SourceDocType := new$DestDocType;
--     new$SourceIFS := new$DestIFS;
--     new$SourceKD := new$DestKD;
--     new$SourceRegionCls := new$DestRegionCls;
--     new$SourceDocBase := new$DestDocBase;
--     new$SourceAssignmentKind := new$DestAssignmentKind;
--     new$SourceSubsidyCls := new$DestSubsidyCls;
--     new$SourceTransfertCLS := new$DestTransfertCLS;
--     new$SourceBudAllocationCls := new$DestBudAllocationCls;
--     new$SourcePayPromiseCls := new$DestPayPromiseCls;
--      
--   END IF;
--   IF (new$BuhOperationCLS IS NULL)
--   THEN 
--     GetIntConst(60, 15,new$BuhOperationCLS);
--   END IF;
--   /*    */
--   IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
--   AND (new$SourcePromise <> :old.SourcePromise)
--   OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
--   OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
--   OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
--   AND (new$DestPromise <> :old.DestPromise)
--   OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
--   OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
--     IF (new$progindex IN (63, 64, 73)) THEN
--       new$Promise := new$SourcePromise;
--          
--     ELSE 
--       IF (new$progindex IN (61, 62, 65, 75)) THEN
--         new$Promise := new$DestPromise;
--            
--       ELSE 
--         IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
--         ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
--           new$Promise := new$DestPromise;
--         END IF;
--       END IF; 
--     END IF;/*     */
--   ELSE
--     IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
--     AND (new$Promise <> :old.Promise)
--     OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
--     OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
--       IF (new$progindex IN (63, 64, 73)) THEN
--         new$SourcePromise := new$Promise;
--            
--       ELSE 
--         IF (new$progindex IN (61, 62, 65, 75)) THEN
--           new$DestPromise := new$Promise;
--              
--         ELSE 
--           IF (new$progindex in (66, 67, 76)) THEN
--             new$SourcePromise := new$Promise;
--             new$DestPromise := new$Promise;
--                
--           END IF;
--         END IF; 
--       END IF;
--     END IF;
--   END IF;
--   /*     \   */
--   IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
--   ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
--       INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
--       WHERE (fac.ID = new$SourceFacialAcc_Cls)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
--   ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
--       INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
--       WHERE (fac.ID = new$DestFacialAcc_Cls)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*       */
--   GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
--   new$Sourcetargetcls,new$Sourcetargetcls);
--   GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
--   new$Desttargetcls,new$Desttargetcls);     

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*  60 :  '   .'; source
--           61 :  '      '; dest
--           62 :  '   ';dest
--           63 :  '    '; source
--           64 :  '   '; source
--           65 :  ' , ';dest
--           66 :  '  ,  - '; source dest
--           67 :  '   ';source
--           68 :  '  \ ';dest
--           69 :  '   \ '; dest
--           70 :  '  \ ';source
--           71 :  '   \ '; dest */
-- 
--   /* ClsType*/
--   if ((new$ClsType is NULL) and
--   (
--   ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
--   (new$ProgIndex = 60)
--   )) then
--     new$ClsType := 1; /*       ClsType */
--       
--   else
--     if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
--     (new$ProgIndex in (63,64,66,67,68,70))) then
--       new$ClsType := 2; /*        ClsType */
--           
--     else
--       if (new$ClsType is null) then
--         new$ClsType := 0; /*  -  */
--       END IF;
--     END IF;
--   END IF;
--   IF ((new$ClsType = 0) AND
--   (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
--   (new$ProgIndex in (63,64,66,67,68,70)))
--   ) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$ClsType = 1) AND (
--   (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
--   (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
--   ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$ClsType = 2) AND (
--   (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
--   (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
--   ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   /* DestClsType*/
--   if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
--     new$DestClsType := new$ClsType;
--   END IF;
--   IF ((new$DestClsType = 0) AND
--   (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
--   (new$ProgIndex in (61,62,65,69,71)))
--   ) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$DestClsType = 1) AND (
--   (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
--   (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
--   ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$DestClsType = 2) AND (
--   (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
--   (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
--   ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -
  NULL;
--   /*       */
--   GetIntConst(30, 15,PromiseMode$);
--   /*     */
--   if (PromiseMode$ <> 1) then
--     /*          */
--     if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$SOURCEPROMISE)
--       ;
--       /*    ,  */
--       if (Promise_Count$ = 0) then
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--     /*          */
--     if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$DestPromise)
--       ;
--       /*    ,  */
--       if (Promise_Count$ = 0) then
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--         
--     END IF;/* end  PromiseMode <> 1*/
--   END IF;
--   /*     */
--   if (PromiseMode$ = 1) then
--     /* source  .    */
--     if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
--     (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
--       select max(InnerPromiseNum) 
--       into BPInnerNum$           from PaymentSchedule 
--       where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum$ <> 0) then
--         new$SourceBudgetPromise := BPInnerNum$;
--                 
--       else
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--     /* dest  .     */
--     if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
--     (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
--       select max(InnerPromiseNum) 
--       into BPInnerNum$           from PaymentSchedule
--       where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum$ <> 0) then
--         new$DestBudgetPromise := BPInnerNum$;
--                 
--       else
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--           
--     /*         NULL,    */
--     /* source */
--     if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
--     (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
--       BEGIN
--         select ANumber 
--         into BPInnerNum$           from PaymentSchedule
--         where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       new$SourcePromise := BPInnerNum$;
--       new$Promise := BPInnerNum$;
--             
--     END IF;
--     /* dest */
--     if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
--     (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
--       BEGIN
--         select ANumber 
--         into BPInnerNum$           from PaymentSchedule
--         where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       new$DestPromise := BPInnerNum$;
--       new$Promise := BPInnerNum$;
--             
--     END IF;
--     /*    ,     */
--     if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
--       new$SourcePromise := null;
--       new$Promise := null;
--             
--     END IF;
--     if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
--       new$DestPromise := null;
--       new$Promise := null;
--             
--     END IF;
--     if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$1
--       from PaymentSchedule
--       where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$1<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Source */
--         select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
--         where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');      
--       END IF;
--     END IF;
--     if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$2
--       from PaymentSchedule
--       where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$2<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Dest */
--         select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
--         where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');      
--       END IF;    
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$SourcePromise is not null and (
    (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
    (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$SourceExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null and (
    (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
    (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$DestExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -
  NULL;
--   /*          (  ) */
--   if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
--     BEGIN
--       select c.AcceptDate into CapAcceptDate$
--       from facialfincaption c
--       where c.id = new$RecordIndex;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN
--         CapAcceptDate$ := NULL;
--     END;
-- 
--     if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
--       new$AcceptDate := new$AcceptDate;
--     else
--       RaiseException('ex_wrongacceptdate');
--     end if;
--   end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -
  NULL;
--    IF (new$RVersion IS NULL) THEN
--       new$RVersion := 1;
--    ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
--       new$RVersion := :OLD.RVersion;
--    ELSE
--       new$RVersion := :OLD.RVersion + 1;
--    END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -
  NULL;
--   if (new$ClsType <> :old.ClsType) then
--     update FacialFinCaption set
--       ClsType = new$ClsType,
--       RVersion = -1
--     where
--       (id = new$RecordIndex)and(ClsType <> new$ClsType);
--   end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
-- ALTER TRIGGER Tr_FacialFinDetail_AU_500
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;
-- 
--    /*     */
--    IF     (new$BudgetRef <> :OLD.BudgetRef)
--       AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
--       raiseException ('Ex_CantModufyBudget');
--    END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 12.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*     ,      */ 
--   i_fintype$ := -1 ;
--   IF (new$SourceFintype IS NULL) THEN 
--     BEGIN
--       SELECT constvalue INTO i_fintype$   FROM intconst
--       WHERE (progindex=30) AND (constindex=10) ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     new$SourceFintype := i_fintype$  ;
--      
--   END IF;
--   IF (new$DestFintype IS NULL) THEN 
--     IF (i_fintype$ = -1) THEN
--       BEGIN
--         SELECT constvalue INTO i_fintype$   FROM intconst
--         WHERE (progindex=30) AND (constindex=10) ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--     END IF;
--     new$DestFintype := i_fintype$  ;
--      
--   END IF;
--   IF (new$SourceFacialAcc_CLS IS NULL) THEN 
--     new$SourceFacialAcc_CLS := 0;
--   END IF;
--   /*   */
--   IF (new$SourceKVR IS NULL) THEN 
--     new$SourceKVR := 0;
--   END IF;
--   IF (new$SourceKESR IS NULL) THEN 
--     new$SourceKESR := 0;
--   END IF;
--   IF (new$SourceKVSR IS NULL) THEN 
--     new$SourceKVSR := 0;
--   END IF;
--   IF (new$SourceKFSR IS NULL) THEN 
--     new$SourceKFSR := 0;
--   END IF;
--   IF (new$SourceKCSR IS NULL) THEN 
--     new$SourceKCSR := 0;
--   END IF;
--   IF (new$SourceSubKESR IS NULL) THEN 
--     new$SourceSubKESR := 0;
--   END IF;
--   IF (new$SourceDirectionCls IS NULL) THEN 
--     new$SourceDirectionCls := 0;
--   END IF;
--   IF (new$SourceFact IS NULL) THEN 
--     new$SourceFact := 0;
--   END IF;
--   IF (new$SourceMeansType IS NULL) THEN 
--     new$SourceMeansType := 0;
--   END IF;
--   IF (new$SourceFinSource IS NULL) THEN 
--     new$SourceFinSource := 0;
--   END IF;
--   IF (new$SourceFinType IS NULL) THEN 
--     new$SourceFinType := 0;
--   END IF;
--   IF (new$SourceDocType IS NULL) THEN 
--     new$SourceDocType := 0;
--   END IF;
--   IF (new$Sourceifs IS NULL) THEN 
--     new$Sourceifs := 0;
--   END IF;
--   IF (new$SourceKD IS NULL) THEN 
--     new$SourceKD := 0;
--   END IF;
--   IF (new$SourceFundsSource IS NULL) THEN 
--     new$SourceFundsSource := 0;
--   END IF;
--   IF (new$SourceAssignmentKind IS NULL) THEN 
--     new$SourceAssignmentKind := 0;
--   END IF;
--   IF (new$SourceRegionCLS IS NULL) THEN 
--     new$SourceRegionCLS := 0;
--   END IF;
--   IF (new$DestFacialAcc_CLS IS NULL) THEN 
--     new$DestFacialAcc_CLS := 0;
--   END IF;
--   /*   */
--   IF (new$DestKVR IS NULL) THEN 
--     new$DestKVR := 0;
--   END IF;
--   IF (new$DestKESR IS NULL) THEN 
--     new$DestKESR := 0;
--   END IF;
--   IF (new$DestKVSR IS NULL) THEN 
--     new$DestKVSR := 0;
--   END IF;
--   IF (new$DestKFSR IS NULL) THEN 
--     new$DestKFSR := 0;
--   END IF;
--   IF (new$DestKCSR IS NULL) THEN 
--     new$DestKCSR := 0;
--   END IF;
--   IF (new$DestSubKESR IS NULL) THEN 
--     new$DestSubKESR := 0;
--   END IF;
--   IF (new$DestDirectionCls IS NULL) THEN 
--     new$DestDirectionCls := 0;
--   END IF;
--   IF (new$DestFact IS NULL) THEN 
--     new$DestFact := 0;
--   END IF;
--   IF (new$DestMeansType IS NULL) THEN 
--     new$DestMeansType := 0;
--   END IF;
--   IF (new$DestFinSource IS NULL) THEN 
--     new$DestFinSource := 0;
--   END IF;
--   IF (new$DestFinType IS NULL) THEN 
--     new$DestFinType := 0;
--   END IF;
--   IF (new$DestDocType IS NULL) THEN 
--     new$DestDocType := 0;
--   END IF;
--   IF (new$Destifs IS NULL) THEN 
--     new$Destifs := 0;
--   END IF;
--   IF (new$DestKD IS NULL) THEN 
--     new$DestKD := 0;
--   END IF;
--   IF (new$DestFundsSource IS NULL) THEN 
--     new$DestFundsSource := 0;
--   END IF;
--   IF (new$DestAssignmentKind IS NULL) THEN 
--     new$DestAssignmentKind := 0;
--   END IF;
--   IF (new$DestRegionCLS IS NULL) THEN 
--     new$DestRegionCLS := 0;
--   END IF;
--   /*   :       */
--   if (new$progindex=76) then
--     new$SourceKVR := new$DestKVR;
--     new$SourceKESR := new$DestKESR;
--     new$SourceKVSR := new$DestKVSR;
--     new$SourceKFSR := new$DestKFSR;
--     new$SourceKCSR := new$DestKCSR;
--     new$SourceSubKESR := new$DestSubKESR;
--     new$SourceDirectionCls := new$DestDirectionCls;
--     new$SourceFact := new$DestFact;
--     new$SourceMeansType := new$DestMeansType;
--     new$SourceFinSource := new$DestFinSource;
--     new$SourceFinType := new$DestFinType;
--     new$SourceDocType := new$DestDocType;
--     new$SourceIFS := new$DestIFS;
--     new$SourceKD := new$DestKD;
--     new$SourceRegionCls := new$DestRegionCls;
--     new$SourceDocBase := new$DestDocBase;
--     new$SourceAssignmentKind := new$DestAssignmentKind;
--     new$SourceSubsidyCls := new$DestSubsidyCls;
--     new$SourceTransfertCLS := new$DestTransfertCLS;
--     new$SourceBudAllocationCls := new$DestBudAllocationCls;
--     new$SourcePayPromiseCls := new$DestPayPromiseCls;
--      
--   END IF;
--   IF (new$BuhOperationCLS IS NULL)
--   THEN 
--     GetIntConst(60, 15,new$BuhOperationCLS);
--   END IF;
--   /*    */
--   IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
--   AND (new$SourcePromise <> :old.SourcePromise)
--   OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
--   OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
--   OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
--   AND (new$DestPromise <> :old.DestPromise)
--   OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
--   OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
--     IF (new$progindex IN (63, 64, 73)) THEN
--       new$Promise := new$SourcePromise;
--          
--     ELSE 
--       IF (new$progindex IN (61, 62, 65, 75)) THEN
--         new$Promise := new$DestPromise;
--            
--       ELSE 
--         IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
--         ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
--           new$Promise := new$DestPromise;
--         END IF;
--       END IF; 
--     END IF;/*     */
--   ELSE
--     IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
--     AND (new$Promise <> :old.Promise)
--     OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
--     OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
--       IF (new$progindex IN (63, 64, 73)) THEN
--         new$SourcePromise := new$Promise;
--            
--       ELSE 
--         IF (new$progindex IN (61, 62, 65, 75)) THEN
--           new$DestPromise := new$Promise;
--              
--         ELSE 
--           IF (new$progindex in (66, 67, 76)) THEN
--             new$SourcePromise := new$Promise;
--             new$DestPromise := new$Promise;
--                
--           END IF;
--         END IF; 
--       END IF;
--     END IF;
--   END IF;
--   /*     \   */
--   IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
--   ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
--       INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
--       WHERE (fac.ID = new$SourceFacialAcc_Cls)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
--   ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
--       INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
--       WHERE (fac.ID = new$DestFacialAcc_Cls)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*       */
--   GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
--   new$Sourcetargetcls,new$Sourcetargetcls);
--   GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
--   new$Desttargetcls,new$Desttargetcls);     

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*  60 :  '   .'; source
--           61 :  '      '; dest
--           62 :  '   ';dest
--           63 :  '    '; source
--           64 :  '   '; source
--           65 :  ' , ';dest
--           66 :  '  ,  - '; source dest
--           67 :  '   ';source
--           68 :  '  \ ';dest
--           69 :  '   \ '; dest
--           70 :  '  \ ';source
--           71 :  '   \ '; dest */
-- 
--   /* ClsType*/
--   if ((new$ClsType is NULL) and
--   (
--   ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
--   (new$ProgIndex = 60)
--   )) then
--     new$ClsType := 1; /*       ClsType */
--       
--   else
--     if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
--     (new$ProgIndex in (63,64,66,67,68,70))) then
--       new$ClsType := 2; /*        ClsType */
--           
--     else
--       if (new$ClsType is null) then
--         new$ClsType := 0; /*  -  */
--       END IF;
--     END IF;
--   END IF;
--   IF ((new$ClsType = 0) AND
--   (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
--   (new$ProgIndex in (63,64,66,67,68,70)))
--   ) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$ClsType = 1) AND (
--   (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
--   (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
--   ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$ClsType = 2) AND (
--   (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
--   (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
--   ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   /* DestClsType*/
--   if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
--     new$DestClsType := new$ClsType;
--   END IF;
--   IF ((new$DestClsType = 0) AND
--   (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
--   (new$ProgIndex in (61,62,65,69,71)))
--   ) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$DestClsType = 1) AND (
--   (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
--   (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
--   ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$DestClsType = 2) AND (
--   (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
--   (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
--   ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -
  NULL;
--   /*       */
--   GetIntConst(30, 15,PromiseMode$);
--   /*     */
--   if (PromiseMode$ <> 1) then
--     /*          */
--     if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$SOURCEPROMISE)
--       ;
--       /*    ,  */
--       if (Promise_Count$ = 0) then
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--     /*          */
--     if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$DestPromise)
--       ;
--       /*    ,  */
--       if (Promise_Count$ = 0) then
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--         
--     END IF;/* end  PromiseMode <> 1*/
--   END IF;
--   /*     */
--   if (PromiseMode$ = 1) then
--     /* source  .    */
--     if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
--     (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
--       select max(InnerPromiseNum) 
--       into BPInnerNum$           from PaymentSchedule 
--       where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum$ <> 0) then
--         new$SourceBudgetPromise := BPInnerNum$;
--                 
--       else
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--     /* dest  .     */
--     if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
--     (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
--       select max(InnerPromiseNum) 
--       into BPInnerNum$           from PaymentSchedule
--       where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum$ <> 0) then
--         new$DestBudgetPromise := BPInnerNum$;
--                 
--       else
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--           
--     /*         NULL,    */
--     /* source */
--     if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
--     (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
--       BEGIN
--         select ANumber 
--         into BPInnerNum$           from PaymentSchedule
--         where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       new$SourcePromise := BPInnerNum$;
--       new$Promise := BPInnerNum$;
--             
--     END IF;
--     /* dest */
--     if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
--     (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
--       BEGIN
--         select ANumber 
--         into BPInnerNum$           from PaymentSchedule
--         where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       new$DestPromise := BPInnerNum$;
--       new$Promise := BPInnerNum$;
--             
--     END IF;
--     /*    ,     */
--     if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
--       new$SourcePromise := null;
--       new$Promise := null;
--             
--     END IF;
--     if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
--       new$DestPromise := null;
--       new$Promise := null;
--             
--     END IF;
--     if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$1
--       from PaymentSchedule
--       where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$1<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Source */
--         select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
--         where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');      
--       END IF;
--     END IF;
--     if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$2
--       from PaymentSchedule
--       where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$2<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Dest */
--         select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
--         where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');      
--       END IF;    
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$SourcePromise is not null and (
    (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
    (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$SourceExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null and (
    (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
    (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$DestExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -
  NULL;
--   /*          (  ) */
--   if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
--     BEGIN
--       select c.AcceptDate into CapAcceptDate$
--       from facialfincaption c
--       where c.id = new$RecordIndex;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN
--         CapAcceptDate$ := NULL;
--     END;
-- 
--     if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
--       new$AcceptDate := new$AcceptDate;
--     else
--       RaiseException('ex_wrongacceptdate');
--     end if;
--   end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -
  NULL;
--    IF (new$RVersion IS NULL) THEN
--       new$RVersion := 1;
--    ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
--       new$RVersion := :OLD.RVersion;
--    ELSE
--       new$RVersion := :OLD.RVersion + 1;
--    END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -
  NULL;
--   if (new$ClsType <> :old.ClsType) then
--     update FacialFinCaption set
--       ClsType = new$ClsType,
--       RVersion = -1
--     where
--       (id = new$RecordIndex)and(ClsType <> new$ClsType);
--   end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -
  NULL;
--   if (new$ID<>:old.ID) then
--     insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
--     delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
--   end if;

END;
/
-- ALTER TRIGGER TR_FacialFinDetail_BU_210
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;
-- 
--    /*     */
--    IF     (new$BudgetRef <> :OLD.BudgetRef)
--       AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
--       raiseException ('Ex_CantModufyBudget');
--    END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 12.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*     ,      */ 
--   i_fintype$ := -1 ;
--   IF (new$SourceFintype IS NULL) THEN 
--     BEGIN
--       SELECT constvalue INTO i_fintype$   FROM intconst
--       WHERE (progindex=30) AND (constindex=10) ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     new$SourceFintype := i_fintype$  ;
--      
--   END IF;
--   IF (new$DestFintype IS NULL) THEN 
--     IF (i_fintype$ = -1) THEN
--       BEGIN
--         SELECT constvalue INTO i_fintype$   FROM intconst
--         WHERE (progindex=30) AND (constindex=10) ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--     END IF;
--     new$DestFintype := i_fintype$  ;
--      
--   END IF;
--   IF (new$SourceFacialAcc_CLS IS NULL) THEN 
--     new$SourceFacialAcc_CLS := 0;
--   END IF;
--   /*   */
--   IF (new$SourceKVR IS NULL) THEN 
--     new$SourceKVR := 0;
--   END IF;
--   IF (new$SourceKESR IS NULL) THEN 
--     new$SourceKESR := 0;
--   END IF;
--   IF (new$SourceKVSR IS NULL) THEN 
--     new$SourceKVSR := 0;
--   END IF;
--   IF (new$SourceKFSR IS NULL) THEN 
--     new$SourceKFSR := 0;
--   END IF;
--   IF (new$SourceKCSR IS NULL) THEN 
--     new$SourceKCSR := 0;
--   END IF;
--   IF (new$SourceSubKESR IS NULL) THEN 
--     new$SourceSubKESR := 0;
--   END IF;
--   IF (new$SourceDirectionCls IS NULL) THEN 
--     new$SourceDirectionCls := 0;
--   END IF;
--   IF (new$SourceFact IS NULL) THEN 
--     new$SourceFact := 0;
--   END IF;
--   IF (new$SourceMeansType IS NULL) THEN 
--     new$SourceMeansType := 0;
--   END IF;
--   IF (new$SourceFinSource IS NULL) THEN 
--     new$SourceFinSource := 0;
--   END IF;
--   IF (new$SourceFinType IS NULL) THEN 
--     new$SourceFinType := 0;
--   END IF;
--   IF (new$SourceDocType IS NULL) THEN 
--     new$SourceDocType := 0;
--   END IF;
--   IF (new$Sourceifs IS NULL) THEN 
--     new$Sourceifs := 0;
--   END IF;
--   IF (new$SourceKD IS NULL) THEN 
--     new$SourceKD := 0;
--   END IF;
--   IF (new$SourceFundsSource IS NULL) THEN 
--     new$SourceFundsSource := 0;
--   END IF;
--   IF (new$SourceAssignmentKind IS NULL) THEN 
--     new$SourceAssignmentKind := 0;
--   END IF;
--   IF (new$SourceRegionCLS IS NULL) THEN 
--     new$SourceRegionCLS := 0;
--   END IF;
--   IF (new$DestFacialAcc_CLS IS NULL) THEN 
--     new$DestFacialAcc_CLS := 0;
--   END IF;
--   /*   */
--   IF (new$DestKVR IS NULL) THEN 
--     new$DestKVR := 0;
--   END IF;
--   IF (new$DestKESR IS NULL) THEN 
--     new$DestKESR := 0;
--   END IF;
--   IF (new$DestKVSR IS NULL) THEN 
--     new$DestKVSR := 0;
--   END IF;
--   IF (new$DestKFSR IS NULL) THEN 
--     new$DestKFSR := 0;
--   END IF;
--   IF (new$DestKCSR IS NULL) THEN 
--     new$DestKCSR := 0;
--   END IF;
--   IF (new$DestSubKESR IS NULL) THEN 
--     new$DestSubKESR := 0;
--   END IF;
--   IF (new$DestDirectionCls IS NULL) THEN 
--     new$DestDirectionCls := 0;
--   END IF;
--   IF (new$DestFact IS NULL) THEN 
--     new$DestFact := 0;
--   END IF;
--   IF (new$DestMeansType IS NULL) THEN 
--     new$DestMeansType := 0;
--   END IF;
--   IF (new$DestFinSource IS NULL) THEN 
--     new$DestFinSource := 0;
--   END IF;
--   IF (new$DestFinType IS NULL) THEN 
--     new$DestFinType := 0;
--   END IF;
--   IF (new$DestDocType IS NULL) THEN 
--     new$DestDocType := 0;
--   END IF;
--   IF (new$Destifs IS NULL) THEN 
--     new$Destifs := 0;
--   END IF;
--   IF (new$DestKD IS NULL) THEN 
--     new$DestKD := 0;
--   END IF;
--   IF (new$DestFundsSource IS NULL) THEN 
--     new$DestFundsSource := 0;
--   END IF;
--   IF (new$DestAssignmentKind IS NULL) THEN 
--     new$DestAssignmentKind := 0;
--   END IF;
--   IF (new$DestRegionCLS IS NULL) THEN 
--     new$DestRegionCLS := 0;
--   END IF;
--   /*   :       */
--   if (new$progindex=76) then
--     new$SourceKVR := new$DestKVR;
--     new$SourceKESR := new$DestKESR;
--     new$SourceKVSR := new$DestKVSR;
--     new$SourceKFSR := new$DestKFSR;
--     new$SourceKCSR := new$DestKCSR;
--     new$SourceSubKESR := new$DestSubKESR;
--     new$SourceDirectionCls := new$DestDirectionCls;
--     new$SourceFact := new$DestFact;
--     new$SourceMeansType := new$DestMeansType;
--     new$SourceFinSource := new$DestFinSource;
--     new$SourceFinType := new$DestFinType;
--     new$SourceDocType := new$DestDocType;
--     new$SourceIFS := new$DestIFS;
--     new$SourceKD := new$DestKD;
--     new$SourceRegionCls := new$DestRegionCls;
--     new$SourceDocBase := new$DestDocBase;
--     new$SourceAssignmentKind := new$DestAssignmentKind;
--     new$SourceSubsidyCls := new$DestSubsidyCls;
--     new$SourceTransfertCLS := new$DestTransfertCLS;
--     new$SourceBudAllocationCls := new$DestBudAllocationCls;
--     new$SourcePayPromiseCls := new$DestPayPromiseCls;
--      
--   END IF;
--   IF (new$BuhOperationCLS IS NULL)
--   THEN 
--     GetIntConst(60, 15,new$BuhOperationCLS);
--   END IF;
--   /*    */
--   IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
--   AND (new$SourcePromise <> :old.SourcePromise)
--   OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
--   OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
--   OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
--   AND (new$DestPromise <> :old.DestPromise)
--   OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
--   OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
--     IF (new$progindex IN (63, 64, 73)) THEN
--       new$Promise := new$SourcePromise;
--          
--     ELSE 
--       IF (new$progindex IN (61, 62, 65, 75)) THEN
--         new$Promise := new$DestPromise;
--            
--       ELSE 
--         IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
--         ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
--           new$Promise := new$DestPromise;
--         END IF;
--       END IF; 
--     END IF;/*     */
--   ELSE
--     IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
--     AND (new$Promise <> :old.Promise)
--     OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
--     OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
--       IF (new$progindex IN (63, 64, 73)) THEN
--         new$SourcePromise := new$Promise;
--            
--       ELSE 
--         IF (new$progindex IN (61, 62, 65, 75)) THEN
--           new$DestPromise := new$Promise;
--              
--         ELSE 
--           IF (new$progindex in (66, 67, 76)) THEN
--             new$SourcePromise := new$Promise;
--             new$DestPromise := new$Promise;
--                
--           END IF;
--         END IF; 
--       END IF;
--     END IF;
--   END IF;
--   /*     \   */
--   IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
--   ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
--       INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
--       WHERE (fac.ID = new$SourceFacialAcc_Cls)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
--   ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
--       INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
--       WHERE (fac.ID = new$DestFacialAcc_Cls)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*       */
--   GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
--   new$Sourcetargetcls,new$Sourcetargetcls);
--   GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
--   new$Desttargetcls,new$Desttargetcls);     

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*  60 :  '   .'; source
--           61 :  '      '; dest
--           62 :  '   ';dest
--           63 :  '    '; source
--           64 :  '   '; source
--           65 :  ' , ';dest
--           66 :  '  ,  - '; source dest
--           67 :  '   ';source
--           68 :  '  \ ';dest
--           69 :  '   \ '; dest
--           70 :  '  \ ';source
--           71 :  '   \ '; dest */
-- 
--   /* ClsType*/
--   if ((new$ClsType is NULL) and
--   (
--   ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
--   (new$ProgIndex = 60)
--   )) then
--     new$ClsType := 1; /*       ClsType */
--       
--   else
--     if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
--     (new$ProgIndex in (63,64,66,67,68,70))) then
--       new$ClsType := 2; /*        ClsType */
--           
--     else
--       if (new$ClsType is null) then
--         new$ClsType := 0; /*  -  */
--       END IF;
--     END IF;
--   END IF;
--   IF ((new$ClsType = 0) AND
--   (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
--   (new$ProgIndex in (63,64,66,67,68,70)))
--   ) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$ClsType = 1) AND (
--   (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
--   (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
--   ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$ClsType = 2) AND (
--   (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
--   (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
--   ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   /* DestClsType*/
--   if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
--     new$DestClsType := new$ClsType;
--   END IF;
--   IF ((new$DestClsType = 0) AND
--   (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
--   (new$ProgIndex in (61,62,65,69,71)))
--   ) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$DestClsType = 1) AND (
--   (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
--   (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
--   ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$DestClsType = 2) AND (
--   (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
--   (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
--   ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -
  NULL;
--   /*       */
--   GetIntConst(30, 15,PromiseMode$);
--   /*     */
--   if (PromiseMode$ <> 1) then
--     /*          */
--     if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$SOURCEPROMISE)
--       ;
--       /*    ,  */
--       if (Promise_Count$ = 0) then
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--     /*          */
--     if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$DestPromise)
--       ;
--       /*    ,  */
--       if (Promise_Count$ = 0) then
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--         
--     END IF;/* end  PromiseMode <> 1*/
--   END IF;
--   /*     */
--   if (PromiseMode$ = 1) then
--     /* source  .    */
--     if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
--     (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
--       select max(InnerPromiseNum) 
--       into BPInnerNum$           from PaymentSchedule 
--       where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum$ <> 0) then
--         new$SourceBudgetPromise := BPInnerNum$;
--                 
--       else
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--     /* dest  .     */
--     if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
--     (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
--       select max(InnerPromiseNum) 
--       into BPInnerNum$           from PaymentSchedule
--       where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum$ <> 0) then
--         new$DestBudgetPromise := BPInnerNum$;
--                 
--       else
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--           
--     /*         NULL,    */
--     /* source */
--     if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
--     (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
--       BEGIN
--         select ANumber 
--         into BPInnerNum$           from PaymentSchedule
--         where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       new$SourcePromise := BPInnerNum$;
--       new$Promise := BPInnerNum$;
--             
--     END IF;
--     /* dest */
--     if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
--     (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
--       BEGIN
--         select ANumber 
--         into BPInnerNum$           from PaymentSchedule
--         where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       new$DestPromise := BPInnerNum$;
--       new$Promise := BPInnerNum$;
--             
--     END IF;
--     /*    ,     */
--     if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
--       new$SourcePromise := null;
--       new$Promise := null;
--             
--     END IF;
--     if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
--       new$DestPromise := null;
--       new$Promise := null;
--             
--     END IF;
--     if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$1
--       from PaymentSchedule
--       where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$1<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Source */
--         select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
--         where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');      
--       END IF;
--     END IF;
--     if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$2
--       from PaymentSchedule
--       where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$2<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Dest */
--         select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
--         where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');      
--       END IF;    
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*    ?*/
--   GetIntConst(30, 15,PromiseMode1$);
--   if (PromiseMode1$ = 1) then
--     /*        */
--     if (new$SourcePromise is not null and (
--     (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
--     (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex$ = 308) then
--         new$SourceExecDoc := ExecID$;
--         new$SourceExecInnerNumber := ExecInnerNumber$;
--               
--       else 
--         if (new$SourceExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
--             where
--             Id = new$SourceExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */        
--           new$SourceExecInnerNumber := ExecInnerNumber$;
--                 
--         END IF;    
--       END IF;/*       ,   ,  */
--     else 
--       if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber$       from ExecutionDocumentsCaption
--           where
--           Id = new$SourceExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$SourceExecInnerNumber := ExecInnerNumber$;
--             
--       END IF;
--     END IF;
--     /*     Dest */
-- 
--     /*        */
--     if (new$DestPromise is not null and (
--     (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
--     (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex$ = 308) then
--         new$DestExecDoc := ExecID$;
--         new$DestExecInnerNumber := ExecInnerNumber$;
--               
--       else 
--         if (new$DestExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
--             where
--             Id = new$DestExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */        
--           new$DestExecInnerNumber := ExecInnerNumber$;
--                 
--         END IF;    
--       END IF;/*       ,   ,  */
--     else 
--       if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber$       from ExecutionDocumentsCaption
--           where
--           Id = new$DestExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$DestExecInnerNumber := ExecInnerNumber$;
--             
--       END IF;
--     END IF;
--     if (new$SourceExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls1$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Source */
--         select Accepted
--         into EDAccepted$       from ExecutionDocumentsCaption
--         where id = new$SourceExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');    
--       END IF;
--     END IF;
--     if (new$DestExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls1$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Dest */
--         select Accepted
--         into EDAccepted$       from ExecutionDocumentsCaption
--         where ID = new$DestExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');    
--       END IF;  
--     END IF;/*   " "*/
--   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -
  NULL;
--   /*          (  ) */
--   if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
--     BEGIN
--       select c.AcceptDate into CapAcceptDate$
--       from facialfincaption c
--       where c.id = new$RecordIndex;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN
--         CapAcceptDate$ := NULL;
--     END;
-- 
--     if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
--       new$AcceptDate := new$AcceptDate;
--     else
--       RaiseException('ex_wrongacceptdate');
--     end if;
--   end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -
  NULL;
--    IF (new$RVersion IS NULL) THEN
--       new$RVersion := 1;
--    ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
--       new$RVersion := :OLD.RVersion;
--    ELSE
--       new$RVersion := :OLD.RVersion + 1;
--    END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -
  NULL;
--   if (new$ClsType <> :old.ClsType) then
--     update FacialFinCaption set
--       ClsType = new$ClsType,
--       RVersion = -1
--     where
--       (id = new$RecordIndex)and(ClsType <> new$ClsType);
--   end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -
  NULL;
--   if (new$ID<>:old.ID) then
--     insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
--     delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
--   end if;

END;
/
ALTER TRIGGER TR_INCOMES32_BU_500 DISABLE
/
-- ALTER TRIGGER tr_Incomes32_bu_30
CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN 
    new$DocBase := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN 
    new$Gosni := 0;
  END IF;
  /* 3 -    */
  IF (new$ProgIndex IS NULL) THEN 
    new$ProgIndex := 3; 
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0; 
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN 
    new$FACIALACC_CLS := 0; 
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN 
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN 
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN 
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN 
    new$AccountIndex := 0; 
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN 
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN 
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN 
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN 
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN 
    new$DirectionCLS := 0;
  END IF;
  IF (new$FinType is null) then 
    new$FinType := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  /*   .        */
  IF (new$IFS_CORR IS NULL) THEN 
    new$Ifs_Corr := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$Ifs := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  BEGIN

    /*     */
    /*   after   ,*/ 
    /*      */
    SELECT ProgIndex, AcceptDate, ReestrNumber
    INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
    WHERE
    (qt.ID = new$RecordIndex)
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*              
           (  , , ) */
  /*   -    () */
  IF (CapProgIndex2$ = 45)
  THEN 
    IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN 
      /*        ,
                     */            
      new$FederalFundsRef := new$ID;
      /* if-then*/
    ELSE 
      new$FederalFundsRef := NULL;
      /* if-else*/  
    END IF;/* if (CapProgIndex=45) */
  END IF;
  /*     */
  IF (new$BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
      IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
        RaiseException('Ex_CantModufyBudget');
      END IF;
      IF (new$Progindex = 41) THEN
        SELECT COUNT(inc.id ) INTO CNT$1
        FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
        IF ((CNT$1<> 0)) THEN
          RaiseException('Ex_CantModufyBudget');
        END IF;   
      END IF;
    END IF;
  END IF;
  /*     \*/
  IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
  ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
  new$targetcls,new$targetcls);  

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

  BEGIN
    SELECT Inn
     INTO new$Inn
     FROM Organizations o
    WHERE (o.ID = new$Org_Ref);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*      */
  IF (new$ProgIndex <> 42) THEN
    BEGIN
      SELECT ProgIndex, DocNumber, AcceptDate
      INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
      WHERE
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*   -  ,   */
  IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
  THEN 
    IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
    (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
    THEN 
      BEGIN
        SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
        WHERE inc.id = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (Kd_Master$ = new$Kd) THEN 
        CapAcceptDate$ := new$DOCDATE;
        CapProgIndex$  := new$ProgIndex;
        CapDocNumber$  := new$DocNum;
        /*  */        
      END IF;/*       (         )*/
    END IF;
    IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
    THEN 

      /*      */
      /* /      Incomes32, ..      ,     */

      /*     /   */
      SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
      INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
      ;
      /*            ,  .*/
      /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
                      ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
                     ) THEN
                    EXCEPTION EX_CANNOTUPDATENUMBER;*/
                 
                
      IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
      then
        if ((new$DocType <> :old.DocType )
        or (new$Debit <> :old.Debit )
        or (new$Credit <> :old.Credit)
        or (new$org_ref <> :old.org_ref)
        or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
        or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
        )
        then
          RaiseException('EX_CANNOTUPDATENUMBER');
        END IF;
      END IF;
                


      /*           */
      IF (PayDocCount$ = 0)
      THEN 
        /*       */
        GetIntConst(11, 2,ConstPayQueue$);
        /*       */
        GetIntConst(11, 1,ConstSendBy$);

        /*    */
        INSERT INTO PayDoc32
        (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
        Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
        VALUES
        (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
        new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
        /* (new.Debit - new.Credit) --- ..      ,    ,
                                     */

        /* if-then */
      ELSE 
        /*     */
        IF (((new$AccountRef = :old.AccountRef) OR
        ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
        AND (new$IncAccount = :old.IncAccount)
        AND (new$BudgetRef = :old.BudgetRef)
        AND ((new$Note = :old.Note) OR
        ((new$Note IS NULL) AND (:old.Note IS NULL)))
        AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
        ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
        AND ((new$TaxNote = :old.TaxNote) OR
        ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
        )  THEN
          new$AccountRef := new$AccountRef;
                          
        ELSE

          UPDATE PayDoc32 pd
          SET
          pd.AccountRef = new$AccountRef,
          pd.PayerAttrRef = new$IncAccount,
          pd.AcceptorAttrRef = new$AccountRef,
          pd.TextNote = new$Note,
          pd.TaxNote = new$TaxNote,
          pd.BudgetRef = new$BudgetRef,
          pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
          pd.InputDate = CapAcceptDate$,
          pd.SourceDocNumber = CapDocNumber$,
          pd.FACIALACC_CLS = new$FACIALACC_CLS
          WHERE
          (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
        END IF;
        IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
        OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
        THEN  
          IF (Divided$ > 0)
          THEN
            /*  ,      */
            RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
          ELSE
            UPDATE PayDoc32 pd
            SET
            pd.Credit = new$Debit - new$Credit
            WHERE
            (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
          END IF;/* if-then*/            
        END IF;/* if-else*/
      END IF;
      /*     / */
      /*   :     ,     */
      /*  ,     */
      SELECT MAX(pd.AcceptDate)
      INTO Date_Pd$           FROM PayDoc32 pd
      WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
      ;
      new$Idate := Date_Pd$;
      /* if-then*/
    ELSE 
      /*       
                          -
                    . */
      DELETE FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex = new$ProgIndex)
      AND (pd.RecordIndex = new$id);
      /* if-else*/  
    END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -
  NULL;
--   if ((new$DocDate is null) and (new$ProgIndex=45)) then 
--     BEGIN
--       select q.BuildDate 
--       into 
--       new$DocDate        from QuotesTitle q 
--       where q.id = new$RecordIndex 
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   if ((new$DocDate is null) and (new$IDATE is not null)) then
--     new$DocDate := new$IDATE;
--   END IF;
--   if ((new$DOCDATE is not null)) then
--     new$RecordDate := new$DOCDATE;
--   END IF;
--   /*         */
--   if ((new$IDate is not null) and (new$RejectCls is not null)) then
--     RaiseException('EX_DOCNOTACCEPTREJECT');
--   END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
            */
         new$FederalFundsRef := new$ID;
      ELSE
         new$FederalFundsRef := NULL;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN
      select KDValue   into oldKD$ from kd where Id=:old.kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN

      /*     */
      select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
      IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
      into
      idKD1$,
      val_DocCount1$,
      val_DocType1$,
      val_Org_Ref1$,
      val_AccountIndex1$,
      val_SubKD1$,
      val_RegionCLS1$,
      val_GosNI1$,
      val_IncAccount1$,
      val_BudgetRef1$,
      val_MEANSTYPE1$  , 
      val_FACIALACC_CLS1$,
      val_TransfertCls1$         from incomes32 where id=new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not idKD1$ is null) then
      if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
      (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
        /*   ,    */
        delete
        from Incomes32
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      (new$Debit<>0))
      /*       */
      then 
        RaiseException('ex_UnknownRedirect');
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
        /*   ,   ,   */
        insert into
        Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
        Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
        val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
        val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
        new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
      END IF;
      if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
      and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
        /*      ,   */
        update Incomes32
        set
        DocNum = new$DocNum,
        DocCount = val_DocCount1$,
        iDate = new$iDate,
        DOCDATE = new$DOCDATE,
        Debit = 0,
        Credit = -new$Credit,
        DocType = val_DocType1$,
        Org_Ref = val_Org_Ref1$,
        AccountIndex = val_AccountIndex1$,
        KD = idKD1$,
        SubKD = val_SubKD1$,
        RegionCLS = val_RegionCLS1$,
        GosNI = val_GosNI1$,
        ProgIndex = 43,
        RecordIndex = new$Id,
        IncAccount = val_IncAccount1$,
        BudgetRef = val_BudgetRef1$,
        Note = new$Note,
        MEANSTYPE = val_MEANSTYPE1$,
        FACIALACC_CLS = val_FACIALACC_CLS1$,
        TransfertCls = val_TransfertCls1$,
        RVersion = -1
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
         
      END IF; 
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 41)    /*   () */
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    /*       */
    FOR REC$1 IN (SELECT inc.id
     AS val_ID42    FROM Incomes32 inc
    LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
    WHERE (inc.ProgIndex =  42) and
    (inc.RecordIndex =  new$id) and
    (inc.debit = 0) and
    (not(kd.kdvalue like unkKD$)) and
    (not(kd.kdvalue like unkVKD$))
    )
    LOOP
      BEGIN
        /*       */
        select inc.id
        into val_ID431$         FROM Incomes32 inc
        WHERE (inc.ProgIndex =  43) and
        (inc.RecordIndex =  REC$1.val_ID42)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      /*     ,   Credit, ProgIndex, RecordIndex */
      update Incomes32
      set
      DocNum = new$DocNum,
      DocCount = new$DocCount,       
      DOCDATE = new$DOCDATE,
      Debit = 0,
      DocType = new$DocType,
      Org_Ref = new$Org_Ref,
      AccountIndex = new$AccountIndex,
      KD = new$Kd,
      SubKD = new$SubKD,
      RegionCLS = new$RegionCLS,
      GosNI = new$GosNI,
      IncAccount = new$IncAccount,
      BudgetRef = new$BudgetRef,
      Note = new$Note,
      MEANSTYPE = new$MEANSTYPE,
      FACIALACC_CLS = new$FACIALACC_CLS,
      FACT = new$FACT,
      TransfertCls = new$TransfertCls,
      DirectionCls = new$DirectionCls,
      rversion = -1
      where id = val_ID431$;

        
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       --       ClsType
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                --  - 
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      --   
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   IF (NEW$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (161, :OLD.ID, SYSDATE);
      DELETE FROM DelRecIndexes
        WHERE (TableID = 161) AND (RecordId = NEW$ID);
   END IF;

END;
/
-- ALTER TRIGGER tr_Incomes32_bu
CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   IF (new$Fact IS NULL) THEN 
--     new$Fact := 0;
--   END IF;
--   IF (new$DocBase IS NULL) THEN 
--     new$DocBase := 0;
--   END IF;
--   IF (new$Gosni IS NULL) THEN 
--     new$Gosni := 0;
--   END IF;
--   /* 3 -    */
--   IF (new$ProgIndex IS NULL) THEN 
--     new$ProgIndex := 3; 
--   END IF;
--   IF (new$KD IS NULL) THEN 
--     new$KD := 0; 
--   END IF;
--   /*   */
--   IF (new$FACIALACC_CLS IS NULL) THEN 
--     new$FACIALACC_CLS := 0; 
--   END IF;
--   IF (new$MeansType IS NULL) THEN 
--     new$MeansType := 0;
--   END IF;
--   IF (new$Debit IS NULL) THEN 
--     new$Debit := 0;
--   END IF;
--   IF (new$Credit IS NULL) THEN 
--     new$Credit := 0;
--   END IF;
--   IF (new$Org_Ref IS NULL) THEN 
--     new$Org_Ref := 0;
--   END IF;
--   IF (new$AccountIndex IS NULL) THEN 
--     new$AccountIndex := 0; 
--   END IF;
--   IF (new$DocType IS NULL) THEN 
--     new$DocType := 0;
--   END IF;
--   IF (new$SubKD IS NULL) THEN 
--     new$SubKD := 0;
--   END IF;
--   IF (new$RegionCLS IS NULL) THEN 
--     new$RegionCLS := 0;
--   END IF;
--   IF (new$DocCount IS NULL) THEN 
--     new$DocCount := 1;
--   END IF;
--   IF (new$BuhPaymentCLS IS NULL) THEN 
--     new$BuhPaymentCLS := 0;
--   END IF;
--   IF (new$KVSR IS NULL) THEN 
--     new$KVSR := 0;
--   END IF;
--   IF (new$KFSR IS NULL) THEN 
--     new$KFSR := 0;
--   END IF;
--   IF (new$KESR IS NULL) THEN 
--     new$KESR := 0;
--   END IF;
--   IF (new$KVR IS NULL) THEN 
--     new$KVR := 0;
--   END IF;
--   IF (new$KCSR IS NULL) THEN 
--     new$KCSR := 0;
--   END IF;
--   IF (new$OKATO IS NULL) THEN 
--     new$OKATO := 0;
--   END IF;
--   IF (new$FundsSource IS NULL) THEN 
--     new$FundsSource := 0;
--   END IF;
--   IF (new$DirectionCLS IS NULL) THEN 
--     new$DirectionCLS := 0;
--   END IF;
--   IF (new$FinType is null) then 
--     new$FinType := 0;
--   END IF;
--   IF (new$Debit * new$Credit <> 0) THEN
--     RaiseException('ex_FailDebetCretitValue');
--   END IF;
--   /*   .        */
--   IF (new$IFS_CORR IS NULL) THEN 
--     new$Ifs_Corr := 0;
--   END IF;
--   IF (new$IFS IS NULL) THEN 
--     new$Ifs := 0;
--   END IF;
--   IF (new$BuhOperationCLS IS NULL)
--   THEN 
--     GetIntConst(60, 15,new$BuhOperationCLS);
--   END IF;
--   BEGIN
-- 
--     /*     */
--     /*   after   ,*/ 
--     /*      */
--     SELECT ProgIndex, AcceptDate, ReestrNumber
--     INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
--     WHERE
--     (qt.ID = new$RecordIndex)
--     ;
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;
--   /*              
--            (  , , ) */
--   /*   -    () */
--   IF (CapProgIndex2$ = 45)
--   THEN 
--     IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
--     THEN 
--       /*        ,
--                      */            
--       new$FederalFundsRef := new$ID;
--       /* if-then*/
--     ELSE 
--       new$FederalFundsRef := NULL;
--       /* if-else*/  
--     END IF;/* if (CapProgIndex=45) */
--   END IF;
--   /*     */
--   IF (new$BudgetRef <> :old.BudgetRef) THEN
--     IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
--       IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
--         RaiseException('Ex_CantModufyBudget');
--       END IF;
--       IF (new$Progindex = 41) THEN
--         SELECT COUNT(inc.id ) INTO CNT$1
--         FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
--         IF ((CNT$1<> 0)) THEN
--           RaiseException('Ex_CantModufyBudget');
--         END IF;   
--       END IF;
--     END IF;
--   END IF;
--   /*     \*/
--   IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
--   ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
--       INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
--       WHERE fac.ID = new$FacialACC_Cls
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*    */
--   GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
--   new$targetcls,new$targetcls);  

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

  BEGIN
    SELECT Inn
     INTO new$Inn
     FROM Organizations o
    WHERE (o.ID = new$Org_Ref);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*      */
  IF (new$ProgIndex <> 42) THEN
    BEGIN
      SELECT ProgIndex, DocNumber, AcceptDate
      INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
      WHERE
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*   -  ,   */
  IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
  THEN 
    IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
    (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
    THEN 
      BEGIN
        SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
        WHERE inc.id = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (Kd_Master$ = new$Kd) THEN 
        CapAcceptDate$ := new$DOCDATE;
        CapProgIndex$  := new$ProgIndex;
        CapDocNumber$  := new$DocNum;
        /*  */        
      END IF;/*       (         )*/
    END IF;
    IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
    THEN 

      /*      */
      /* /      Incomes32, ..      ,     */

      /*     /   */
      SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
      INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
      ;
      /*            ,  .*/
      /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
                      ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
                     ) THEN
                    EXCEPTION EX_CANNOTUPDATENUMBER;*/
                 
                
      IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
      then
        if ((new$DocType <> :old.DocType )
        or (new$Debit <> :old.Debit )
        or (new$Credit <> :old.Credit)
        or (new$org_ref <> :old.org_ref)
        or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
        or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
        )
        then
          RaiseException('EX_CANNOTUPDATENUMBER');
        END IF;
      END IF;
                


      /*           */
      IF (PayDocCount$ = 0)
      THEN 
        /*       */
        GetIntConst(11, 2,ConstPayQueue$);
        /*       */
        GetIntConst(11, 1,ConstSendBy$);

        /*    */
        INSERT INTO PayDoc32
        (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
        Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
        VALUES
        (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
        new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
        /* (new.Debit - new.Credit) --- ..      ,    ,
                                     */

        /* if-then */
      ELSE 
        /*     */
        IF (((new$AccountRef = :old.AccountRef) OR
        ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
        AND (new$IncAccount = :old.IncAccount)
        AND (new$BudgetRef = :old.BudgetRef)
        AND ((new$Note = :old.Note) OR
        ((new$Note IS NULL) AND (:old.Note IS NULL)))
        AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
        ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
        AND ((new$TaxNote = :old.TaxNote) OR
        ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
        )  THEN
          new$AccountRef := new$AccountRef;
                          
        ELSE

          UPDATE PayDoc32 pd
          SET
          pd.AccountRef = new$AccountRef,
          pd.PayerAttrRef = new$IncAccount,
          pd.AcceptorAttrRef = new$AccountRef,
          pd.TextNote = new$Note,
          pd.TaxNote = new$TaxNote,
          pd.BudgetRef = new$BudgetRef,
          pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
          pd.InputDate = CapAcceptDate$,
          pd.SourceDocNumber = CapDocNumber$,
          pd.FACIALACC_CLS = new$FACIALACC_CLS
          WHERE
          (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
        END IF;
        IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
        OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
        THEN  
          IF (Divided$ > 0)
          THEN
            /*  ,      */
            RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
          ELSE
            UPDATE PayDoc32 pd
            SET
            pd.Credit = new$Debit - new$Credit
            WHERE
            (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
          END IF;/* if-then*/            
        END IF;/* if-else*/
      END IF;
      /*     / */
      /*   :     ,     */
      /*  ,     */
      SELECT MAX(pd.AcceptDate)
      INTO Date_Pd$           FROM PayDoc32 pd
      WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
      ;
      new$Idate := Date_Pd$;
      /* if-then*/
    ELSE 
      /*       
                          -
                    . */
      DELETE FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex = new$ProgIndex)
      AND (pd.RecordIndex = new$id);
      /* if-else*/  
    END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -
  NULL;
--   if ((new$DocDate is null) and (new$ProgIndex=45)) then 
--     BEGIN
--       select q.BuildDate 
--       into 
--       new$DocDate        from QuotesTitle q 
--       where q.id = new$RecordIndex 
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   if ((new$DocDate is null) and (new$IDATE is not null)) then
--     new$DocDate := new$IDATE;
--   END IF;
--   if ((new$DOCDATE is not null)) then
--     new$RecordDate := new$DOCDATE;
--   END IF;
--   /*         */
--   if ((new$IDate is not null) and (new$RejectCls is not null)) then
--     RaiseException('EX_DOCNOTACCEPTREJECT');
--   END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
            */
         new$FederalFundsRef := new$ID;
      ELSE
         new$FederalFundsRef := NULL;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN
      select KDValue   into oldKD$ from kd where Id=:old.kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN

      /*     */
      select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
      IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
      into
      idKD1$,
      val_DocCount1$,
      val_DocType1$,
      val_Org_Ref1$,
      val_AccountIndex1$,
      val_SubKD1$,
      val_RegionCLS1$,
      val_GosNI1$,
      val_IncAccount1$,
      val_BudgetRef1$,
      val_MEANSTYPE1$  , 
      val_FACIALACC_CLS1$,
      val_TransfertCls1$         from incomes32 where id=new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not idKD1$ is null) then
      if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
      (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
        /*   ,    */
        delete
        from Incomes32
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      (new$Debit<>0))
      /*       */
      then 
        RaiseException('ex_UnknownRedirect');
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
        /*   ,   ,   */
        insert into
        Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
        Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
        val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
        val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
        new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
      END IF;
      if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
      and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
        /*      ,   */
        update Incomes32
        set
        DocNum = new$DocNum,
        DocCount = val_DocCount1$,
        iDate = new$iDate,
        DOCDATE = new$DOCDATE,
        Debit = 0,
        Credit = -new$Credit,
        DocType = val_DocType1$,
        Org_Ref = val_Org_Ref1$,
        AccountIndex = val_AccountIndex1$,
        KD = idKD1$,
        SubKD = val_SubKD1$,
        RegionCLS = val_RegionCLS1$,
        GosNI = val_GosNI1$,
        ProgIndex = 43,
        RecordIndex = new$Id,
        IncAccount = val_IncAccount1$,
        BudgetRef = val_BudgetRef1$,
        Note = new$Note,
        MEANSTYPE = val_MEANSTYPE1$,
        FACIALACC_CLS = val_FACIALACC_CLS1$,
        TransfertCls = val_TransfertCls1$,
        RVersion = -1
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
         
      END IF; 
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 41)    /*   () */
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    /*       */
    FOR REC$1 IN (SELECT inc.id
     AS val_ID42    FROM Incomes32 inc
    LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
    WHERE (inc.ProgIndex =  42) and
    (inc.RecordIndex =  new$id) and
    (inc.debit = 0) and
    (not(kd.kdvalue like unkKD$)) and
    (not(kd.kdvalue like unkVKD$))
    )
    LOOP
      BEGIN
        /*       */
        select inc.id
        into val_ID431$         FROM Incomes32 inc
        WHERE (inc.ProgIndex =  43) and
        (inc.RecordIndex =  REC$1.val_ID42)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      /*     ,   Credit, ProgIndex, RecordIndex */
      update Incomes32
      set
      DocNum = new$DocNum,
      DocCount = new$DocCount,       
      DOCDATE = new$DOCDATE,
      Debit = 0,
      DocType = new$DocType,
      Org_Ref = new$Org_Ref,
      AccountIndex = new$AccountIndex,
      KD = new$Kd,
      SubKD = new$SubKD,
      RegionCLS = new$RegionCLS,
      GosNI = new$GosNI,
      IncAccount = new$IncAccount,
      BudgetRef = new$BudgetRef,
      Note = new$Note,
      MEANSTYPE = new$MEANSTYPE,
      FACIALACC_CLS = new$FACIALACC_CLS,
      FACT = new$FACT,
      TransfertCls = new$TransfertCls,
      DirectionCls = new$DirectionCls,
      rversion = -1
      where id = val_ID431$;

        
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       --       ClsType
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                --  - 
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      --   
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   IF (NEW$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (161, :OLD.ID, SYSDATE);
      DELETE FROM DelRecIndexes
        WHERE (TableID = 161) AND (RecordId = NEW$ID);
   END IF;

END;
/
-- ALTER TRIGGER tr_Incomes32_bu_70
CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   IF (new$Fact IS NULL) THEN 
--     new$Fact := 0;
--   END IF;
--   IF (new$DocBase IS NULL) THEN 
--     new$DocBase := 0;
--   END IF;
--   IF (new$Gosni IS NULL) THEN 
--     new$Gosni := 0;
--   END IF;
--   /* 3 -    */
--   IF (new$ProgIndex IS NULL) THEN 
--     new$ProgIndex := 3; 
--   END IF;
--   IF (new$KD IS NULL) THEN 
--     new$KD := 0; 
--   END IF;
--   /*   */
--   IF (new$FACIALACC_CLS IS NULL) THEN 
--     new$FACIALACC_CLS := 0; 
--   END IF;
--   IF (new$MeansType IS NULL) THEN 
--     new$MeansType := 0;
--   END IF;
--   IF (new$Debit IS NULL) THEN 
--     new$Debit := 0;
--   END IF;
--   IF (new$Credit IS NULL) THEN 
--     new$Credit := 0;
--   END IF;
--   IF (new$Org_Ref IS NULL) THEN 
--     new$Org_Ref := 0;
--   END IF;
--   IF (new$AccountIndex IS NULL) THEN 
--     new$AccountIndex := 0; 
--   END IF;
--   IF (new$DocType IS NULL) THEN 
--     new$DocType := 0;
--   END IF;
--   IF (new$SubKD IS NULL) THEN 
--     new$SubKD := 0;
--   END IF;
--   IF (new$RegionCLS IS NULL) THEN 
--     new$RegionCLS := 0;
--   END IF;
--   IF (new$DocCount IS NULL) THEN 
--     new$DocCount := 1;
--   END IF;
--   IF (new$BuhPaymentCLS IS NULL) THEN 
--     new$BuhPaymentCLS := 0;
--   END IF;
--   IF (new$KVSR IS NULL) THEN 
--     new$KVSR := 0;
--   END IF;
--   IF (new$KFSR IS NULL) THEN 
--     new$KFSR := 0;
--   END IF;
--   IF (new$KESR IS NULL) THEN 
--     new$KESR := 0;
--   END IF;
--   IF (new$KVR IS NULL) THEN 
--     new$KVR := 0;
--   END IF;
--   IF (new$KCSR IS NULL) THEN 
--     new$KCSR := 0;
--   END IF;
--   IF (new$OKATO IS NULL) THEN 
--     new$OKATO := 0;
--   END IF;
--   IF (new$FundsSource IS NULL) THEN 
--     new$FundsSource := 0;
--   END IF;
--   IF (new$DirectionCLS IS NULL) THEN 
--     new$DirectionCLS := 0;
--   END IF;
--   IF (new$FinType is null) then 
--     new$FinType := 0;
--   END IF;
--   IF (new$Debit * new$Credit <> 0) THEN
--     RaiseException('ex_FailDebetCretitValue');
--   END IF;
--   /*   .        */
--   IF (new$IFS_CORR IS NULL) THEN 
--     new$Ifs_Corr := 0;
--   END IF;
--   IF (new$IFS IS NULL) THEN 
--     new$Ifs := 0;
--   END IF;
--   IF (new$BuhOperationCLS IS NULL)
--   THEN 
--     GetIntConst(60, 15,new$BuhOperationCLS);
--   END IF;
--   BEGIN
-- 
--     /*     */
--     /*   after   ,*/ 
--     /*      */
--     SELECT ProgIndex, AcceptDate, ReestrNumber
--     INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
--     WHERE
--     (qt.ID = new$RecordIndex)
--     ;
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;
--   /*              
--            (  , , ) */
--   /*   -    () */
--   IF (CapProgIndex2$ = 45)
--   THEN 
--     IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
--     THEN 
--       /*        ,
--                      */            
--       new$FederalFundsRef := new$ID;
--       /* if-then*/
--     ELSE 
--       new$FederalFundsRef := NULL;
--       /* if-else*/  
--     END IF;/* if (CapProgIndex=45) */
--   END IF;
--   /*     */
--   IF (new$BudgetRef <> :old.BudgetRef) THEN
--     IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
--       IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
--         RaiseException('Ex_CantModufyBudget');
--       END IF;
--       IF (new$Progindex = 41) THEN
--         SELECT COUNT(inc.id ) INTO CNT$1
--         FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
--         IF ((CNT$1<> 0)) THEN
--           RaiseException('Ex_CantModufyBudget');
--         END IF;   
--       END IF;
--     END IF;
--   END IF;
--   /*     \*/
--   IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
--   ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
--       INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
--       WHERE fac.ID = new$FacialACC_Cls
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*    */
--   GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
--   new$targetcls,new$targetcls);  

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

  BEGIN
    SELECT Inn
     INTO new$Inn
     FROM Organizations o
    WHERE (o.ID = new$Org_Ref);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*      */
  IF (new$ProgIndex <> 42) THEN
    BEGIN
      SELECT ProgIndex, DocNumber, AcceptDate
      INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
      WHERE
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*   -  ,   */
  IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
  THEN 
    IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
    (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
    THEN 
      BEGIN
        SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
        WHERE inc.id = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (Kd_Master$ = new$Kd) THEN 
        CapAcceptDate$ := new$DOCDATE;
        CapProgIndex$  := new$ProgIndex;
        CapDocNumber$  := new$DocNum;
        /*  */        
      END IF;/*       (         )*/
    END IF;
    IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
    THEN 

      /*      */
      /* /      Incomes32, ..      ,     */

      /*     /   */
      SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
      INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
      ;
      /*            ,  .*/
      /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
                      ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
                     ) THEN
                    EXCEPTION EX_CANNOTUPDATENUMBER;*/
                 
                
      IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
      then
        if ((new$DocType <> :old.DocType )
        or (new$Debit <> :old.Debit )
        or (new$Credit <> :old.Credit)
        or (new$org_ref <> :old.org_ref)
        or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
        or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
        )
        then
          RaiseException('EX_CANNOTUPDATENUMBER');
        END IF;
      END IF;
                


      /*           */
      IF (PayDocCount$ = 0)
      THEN 
        /*       */
        GetIntConst(11, 2,ConstPayQueue$);
        /*       */
        GetIntConst(11, 1,ConstSendBy$);

        /*    */
        INSERT INTO PayDoc32
        (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
        Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
        VALUES
        (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
        new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
        /* (new.Debit - new.Credit) --- ..      ,    ,
                                     */

        /* if-then */
      ELSE 
        /*     */
        IF (((new$AccountRef = :old.AccountRef) OR
        ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
        AND (new$IncAccount = :old.IncAccount)
        AND (new$BudgetRef = :old.BudgetRef)
        AND ((new$Note = :old.Note) OR
        ((new$Note IS NULL) AND (:old.Note IS NULL)))
        AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
        ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
        AND ((new$TaxNote = :old.TaxNote) OR
        ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
        )  THEN
          new$AccountRef := new$AccountRef;
                          
        ELSE

          UPDATE PayDoc32 pd
          SET
          pd.AccountRef = new$AccountRef,
          pd.PayerAttrRef = new$IncAccount,
          pd.AcceptorAttrRef = new$AccountRef,
          pd.TextNote = new$Note,
          pd.TaxNote = new$TaxNote,
          pd.BudgetRef = new$BudgetRef,
          pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
          pd.InputDate = CapAcceptDate$,
          pd.SourceDocNumber = CapDocNumber$,
          pd.FACIALACC_CLS = new$FACIALACC_CLS
          WHERE
          (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
        END IF;
        IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
        OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
        THEN  
          IF (Divided$ > 0)
          THEN
            /*  ,      */
            RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
          ELSE
            UPDATE PayDoc32 pd
            SET
            pd.Credit = new$Debit - new$Credit
            WHERE
            (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
          END IF;/* if-then*/            
        END IF;/* if-else*/
      END IF;
      /*     / */
      /*   :     ,     */
      /*  ,     */
      SELECT MAX(pd.AcceptDate)
      INTO Date_Pd$           FROM PayDoc32 pd
      WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
      ;
      new$Idate := Date_Pd$;
      /* if-then*/
    ELSE 
      /*       
                          -
                    . */
      DELETE FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex = new$ProgIndex)
      AND (pd.RecordIndex = new$id);
      /* if-else*/  
    END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -
  NULL;
--   if ((new$DocDate is null) and (new$ProgIndex=45)) then 
--     BEGIN
--       select q.BuildDate 
--       into 
--       new$DocDate        from QuotesTitle q 
--       where q.id = new$RecordIndex 
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   if ((new$DocDate is null) and (new$IDATE is not null)) then
--     new$DocDate := new$IDATE;
--   END IF;
--   if ((new$DOCDATE is not null)) then
--     new$RecordDate := new$DOCDATE;
--   END IF;
--   /*         */
--   if ((new$IDate is not null) and (new$RejectCls is not null)) then
--     RaiseException('EX_DOCNOTACCEPTREJECT');
--   END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -
  NULL;
--    /*     */
--    BEGIN
--       SELECT ProgIndex, AcceptDate, ReestrNumber
--         INTO CapProgIndex, CapAcceptDate, CapReestrNumber
--         FROM QuotesTitle qt
--        WHERE (qt.ID = new$RecordIndex);
--    EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--    END;
-- 
--    /*   -    () */
--    IF (CapProgIndex = 45) THEN
--       IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
--          /*        ,
--             */
--          new$FederalFundsRef := new$ID;
--       ELSE
--          new$FederalFundsRef := NULL;
--       END IF;
--    END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN
      select KDValue   into oldKD$ from kd where Id=:old.kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN

      /*     */
      select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
      IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
      into
      idKD1$,
      val_DocCount1$,
      val_DocType1$,
      val_Org_Ref1$,
      val_AccountIndex1$,
      val_SubKD1$,
      val_RegionCLS1$,
      val_GosNI1$,
      val_IncAccount1$,
      val_BudgetRef1$,
      val_MEANSTYPE1$  , 
      val_FACIALACC_CLS1$,
      val_TransfertCls1$         from incomes32 where id=new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not idKD1$ is null) then
      if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
      (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
        /*   ,    */
        delete
        from Incomes32
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      (new$Debit<>0))
      /*       */
      then 
        RaiseException('ex_UnknownRedirect');
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
        /*   ,   ,   */
        insert into
        Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
        Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
        val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
        val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
        new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
      END IF;
      if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
      and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
        /*      ,   */
        update Incomes32
        set
        DocNum = new$DocNum,
        DocCount = val_DocCount1$,
        iDate = new$iDate,
        DOCDATE = new$DOCDATE,
        Debit = 0,
        Credit = -new$Credit,
        DocType = val_DocType1$,
        Org_Ref = val_Org_Ref1$,
        AccountIndex = val_AccountIndex1$,
        KD = idKD1$,
        SubKD = val_SubKD1$,
        RegionCLS = val_RegionCLS1$,
        GosNI = val_GosNI1$,
        ProgIndex = 43,
        RecordIndex = new$Id,
        IncAccount = val_IncAccount1$,
        BudgetRef = val_BudgetRef1$,
        Note = new$Note,
        MEANSTYPE = val_MEANSTYPE1$,
        FACIALACC_CLS = val_FACIALACC_CLS1$,
        TransfertCls = val_TransfertCls1$,
        RVersion = -1
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
         
      END IF; 
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 41)    /*   () */
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    /*       */
    FOR REC$1 IN (SELECT inc.id
     AS val_ID42    FROM Incomes32 inc
    LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
    WHERE (inc.ProgIndex =  42) and
    (inc.RecordIndex =  new$id) and
    (inc.debit = 0) and
    (not(kd.kdvalue like unkKD$)) and
    (not(kd.kdvalue like unkVKD$))
    )
    LOOP
      BEGIN
        /*       */
        select inc.id
        into val_ID431$         FROM Incomes32 inc
        WHERE (inc.ProgIndex =  43) and
        (inc.RecordIndex =  REC$1.val_ID42)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      /*     ,   Credit, ProgIndex, RecordIndex */
      update Incomes32
      set
      DocNum = new$DocNum,
      DocCount = new$DocCount,       
      DOCDATE = new$DOCDATE,
      Debit = 0,
      DocType = new$DocType,
      Org_Ref = new$Org_Ref,
      AccountIndex = new$AccountIndex,
      KD = new$Kd,
      SubKD = new$SubKD,
      RegionCLS = new$RegionCLS,
      GosNI = new$GosNI,
      IncAccount = new$IncAccount,
      BudgetRef = new$BudgetRef,
      Note = new$Note,
      MEANSTYPE = new$MEANSTYPE,
      FACIALACC_CLS = new$FACIALACC_CLS,
      FACT = new$FACT,
      TransfertCls = new$TransfertCls,
      DirectionCls = new$DirectionCls,
      rversion = -1
      where id = val_ID431$;

        
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       --       ClsType
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                --  - 
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      --   
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   IF (NEW$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (161, :OLD.ID, SYSDATE);
      DELETE FROM DelRecIndexes
        WHERE (TableID = 161) AND (RecordId = NEW$ID);
   END IF;

END;
/
-- ALTER TRIGGER TR_INCOMES32_BU_700
CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   IF (new$Fact IS NULL) THEN 
--     new$Fact := 0;
--   END IF;
--   IF (new$DocBase IS NULL) THEN 
--     new$DocBase := 0;
--   END IF;
--   IF (new$Gosni IS NULL) THEN 
--     new$Gosni := 0;
--   END IF;
--   /* 3 -    */
--   IF (new$ProgIndex IS NULL) THEN 
--     new$ProgIndex := 3; 
--   END IF;
--   IF (new$KD IS NULL) THEN 
--     new$KD := 0; 
--   END IF;
--   /*   */
--   IF (new$FACIALACC_CLS IS NULL) THEN 
--     new$FACIALACC_CLS := 0; 
--   END IF;
--   IF (new$MeansType IS NULL) THEN 
--     new$MeansType := 0;
--   END IF;
--   IF (new$Debit IS NULL) THEN 
--     new$Debit := 0;
--   END IF;
--   IF (new$Credit IS NULL) THEN 
--     new$Credit := 0;
--   END IF;
--   IF (new$Org_Ref IS NULL) THEN 
--     new$Org_Ref := 0;
--   END IF;
--   IF (new$AccountIndex IS NULL) THEN 
--     new$AccountIndex := 0; 
--   END IF;
--   IF (new$DocType IS NULL) THEN 
--     new$DocType := 0;
--   END IF;
--   IF (new$SubKD IS NULL) THEN 
--     new$SubKD := 0;
--   END IF;
--   IF (new$RegionCLS IS NULL) THEN 
--     new$RegionCLS := 0;
--   END IF;
--   IF (new$DocCount IS NULL) THEN 
--     new$DocCount := 1;
--   END IF;
--   IF (new$BuhPaymentCLS IS NULL) THEN 
--     new$BuhPaymentCLS := 0;
--   END IF;
--   IF (new$KVSR IS NULL) THEN 
--     new$KVSR := 0;
--   END IF;
--   IF (new$KFSR IS NULL) THEN 
--     new$KFSR := 0;
--   END IF;
--   IF (new$KESR IS NULL) THEN 
--     new$KESR := 0;
--   END IF;
--   IF (new$KVR IS NULL) THEN 
--     new$KVR := 0;
--   END IF;
--   IF (new$KCSR IS NULL) THEN 
--     new$KCSR := 0;
--   END IF;
--   IF (new$OKATO IS NULL) THEN 
--     new$OKATO := 0;
--   END IF;
--   IF (new$FundsSource IS NULL) THEN 
--     new$FundsSource := 0;
--   END IF;
--   IF (new$DirectionCLS IS NULL) THEN 
--     new$DirectionCLS := 0;
--   END IF;
--   IF (new$FinType is null) then 
--     new$FinType := 0;
--   END IF;
--   IF (new$Debit * new$Credit <> 0) THEN
--     RaiseException('ex_FailDebetCretitValue');
--   END IF;
--   /*   .        */
--   IF (new$IFS_CORR IS NULL) THEN 
--     new$Ifs_Corr := 0;
--   END IF;
--   IF (new$IFS IS NULL) THEN 
--     new$Ifs := 0;
--   END IF;
--   IF (new$BuhOperationCLS IS NULL)
--   THEN 
--     GetIntConst(60, 15,new$BuhOperationCLS);
--   END IF;
--   BEGIN
-- 
--     /*     */
--     /*   after   ,*/ 
--     /*      */
--     SELECT ProgIndex, AcceptDate, ReestrNumber
--     INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
--     WHERE
--     (qt.ID = new$RecordIndex)
--     ;
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;
--   /*              
--            (  , , ) */
--   /*   -    () */
--   IF (CapProgIndex2$ = 45)
--   THEN 
--     IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
--     THEN 
--       /*        ,
--                      */            
--       new$FederalFundsRef := new$ID;
--       /* if-then*/
--     ELSE 
--       new$FederalFundsRef := NULL;
--       /* if-else*/  
--     END IF;/* if (CapProgIndex=45) */
--   END IF;
--   /*     */
--   IF (new$BudgetRef <> :old.BudgetRef) THEN
--     IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
--       IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
--         RaiseException('Ex_CantModufyBudget');
--       END IF;
--       IF (new$Progindex = 41) THEN
--         SELECT COUNT(inc.id ) INTO CNT$1
--         FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
--         IF ((CNT$1<> 0)) THEN
--           RaiseException('Ex_CantModufyBudget');
--         END IF;   
--       END IF;
--     END IF;
--   END IF;
--   /*     \*/
--   IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
--   ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
--       INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
--       WHERE fac.ID = new$FacialACC_Cls
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*    */
--   GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
--   new$targetcls,new$targetcls);  

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

  BEGIN
    SELECT Inn
     INTO new$Inn
     FROM Organizations o
    WHERE (o.ID = new$Org_Ref);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*      */
  IF (new$ProgIndex <> 42) THEN
    BEGIN
      SELECT ProgIndex, DocNumber, AcceptDate
      INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
      WHERE
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*   -  ,   */
  IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
  THEN 
    IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
    (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
    THEN 
      BEGIN
        SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
        WHERE inc.id = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (Kd_Master$ = new$Kd) THEN 
        CapAcceptDate$ := new$DOCDATE;
        CapProgIndex$  := new$ProgIndex;
        CapDocNumber$  := new$DocNum;
        /*  */        
      END IF;/*       (         )*/
    END IF;
    IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
    THEN 

      /*      */
      /* /      Incomes32, ..      ,     */

      /*     /   */
      SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
      INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
      ;
      /*            ,  .*/
      /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
                      ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
                     ) THEN
                    EXCEPTION EX_CANNOTUPDATENUMBER;*/
                 
                
      IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
      then
        if ((new$DocType <> :old.DocType )
        or (new$Debit <> :old.Debit )
        or (new$Credit <> :old.Credit)
        or (new$org_ref <> :old.org_ref)
        or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
        or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
        )
        then
          RaiseException('EX_CANNOTUPDATENUMBER');
        END IF;
      END IF;
                


      /*           */
      IF (PayDocCount$ = 0)
      THEN 
        /*       */
        GetIntConst(11, 2,ConstPayQueue$);
        /*       */
        GetIntConst(11, 1,ConstSendBy$);

        /*    */
        INSERT INTO PayDoc32
        (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
        Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
        VALUES
        (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
        new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
        /* (new.Debit - new.Credit) --- ..      ,    ,
                                     */

        /* if-then */
      ELSE 
        /*     */
        IF (((new$AccountRef = :old.AccountRef) OR
        ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
        AND (new$IncAccount = :old.IncAccount)
        AND (new$BudgetRef = :old.BudgetRef)
        AND ((new$Note = :old.Note) OR
        ((new$Note IS NULL) AND (:old.Note IS NULL)))
        AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
        ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
        AND ((new$TaxNote = :old.TaxNote) OR
        ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
        )  THEN
          new$AccountRef := new$AccountRef;
                          
        ELSE

          UPDATE PayDoc32 pd
          SET
          pd.AccountRef = new$AccountRef,
          pd.PayerAttrRef = new$IncAccount,
          pd.AcceptorAttrRef = new$AccountRef,
          pd.TextNote = new$Note,
          pd.TaxNote = new$TaxNote,
          pd.BudgetRef = new$BudgetRef,
          pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
          pd.InputDate = CapAcceptDate$,
          pd.SourceDocNumber = CapDocNumber$,
          pd.FACIALACC_CLS = new$FACIALACC_CLS
          WHERE
          (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
        END IF;
        IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
        OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
        THEN  
          IF (Divided$ > 0)
          THEN
            /*  ,      */
            RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
          ELSE
            UPDATE PayDoc32 pd
            SET
            pd.Credit = new$Debit - new$Credit
            WHERE
            (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
          END IF;/* if-then*/            
        END IF;/* if-else*/
      END IF;
      /*     / */
      /*   :     ,     */
      /*  ,     */
      SELECT MAX(pd.AcceptDate)
      INTO Date_Pd$           FROM PayDoc32 pd
      WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
      ;
      new$Idate := Date_Pd$;
      /* if-then*/
    ELSE 
      /*       
                          -
                    . */
      DELETE FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex = new$ProgIndex)
      AND (pd.RecordIndex = new$id);
      /* if-else*/  
    END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -
  NULL;
--   if ((new$DocDate is null) and (new$ProgIndex=45)) then 
--     BEGIN
--       select q.BuildDate 
--       into 
--       new$DocDate        from QuotesTitle q 
--       where q.id = new$RecordIndex 
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   if ((new$DocDate is null) and (new$IDATE is not null)) then
--     new$DocDate := new$IDATE;
--   END IF;
--   if ((new$DOCDATE is not null)) then
--     new$RecordDate := new$DOCDATE;
--   END IF;
--   /*         */
--   if ((new$IDate is not null) and (new$RejectCls is not null)) then
--     RaiseException('EX_DOCNOTACCEPTREJECT');
--   END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -
  NULL;
--    /*     */
--    BEGIN
--       SELECT ProgIndex, AcceptDate, ReestrNumber
--         INTO CapProgIndex, CapAcceptDate, CapReestrNumber
--         FROM QuotesTitle qt
--        WHERE (qt.ID = new$RecordIndex);
--    EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--    END;
-- 
--    /*   -    () */
--    IF (CapProgIndex = 45) THEN
--       IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
--          /*        ,
--             */
--          new$FederalFundsRef := new$ID;
--       ELSE
--          new$FederalFundsRef := NULL;
--       END IF;
--    END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN
      select KDValue   into oldKD$ from kd where Id=:old.kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN

      /*     */
      select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
      IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
      into
      idKD1$,
      val_DocCount1$,
      val_DocType1$,
      val_Org_Ref1$,
      val_AccountIndex1$,
      val_SubKD1$,
      val_RegionCLS1$,
      val_GosNI1$,
      val_IncAccount1$,
      val_BudgetRef1$,
      val_MEANSTYPE1$  , 
      val_FACIALACC_CLS1$,
      val_TransfertCls1$         from incomes32 where id=new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not idKD1$ is null) then
      if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
      (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
        /*   ,    */
        delete
        from Incomes32
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      (new$Debit<>0))
      /*       */
      then 
        RaiseException('ex_UnknownRedirect');
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
        /*   ,   ,   */
        insert into
        Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
        Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
        val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
        val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
        new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
      END IF;
      if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
      and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
        /*      ,   */
        update Incomes32
        set
        DocNum = new$DocNum,
        DocCount = val_DocCount1$,
        iDate = new$iDate,
        DOCDATE = new$DOCDATE,
        Debit = 0,
        Credit = -new$Credit,
        DocType = val_DocType1$,
        Org_Ref = val_Org_Ref1$,
        AccountIndex = val_AccountIndex1$,
        KD = idKD1$,
        SubKD = val_SubKD1$,
        RegionCLS = val_RegionCLS1$,
        GosNI = val_GosNI1$,
        ProgIndex = 43,
        RecordIndex = new$Id,
        IncAccount = val_IncAccount1$,
        BudgetRef = val_BudgetRef1$,
        Note = new$Note,
        MEANSTYPE = val_MEANSTYPE1$,
        FACIALACC_CLS = val_FACIALACC_CLS1$,
        TransfertCls = val_TransfertCls1$,
        RVersion = -1
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
         
      END IF; 
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 41)    /*   () */
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    /*       */
    FOR REC$1 IN (SELECT inc.id
     AS val_ID42    FROM Incomes32 inc
    LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
    WHERE (inc.ProgIndex =  42) and
    (inc.RecordIndex =  new$id) and
    (inc.debit = 0) and
    (not(kd.kdvalue like unkKD$)) and
    (not(kd.kdvalue like unkVKD$))
    )
    LOOP
      BEGIN
        /*       */
        select inc.id
        into val_ID431$         FROM Incomes32 inc
        WHERE (inc.ProgIndex =  43) and
        (inc.RecordIndex =  REC$1.val_ID42)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      /*     ,   Credit, ProgIndex, RecordIndex */
      update Incomes32
      set
      DocNum = new$DocNum,
      DocCount = new$DocCount,       
      DOCDATE = new$DOCDATE,
      Debit = 0,
      DocType = new$DocType,
      Org_Ref = new$Org_Ref,
      AccountIndex = new$AccountIndex,
      KD = new$Kd,
      SubKD = new$SubKD,
      RegionCLS = new$RegionCLS,
      GosNI = new$GosNI,
      IncAccount = new$IncAccount,
      BudgetRef = new$BudgetRef,
      Note = new$Note,
      MEANSTYPE = new$MEANSTYPE,
      FACIALACC_CLS = new$FACIALACC_CLS,
      FACT = new$FACT,
      TransfertCls = new$TransfertCls,
      DirectionCls = new$DirectionCls,
      rversion = -1
      where id = val_ID431$;

        
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       --       ClsType
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                --  - 
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      --   
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (new$RVersion IS NULL) THEN
--       new$RVersion := 1;
--    ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
--       new$RVersion := :OLD.RVersion;
--    ELSE
--       new$RVersion := :OLD.RVersion + 1;
--    END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   IF (NEW$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (161, :OLD.ID, SYSDATE);
      DELETE FROM DelRecIndexes
        WHERE (TableID = 161) AND (RecordId = NEW$ID);
   END IF;

END;
/
-- ALTER TRIGGER tr_Incomes32_bu_0
CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   IF (new$Fact IS NULL) THEN 
--     new$Fact := 0;
--   END IF;
--   IF (new$DocBase IS NULL) THEN 
--     new$DocBase := 0;
--   END IF;
--   IF (new$Gosni IS NULL) THEN 
--     new$Gosni := 0;
--   END IF;
--   /* 3 -    */
--   IF (new$ProgIndex IS NULL) THEN 
--     new$ProgIndex := 3; 
--   END IF;
--   IF (new$KD IS NULL) THEN 
--     new$KD := 0; 
--   END IF;
--   /*   */
--   IF (new$FACIALACC_CLS IS NULL) THEN 
--     new$FACIALACC_CLS := 0; 
--   END IF;
--   IF (new$MeansType IS NULL) THEN 
--     new$MeansType := 0;
--   END IF;
--   IF (new$Debit IS NULL) THEN 
--     new$Debit := 0;
--   END IF;
--   IF (new$Credit IS NULL) THEN 
--     new$Credit := 0;
--   END IF;
--   IF (new$Org_Ref IS NULL) THEN 
--     new$Org_Ref := 0;
--   END IF;
--   IF (new$AccountIndex IS NULL) THEN 
--     new$AccountIndex := 0; 
--   END IF;
--   IF (new$DocType IS NULL) THEN 
--     new$DocType := 0;
--   END IF;
--   IF (new$SubKD IS NULL) THEN 
--     new$SubKD := 0;
--   END IF;
--   IF (new$RegionCLS IS NULL) THEN 
--     new$RegionCLS := 0;
--   END IF;
--   IF (new$DocCount IS NULL) THEN 
--     new$DocCount := 1;
--   END IF;
--   IF (new$BuhPaymentCLS IS NULL) THEN 
--     new$BuhPaymentCLS := 0;
--   END IF;
--   IF (new$KVSR IS NULL) THEN 
--     new$KVSR := 0;
--   END IF;
--   IF (new$KFSR IS NULL) THEN 
--     new$KFSR := 0;
--   END IF;
--   IF (new$KESR IS NULL) THEN 
--     new$KESR := 0;
--   END IF;
--   IF (new$KVR IS NULL) THEN 
--     new$KVR := 0;
--   END IF;
--   IF (new$KCSR IS NULL) THEN 
--     new$KCSR := 0;
--   END IF;
--   IF (new$OKATO IS NULL) THEN 
--     new$OKATO := 0;
--   END IF;
--   IF (new$FundsSource IS NULL) THEN 
--     new$FundsSource := 0;
--   END IF;
--   IF (new$DirectionCLS IS NULL) THEN 
--     new$DirectionCLS := 0;
--   END IF;
--   IF (new$FinType is null) then 
--     new$FinType := 0;
--   END IF;
--   IF (new$Debit * new$Credit <> 0) THEN
--     RaiseException('ex_FailDebetCretitValue');
--   END IF;
--   /*   .        */
--   IF (new$IFS_CORR IS NULL) THEN 
--     new$Ifs_Corr := 0;
--   END IF;
--   IF (new$IFS IS NULL) THEN 
--     new$Ifs := 0;
--   END IF;
--   IF (new$BuhOperationCLS IS NULL)
--   THEN 
--     GetIntConst(60, 15,new$BuhOperationCLS);
--   END IF;
--   BEGIN
-- 
--     /*     */
--     /*   after   ,*/ 
--     /*      */
--     SELECT ProgIndex, AcceptDate, ReestrNumber
--     INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
--     WHERE
--     (qt.ID = new$RecordIndex)
--     ;
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;
--   /*              
--            (  , , ) */
--   /*   -    () */
--   IF (CapProgIndex2$ = 45)
--   THEN 
--     IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
--     THEN 
--       /*        ,
--                      */            
--       new$FederalFundsRef := new$ID;
--       /* if-then*/
--     ELSE 
--       new$FederalFundsRef := NULL;
--       /* if-else*/  
--     END IF;/* if (CapProgIndex=45) */
--   END IF;
--   /*     */
--   IF (new$BudgetRef <> :old.BudgetRef) THEN
--     IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
--       IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
--         RaiseException('Ex_CantModufyBudget');
--       END IF;
--       IF (new$Progindex = 41) THEN
--         SELECT COUNT(inc.id ) INTO CNT$1
--         FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
--         IF ((CNT$1<> 0)) THEN
--           RaiseException('Ex_CantModufyBudget');
--         END IF;   
--       END IF;
--     END IF;
--   END IF;
--   /*     \*/
--   IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
--   ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
--       INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
--       WHERE fac.ID = new$FacialACC_Cls
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*    */
--   GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
--   new$targetcls,new$targetcls);  

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -
  NULL;
--   BEGIN
--     SELECT Inn
--      INTO new$Inn
--      FROM Organizations o
--     WHERE (o.ID = new$Org_Ref);
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*      */
  IF (new$ProgIndex <> 42) THEN
    BEGIN
      SELECT ProgIndex, DocNumber, AcceptDate
      INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
      WHERE
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*   -  ,   */
  IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
  THEN 
    IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
    (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
    THEN 
      BEGIN
        SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
        WHERE inc.id = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (Kd_Master$ = new$Kd) THEN 
        CapAcceptDate$ := new$DOCDATE;
        CapProgIndex$  := new$ProgIndex;
        CapDocNumber$  := new$DocNum;
        /*  */        
      END IF;/*       (         )*/
    END IF;
    IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
    THEN 

      /*      */
      /* /      Incomes32, ..      ,     */

      /*     /   */
      SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
      INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
      ;
      /*            ,  .*/
      /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
                      ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
                     ) THEN
                    EXCEPTION EX_CANNOTUPDATENUMBER;*/
                 
                
      IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
      then
        if ((new$DocType <> :old.DocType )
        or (new$Debit <> :old.Debit )
        or (new$Credit <> :old.Credit)
        or (new$org_ref <> :old.org_ref)
        or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
        or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
        )
        then
          RaiseException('EX_CANNOTUPDATENUMBER');
        END IF;
      END IF;
                


      /*           */
      IF (PayDocCount$ = 0)
      THEN 
        /*       */
        GetIntConst(11, 2,ConstPayQueue$);
        /*       */
        GetIntConst(11, 1,ConstSendBy$);

        /*    */
        INSERT INTO PayDoc32
        (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
        Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
        VALUES
        (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
        new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
        /* (new.Debit - new.Credit) --- ..      ,    ,
                                     */

        /* if-then */
      ELSE 
        /*     */
        IF (((new$AccountRef = :old.AccountRef) OR
        ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
        AND (new$IncAccount = :old.IncAccount)
        AND (new$BudgetRef = :old.BudgetRef)
        AND ((new$Note = :old.Note) OR
        ((new$Note IS NULL) AND (:old.Note IS NULL)))
        AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
        ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
        AND ((new$TaxNote = :old.TaxNote) OR
        ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
        )  THEN
          new$AccountRef := new$AccountRef;
                          
        ELSE

          UPDATE PayDoc32 pd
          SET
          pd.AccountRef = new$AccountRef,
          pd.PayerAttrRef = new$IncAccount,
          pd.AcceptorAttrRef = new$AccountRef,
          pd.TextNote = new$Note,
          pd.TaxNote = new$TaxNote,
          pd.BudgetRef = new$BudgetRef,
          pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
          pd.InputDate = CapAcceptDate$,
          pd.SourceDocNumber = CapDocNumber$,
          pd.FACIALACC_CLS = new$FACIALACC_CLS
          WHERE
          (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
        END IF;
        IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
        OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
        THEN  
          IF (Divided$ > 0)
          THEN
            /*  ,      */
            RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
          ELSE
            UPDATE PayDoc32 pd
            SET
            pd.Credit = new$Debit - new$Credit
            WHERE
            (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
          END IF;/* if-then*/            
        END IF;/* if-else*/
      END IF;
      /*     / */
      /*   :     ,     */
      /*  ,     */
      SELECT MAX(pd.AcceptDate)
      INTO Date_Pd$           FROM PayDoc32 pd
      WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
      ;
      new$Idate := Date_Pd$;
      /* if-then*/
    ELSE 
      /*       
                          -
                    . */
      DELETE FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex = new$ProgIndex)
      AND (pd.RecordIndex = new$id);
      /* if-else*/  
    END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -
  NULL;
--   if ((new$DocDate is null) and (new$ProgIndex=45)) then 
--     BEGIN
--       select q.BuildDate 
--       into 
--       new$DocDate        from QuotesTitle q 
--       where q.id = new$RecordIndex 
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   if ((new$DocDate is null) and (new$IDATE is not null)) then
--     new$DocDate := new$IDATE;
--   END IF;
--   if ((new$DOCDATE is not null)) then
--     new$RecordDate := new$DOCDATE;
--   END IF;
--   /*         */
--   if ((new$IDate is not null) and (new$RejectCls is not null)) then
--     RaiseException('EX_DOCNOTACCEPTREJECT');
--   END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -
  NULL;
--    /*     */
--    BEGIN
--       SELECT ProgIndex, AcceptDate, ReestrNumber
--         INTO CapProgIndex, CapAcceptDate, CapReestrNumber
--         FROM QuotesTitle qt
--        WHERE (qt.ID = new$RecordIndex);
--    EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--    END;
-- 
--    /*   -    () */
--    IF (CapProgIndex = 45) THEN
--       IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
--          /*        ,
--             */
--          new$FederalFundsRef := new$ID;
--       ELSE
--          new$FederalFundsRef := NULL;
--       END IF;
--    END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN
      select KDValue   into oldKD$ from kd where Id=:old.kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN

      /*     */
      select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
      IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
      into
      idKD1$,
      val_DocCount1$,
      val_DocType1$,
      val_Org_Ref1$,
      val_AccountIndex1$,
      val_SubKD1$,
      val_RegionCLS1$,
      val_GosNI1$,
      val_IncAccount1$,
      val_BudgetRef1$,
      val_MEANSTYPE1$  , 
      val_FACIALACC_CLS1$,
      val_TransfertCls1$         from incomes32 where id=new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not idKD1$ is null) then
      if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
      (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
        /*   ,    */
        delete
        from Incomes32
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      (new$Debit<>0))
      /*       */
      then 
        RaiseException('ex_UnknownRedirect');
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
        /*   ,   ,   */
        insert into
        Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
        Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
        val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
        val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
        new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
      END IF;
      if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
      and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
        /*      ,   */
        update Incomes32
        set
        DocNum = new$DocNum,
        DocCount = val_DocCount1$,
        iDate = new$iDate,
        DOCDATE = new$DOCDATE,
        Debit = 0,
        Credit = -new$Credit,
        DocType = val_DocType1$,
        Org_Ref = val_Org_Ref1$,
        AccountIndex = val_AccountIndex1$,
        KD = idKD1$,
        SubKD = val_SubKD1$,
        RegionCLS = val_RegionCLS1$,
        GosNI = val_GosNI1$,
        ProgIndex = 43,
        RecordIndex = new$Id,
        IncAccount = val_IncAccount1$,
        BudgetRef = val_BudgetRef1$,
        Note = new$Note,
        MEANSTYPE = val_MEANSTYPE1$,
        FACIALACC_CLS = val_FACIALACC_CLS1$,
        TransfertCls = val_TransfertCls1$,
        RVersion = -1
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
         
      END IF; 
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 41)    /*   () */
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    /*       */
    FOR REC$1 IN (SELECT inc.id
     AS val_ID42    FROM Incomes32 inc
    LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
    WHERE (inc.ProgIndex =  42) and
    (inc.RecordIndex =  new$id) and
    (inc.debit = 0) and
    (not(kd.kdvalue like unkKD$)) and
    (not(kd.kdvalue like unkVKD$))
    )
    LOOP
      BEGIN
        /*       */
        select inc.id
        into val_ID431$         FROM Incomes32 inc
        WHERE (inc.ProgIndex =  43) and
        (inc.RecordIndex =  REC$1.val_ID42)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      /*     ,   Credit, ProgIndex, RecordIndex */
      update Incomes32
      set
      DocNum = new$DocNum,
      DocCount = new$DocCount,       
      DOCDATE = new$DOCDATE,
      Debit = 0,
      DocType = new$DocType,
      Org_Ref = new$Org_Ref,
      AccountIndex = new$AccountIndex,
      KD = new$Kd,
      SubKD = new$SubKD,
      RegionCLS = new$RegionCLS,
      GosNI = new$GosNI,
      IncAccount = new$IncAccount,
      BudgetRef = new$BudgetRef,
      Note = new$Note,
      MEANSTYPE = new$MEANSTYPE,
      FACIALACC_CLS = new$FACIALACC_CLS,
      FACT = new$FACT,
      TransfertCls = new$TransfertCls,
      DirectionCls = new$DirectionCls,
      rversion = -1
      where id = val_ID431$;

        
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       --       ClsType
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                --  - 
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      --   
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (new$RVersion IS NULL) THEN
--       new$RVersion := 1;
--    ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
--       new$RVersion := :OLD.RVersion;
--    ELSE
--       new$RVersion := :OLD.RVersion + 1;
--    END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   IF (NEW$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (161, :OLD.ID, SYSDATE);
      DELETE FROM DelRecIndexes
        WHERE (TableID = 161) AND (RecordId = NEW$ID);
   END IF;

END;
/
-- ALTER TRIGGER TR_Incomes_BU_5
CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   IF (new$Fact IS NULL) THEN 
--     new$Fact := 0;
--   END IF;
--   IF (new$DocBase IS NULL) THEN 
--     new$DocBase := 0;
--   END IF;
--   IF (new$Gosni IS NULL) THEN 
--     new$Gosni := 0;
--   END IF;
--   /* 3 -    */
--   IF (new$ProgIndex IS NULL) THEN 
--     new$ProgIndex := 3; 
--   END IF;
--   IF (new$KD IS NULL) THEN 
--     new$KD := 0; 
--   END IF;
--   /*   */
--   IF (new$FACIALACC_CLS IS NULL) THEN 
--     new$FACIALACC_CLS := 0; 
--   END IF;
--   IF (new$MeansType IS NULL) THEN 
--     new$MeansType := 0;
--   END IF;
--   IF (new$Debit IS NULL) THEN 
--     new$Debit := 0;
--   END IF;
--   IF (new$Credit IS NULL) THEN 
--     new$Credit := 0;
--   END IF;
--   IF (new$Org_Ref IS NULL) THEN 
--     new$Org_Ref := 0;
--   END IF;
--   IF (new$AccountIndex IS NULL) THEN 
--     new$AccountIndex := 0; 
--   END IF;
--   IF (new$DocType IS NULL) THEN 
--     new$DocType := 0;
--   END IF;
--   IF (new$SubKD IS NULL) THEN 
--     new$SubKD := 0;
--   END IF;
--   IF (new$RegionCLS IS NULL) THEN 
--     new$RegionCLS := 0;
--   END IF;
--   IF (new$DocCount IS NULL) THEN 
--     new$DocCount := 1;
--   END IF;
--   IF (new$BuhPaymentCLS IS NULL) THEN 
--     new$BuhPaymentCLS := 0;
--   END IF;
--   IF (new$KVSR IS NULL) THEN 
--     new$KVSR := 0;
--   END IF;
--   IF (new$KFSR IS NULL) THEN 
--     new$KFSR := 0;
--   END IF;
--   IF (new$KESR IS NULL) THEN 
--     new$KESR := 0;
--   END IF;
--   IF (new$KVR IS NULL) THEN 
--     new$KVR := 0;
--   END IF;
--   IF (new$KCSR IS NULL) THEN 
--     new$KCSR := 0;
--   END IF;
--   IF (new$OKATO IS NULL) THEN 
--     new$OKATO := 0;
--   END IF;
--   IF (new$FundsSource IS NULL) THEN 
--     new$FundsSource := 0;
--   END IF;
--   IF (new$DirectionCLS IS NULL) THEN 
--     new$DirectionCLS := 0;
--   END IF;
--   IF (new$FinType is null) then 
--     new$FinType := 0;
--   END IF;
--   IF (new$Debit * new$Credit <> 0) THEN
--     RaiseException('ex_FailDebetCretitValue');
--   END IF;
--   /*   .        */
--   IF (new$IFS_CORR IS NULL) THEN 
--     new$Ifs_Corr := 0;
--   END IF;
--   IF (new$IFS IS NULL) THEN 
--     new$Ifs := 0;
--   END IF;
--   IF (new$BuhOperationCLS IS NULL)
--   THEN 
--     GetIntConst(60, 15,new$BuhOperationCLS);
--   END IF;
--   BEGIN
-- 
--     /*     */
--     /*   after   ,*/ 
--     /*      */
--     SELECT ProgIndex, AcceptDate, ReestrNumber
--     INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
--     WHERE
--     (qt.ID = new$RecordIndex)
--     ;
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;
--   /*              
--            (  , , ) */
--   /*   -    () */
--   IF (CapProgIndex2$ = 45)
--   THEN 
--     IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
--     THEN 
--       /*        ,
--                      */            
--       new$FederalFundsRef := new$ID;
--       /* if-then*/
--     ELSE 
--       new$FederalFundsRef := NULL;
--       /* if-else*/  
--     END IF;/* if (CapProgIndex=45) */
--   END IF;
--   /*     */
--   IF (new$BudgetRef <> :old.BudgetRef) THEN
--     IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
--       IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
--         RaiseException('Ex_CantModufyBudget');
--       END IF;
--       IF (new$Progindex = 41) THEN
--         SELECT COUNT(inc.id ) INTO CNT$1
--         FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
--         IF ((CNT$1<> 0)) THEN
--           RaiseException('Ex_CantModufyBudget');
--         END IF;   
--       END IF;
--     END IF;
--   END IF;
--   /*     \*/
--   IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
--   ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
--       INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
--       WHERE fac.ID = new$FacialACC_Cls
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*    */
--   GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
--   new$targetcls,new$targetcls);  

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
--       new$DocNum := CAST (new$DocNumber AS VARCHAR2);
--    END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -
  NULL;
--   BEGIN
--     SELECT Inn
--      INTO new$Inn
--      FROM Organizations o
--     WHERE (o.ID = new$Org_Ref);
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*      */
  IF (new$ProgIndex <> 42) THEN
    BEGIN
      SELECT ProgIndex, DocNumber, AcceptDate
      INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
      WHERE
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*   -  ,   */
  IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
  THEN 
    IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
    (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
    THEN 
      BEGIN
        SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
        WHERE inc.id = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (Kd_Master$ = new$Kd) THEN 
        CapAcceptDate$ := new$DOCDATE;
        CapProgIndex$  := new$ProgIndex;
        CapDocNumber$  := new$DocNum;
        /*  */        
      END IF;/*       (         )*/
    END IF;
    IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
    THEN 

      /*      */
      /* /      Incomes32, ..      ,     */

      /*     /   */
      SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
      INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
      ;
      /*            ,  .*/
      /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
                      ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
                     ) THEN
                    EXCEPTION EX_CANNOTUPDATENUMBER;*/
                 
                
      IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
      then
        if ((new$DocType <> :old.DocType )
        or (new$Debit <> :old.Debit )
        or (new$Credit <> :old.Credit)
        or (new$org_ref <> :old.org_ref)
        or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
        or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
        )
        then
          RaiseException('EX_CANNOTUPDATENUMBER');
        END IF;
      END IF;
                


      /*           */
      IF (PayDocCount$ = 0)
      THEN 
        /*       */
        GetIntConst(11, 2,ConstPayQueue$);
        /*       */
        GetIntConst(11, 1,ConstSendBy$);

        /*    */
        INSERT INTO PayDoc32
        (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
        Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
        VALUES
        (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
        new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
        /* (new.Debit - new.Credit) --- ..      ,    ,
                                     */

        /* if-then */
      ELSE 
        /*     */
        IF (((new$AccountRef = :old.AccountRef) OR
        ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
        AND (new$IncAccount = :old.IncAccount)
        AND (new$BudgetRef = :old.BudgetRef)
        AND ((new$Note = :old.Note) OR
        ((new$Note IS NULL) AND (:old.Note IS NULL)))
        AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
        ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
        AND ((new$TaxNote = :old.TaxNote) OR
        ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
        )  THEN
          new$AccountRef := new$AccountRef;
                          
        ELSE

          UPDATE PayDoc32 pd
          SET
          pd.AccountRef = new$AccountRef,
          pd.PayerAttrRef = new$IncAccount,
          pd.AcceptorAttrRef = new$AccountRef,
          pd.TextNote = new$Note,
          pd.TaxNote = new$TaxNote,
          pd.BudgetRef = new$BudgetRef,
          pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
          pd.InputDate = CapAcceptDate$,
          pd.SourceDocNumber = CapDocNumber$,
          pd.FACIALACC_CLS = new$FACIALACC_CLS
          WHERE
          (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
        END IF;
        IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
        OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
        THEN  
          IF (Divided$ > 0)
          THEN
            /*  ,      */
            RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
          ELSE
            UPDATE PayDoc32 pd
            SET
            pd.Credit = new$Debit - new$Credit
            WHERE
            (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
          END IF;/* if-then*/            
        END IF;/* if-else*/
      END IF;
      /*     / */
      /*   :     ,     */
      /*  ,     */
      SELECT MAX(pd.AcceptDate)
      INTO Date_Pd$           FROM PayDoc32 pd
      WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
      ;
      new$Idate := Date_Pd$;
      /* if-then*/
    ELSE 
      /*       
                          -
                    . */
      DELETE FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex = new$ProgIndex)
      AND (pd.RecordIndex = new$id);
      /* if-else*/  
    END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -
  NULL;
--   if ((new$DocDate is null) and (new$ProgIndex=45)) then 
--     BEGIN
--       select q.BuildDate 
--       into 
--       new$DocDate        from QuotesTitle q 
--       where q.id = new$RecordIndex 
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   if ((new$DocDate is null) and (new$IDATE is not null)) then
--     new$DocDate := new$IDATE;
--   END IF;
--   if ((new$DOCDATE is not null)) then
--     new$RecordDate := new$DOCDATE;
--   END IF;
--   /*         */
--   if ((new$IDate is not null) and (new$RejectCls is not null)) then
--     RaiseException('EX_DOCNOTACCEPTREJECT');
--   END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -
  NULL;
--    /*     */
--    BEGIN
--       SELECT ProgIndex, AcceptDate, ReestrNumber
--         INTO CapProgIndex, CapAcceptDate, CapReestrNumber
--         FROM QuotesTitle qt
--        WHERE (qt.ID = new$RecordIndex);
--    EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--    END;
-- 
--    /*   -    () */
--    IF (CapProgIndex = 45) THEN
--       IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
--          /*        ,
--             */
--          new$FederalFundsRef := new$ID;
--       ELSE
--          new$FederalFundsRef := NULL;
--       END IF;
--    END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN
      select KDValue   into oldKD$ from kd where Id=:old.kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN

      /*     */
      select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
      IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
      into
      idKD1$,
      val_DocCount1$,
      val_DocType1$,
      val_Org_Ref1$,
      val_AccountIndex1$,
      val_SubKD1$,
      val_RegionCLS1$,
      val_GosNI1$,
      val_IncAccount1$,
      val_BudgetRef1$,
      val_MEANSTYPE1$  , 
      val_FACIALACC_CLS1$,
      val_TransfertCls1$         from incomes32 where id=new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not idKD1$ is null) then
      if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
      (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
        /*   ,    */
        delete
        from Incomes32
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      (new$Debit<>0))
      /*       */
      then 
        RaiseException('ex_UnknownRedirect');
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
        /*   ,   ,   */
        insert into
        Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
        Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
        val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
        val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
        new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
      END IF;
      if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
      and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
        /*      ,   */
        update Incomes32
        set
        DocNum = new$DocNum,
        DocCount = val_DocCount1$,
        iDate = new$iDate,
        DOCDATE = new$DOCDATE,
        Debit = 0,
        Credit = -new$Credit,
        DocType = val_DocType1$,
        Org_Ref = val_Org_Ref1$,
        AccountIndex = val_AccountIndex1$,
        KD = idKD1$,
        SubKD = val_SubKD1$,
        RegionCLS = val_RegionCLS1$,
        GosNI = val_GosNI1$,
        ProgIndex = 43,
        RecordIndex = new$Id,
        IncAccount = val_IncAccount1$,
        BudgetRef = val_BudgetRef1$,
        Note = new$Note,
        MEANSTYPE = val_MEANSTYPE1$,
        FACIALACC_CLS = val_FACIALACC_CLS1$,
        TransfertCls = val_TransfertCls1$,
        RVersion = -1
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
         
      END IF; 
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 41)    /*   () */
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    /*       */
    FOR REC$1 IN (SELECT inc.id
     AS val_ID42    FROM Incomes32 inc
    LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
    WHERE (inc.ProgIndex =  42) and
    (inc.RecordIndex =  new$id) and
    (inc.debit = 0) and
    (not(kd.kdvalue like unkKD$)) and
    (not(kd.kdvalue like unkVKD$))
    )
    LOOP
      BEGIN
        /*       */
        select inc.id
        into val_ID431$         FROM Incomes32 inc
        WHERE (inc.ProgIndex =  43) and
        (inc.RecordIndex =  REC$1.val_ID42)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      /*     ,   Credit, ProgIndex, RecordIndex */
      update Incomes32
      set
      DocNum = new$DocNum,
      DocCount = new$DocCount,       
      DOCDATE = new$DOCDATE,
      Debit = 0,
      DocType = new$DocType,
      Org_Ref = new$Org_Ref,
      AccountIndex = new$AccountIndex,
      KD = new$Kd,
      SubKD = new$SubKD,
      RegionCLS = new$RegionCLS,
      GosNI = new$GosNI,
      IncAccount = new$IncAccount,
      BudgetRef = new$BudgetRef,
      Note = new$Note,
      MEANSTYPE = new$MEANSTYPE,
      FACIALACC_CLS = new$FACIALACC_CLS,
      FACT = new$FACT,
      TransfertCls = new$TransfertCls,
      DirectionCls = new$DirectionCls,
      rversion = -1
      where id = val_ID431$;

        
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       --       ClsType
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                --  - 
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      --   
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (new$RVersion IS NULL) THEN
--       new$RVersion := 1;
--    ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
--       new$RVersion := :OLD.RVersion;
--    ELSE
--       new$RVersion := :OLD.RVersion + 1;
--    END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   IF (NEW$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (161, :OLD.ID, SYSDATE);
      DELETE FROM DelRecIndexes
        WHERE (TableID = 161) AND (RecordId = NEW$ID);
   END IF;

END;
/
-- ALTER TRIGGER t_Incomes32_bu_20
CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   IF (new$Fact IS NULL) THEN 
--     new$Fact := 0;
--   END IF;
--   IF (new$DocBase IS NULL) THEN 
--     new$DocBase := 0;
--   END IF;
--   IF (new$Gosni IS NULL) THEN 
--     new$Gosni := 0;
--   END IF;
--   /* 3 -    */
--   IF (new$ProgIndex IS NULL) THEN 
--     new$ProgIndex := 3; 
--   END IF;
--   IF (new$KD IS NULL) THEN 
--     new$KD := 0; 
--   END IF;
--   /*   */
--   IF (new$FACIALACC_CLS IS NULL) THEN 
--     new$FACIALACC_CLS := 0; 
--   END IF;
--   IF (new$MeansType IS NULL) THEN 
--     new$MeansType := 0;
--   END IF;
--   IF (new$Debit IS NULL) THEN 
--     new$Debit := 0;
--   END IF;
--   IF (new$Credit IS NULL) THEN 
--     new$Credit := 0;
--   END IF;
--   IF (new$Org_Ref IS NULL) THEN 
--     new$Org_Ref := 0;
--   END IF;
--   IF (new$AccountIndex IS NULL) THEN 
--     new$AccountIndex := 0; 
--   END IF;
--   IF (new$DocType IS NULL) THEN 
--     new$DocType := 0;
--   END IF;
--   IF (new$SubKD IS NULL) THEN 
--     new$SubKD := 0;
--   END IF;
--   IF (new$RegionCLS IS NULL) THEN 
--     new$RegionCLS := 0;
--   END IF;
--   IF (new$DocCount IS NULL) THEN 
--     new$DocCount := 1;
--   END IF;
--   IF (new$BuhPaymentCLS IS NULL) THEN 
--     new$BuhPaymentCLS := 0;
--   END IF;
--   IF (new$KVSR IS NULL) THEN 
--     new$KVSR := 0;
--   END IF;
--   IF (new$KFSR IS NULL) THEN 
--     new$KFSR := 0;
--   END IF;
--   IF (new$KESR IS NULL) THEN 
--     new$KESR := 0;
--   END IF;
--   IF (new$KVR IS NULL) THEN 
--     new$KVR := 0;
--   END IF;
--   IF (new$KCSR IS NULL) THEN 
--     new$KCSR := 0;
--   END IF;
--   IF (new$OKATO IS NULL) THEN 
--     new$OKATO := 0;
--   END IF;
--   IF (new$FundsSource IS NULL) THEN 
--     new$FundsSource := 0;
--   END IF;
--   IF (new$DirectionCLS IS NULL) THEN 
--     new$DirectionCLS := 0;
--   END IF;
--   IF (new$FinType is null) then 
--     new$FinType := 0;
--   END IF;
--   IF (new$Debit * new$Credit <> 0) THEN
--     RaiseException('ex_FailDebetCretitValue');
--   END IF;
--   /*   .        */
--   IF (new$IFS_CORR IS NULL) THEN 
--     new$Ifs_Corr := 0;
--   END IF;
--   IF (new$IFS IS NULL) THEN 
--     new$Ifs := 0;
--   END IF;
--   IF (new$BuhOperationCLS IS NULL)
--   THEN 
--     GetIntConst(60, 15,new$BuhOperationCLS);
--   END IF;
--   BEGIN
-- 
--     /*     */
--     /*   after   ,*/ 
--     /*      */
--     SELECT ProgIndex, AcceptDate, ReestrNumber
--     INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
--     WHERE
--     (qt.ID = new$RecordIndex)
--     ;
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;
--   /*              
--            (  , , ) */
--   /*   -    () */
--   IF (CapProgIndex2$ = 45)
--   THEN 
--     IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
--     THEN 
--       /*        ,
--                      */            
--       new$FederalFundsRef := new$ID;
--       /* if-then*/
--     ELSE 
--       new$FederalFundsRef := NULL;
--       /* if-else*/  
--     END IF;/* if (CapProgIndex=45) */
--   END IF;
--   /*     */
--   IF (new$BudgetRef <> :old.BudgetRef) THEN
--     IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
--       IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
--         RaiseException('Ex_CantModufyBudget');
--       END IF;
--       IF (new$Progindex = 41) THEN
--         SELECT COUNT(inc.id ) INTO CNT$1
--         FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
--         IF ((CNT$1<> 0)) THEN
--           RaiseException('Ex_CantModufyBudget');
--         END IF;   
--       END IF;
--     END IF;
--   END IF;
--   /*     \*/
--   IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
--   ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
--       INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
--       WHERE fac.ID = new$FacialACC_Cls
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*    */
--   GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
--   new$targetcls,new$targetcls);  

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
--       new$DocNum := CAST (new$DocNumber AS VARCHAR2);
--    END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -
  NULL;
--   BEGIN
--     SELECT Inn
--      INTO new$Inn
--      FROM Organizations o
--     WHERE (o.ID = new$Org_Ref);
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -
  NULL;
--   /*      */
--   IF (new$ProgIndex <> 42) THEN
--     BEGIN
--       SELECT ProgIndex, DocNumber, AcceptDate
--       INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
--       WHERE
--       (qt.ID = new$RecordIndex)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*   -  ,   */
--   IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
--   THEN 
--     IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
--     (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
--     THEN 
--       BEGIN
--         SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
--         WHERE inc.id = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       IF (Kd_Master$ = new$Kd) THEN 
--         CapAcceptDate$ := new$DOCDATE;
--         CapProgIndex$  := new$ProgIndex;
--         CapDocNumber$  := new$DocNum;
--         /*  */        
--       END IF;/*       (         )*/
--     END IF;
--     IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
--     THEN 
-- 
--       /*      */
--       /* /      Incomes32, ..      ,     */
-- 
--       /*     /   */
--       SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
--       INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
--       WHERE
--       (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
--       ;
--       /*            ,  .*/
--       /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
--                       ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
--                      ) THEN
--                     EXCEPTION EX_CANNOTUPDATENUMBER;*/
--                  
--                 
--       IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
--       then
--         if ((new$DocType <> :old.DocType )
--         or (new$Debit <> :old.Debit )
--         or (new$Credit <> :old.Credit)
--         or (new$org_ref <> :old.org_ref)
--         or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
--         or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
--         )
--         then
--           RaiseException('EX_CANNOTUPDATENUMBER');
--         END IF;
--       END IF;
--                 
-- 
-- 
--       /*           */
--       IF (PayDocCount$ = 0)
--       THEN 
--         /*       */
--         GetIntConst(11, 2,ConstPayQueue$);
--         /*       */
--         GetIntConst(11, 1,ConstSendBy$);
-- 
--         /*    */
--         INSERT INTO PayDoc32
--         (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
--         Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
--         VALUES
--         (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
--         new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
--         /* (new.Debit - new.Credit) --- ..      ,    ,
--                                      */
-- 
--         /* if-then */
--       ELSE 
--         /*     */
--         IF (((new$AccountRef = :old.AccountRef) OR
--         ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
--         AND (new$IncAccount = :old.IncAccount)
--         AND (new$BudgetRef = :old.BudgetRef)
--         AND ((new$Note = :old.Note) OR
--         ((new$Note IS NULL) AND (:old.Note IS NULL)))
--         AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
--         ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
--         AND ((new$TaxNote = :old.TaxNote) OR
--         ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
--         )  THEN
--           new$AccountRef := new$AccountRef;
--                           
--         ELSE
-- 
--           UPDATE PayDoc32 pd
--           SET
--           pd.AccountRef = new$AccountRef,
--           pd.PayerAttrRef = new$IncAccount,
--           pd.AcceptorAttrRef = new$AccountRef,
--           pd.TextNote = new$Note,
--           pd.TaxNote = new$TaxNote,
--           pd.BudgetRef = new$BudgetRef,
--           pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
--           pd.InputDate = CapAcceptDate$,
--           pd.SourceDocNumber = CapDocNumber$,
--           pd.FACIALACC_CLS = new$FACIALACC_CLS
--           WHERE
--           (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
--                           
--         END IF;
--         IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
--         OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
--         THEN  
--           IF (Divided$ > 0)
--           THEN
--             /*  ,      */
--             RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
--           ELSE
--             UPDATE PayDoc32 pd
--             SET
--             pd.Credit = new$Debit - new$Credit
--             WHERE
--             (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
--                           
--           END IF;/* if-then*/            
--         END IF;/* if-else*/
--       END IF;
--       /*     / */
--       /*   :     ,     */
--       /*  ,     */
--       SELECT MAX(pd.AcceptDate)
--       INTO Date_Pd$           FROM PayDoc32 pd
--       WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
--       ;
--       new$Idate := Date_Pd$;
--       /* if-then*/
--     ELSE 
--       /*       
--                           -
--                     . */
--       DELETE FROM PayDoc32 pd
--       WHERE
--       (pd.ProgIndex = new$ProgIndex)
--       AND (pd.RecordIndex = new$id);
--       /* if-else*/  
--     END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
--   END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -
  NULL;
--   if ((new$DocDate is null) and (new$ProgIndex=45)) then 
--     BEGIN
--       select q.BuildDate 
--       into 
--       new$DocDate        from QuotesTitle q 
--       where q.id = new$RecordIndex 
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   if ((new$DocDate is null) and (new$IDATE is not null)) then
--     new$DocDate := new$IDATE;
--   END IF;
--   if ((new$DOCDATE is not null)) then
--     new$RecordDate := new$DOCDATE;
--   END IF;
--   /*         */
--   if ((new$IDate is not null) and (new$RejectCls is not null)) then
--     RaiseException('EX_DOCNOTACCEPTREJECT');
--   END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -
  NULL;
--    /*     */
--    BEGIN
--       SELECT ProgIndex, AcceptDate, ReestrNumber
--         INTO CapProgIndex, CapAcceptDate, CapReestrNumber
--         FROM QuotesTitle qt
--        WHERE (qt.ID = new$RecordIndex);
--    EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--    END;
-- 
--    /*   -    () */
--    IF (CapProgIndex = 45) THEN
--       IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
--          /*        ,
--             */
--          new$FederalFundsRef := new$ID;
--       ELSE
--          new$FederalFundsRef := NULL;
--       END IF;
--    END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN
      select KDValue   into oldKD$ from kd where Id=:old.kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN

      /*     */
      select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
      IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
      into
      idKD1$,
      val_DocCount1$,
      val_DocType1$,
      val_Org_Ref1$,
      val_AccountIndex1$,
      val_SubKD1$,
      val_RegionCLS1$,
      val_GosNI1$,
      val_IncAccount1$,
      val_BudgetRef1$,
      val_MEANSTYPE1$  , 
      val_FACIALACC_CLS1$,
      val_TransfertCls1$         from incomes32 where id=new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not idKD1$ is null) then
      if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
      (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
        /*   ,    */
        delete
        from Incomes32
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      (new$Debit<>0))
      /*       */
      then 
        RaiseException('ex_UnknownRedirect');
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
        /*   ,   ,   */
        insert into
        Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
        Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
        val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
        val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
        new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
      END IF;
      if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
      and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
        /*      ,   */
        update Incomes32
        set
        DocNum = new$DocNum,
        DocCount = val_DocCount1$,
        iDate = new$iDate,
        DOCDATE = new$DOCDATE,
        Debit = 0,
        Credit = -new$Credit,
        DocType = val_DocType1$,
        Org_Ref = val_Org_Ref1$,
        AccountIndex = val_AccountIndex1$,
        KD = idKD1$,
        SubKD = val_SubKD1$,
        RegionCLS = val_RegionCLS1$,
        GosNI = val_GosNI1$,
        ProgIndex = 43,
        RecordIndex = new$Id,
        IncAccount = val_IncAccount1$,
        BudgetRef = val_BudgetRef1$,
        Note = new$Note,
        MEANSTYPE = val_MEANSTYPE1$,
        FACIALACC_CLS = val_FACIALACC_CLS1$,
        TransfertCls = val_TransfertCls1$,
        RVersion = -1
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
         
      END IF; 
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 41)    /*   () */
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    /*       */
    FOR REC$1 IN (SELECT inc.id
     AS val_ID42    FROM Incomes32 inc
    LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
    WHERE (inc.ProgIndex =  42) and
    (inc.RecordIndex =  new$id) and
    (inc.debit = 0) and
    (not(kd.kdvalue like unkKD$)) and
    (not(kd.kdvalue like unkVKD$))
    )
    LOOP
      BEGIN
        /*       */
        select inc.id
        into val_ID431$         FROM Incomes32 inc
        WHERE (inc.ProgIndex =  43) and
        (inc.RecordIndex =  REC$1.val_ID42)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      /*     ,   Credit, ProgIndex, RecordIndex */
      update Incomes32
      set
      DocNum = new$DocNum,
      DocCount = new$DocCount,       
      DOCDATE = new$DOCDATE,
      Debit = 0,
      DocType = new$DocType,
      Org_Ref = new$Org_Ref,
      AccountIndex = new$AccountIndex,
      KD = new$Kd,
      SubKD = new$SubKD,
      RegionCLS = new$RegionCLS,
      GosNI = new$GosNI,
      IncAccount = new$IncAccount,
      BudgetRef = new$BudgetRef,
      Note = new$Note,
      MEANSTYPE = new$MEANSTYPE,
      FACIALACC_CLS = new$FACIALACC_CLS,
      FACT = new$FACT,
      TransfertCls = new$TransfertCls,
      DirectionCls = new$DirectionCls,
      rversion = -1
      where id = val_ID431$;

        
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       --       ClsType
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                --  - 
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      --   
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (new$RVersion IS NULL) THEN
--       new$RVersion := 1;
--    ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
--       new$RVersion := :OLD.RVersion;
--    ELSE
--       new$RVersion := :OLD.RVersion + 1;
--    END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   IF (NEW$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (161, :OLD.ID, SYSDATE);
      DELETE FROM DelRecIndexes
        WHERE (TableID = 161) AND (RecordId = NEW$ID);
   END IF;

END;
/
-- ALTER TRIGGER tr_Incomes32_bu_100
CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   IF (new$Fact IS NULL) THEN 
--     new$Fact := 0;
--   END IF;
--   IF (new$DocBase IS NULL) THEN 
--     new$DocBase := 0;
--   END IF;
--   IF (new$Gosni IS NULL) THEN 
--     new$Gosni := 0;
--   END IF;
--   /* 3 -    */
--   IF (new$ProgIndex IS NULL) THEN 
--     new$ProgIndex := 3; 
--   END IF;
--   IF (new$KD IS NULL) THEN 
--     new$KD := 0; 
--   END IF;
--   /*   */
--   IF (new$FACIALACC_CLS IS NULL) THEN 
--     new$FACIALACC_CLS := 0; 
--   END IF;
--   IF (new$MeansType IS NULL) THEN 
--     new$MeansType := 0;
--   END IF;
--   IF (new$Debit IS NULL) THEN 
--     new$Debit := 0;
--   END IF;
--   IF (new$Credit IS NULL) THEN 
--     new$Credit := 0;
--   END IF;
--   IF (new$Org_Ref IS NULL) THEN 
--     new$Org_Ref := 0;
--   END IF;
--   IF (new$AccountIndex IS NULL) THEN 
--     new$AccountIndex := 0; 
--   END IF;
--   IF (new$DocType IS NULL) THEN 
--     new$DocType := 0;
--   END IF;
--   IF (new$SubKD IS NULL) THEN 
--     new$SubKD := 0;
--   END IF;
--   IF (new$RegionCLS IS NULL) THEN 
--     new$RegionCLS := 0;
--   END IF;
--   IF (new$DocCount IS NULL) THEN 
--     new$DocCount := 1;
--   END IF;
--   IF (new$BuhPaymentCLS IS NULL) THEN 
--     new$BuhPaymentCLS := 0;
--   END IF;
--   IF (new$KVSR IS NULL) THEN 
--     new$KVSR := 0;
--   END IF;
--   IF (new$KFSR IS NULL) THEN 
--     new$KFSR := 0;
--   END IF;
--   IF (new$KESR IS NULL) THEN 
--     new$KESR := 0;
--   END IF;
--   IF (new$KVR IS NULL) THEN 
--     new$KVR := 0;
--   END IF;
--   IF (new$KCSR IS NULL) THEN 
--     new$KCSR := 0;
--   END IF;
--   IF (new$OKATO IS NULL) THEN 
--     new$OKATO := 0;
--   END IF;
--   IF (new$FundsSource IS NULL) THEN 
--     new$FundsSource := 0;
--   END IF;
--   IF (new$DirectionCLS IS NULL) THEN 
--     new$DirectionCLS := 0;
--   END IF;
--   IF (new$FinType is null) then 
--     new$FinType := 0;
--   END IF;
--   IF (new$Debit * new$Credit <> 0) THEN
--     RaiseException('ex_FailDebetCretitValue');
--   END IF;
--   /*   .        */
--   IF (new$IFS_CORR IS NULL) THEN 
--     new$Ifs_Corr := 0;
--   END IF;
--   IF (new$IFS IS NULL) THEN 
--     new$Ifs := 0;
--   END IF;
--   IF (new$BuhOperationCLS IS NULL)
--   THEN 
--     GetIntConst(60, 15,new$BuhOperationCLS);
--   END IF;
--   BEGIN
-- 
--     /*     */
--     /*   after   ,*/ 
--     /*      */
--     SELECT ProgIndex, AcceptDate, ReestrNumber
--     INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
--     WHERE
--     (qt.ID = new$RecordIndex)
--     ;
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;
--   /*              
--            (  , , ) */
--   /*   -    () */
--   IF (CapProgIndex2$ = 45)
--   THEN 
--     IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
--     THEN 
--       /*        ,
--                      */            
--       new$FederalFundsRef := new$ID;
--       /* if-then*/
--     ELSE 
--       new$FederalFundsRef := NULL;
--       /* if-else*/  
--     END IF;/* if (CapProgIndex=45) */
--   END IF;
--   /*     */
--   IF (new$BudgetRef <> :old.BudgetRef) THEN
--     IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
--       IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
--         RaiseException('Ex_CantModufyBudget');
--       END IF;
--       IF (new$Progindex = 41) THEN
--         SELECT COUNT(inc.id ) INTO CNT$1
--         FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
--         IF ((CNT$1<> 0)) THEN
--           RaiseException('Ex_CantModufyBudget');
--         END IF;   
--       END IF;
--     END IF;
--   END IF;
--   /*     \*/
--   IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
--   ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
--       INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
--       WHERE fac.ID = new$FacialACC_Cls
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*    */
--   GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
--   new$targetcls,new$targetcls);  

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
--       new$DocNum := CAST (new$DocNumber AS VARCHAR2);
--    END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -
  NULL;
--   BEGIN
--     SELECT Inn
--      INTO new$Inn
--      FROM Organizations o
--     WHERE (o.ID = new$Org_Ref);
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -
  NULL;
--   /*      */
--   IF (new$ProgIndex <> 42) THEN
--     BEGIN
--       SELECT ProgIndex, DocNumber, AcceptDate
--       INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
--       WHERE
--       (qt.ID = new$RecordIndex)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*   -  ,   */
--   IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
--   THEN 
--     IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
--     (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
--     THEN 
--       BEGIN
--         SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
--         WHERE inc.id = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       IF (Kd_Master$ = new$Kd) THEN 
--         CapAcceptDate$ := new$DOCDATE;
--         CapProgIndex$  := new$ProgIndex;
--         CapDocNumber$  := new$DocNum;
--         /*  */        
--       END IF;/*       (         )*/
--     END IF;
--     IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
--     THEN 
-- 
--       /*      */
--       /* /      Incomes32, ..      ,     */
-- 
--       /*     /   */
--       SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
--       INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
--       WHERE
--       (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
--       ;
--       /*            ,  .*/
--       /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
--                       ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
--                      ) THEN
--                     EXCEPTION EX_CANNOTUPDATENUMBER;*/
--                  
--                 
--       IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
--       then
--         if ((new$DocType <> :old.DocType )
--         or (new$Debit <> :old.Debit )
--         or (new$Credit <> :old.Credit)
--         or (new$org_ref <> :old.org_ref)
--         or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
--         or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
--         )
--         then
--           RaiseException('EX_CANNOTUPDATENUMBER');
--         END IF;
--       END IF;
--                 
-- 
-- 
--       /*           */
--       IF (PayDocCount$ = 0)
--       THEN 
--         /*       */
--         GetIntConst(11, 2,ConstPayQueue$);
--         /*       */
--         GetIntConst(11, 1,ConstSendBy$);
-- 
--         /*    */
--         INSERT INTO PayDoc32
--         (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
--         Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
--         VALUES
--         (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
--         new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
--         /* (new.Debit - new.Credit) --- ..      ,    ,
--                                      */
-- 
--         /* if-then */
--       ELSE 
--         /*     */
--         IF (((new$AccountRef = :old.AccountRef) OR
--         ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
--         AND (new$IncAccount = :old.IncAccount)
--         AND (new$BudgetRef = :old.BudgetRef)
--         AND ((new$Note = :old.Note) OR
--         ((new$Note IS NULL) AND (:old.Note IS NULL)))
--         AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
--         ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
--         AND ((new$TaxNote = :old.TaxNote) OR
--         ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
--         )  THEN
--           new$AccountRef := new$AccountRef;
--                           
--         ELSE
-- 
--           UPDATE PayDoc32 pd
--           SET
--           pd.AccountRef = new$AccountRef,
--           pd.PayerAttrRef = new$IncAccount,
--           pd.AcceptorAttrRef = new$AccountRef,
--           pd.TextNote = new$Note,
--           pd.TaxNote = new$TaxNote,
--           pd.BudgetRef = new$BudgetRef,
--           pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
--           pd.InputDate = CapAcceptDate$,
--           pd.SourceDocNumber = CapDocNumber$,
--           pd.FACIALACC_CLS = new$FACIALACC_CLS
--           WHERE
--           (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
--                           
--         END IF;
--         IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
--         OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
--         THEN  
--           IF (Divided$ > 0)
--           THEN
--             /*  ,      */
--             RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
--           ELSE
--             UPDATE PayDoc32 pd
--             SET
--             pd.Credit = new$Debit - new$Credit
--             WHERE
--             (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
--                           
--           END IF;/* if-then*/            
--         END IF;/* if-else*/
--       END IF;
--       /*     / */
--       /*   :     ,     */
--       /*  ,     */
--       SELECT MAX(pd.AcceptDate)
--       INTO Date_Pd$           FROM PayDoc32 pd
--       WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
--       ;
--       new$Idate := Date_Pd$;
--       /* if-then*/
--     ELSE 
--       /*       
--                           -
--                     . */
--       DELETE FROM PayDoc32 pd
--       WHERE
--       (pd.ProgIndex = new$ProgIndex)
--       AND (pd.RecordIndex = new$id);
--       /* if-else*/  
--     END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
--   END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -
  NULL;
--   if ((new$DocDate is null) and (new$ProgIndex=45)) then 
--     BEGIN
--       select q.BuildDate 
--       into 
--       new$DocDate        from QuotesTitle q 
--       where q.id = new$RecordIndex 
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   if ((new$DocDate is null) and (new$IDATE is not null)) then
--     new$DocDate := new$IDATE;
--   END IF;
--   if ((new$DOCDATE is not null)) then
--     new$RecordDate := new$DOCDATE;
--   END IF;
--   /*         */
--   if ((new$IDate is not null) and (new$RejectCls is not null)) then
--     RaiseException('EX_DOCNOTACCEPTREJECT');
--   END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -
  NULL;
--    /*     */
--    BEGIN
--       SELECT ProgIndex, AcceptDate, ReestrNumber
--         INTO CapProgIndex, CapAcceptDate, CapReestrNumber
--         FROM QuotesTitle qt
--        WHERE (qt.ID = new$RecordIndex);
--    EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--    END;
-- 
--    /*   -    () */
--    IF (CapProgIndex = 45) THEN
--       IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
--          /*        ,
--             */
--          new$FederalFundsRef := new$ID;
--       ELSE
--          new$FederalFundsRef := NULL;
--       END IF;
--    END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ProgIndex = 42)
--   then 
--     /*    */
--     GetVarCharConst(3,0,unkKD$);
--     /*     */
--     GetVarCharConst(3,11,unkVKD$);  
--     BEGIN
-- 
--       select KDValue   into newKD$ from kd where Id=new$kd
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     BEGIN
--       select KDValue   into oldKD$ from kd where Id=:old.kd
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     BEGIN
-- 
--       /*     */
--       select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
--       IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
--       into
--       idKD1$,
--       val_DocCount1$,
--       val_DocType1$,
--       val_Org_Ref1$,
--       val_AccountIndex1$,
--       val_SubKD1$,
--       val_RegionCLS1$,
--       val_GosNI1$,
--       val_IncAccount1$,
--       val_BudgetRef1$,
--       val_MEANSTYPE1$  , 
--       val_FACIALACC_CLS1$,
--       val_TransfertCls1$         from incomes32 where id=new$RecordIndex
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     if (not idKD1$ is null) then
--       if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
--       (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
--         /*   ,    */
--         delete
--         from Incomes32
--         where
--         (ProgIndex=43)and
--         (RecordIndex=:old.id);
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
--       (new$Debit<>0))
--       /*       */
--       then 
--         RaiseException('ex_UnknownRedirect');
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
--       ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
--         /*   ,   ,   */
--         insert into
--         Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
--         Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
--         RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
--         Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
--         val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
--         val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
--         new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
--       and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
--         /*      ,   */
--         update Incomes32
--         set
--         DocNum = new$DocNum,
--         DocCount = val_DocCount1$,
--         iDate = new$iDate,
--         DOCDATE = new$DOCDATE,
--         Debit = 0,
--         Credit = -new$Credit,
--         DocType = val_DocType1$,
--         Org_Ref = val_Org_Ref1$,
--         AccountIndex = val_AccountIndex1$,
--         KD = idKD1$,
--         SubKD = val_SubKD1$,
--         RegionCLS = val_RegionCLS1$,
--         GosNI = val_GosNI1$,
--         ProgIndex = 43,
--         RecordIndex = new$Id,
--         IncAccount = val_IncAccount1$,
--         BudgetRef = val_BudgetRef1$,
--         Note = new$Note,
--         MEANSTYPE = val_MEANSTYPE1$,
--         FACIALACC_CLS = val_FACIALACC_CLS1$,
--         TransfertCls = val_TransfertCls1$,
--         RVersion = -1
--         where
--         (ProgIndex=43)and
--         (RecordIndex=:old.id);
--          
--       END IF; 
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 41)    /*   () */
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    /*       */
    FOR REC$1 IN (SELECT inc.id
     AS val_ID42    FROM Incomes32 inc
    LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
    WHERE (inc.ProgIndex =  42) and
    (inc.RecordIndex =  new$id) and
    (inc.debit = 0) and
    (not(kd.kdvalue like unkKD$)) and
    (not(kd.kdvalue like unkVKD$))
    )
    LOOP
      BEGIN
        /*       */
        select inc.id
        into val_ID431$         FROM Incomes32 inc
        WHERE (inc.ProgIndex =  43) and
        (inc.RecordIndex =  REC$1.val_ID42)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      /*     ,   Credit, ProgIndex, RecordIndex */
      update Incomes32
      set
      DocNum = new$DocNum,
      DocCount = new$DocCount,       
      DOCDATE = new$DOCDATE,
      Debit = 0,
      DocType = new$DocType,
      Org_Ref = new$Org_Ref,
      AccountIndex = new$AccountIndex,
      KD = new$Kd,
      SubKD = new$SubKD,
      RegionCLS = new$RegionCLS,
      GosNI = new$GosNI,
      IncAccount = new$IncAccount,
      BudgetRef = new$BudgetRef,
      Note = new$Note,
      MEANSTYPE = new$MEANSTYPE,
      FACIALACC_CLS = new$FACIALACC_CLS,
      FACT = new$FACT,
      TransfertCls = new$TransfertCls,
      DirectionCls = new$DirectionCls,
      rversion = -1
      where id = val_ID431$;

        
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       --       ClsType
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                --  - 
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      --   
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (new$RVersion IS NULL) THEN
--       new$RVersion := 1;
--    ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
--       new$RVersion := :OLD.RVersion;
--    ELSE
--       new$RVersion := :OLD.RVersion + 1;
--    END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   IF (NEW$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (161, :OLD.ID, SYSDATE);
      DELETE FROM DelRecIndexes
        WHERE (TableID = 161) AND (RecordId = NEW$ID);
   END IF;

END;
/
-- ALTER TRIGGER TR_INCOMES32_BU_110
CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   IF (new$Fact IS NULL) THEN 
--     new$Fact := 0;
--   END IF;
--   IF (new$DocBase IS NULL) THEN 
--     new$DocBase := 0;
--   END IF;
--   IF (new$Gosni IS NULL) THEN 
--     new$Gosni := 0;
--   END IF;
--   /* 3 -    */
--   IF (new$ProgIndex IS NULL) THEN 
--     new$ProgIndex := 3; 
--   END IF;
--   IF (new$KD IS NULL) THEN 
--     new$KD := 0; 
--   END IF;
--   /*   */
--   IF (new$FACIALACC_CLS IS NULL) THEN 
--     new$FACIALACC_CLS := 0; 
--   END IF;
--   IF (new$MeansType IS NULL) THEN 
--     new$MeansType := 0;
--   END IF;
--   IF (new$Debit IS NULL) THEN 
--     new$Debit := 0;
--   END IF;
--   IF (new$Credit IS NULL) THEN 
--     new$Credit := 0;
--   END IF;
--   IF (new$Org_Ref IS NULL) THEN 
--     new$Org_Ref := 0;
--   END IF;
--   IF (new$AccountIndex IS NULL) THEN 
--     new$AccountIndex := 0; 
--   END IF;
--   IF (new$DocType IS NULL) THEN 
--     new$DocType := 0;
--   END IF;
--   IF (new$SubKD IS NULL) THEN 
--     new$SubKD := 0;
--   END IF;
--   IF (new$RegionCLS IS NULL) THEN 
--     new$RegionCLS := 0;
--   END IF;
--   IF (new$DocCount IS NULL) THEN 
--     new$DocCount := 1;
--   END IF;
--   IF (new$BuhPaymentCLS IS NULL) THEN 
--     new$BuhPaymentCLS := 0;
--   END IF;
--   IF (new$KVSR IS NULL) THEN 
--     new$KVSR := 0;
--   END IF;
--   IF (new$KFSR IS NULL) THEN 
--     new$KFSR := 0;
--   END IF;
--   IF (new$KESR IS NULL) THEN 
--     new$KESR := 0;
--   END IF;
--   IF (new$KVR IS NULL) THEN 
--     new$KVR := 0;
--   END IF;
--   IF (new$KCSR IS NULL) THEN 
--     new$KCSR := 0;
--   END IF;
--   IF (new$OKATO IS NULL) THEN 
--     new$OKATO := 0;
--   END IF;
--   IF (new$FundsSource IS NULL) THEN 
--     new$FundsSource := 0;
--   END IF;
--   IF (new$DirectionCLS IS NULL) THEN 
--     new$DirectionCLS := 0;
--   END IF;
--   IF (new$FinType is null) then 
--     new$FinType := 0;
--   END IF;
--   IF (new$Debit * new$Credit <> 0) THEN
--     RaiseException('ex_FailDebetCretitValue');
--   END IF;
--   /*   .        */
--   IF (new$IFS_CORR IS NULL) THEN 
--     new$Ifs_Corr := 0;
--   END IF;
--   IF (new$IFS IS NULL) THEN 
--     new$Ifs := 0;
--   END IF;
--   IF (new$BuhOperationCLS IS NULL)
--   THEN 
--     GetIntConst(60, 15,new$BuhOperationCLS);
--   END IF;
--   BEGIN
-- 
--     /*     */
--     /*   after   ,*/ 
--     /*      */
--     SELECT ProgIndex, AcceptDate, ReestrNumber
--     INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
--     WHERE
--     (qt.ID = new$RecordIndex)
--     ;
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;
--   /*              
--            (  , , ) */
--   /*   -    () */
--   IF (CapProgIndex2$ = 45)
--   THEN 
--     IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
--     THEN 
--       /*        ,
--                      */            
--       new$FederalFundsRef := new$ID;
--       /* if-then*/
--     ELSE 
--       new$FederalFundsRef := NULL;
--       /* if-else*/  
--     END IF;/* if (CapProgIndex=45) */
--   END IF;
--   /*     */
--   IF (new$BudgetRef <> :old.BudgetRef) THEN
--     IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
--       IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
--         RaiseException('Ex_CantModufyBudget');
--       END IF;
--       IF (new$Progindex = 41) THEN
--         SELECT COUNT(inc.id ) INTO CNT$1
--         FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
--         IF ((CNT$1<> 0)) THEN
--           RaiseException('Ex_CantModufyBudget');
--         END IF;   
--       END IF;
--     END IF;
--   END IF;
--   /*     \*/
--   IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
--   ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
--       INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
--       WHERE fac.ID = new$FacialACC_Cls
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*    */
--   GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
--   new$targetcls,new$targetcls);  

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
--       new$DocNum := CAST (new$DocNumber AS VARCHAR2);
--    END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -
  NULL;
--   BEGIN
--     SELECT Inn
--      INTO new$Inn
--      FROM Organizations o
--     WHERE (o.ID = new$Org_Ref);
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -
  NULL;
--   /*      */
--   IF (new$ProgIndex <> 42) THEN
--     BEGIN
--       SELECT ProgIndex, DocNumber, AcceptDate
--       INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
--       WHERE
--       (qt.ID = new$RecordIndex)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*   -  ,   */
--   IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
--   THEN 
--     IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
--     (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
--     THEN 
--       BEGIN
--         SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
--         WHERE inc.id = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       IF (Kd_Master$ = new$Kd) THEN 
--         CapAcceptDate$ := new$DOCDATE;
--         CapProgIndex$  := new$ProgIndex;
--         CapDocNumber$  := new$DocNum;
--         /*  */        
--       END IF;/*       (         )*/
--     END IF;
--     IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
--     THEN 
-- 
--       /*      */
--       /* /      Incomes32, ..      ,     */
-- 
--       /*     /   */
--       SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
--       INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
--       WHERE
--       (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
--       ;
--       /*            ,  .*/
--       /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
--                       ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
--                      ) THEN
--                     EXCEPTION EX_CANNOTUPDATENUMBER;*/
--                  
--                 
--       IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
--       then
--         if ((new$DocType <> :old.DocType )
--         or (new$Debit <> :old.Debit )
--         or (new$Credit <> :old.Credit)
--         or (new$org_ref <> :old.org_ref)
--         or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
--         or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
--         )
--         then
--           RaiseException('EX_CANNOTUPDATENUMBER');
--         END IF;
--       END IF;
--                 
-- 
-- 
--       /*           */
--       IF (PayDocCount$ = 0)
--       THEN 
--         /*       */
--         GetIntConst(11, 2,ConstPayQueue$);
--         /*       */
--         GetIntConst(11, 1,ConstSendBy$);
-- 
--         /*    */
--         INSERT INTO PayDoc32
--         (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
--         Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
--         VALUES
--         (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
--         new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
--         /* (new.Debit - new.Credit) --- ..      ,    ,
--                                      */
-- 
--         /* if-then */
--       ELSE 
--         /*     */
--         IF (((new$AccountRef = :old.AccountRef) OR
--         ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
--         AND (new$IncAccount = :old.IncAccount)
--         AND (new$BudgetRef = :old.BudgetRef)
--         AND ((new$Note = :old.Note) OR
--         ((new$Note IS NULL) AND (:old.Note IS NULL)))
--         AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
--         ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
--         AND ((new$TaxNote = :old.TaxNote) OR
--         ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
--         )  THEN
--           new$AccountRef := new$AccountRef;
--                           
--         ELSE
-- 
--           UPDATE PayDoc32 pd
--           SET
--           pd.AccountRef = new$AccountRef,
--           pd.PayerAttrRef = new$IncAccount,
--           pd.AcceptorAttrRef = new$AccountRef,
--           pd.TextNote = new$Note,
--           pd.TaxNote = new$TaxNote,
--           pd.BudgetRef = new$BudgetRef,
--           pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
--           pd.InputDate = CapAcceptDate$,
--           pd.SourceDocNumber = CapDocNumber$,
--           pd.FACIALACC_CLS = new$FACIALACC_CLS
--           WHERE
--           (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
--                           
--         END IF;
--         IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
--         OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
--         THEN  
--           IF (Divided$ > 0)
--           THEN
--             /*  ,      */
--             RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
--           ELSE
--             UPDATE PayDoc32 pd
--             SET
--             pd.Credit = new$Debit - new$Credit
--             WHERE
--             (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
--                           
--           END IF;/* if-then*/            
--         END IF;/* if-else*/
--       END IF;
--       /*     / */
--       /*   :     ,     */
--       /*  ,     */
--       SELECT MAX(pd.AcceptDate)
--       INTO Date_Pd$           FROM PayDoc32 pd
--       WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
--       ;
--       new$Idate := Date_Pd$;
--       /* if-then*/
--     ELSE 
--       /*       
--                           -
--                     . */
--       DELETE FROM PayDoc32 pd
--       WHERE
--       (pd.ProgIndex = new$ProgIndex)
--       AND (pd.RecordIndex = new$id);
--       /* if-else*/  
--     END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
--   END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -
  NULL;
--   if ((new$DocDate is null) and (new$ProgIndex=45)) then 
--     BEGIN
--       select q.BuildDate 
--       into 
--       new$DocDate        from QuotesTitle q 
--       where q.id = new$RecordIndex 
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   if ((new$DocDate is null) and (new$IDATE is not null)) then
--     new$DocDate := new$IDATE;
--   END IF;
--   if ((new$DOCDATE is not null)) then
--     new$RecordDate := new$DOCDATE;
--   END IF;
--   /*         */
--   if ((new$IDate is not null) and (new$RejectCls is not null)) then
--     RaiseException('EX_DOCNOTACCEPTREJECT');
--   END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -
  NULL;
--    /*     */
--    BEGIN
--       SELECT ProgIndex, AcceptDate, ReestrNumber
--         INTO CapProgIndex, CapAcceptDate, CapReestrNumber
--         FROM QuotesTitle qt
--        WHERE (qt.ID = new$RecordIndex);
--    EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--    END;
-- 
--    /*   -    () */
--    IF (CapProgIndex = 45) THEN
--       IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
--          /*        ,
--             */
--          new$FederalFundsRef := new$ID;
--       ELSE
--          new$FederalFundsRef := NULL;
--       END IF;
--    END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ProgIndex = 42)
--   then 
--     /*    */
--     GetVarCharConst(3,0,unkKD$);
--     /*     */
--     GetVarCharConst(3,11,unkVKD$);  
--     BEGIN
-- 
--       select KDValue   into newKD$ from kd where Id=new$kd
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     BEGIN
--       select KDValue   into oldKD$ from kd where Id=:old.kd
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     BEGIN
-- 
--       /*     */
--       select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
--       IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
--       into
--       idKD1$,
--       val_DocCount1$,
--       val_DocType1$,
--       val_Org_Ref1$,
--       val_AccountIndex1$,
--       val_SubKD1$,
--       val_RegionCLS1$,
--       val_GosNI1$,
--       val_IncAccount1$,
--       val_BudgetRef1$,
--       val_MEANSTYPE1$  , 
--       val_FACIALACC_CLS1$,
--       val_TransfertCls1$         from incomes32 where id=new$RecordIndex
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     if (not idKD1$ is null) then
--       if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
--       (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
--         /*   ,    */
--         delete
--         from Incomes32
--         where
--         (ProgIndex=43)and
--         (RecordIndex=:old.id);
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
--       (new$Debit<>0))
--       /*       */
--       then 
--         RaiseException('ex_UnknownRedirect');
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
--       ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
--         /*   ,   ,   */
--         insert into
--         Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
--         Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
--         RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
--         Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
--         val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
--         val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
--         new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
--       and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
--         /*      ,   */
--         update Incomes32
--         set
--         DocNum = new$DocNum,
--         DocCount = val_DocCount1$,
--         iDate = new$iDate,
--         DOCDATE = new$DOCDATE,
--         Debit = 0,
--         Credit = -new$Credit,
--         DocType = val_DocType1$,
--         Org_Ref = val_Org_Ref1$,
--         AccountIndex = val_AccountIndex1$,
--         KD = idKD1$,
--         SubKD = val_SubKD1$,
--         RegionCLS = val_RegionCLS1$,
--         GosNI = val_GosNI1$,
--         ProgIndex = 43,
--         RecordIndex = new$Id,
--         IncAccount = val_IncAccount1$,
--         BudgetRef = val_BudgetRef1$,
--         Note = new$Note,
--         MEANSTYPE = val_MEANSTYPE1$,
--         FACIALACC_CLS = val_FACIALACC_CLS1$,
--         TransfertCls = val_TransfertCls1$,
--         RVersion = -1
--         where
--         (ProgIndex=43)and
--         (RecordIndex=:old.id);
--          
--       END IF; 
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 41)    /*   () */
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    /*       */
    FOR REC$1 IN (SELECT inc.id
     AS val_ID42    FROM Incomes32 inc
    LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
    WHERE (inc.ProgIndex =  42) and
    (inc.RecordIndex =  new$id) and
    (inc.debit = 0) and
    (not(kd.kdvalue like unkKD$)) and
    (not(kd.kdvalue like unkVKD$))
    )
    LOOP
      BEGIN
        /*       */
        select inc.id
        into val_ID431$         FROM Incomes32 inc
        WHERE (inc.ProgIndex =  43) and
        (inc.RecordIndex =  REC$1.val_ID42)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      /*     ,   Credit, ProgIndex, RecordIndex */
      update Incomes32
      set
      DocNum = new$DocNum,
      DocCount = new$DocCount,       
      DOCDATE = new$DOCDATE,
      Debit = 0,
      DocType = new$DocType,
      Org_Ref = new$Org_Ref,
      AccountIndex = new$AccountIndex,
      KD = new$Kd,
      SubKD = new$SubKD,
      RegionCLS = new$RegionCLS,
      GosNI = new$GosNI,
      IncAccount = new$IncAccount,
      BudgetRef = new$BudgetRef,
      Note = new$Note,
      MEANSTYPE = new$MEANSTYPE,
      FACIALACC_CLS = new$FACIALACC_CLS,
      FACT = new$FACT,
      TransfertCls = new$TransfertCls,
      DirectionCls = new$DirectionCls,
      rversion = -1
      where id = val_ID431$;

        
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
--       new$ClsType := 1;       --       ClsType
--    ELSIF (new$ClsType IS NULL) THEN
--       new$ClsType := 2;                                --  - 
--    END IF;
-- 
--    IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
--       --  
--       RaiseEXCEPTION ('EX_WRONGBUDCLS');
--    END IF;
-- 
--    IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
--       --  
--       RaiseEXCEPTION ('EX_WRONGBUDCLS');
--    END IF;
-- 
--    IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
--       --   
--       RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
--    END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (new$RVersion IS NULL) THEN
--       new$RVersion := 1;
--    ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
--       new$RVersion := :OLD.RVersion;
--    ELSE
--       new$RVersion := :OLD.RVersion + 1;
--    END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   IF (NEW$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (161, :OLD.ID, SYSDATE);
      DELETE FROM DelRecIndexes
        WHERE (TableID = 161) AND (RecordId = NEW$ID);
   END IF;

END;
/
-- ALTER TRIGGER tr_Incomes32_au_500
CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   IF (new$Fact IS NULL) THEN 
--     new$Fact := 0;
--   END IF;
--   IF (new$DocBase IS NULL) THEN 
--     new$DocBase := 0;
--   END IF;
--   IF (new$Gosni IS NULL) THEN 
--     new$Gosni := 0;
--   END IF;
--   /* 3 -    */
--   IF (new$ProgIndex IS NULL) THEN 
--     new$ProgIndex := 3; 
--   END IF;
--   IF (new$KD IS NULL) THEN 
--     new$KD := 0; 
--   END IF;
--   /*   */
--   IF (new$FACIALACC_CLS IS NULL) THEN 
--     new$FACIALACC_CLS := 0; 
--   END IF;
--   IF (new$MeansType IS NULL) THEN 
--     new$MeansType := 0;
--   END IF;
--   IF (new$Debit IS NULL) THEN 
--     new$Debit := 0;
--   END IF;
--   IF (new$Credit IS NULL) THEN 
--     new$Credit := 0;
--   END IF;
--   IF (new$Org_Ref IS NULL) THEN 
--     new$Org_Ref := 0;
--   END IF;
--   IF (new$AccountIndex IS NULL) THEN 
--     new$AccountIndex := 0; 
--   END IF;
--   IF (new$DocType IS NULL) THEN 
--     new$DocType := 0;
--   END IF;
--   IF (new$SubKD IS NULL) THEN 
--     new$SubKD := 0;
--   END IF;
--   IF (new$RegionCLS IS NULL) THEN 
--     new$RegionCLS := 0;
--   END IF;
--   IF (new$DocCount IS NULL) THEN 
--     new$DocCount := 1;
--   END IF;
--   IF (new$BuhPaymentCLS IS NULL) THEN 
--     new$BuhPaymentCLS := 0;
--   END IF;
--   IF (new$KVSR IS NULL) THEN 
--     new$KVSR := 0;
--   END IF;
--   IF (new$KFSR IS NULL) THEN 
--     new$KFSR := 0;
--   END IF;
--   IF (new$KESR IS NULL) THEN 
--     new$KESR := 0;
--   END IF;
--   IF (new$KVR IS NULL) THEN 
--     new$KVR := 0;
--   END IF;
--   IF (new$KCSR IS NULL) THEN 
--     new$KCSR := 0;
--   END IF;
--   IF (new$OKATO IS NULL) THEN 
--     new$OKATO := 0;
--   END IF;
--   IF (new$FundsSource IS NULL) THEN 
--     new$FundsSource := 0;
--   END IF;
--   IF (new$DirectionCLS IS NULL) THEN 
--     new$DirectionCLS := 0;
--   END IF;
--   IF (new$FinType is null) then 
--     new$FinType := 0;
--   END IF;
--   IF (new$Debit * new$Credit <> 0) THEN
--     RaiseException('ex_FailDebetCretitValue');
--   END IF;
--   /*   .        */
--   IF (new$IFS_CORR IS NULL) THEN 
--     new$Ifs_Corr := 0;
--   END IF;
--   IF (new$IFS IS NULL) THEN 
--     new$Ifs := 0;
--   END IF;
--   IF (new$BuhOperationCLS IS NULL)
--   THEN 
--     GetIntConst(60, 15,new$BuhOperationCLS);
--   END IF;
--   BEGIN
-- 
--     /*     */
--     /*   after   ,*/ 
--     /*      */
--     SELECT ProgIndex, AcceptDate, ReestrNumber
--     INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
--     WHERE
--     (qt.ID = new$RecordIndex)
--     ;
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;
--   /*              
--            (  , , ) */
--   /*   -    () */
--   IF (CapProgIndex2$ = 45)
--   THEN 
--     IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
--     THEN 
--       /*        ,
--                      */            
--       new$FederalFundsRef := new$ID;
--       /* if-then*/
--     ELSE 
--       new$FederalFundsRef := NULL;
--       /* if-else*/  
--     END IF;/* if (CapProgIndex=45) */
--   END IF;
--   /*     */
--   IF (new$BudgetRef <> :old.BudgetRef) THEN
--     IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
--       IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
--         RaiseException('Ex_CantModufyBudget');
--       END IF;
--       IF (new$Progindex = 41) THEN
--         SELECT COUNT(inc.id ) INTO CNT$1
--         FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
--         IF ((CNT$1<> 0)) THEN
--           RaiseException('Ex_CantModufyBudget');
--         END IF;   
--       END IF;
--     END IF;
--   END IF;
--   /*     \*/
--   IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
--   ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
--       INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
--       WHERE fac.ID = new$FacialACC_Cls
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*    */
--   GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
--   new$targetcls,new$targetcls);  

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
--       new$DocNum := CAST (new$DocNumber AS VARCHAR2);
--    END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -
  NULL;
--   BEGIN
--     SELECT Inn
--      INTO new$Inn
--      FROM Organizations o
--     WHERE (o.ID = new$Org_Ref);
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -
  NULL;
--   /*      */
--   IF (new$ProgIndex <> 42) THEN
--     BEGIN
--       SELECT ProgIndex, DocNumber, AcceptDate
--       INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
--       WHERE
--       (qt.ID = new$RecordIndex)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*   -  ,   */
--   IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
--   THEN 
--     IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
--     (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
--     THEN 
--       BEGIN
--         SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
--         WHERE inc.id = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       IF (Kd_Master$ = new$Kd) THEN 
--         CapAcceptDate$ := new$DOCDATE;
--         CapProgIndex$  := new$ProgIndex;
--         CapDocNumber$  := new$DocNum;
--         /*  */        
--       END IF;/*       (         )*/
--     END IF;
--     IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
--     THEN 
-- 
--       /*      */
--       /* /      Incomes32, ..      ,     */
-- 
--       /*     /   */
--       SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
--       INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
--       WHERE
--       (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
--       ;
--       /*            ,  .*/
--       /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
--                       ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
--                      ) THEN
--                     EXCEPTION EX_CANNOTUPDATENUMBER;*/
--                  
--                 
--       IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
--       then
--         if ((new$DocType <> :old.DocType )
--         or (new$Debit <> :old.Debit )
--         or (new$Credit <> :old.Credit)
--         or (new$org_ref <> :old.org_ref)
--         or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
--         or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
--         )
--         then
--           RaiseException('EX_CANNOTUPDATENUMBER');
--         END IF;
--       END IF;
--                 
-- 
-- 
--       /*           */
--       IF (PayDocCount$ = 0)
--       THEN 
--         /*       */
--         GetIntConst(11, 2,ConstPayQueue$);
--         /*       */
--         GetIntConst(11, 1,ConstSendBy$);
-- 
--         /*    */
--         INSERT INTO PayDoc32
--         (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
--         Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
--         VALUES
--         (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
--         new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
--         /* (new.Debit - new.Credit) --- ..      ,    ,
--                                      */
-- 
--         /* if-then */
--       ELSE 
--         /*     */
--         IF (((new$AccountRef = :old.AccountRef) OR
--         ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
--         AND (new$IncAccount = :old.IncAccount)
--         AND (new$BudgetRef = :old.BudgetRef)
--         AND ((new$Note = :old.Note) OR
--         ((new$Note IS NULL) AND (:old.Note IS NULL)))
--         AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
--         ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
--         AND ((new$TaxNote = :old.TaxNote) OR
--         ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
--         )  THEN
--           new$AccountRef := new$AccountRef;
--                           
--         ELSE
-- 
--           UPDATE PayDoc32 pd
--           SET
--           pd.AccountRef = new$AccountRef,
--           pd.PayerAttrRef = new$IncAccount,
--           pd.AcceptorAttrRef = new$AccountRef,
--           pd.TextNote = new$Note,
--           pd.TaxNote = new$TaxNote,
--           pd.BudgetRef = new$BudgetRef,
--           pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
--           pd.InputDate = CapAcceptDate$,
--           pd.SourceDocNumber = CapDocNumber$,
--           pd.FACIALACC_CLS = new$FACIALACC_CLS
--           WHERE
--           (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
--                           
--         END IF;
--         IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
--         OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
--         THEN  
--           IF (Divided$ > 0)
--           THEN
--             /*  ,      */
--             RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
--           ELSE
--             UPDATE PayDoc32 pd
--             SET
--             pd.Credit = new$Debit - new$Credit
--             WHERE
--             (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
--                           
--           END IF;/* if-then*/            
--         END IF;/* if-else*/
--       END IF;
--       /*     / */
--       /*   :     ,     */
--       /*  ,     */
--       SELECT MAX(pd.AcceptDate)
--       INTO Date_Pd$           FROM PayDoc32 pd
--       WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
--       ;
--       new$Idate := Date_Pd$;
--       /* if-then*/
--     ELSE 
--       /*       
--                           -
--                     . */
--       DELETE FROM PayDoc32 pd
--       WHERE
--       (pd.ProgIndex = new$ProgIndex)
--       AND (pd.RecordIndex = new$id);
--       /* if-else*/  
--     END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
--   END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -
  NULL;
--   if ((new$DocDate is null) and (new$ProgIndex=45)) then 
--     BEGIN
--       select q.BuildDate 
--       into 
--       new$DocDate        from QuotesTitle q 
--       where q.id = new$RecordIndex 
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   if ((new$DocDate is null) and (new$IDATE is not null)) then
--     new$DocDate := new$IDATE;
--   END IF;
--   if ((new$DOCDATE is not null)) then
--     new$RecordDate := new$DOCDATE;
--   END IF;
--   /*         */
--   if ((new$IDate is not null) and (new$RejectCls is not null)) then
--     RaiseException('EX_DOCNOTACCEPTREJECT');
--   END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -
  NULL;
--    /*     */
--    BEGIN
--       SELECT ProgIndex, AcceptDate, ReestrNumber
--         INTO CapProgIndex, CapAcceptDate, CapReestrNumber
--         FROM QuotesTitle qt
--        WHERE (qt.ID = new$RecordIndex);
--    EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--    END;
-- 
--    /*   -    () */
--    IF (CapProgIndex = 45) THEN
--       IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
--          /*        ,
--             */
--          new$FederalFundsRef := new$ID;
--       ELSE
--          new$FederalFundsRef := NULL;
--       END IF;
--    END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ProgIndex = 42)
--   then 
--     /*    */
--     GetVarCharConst(3,0,unkKD$);
--     /*     */
--     GetVarCharConst(3,11,unkVKD$);  
--     BEGIN
-- 
--       select KDValue   into newKD$ from kd where Id=new$kd
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     BEGIN
--       select KDValue   into oldKD$ from kd where Id=:old.kd
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     BEGIN
-- 
--       /*     */
--       select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
--       IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
--       into
--       idKD1$,
--       val_DocCount1$,
--       val_DocType1$,
--       val_Org_Ref1$,
--       val_AccountIndex1$,
--       val_SubKD1$,
--       val_RegionCLS1$,
--       val_GosNI1$,
--       val_IncAccount1$,
--       val_BudgetRef1$,
--       val_MEANSTYPE1$  , 
--       val_FACIALACC_CLS1$,
--       val_TransfertCls1$         from incomes32 where id=new$RecordIndex
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     if (not idKD1$ is null) then
--       if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
--       (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
--         /*   ,    */
--         delete
--         from Incomes32
--         where
--         (ProgIndex=43)and
--         (RecordIndex=:old.id);
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
--       (new$Debit<>0))
--       /*       */
--       then 
--         RaiseException('ex_UnknownRedirect');
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
--       ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
--         /*   ,   ,   */
--         insert into
--         Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
--         Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
--         RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
--         Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
--         val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
--         val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
--         new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
--       and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
--         /*      ,   */
--         update Incomes32
--         set
--         DocNum = new$DocNum,
--         DocCount = val_DocCount1$,
--         iDate = new$iDate,
--         DOCDATE = new$DOCDATE,
--         Debit = 0,
--         Credit = -new$Credit,
--         DocType = val_DocType1$,
--         Org_Ref = val_Org_Ref1$,
--         AccountIndex = val_AccountIndex1$,
--         KD = idKD1$,
--         SubKD = val_SubKD1$,
--         RegionCLS = val_RegionCLS1$,
--         GosNI = val_GosNI1$,
--         ProgIndex = 43,
--         RecordIndex = new$Id,
--         IncAccount = val_IncAccount1$,
--         BudgetRef = val_BudgetRef1$,
--         Note = new$Note,
--         MEANSTYPE = val_MEANSTYPE1$,
--         FACIALACC_CLS = val_FACIALACC_CLS1$,
--         TransfertCls = val_TransfertCls1$,
--         RVersion = -1
--         where
--         (ProgIndex=43)and
--         (RecordIndex=:old.id);
--          
--       END IF; 
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 41)    /*   () */
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    /*       */
    FOR REC$1 IN (SELECT inc.id
     AS val_ID42    FROM Incomes32 inc
    LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
    WHERE (inc.ProgIndex =  42) and
    (inc.RecordIndex =  new$id) and
    (inc.debit = 0) and
    (not(kd.kdvalue like unkKD$)) and
    (not(kd.kdvalue like unkVKD$))
    )
    LOOP
      BEGIN
        /*       */
        select inc.id
        into val_ID431$         FROM Incomes32 inc
        WHERE (inc.ProgIndex =  43) and
        (inc.RecordIndex =  REC$1.val_ID42)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      /*     ,   Credit, ProgIndex, RecordIndex */
      update Incomes32
      set
      DocNum = new$DocNum,
      DocCount = new$DocCount,       
      DOCDATE = new$DOCDATE,
      Debit = 0,
      DocType = new$DocType,
      Org_Ref = new$Org_Ref,
      AccountIndex = new$AccountIndex,
      KD = new$Kd,
      SubKD = new$SubKD,
      RegionCLS = new$RegionCLS,
      GosNI = new$GosNI,
      IncAccount = new$IncAccount,
      BudgetRef = new$BudgetRef,
      Note = new$Note,
      MEANSTYPE = new$MEANSTYPE,
      FACIALACC_CLS = new$FACIALACC_CLS,
      FACT = new$FACT,
      TransfertCls = new$TransfertCls,
      DirectionCls = new$DirectionCls,
      rversion = -1
      where id = val_ID431$;

        
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
--       new$ClsType := 1;       --       ClsType
--    ELSIF (new$ClsType IS NULL) THEN
--       new$ClsType := 2;                                --  - 
--    END IF;
-- 
--    IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
--       --  
--       RaiseEXCEPTION ('EX_WRONGBUDCLS');
--    END IF;
-- 
--    IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
--       --  
--       RaiseEXCEPTION ('EX_WRONGBUDCLS');
--    END IF;
-- 
--    IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
--       --   
--       RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
--    END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (new$RVersion IS NULL) THEN
--       new$RVersion := 1;
--    ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
--       new$RVersion := :OLD.RVersion;
--    ELSE
--       new$RVersion := :OLD.RVersion + 1;
--    END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (NEW$ID <> :OLD.ID) THEN
--       INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
--         VALUES (161, :OLD.ID, SYSDATE);
--       DELETE FROM DelRecIndexes
--         WHERE (TableID = 161) AND (RecordId = NEW$ID);
--    END IF;

END;
/
-- ALTER TRIGGER TR_INCOMES32_BU_105
CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   IF (new$Fact IS NULL) THEN 
--     new$Fact := 0;
--   END IF;
--   IF (new$DocBase IS NULL) THEN 
--     new$DocBase := 0;
--   END IF;
--   IF (new$Gosni IS NULL) THEN 
--     new$Gosni := 0;
--   END IF;
--   /* 3 -    */
--   IF (new$ProgIndex IS NULL) THEN 
--     new$ProgIndex := 3; 
--   END IF;
--   IF (new$KD IS NULL) THEN 
--     new$KD := 0; 
--   END IF;
--   /*   */
--   IF (new$FACIALACC_CLS IS NULL) THEN 
--     new$FACIALACC_CLS := 0; 
--   END IF;
--   IF (new$MeansType IS NULL) THEN 
--     new$MeansType := 0;
--   END IF;
--   IF (new$Debit IS NULL) THEN 
--     new$Debit := 0;
--   END IF;
--   IF (new$Credit IS NULL) THEN 
--     new$Credit := 0;
--   END IF;
--   IF (new$Org_Ref IS NULL) THEN 
--     new$Org_Ref := 0;
--   END IF;
--   IF (new$AccountIndex IS NULL) THEN 
--     new$AccountIndex := 0; 
--   END IF;
--   IF (new$DocType IS NULL) THEN 
--     new$DocType := 0;
--   END IF;
--   IF (new$SubKD IS NULL) THEN 
--     new$SubKD := 0;
--   END IF;
--   IF (new$RegionCLS IS NULL) THEN 
--     new$RegionCLS := 0;
--   END IF;
--   IF (new$DocCount IS NULL) THEN 
--     new$DocCount := 1;
--   END IF;
--   IF (new$BuhPaymentCLS IS NULL) THEN 
--     new$BuhPaymentCLS := 0;
--   END IF;
--   IF (new$KVSR IS NULL) THEN 
--     new$KVSR := 0;
--   END IF;
--   IF (new$KFSR IS NULL) THEN 
--     new$KFSR := 0;
--   END IF;
--   IF (new$KESR IS NULL) THEN 
--     new$KESR := 0;
--   END IF;
--   IF (new$KVR IS NULL) THEN 
--     new$KVR := 0;
--   END IF;
--   IF (new$KCSR IS NULL) THEN 
--     new$KCSR := 0;
--   END IF;
--   IF (new$OKATO IS NULL) THEN 
--     new$OKATO := 0;
--   END IF;
--   IF (new$FundsSource IS NULL) THEN 
--     new$FundsSource := 0;
--   END IF;
--   IF (new$DirectionCLS IS NULL) THEN 
--     new$DirectionCLS := 0;
--   END IF;
--   IF (new$FinType is null) then 
--     new$FinType := 0;
--   END IF;
--   IF (new$Debit * new$Credit <> 0) THEN
--     RaiseException('ex_FailDebetCretitValue');
--   END IF;
--   /*   .        */
--   IF (new$IFS_CORR IS NULL) THEN 
--     new$Ifs_Corr := 0;
--   END IF;
--   IF (new$IFS IS NULL) THEN 
--     new$Ifs := 0;
--   END IF;
--   IF (new$BuhOperationCLS IS NULL)
--   THEN 
--     GetIntConst(60, 15,new$BuhOperationCLS);
--   END IF;
--   BEGIN
-- 
--     /*     */
--     /*   after   ,*/ 
--     /*      */
--     SELECT ProgIndex, AcceptDate, ReestrNumber
--     INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
--     WHERE
--     (qt.ID = new$RecordIndex)
--     ;
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;
--   /*              
--            (  , , ) */
--   /*   -    () */
--   IF (CapProgIndex2$ = 45)
--   THEN 
--     IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
--     THEN 
--       /*        ,
--                      */            
--       new$FederalFundsRef := new$ID;
--       /* if-then*/
--     ELSE 
--       new$FederalFundsRef := NULL;
--       /* if-else*/  
--     END IF;/* if (CapProgIndex=45) */
--   END IF;
--   /*     */
--   IF (new$BudgetRef <> :old.BudgetRef) THEN
--     IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
--       IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
--         RaiseException('Ex_CantModufyBudget');
--       END IF;
--       IF (new$Progindex = 41) THEN
--         SELECT COUNT(inc.id ) INTO CNT$1
--         FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
--         IF ((CNT$1<> 0)) THEN
--           RaiseException('Ex_CantModufyBudget');
--         END IF;   
--       END IF;
--     END IF;
--   END IF;
--   /*     \*/
--   IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
--   ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
--       INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
--       WHERE fac.ID = new$FacialACC_Cls
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*    */
--   GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
--   new$targetcls,new$targetcls);  

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
--       new$DocNum := CAST (new$DocNumber AS VARCHAR2);
--    END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -
  NULL;
--   BEGIN
--     SELECT Inn
--      INTO new$Inn
--      FROM Organizations o
--     WHERE (o.ID = new$Org_Ref);
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -
  NULL;
--   /*      */
--   IF (new$ProgIndex <> 42) THEN
--     BEGIN
--       SELECT ProgIndex, DocNumber, AcceptDate
--       INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
--       WHERE
--       (qt.ID = new$RecordIndex)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*   -  ,   */
--   IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
--   THEN 
--     IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
--     (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
--     THEN 
--       BEGIN
--         SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
--         WHERE inc.id = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       IF (Kd_Master$ = new$Kd) THEN 
--         CapAcceptDate$ := new$DOCDATE;
--         CapProgIndex$  := new$ProgIndex;
--         CapDocNumber$  := new$DocNum;
--         /*  */        
--       END IF;/*       (         )*/
--     END IF;
--     IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
--     THEN 
-- 
--       /*      */
--       /* /      Incomes32, ..      ,     */
-- 
--       /*     /   */
--       SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
--       INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
--       WHERE
--       (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
--       ;
--       /*            ,  .*/
--       /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
--                       ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
--                      ) THEN
--                     EXCEPTION EX_CANNOTUPDATENUMBER;*/
--                  
--                 
--       IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
--       then
--         if ((new$DocType <> :old.DocType )
--         or (new$Debit <> :old.Debit )
--         or (new$Credit <> :old.Credit)
--         or (new$org_ref <> :old.org_ref)
--         or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
--         or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
--         )
--         then
--           RaiseException('EX_CANNOTUPDATENUMBER');
--         END IF;
--       END IF;
--                 
-- 
-- 
--       /*           */
--       IF (PayDocCount$ = 0)
--       THEN 
--         /*       */
--         GetIntConst(11, 2,ConstPayQueue$);
--         /*       */
--         GetIntConst(11, 1,ConstSendBy$);
-- 
--         /*    */
--         INSERT INTO PayDoc32
--         (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
--         Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
--         VALUES
--         (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
--         new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
--         /* (new.Debit - new.Credit) --- ..      ,    ,
--                                      */
-- 
--         /* if-then */
--       ELSE 
--         /*     */
--         IF (((new$AccountRef = :old.AccountRef) OR
--         ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
--         AND (new$IncAccount = :old.IncAccount)
--         AND (new$BudgetRef = :old.BudgetRef)
--         AND ((new$Note = :old.Note) OR
--         ((new$Note IS NULL) AND (:old.Note IS NULL)))
--         AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
--         ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
--         AND ((new$TaxNote = :old.TaxNote) OR
--         ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
--         )  THEN
--           new$AccountRef := new$AccountRef;
--                           
--         ELSE
-- 
--           UPDATE PayDoc32 pd
--           SET
--           pd.AccountRef = new$AccountRef,
--           pd.PayerAttrRef = new$IncAccount,
--           pd.AcceptorAttrRef = new$AccountRef,
--           pd.TextNote = new$Note,
--           pd.TaxNote = new$TaxNote,
--           pd.BudgetRef = new$BudgetRef,
--           pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
--           pd.InputDate = CapAcceptDate$,
--           pd.SourceDocNumber = CapDocNumber$,
--           pd.FACIALACC_CLS = new$FACIALACC_CLS
--           WHERE
--           (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
--                           
--         END IF;
--         IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
--         OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
--         THEN  
--           IF (Divided$ > 0)
--           THEN
--             /*  ,      */
--             RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
--           ELSE
--             UPDATE PayDoc32 pd
--             SET
--             pd.Credit = new$Debit - new$Credit
--             WHERE
--             (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
--                           
--           END IF;/* if-then*/            
--         END IF;/* if-else*/
--       END IF;
--       /*     / */
--       /*   :     ,     */
--       /*  ,     */
--       SELECT MAX(pd.AcceptDate)
--       INTO Date_Pd$           FROM PayDoc32 pd
--       WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
--       ;
--       new$Idate := Date_Pd$;
--       /* if-then*/
--     ELSE 
--       /*       
--                           -
--                     . */
--       DELETE FROM PayDoc32 pd
--       WHERE
--       (pd.ProgIndex = new$ProgIndex)
--       AND (pd.RecordIndex = new$id);
--       /* if-else*/  
--     END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
--   END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -
  NULL;
--   if ((new$DocDate is null) and (new$ProgIndex=45)) then 
--     BEGIN
--       select q.BuildDate 
--       into 
--       new$DocDate        from QuotesTitle q 
--       where q.id = new$RecordIndex 
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   if ((new$DocDate is null) and (new$IDATE is not null)) then
--     new$DocDate := new$IDATE;
--   END IF;
--   if ((new$DOCDATE is not null)) then
--     new$RecordDate := new$DOCDATE;
--   END IF;
--   /*         */
--   if ((new$IDate is not null) and (new$RejectCls is not null)) then
--     RaiseException('EX_DOCNOTACCEPTREJECT');
--   END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -
  NULL;
--    /*     */
--    BEGIN
--       SELECT ProgIndex, AcceptDate, ReestrNumber
--         INTO CapProgIndex, CapAcceptDate, CapReestrNumber
--         FROM QuotesTitle qt
--        WHERE (qt.ID = new$RecordIndex);
--    EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--    END;
-- 
--    /*   -    () */
--    IF (CapProgIndex = 45) THEN
--       IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
--          /*        ,
--             */
--          new$FederalFundsRef := new$ID;
--       ELSE
--          new$FederalFundsRef := NULL;
--       END IF;
--    END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ProgIndex = 42)
--   then 
--     /*    */
--     GetVarCharConst(3,0,unkKD$);
--     /*     */
--     GetVarCharConst(3,11,unkVKD$);  
--     BEGIN
-- 
--       select KDValue   into newKD$ from kd where Id=new$kd
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     BEGIN
--       select KDValue   into oldKD$ from kd where Id=:old.kd
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     BEGIN
-- 
--       /*     */
--       select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
--       IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
--       into
--       idKD1$,
--       val_DocCount1$,
--       val_DocType1$,
--       val_Org_Ref1$,
--       val_AccountIndex1$,
--       val_SubKD1$,
--       val_RegionCLS1$,
--       val_GosNI1$,
--       val_IncAccount1$,
--       val_BudgetRef1$,
--       val_MEANSTYPE1$  , 
--       val_FACIALACC_CLS1$,
--       val_TransfertCls1$         from incomes32 where id=new$RecordIndex
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     if (not idKD1$ is null) then
--       if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
--       (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
--         /*   ,    */
--         delete
--         from Incomes32
--         where
--         (ProgIndex=43)and
--         (RecordIndex=:old.id);
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
--       (new$Debit<>0))
--       /*       */
--       then 
--         RaiseException('ex_UnknownRedirect');
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
--       ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
--         /*   ,   ,   */
--         insert into
--         Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
--         Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
--         RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
--         Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
--         val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
--         val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
--         new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
--       and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
--         /*      ,   */
--         update Incomes32
--         set
--         DocNum = new$DocNum,
--         DocCount = val_DocCount1$,
--         iDate = new$iDate,
--         DOCDATE = new$DOCDATE,
--         Debit = 0,
--         Credit = -new$Credit,
--         DocType = val_DocType1$,
--         Org_Ref = val_Org_Ref1$,
--         AccountIndex = val_AccountIndex1$,
--         KD = idKD1$,
--         SubKD = val_SubKD1$,
--         RegionCLS = val_RegionCLS1$,
--         GosNI = val_GosNI1$,
--         ProgIndex = 43,
--         RecordIndex = new$Id,
--         IncAccount = val_IncAccount1$,
--         BudgetRef = val_BudgetRef1$,
--         Note = new$Note,
--         MEANSTYPE = val_MEANSTYPE1$,
--         FACIALACC_CLS = val_FACIALACC_CLS1$,
--         TransfertCls = val_TransfertCls1$,
--         RVersion = -1
--         where
--         (ProgIndex=43)and
--         (RecordIndex=:old.id);
--          
--       END IF; 
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ProgIndex = 41)    /*   () */
--   then 
--     /*    */
--     GetVarCharConst(3,0,unkKD$);
--     /*     */
--     GetVarCharConst(3,11,unkVKD$);  
--     /*       */
--     FOR REC$1 IN (SELECT inc.id
--      AS val_ID42    FROM Incomes32 inc
--     LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
--     WHERE (inc.ProgIndex =  42) and
--     (inc.RecordIndex =  new$id) and
--     (inc.debit = 0) and
--     (not(kd.kdvalue like unkKD$)) and
--     (not(kd.kdvalue like unkVKD$))
--     )
--     LOOP
--       BEGIN
--         /*       */
--         select inc.id
--         into val_ID431$         FROM Incomes32 inc
--         WHERE (inc.ProgIndex =  43) and
--         (inc.RecordIndex =  REC$1.val_ID42)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
-- 
--       /*     ,   Credit, ProgIndex, RecordIndex */
--       update Incomes32
--       set
--       DocNum = new$DocNum,
--       DocCount = new$DocCount,       
--       DOCDATE = new$DOCDATE,
--       Debit = 0,
--       DocType = new$DocType,
--       Org_Ref = new$Org_Ref,
--       AccountIndex = new$AccountIndex,
--       KD = new$Kd,
--       SubKD = new$SubKD,
--       RegionCLS = new$RegionCLS,
--       GosNI = new$GosNI,
--       IncAccount = new$IncAccount,
--       BudgetRef = new$BudgetRef,
--       Note = new$Note,
--       MEANSTYPE = new$MEANSTYPE,
--       FACIALACC_CLS = new$FACIALACC_CLS,
--       FACT = new$FACT,
--       TransfertCls = new$TransfertCls,
--       DirectionCls = new$DirectionCls,
--       rversion = -1
--       where id = val_ID431$;
-- 
--         
--     END LOOP;
--   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
--       new$ClsType := 1;       --       ClsType
--    ELSIF (new$ClsType IS NULL) THEN
--       new$ClsType := 2;                                --  - 
--    END IF;
-- 
--    IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
--       --  
--       RaiseEXCEPTION ('EX_WRONGBUDCLS');
--    END IF;
-- 
--    IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
--       --  
--       RaiseEXCEPTION ('EX_WRONGBUDCLS');
--    END IF;
-- 
--    IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
--       --   
--       RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
--    END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (new$RVersion IS NULL) THEN
--       new$RVersion := 1;
--    ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
--       new$RVersion := :OLD.RVersion;
--    ELSE
--       new$RVersion := :OLD.RVersion + 1;
--    END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (NEW$ID <> :OLD.ID) THEN
--       INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
--         VALUES (161, :OLD.ID, SYSDATE);
--       DELETE FROM DelRecIndexes
--         WHERE (TableID = 161) AND (RecordId = NEW$ID);
--    END IF;

END;
/
-- ALTER TRIGGER TR_INCOMES32_BU_300
CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   IF (new$Fact IS NULL) THEN 
--     new$Fact := 0;
--   END IF;
--   IF (new$DocBase IS NULL) THEN 
--     new$DocBase := 0;
--   END IF;
--   IF (new$Gosni IS NULL) THEN 
--     new$Gosni := 0;
--   END IF;
--   /* 3 -    */
--   IF (new$ProgIndex IS NULL) THEN 
--     new$ProgIndex := 3; 
--   END IF;
--   IF (new$KD IS NULL) THEN 
--     new$KD := 0; 
--   END IF;
--   /*   */
--   IF (new$FACIALACC_CLS IS NULL) THEN 
--     new$FACIALACC_CLS := 0; 
--   END IF;
--   IF (new$MeansType IS NULL) THEN 
--     new$MeansType := 0;
--   END IF;
--   IF (new$Debit IS NULL) THEN 
--     new$Debit := 0;
--   END IF;
--   IF (new$Credit IS NULL) THEN 
--     new$Credit := 0;
--   END IF;
--   IF (new$Org_Ref IS NULL) THEN 
--     new$Org_Ref := 0;
--   END IF;
--   IF (new$AccountIndex IS NULL) THEN 
--     new$AccountIndex := 0; 
--   END IF;
--   IF (new$DocType IS NULL) THEN 
--     new$DocType := 0;
--   END IF;
--   IF (new$SubKD IS NULL) THEN 
--     new$SubKD := 0;
--   END IF;
--   IF (new$RegionCLS IS NULL) THEN 
--     new$RegionCLS := 0;
--   END IF;
--   IF (new$DocCount IS NULL) THEN 
--     new$DocCount := 1;
--   END IF;
--   IF (new$BuhPaymentCLS IS NULL) THEN 
--     new$BuhPaymentCLS := 0;
--   END IF;
--   IF (new$KVSR IS NULL) THEN 
--     new$KVSR := 0;
--   END IF;
--   IF (new$KFSR IS NULL) THEN 
--     new$KFSR := 0;
--   END IF;
--   IF (new$KESR IS NULL) THEN 
--     new$KESR := 0;
--   END IF;
--   IF (new$KVR IS NULL) THEN 
--     new$KVR := 0;
--   END IF;
--   IF (new$KCSR IS NULL) THEN 
--     new$KCSR := 0;
--   END IF;
--   IF (new$OKATO IS NULL) THEN 
--     new$OKATO := 0;
--   END IF;
--   IF (new$FundsSource IS NULL) THEN 
--     new$FundsSource := 0;
--   END IF;
--   IF (new$DirectionCLS IS NULL) THEN 
--     new$DirectionCLS := 0;
--   END IF;
--   IF (new$FinType is null) then 
--     new$FinType := 0;
--   END IF;
--   IF (new$Debit * new$Credit <> 0) THEN
--     RaiseException('ex_FailDebetCretitValue');
--   END IF;
--   /*   .        */
--   IF (new$IFS_CORR IS NULL) THEN 
--     new$Ifs_Corr := 0;
--   END IF;
--   IF (new$IFS IS NULL) THEN 
--     new$Ifs := 0;
--   END IF;
--   IF (new$BuhOperationCLS IS NULL)
--   THEN 
--     GetIntConst(60, 15,new$BuhOperationCLS);
--   END IF;
--   BEGIN
-- 
--     /*     */
--     /*   after   ,*/ 
--     /*      */
--     SELECT ProgIndex, AcceptDate, ReestrNumber
--     INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
--     WHERE
--     (qt.ID = new$RecordIndex)
--     ;
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;
--   /*              
--            (  , , ) */
--   /*   -    () */
--   IF (CapProgIndex2$ = 45)
--   THEN 
--     IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
--     THEN 
--       /*        ,
--                      */            
--       new$FederalFundsRef := new$ID;
--       /* if-then*/
--     ELSE 
--       new$FederalFundsRef := NULL;
--       /* if-else*/  
--     END IF;/* if (CapProgIndex=45) */
--   END IF;
--   /*     */
--   IF (new$BudgetRef <> :old.BudgetRef) THEN
--     IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
--       IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
--         RaiseException('Ex_CantModufyBudget');
--       END IF;
--       IF (new$Progindex = 41) THEN
--         SELECT COUNT(inc.id ) INTO CNT$1
--         FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
--         IF ((CNT$1<> 0)) THEN
--           RaiseException('Ex_CantModufyBudget');
--         END IF;   
--       END IF;
--     END IF;
--   END IF;
--   /*     \*/
--   IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
--   ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
--       INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
--       WHERE fac.ID = new$FacialACC_Cls
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*    */
--   GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
--   new$targetcls,new$targetcls);  

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
--       new$DocNum := CAST (new$DocNumber AS VARCHAR2);
--    END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -
  NULL;
--   BEGIN
--     SELECT Inn
--      INTO new$Inn
--      FROM Organizations o
--     WHERE (o.ID = new$Org_Ref);
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -
  NULL;
--   /*      */
--   IF (new$ProgIndex <> 42) THEN
--     BEGIN
--       SELECT ProgIndex, DocNumber, AcceptDate
--       INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
--       WHERE
--       (qt.ID = new$RecordIndex)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*   -  ,   */
--   IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
--   THEN 
--     IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
--     (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
--     THEN 
--       BEGIN
--         SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
--         WHERE inc.id = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       IF (Kd_Master$ = new$Kd) THEN 
--         CapAcceptDate$ := new$DOCDATE;
--         CapProgIndex$  := new$ProgIndex;
--         CapDocNumber$  := new$DocNum;
--         /*  */        
--       END IF;/*       (         )*/
--     END IF;
--     IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
--     THEN 
-- 
--       /*      */
--       /* /      Incomes32, ..      ,     */
-- 
--       /*     /   */
--       SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
--       INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
--       WHERE
--       (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
--       ;
--       /*            ,  .*/
--       /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
--                       ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
--                      ) THEN
--                     EXCEPTION EX_CANNOTUPDATENUMBER;*/
--                  
--                 
--       IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
--       then
--         if ((new$DocType <> :old.DocType )
--         or (new$Debit <> :old.Debit )
--         or (new$Credit <> :old.Credit)
--         or (new$org_ref <> :old.org_ref)
--         or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
--         or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
--         )
--         then
--           RaiseException('EX_CANNOTUPDATENUMBER');
--         END IF;
--       END IF;
--                 
-- 
-- 
--       /*           */
--       IF (PayDocCount$ = 0)
--       THEN 
--         /*       */
--         GetIntConst(11, 2,ConstPayQueue$);
--         /*       */
--         GetIntConst(11, 1,ConstSendBy$);
-- 
--         /*    */
--         INSERT INTO PayDoc32
--         (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
--         Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
--         VALUES
--         (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
--         new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
--         /* (new.Debit - new.Credit) --- ..      ,    ,
--                                      */
-- 
--         /* if-then */
--       ELSE 
--         /*     */
--         IF (((new$AccountRef = :old.AccountRef) OR
--         ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
--         AND (new$IncAccount = :old.IncAccount)
--         AND (new$BudgetRef = :old.BudgetRef)
--         AND ((new$Note = :old.Note) OR
--         ((new$Note IS NULL) AND (:old.Note IS NULL)))
--         AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
--         ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
--         AND ((new$TaxNote = :old.TaxNote) OR
--         ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
--         )  THEN
--           new$AccountRef := new$AccountRef;
--                           
--         ELSE
-- 
--           UPDATE PayDoc32 pd
--           SET
--           pd.AccountRef = new$AccountRef,
--           pd.PayerAttrRef = new$IncAccount,
--           pd.AcceptorAttrRef = new$AccountRef,
--           pd.TextNote = new$Note,
--           pd.TaxNote = new$TaxNote,
--           pd.BudgetRef = new$BudgetRef,
--           pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
--           pd.InputDate = CapAcceptDate$,
--           pd.SourceDocNumber = CapDocNumber$,
--           pd.FACIALACC_CLS = new$FACIALACC_CLS
--           WHERE
--           (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
--                           
--         END IF;
--         IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
--         OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
--         THEN  
--           IF (Divided$ > 0)
--           THEN
--             /*  ,      */
--             RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
--           ELSE
--             UPDATE PayDoc32 pd
--             SET
--             pd.Credit = new$Debit - new$Credit
--             WHERE
--             (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
--                           
--           END IF;/* if-then*/            
--         END IF;/* if-else*/
--       END IF;
--       /*     / */
--       /*   :     ,     */
--       /*  ,     */
--       SELECT MAX(pd.AcceptDate)
--       INTO Date_Pd$           FROM PayDoc32 pd
--       WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
--       ;
--       new$Idate := Date_Pd$;
--       /* if-then*/
--     ELSE 
--       /*       
--                           -
--                     . */
--       DELETE FROM PayDoc32 pd
--       WHERE
--       (pd.ProgIndex = new$ProgIndex)
--       AND (pd.RecordIndex = new$id);
--       /* if-else*/  
--     END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
--   END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -
  NULL;
--   if ((new$DocDate is null) and (new$ProgIndex=45)) then 
--     BEGIN
--       select q.BuildDate 
--       into 
--       new$DocDate        from QuotesTitle q 
--       where q.id = new$RecordIndex 
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   if ((new$DocDate is null) and (new$IDATE is not null)) then
--     new$DocDate := new$IDATE;
--   END IF;
--   if ((new$DOCDATE is not null)) then
--     new$RecordDate := new$DOCDATE;
--   END IF;
--   /*         */
--   if ((new$IDate is not null) and (new$RejectCls is not null)) then
--     RaiseException('EX_DOCNOTACCEPTREJECT');
--   END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -
  NULL;
--    /*     */
--    BEGIN
--       SELECT ProgIndex, AcceptDate, ReestrNumber
--         INTO CapProgIndex, CapAcceptDate, CapReestrNumber
--         FROM QuotesTitle qt
--        WHERE (qt.ID = new$RecordIndex);
--    EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--    END;
-- 
--    /*   -    () */
--    IF (CapProgIndex = 45) THEN
--       IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
--          /*        ,
--             */
--          new$FederalFundsRef := new$ID;
--       ELSE
--          new$FederalFundsRef := NULL;
--       END IF;
--    END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ProgIndex = 42)
--   then 
--     /*    */
--     GetVarCharConst(3,0,unkKD$);
--     /*     */
--     GetVarCharConst(3,11,unkVKD$);  
--     BEGIN
-- 
--       select KDValue   into newKD$ from kd where Id=new$kd
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     BEGIN
--       select KDValue   into oldKD$ from kd where Id=:old.kd
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     BEGIN
-- 
--       /*     */
--       select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
--       IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
--       into
--       idKD1$,
--       val_DocCount1$,
--       val_DocType1$,
--       val_Org_Ref1$,
--       val_AccountIndex1$,
--       val_SubKD1$,
--       val_RegionCLS1$,
--       val_GosNI1$,
--       val_IncAccount1$,
--       val_BudgetRef1$,
--       val_MEANSTYPE1$  , 
--       val_FACIALACC_CLS1$,
--       val_TransfertCls1$         from incomes32 where id=new$RecordIndex
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     if (not idKD1$ is null) then
--       if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
--       (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
--         /*   ,    */
--         delete
--         from Incomes32
--         where
--         (ProgIndex=43)and
--         (RecordIndex=:old.id);
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
--       (new$Debit<>0))
--       /*       */
--       then 
--         RaiseException('ex_UnknownRedirect');
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
--       ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
--         /*   ,   ,   */
--         insert into
--         Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
--         Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
--         RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
--         Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
--         val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
--         val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
--         new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
--       and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
--         /*      ,   */
--         update Incomes32
--         set
--         DocNum = new$DocNum,
--         DocCount = val_DocCount1$,
--         iDate = new$iDate,
--         DOCDATE = new$DOCDATE,
--         Debit = 0,
--         Credit = -new$Credit,
--         DocType = val_DocType1$,
--         Org_Ref = val_Org_Ref1$,
--         AccountIndex = val_AccountIndex1$,
--         KD = idKD1$,
--         SubKD = val_SubKD1$,
--         RegionCLS = val_RegionCLS1$,
--         GosNI = val_GosNI1$,
--         ProgIndex = 43,
--         RecordIndex = new$Id,
--         IncAccount = val_IncAccount1$,
--         BudgetRef = val_BudgetRef1$,
--         Note = new$Note,
--         MEANSTYPE = val_MEANSTYPE1$,
--         FACIALACC_CLS = val_FACIALACC_CLS1$,
--         TransfertCls = val_TransfertCls1$,
--         RVersion = -1
--         where
--         (ProgIndex=43)and
--         (RecordIndex=:old.id);
--          
--       END IF; 
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ProgIndex = 41)    /*   () */
--   then 
--     /*    */
--     GetVarCharConst(3,0,unkKD$);
--     /*     */
--     GetVarCharConst(3,11,unkVKD$);  
--     /*       */
--     FOR REC$1 IN (SELECT inc.id
--      AS val_ID42    FROM Incomes32 inc
--     LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
--     WHERE (inc.ProgIndex =  42) and
--     (inc.RecordIndex =  new$id) and
--     (inc.debit = 0) and
--     (not(kd.kdvalue like unkKD$)) and
--     (not(kd.kdvalue like unkVKD$))
--     )
--     LOOP
--       BEGIN
--         /*       */
--         select inc.id
--         into val_ID431$         FROM Incomes32 inc
--         WHERE (inc.ProgIndex =  43) and
--         (inc.RecordIndex =  REC$1.val_ID42)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
-- 
--       /*     ,   Credit, ProgIndex, RecordIndex */
--       update Incomes32
--       set
--       DocNum = new$DocNum,
--       DocCount = new$DocCount,       
--       DOCDATE = new$DOCDATE,
--       Debit = 0,
--       DocType = new$DocType,
--       Org_Ref = new$Org_Ref,
--       AccountIndex = new$AccountIndex,
--       KD = new$Kd,
--       SubKD = new$SubKD,
--       RegionCLS = new$RegionCLS,
--       GosNI = new$GosNI,
--       IncAccount = new$IncAccount,
--       BudgetRef = new$BudgetRef,
--       Note = new$Note,
--       MEANSTYPE = new$MEANSTYPE,
--       FACIALACC_CLS = new$FACIALACC_CLS,
--       FACT = new$FACT,
--       TransfertCls = new$TransfertCls,
--       DirectionCls = new$DirectionCls,
--       rversion = -1
--       where id = val_ID431$;
-- 
--         
--     END LOOP;
--   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
--       new$ClsType := 1;       --       ClsType
--    ELSIF (new$ClsType IS NULL) THEN
--       new$ClsType := 2;                                --  - 
--    END IF;
-- 
--    IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
--       --  
--       RaiseEXCEPTION ('EX_WRONGBUDCLS');
--    END IF;
-- 
--    IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
--       --  
--       RaiseEXCEPTION ('EX_WRONGBUDCLS');
--    END IF;
-- 
--    IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
--       --   
--       RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
--    END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -
  NULL;
--   IsReject$ := -1;
--   if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
--     IsReject$ := 1;
--   elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
--     IsReject$ := 0;
--   end if;  
--   if (IsReject$ <> -1) then
--     update LinkRecords set
--       IsRejected = IsReject$
--     where
--       (ChildID = :new.ID)
--       or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
--   end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (new$RVersion IS NULL) THEN
--       new$RVersion := 1;
--    ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
--       new$RVersion := :OLD.RVersion;
--    ELSE
--       new$RVersion := :OLD.RVersion + 1;
--    END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (NEW$ID <> :OLD.ID) THEN
--       INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
--         VALUES (161, :OLD.ID, SYSDATE);
--       DELETE FROM DelRecIndexes
--         WHERE (TableID = 161) AND (RecordId = NEW$ID);
--    END IF;

END;
/
ALTER TRIGGER TR_LIMITFINDETAIL_BU_500 DISABLE
/
ALTER TRIGGER TR_PAYMENTSCHEDULE_BU_500 DISABLE
/
ALTER TRIGGER TR_REPCLSDETAILINFO_BU_500 DISABLE
/
ALTER TRIGGER TR_TENDERPRODUCT_BU_500 DISABLE
/
-- ALTER TRIGGER TR_WRITEXECUTIONDETAIL_BU_500
CREATE OR REPLACE TRIGGER TR_WRITEXECUTIONDETAIL_BU_500
  BEFORE UPDATE
  ON WRITEXECUTIONDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_500 (TR_WRITEXECUTIONDETAIL_BU_500)
-- - - - - - - - - - - - -
  NULL;
--   :new.Updatedate := SYSDATE;
--   :new.UpdaterUser := user;

END;
/
commit work 
/
CALL FillTargetCls() 
/
DROP PROCEDURE FillTargetCls 
/
ALTER TRIGGER TR_BUDGETDATA_BU_500 ENABLE
/
-- ALTER TRIGGER tr_BudgetData_bu
CREATE OR REPLACE TRIGGER TR_BUDGETDATA_BU
  BEFORE UPDATE
  ON BUDGETDATA
  FOR EACH ROW
DECLARE
  AutoKvrCorr$ NUMBER(10);
  OrgRefByAcc1$ NUMBER(10);
  CapClsType1$ NUMBER(10);
  doubleUse1$ NUMBER(10);
  BALBOFlag1$ NUMBER(10);
  AllowDivideBA1$ NUMBER(10);
  StimateKind1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_BUDGETDATA_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (:new.KFSR IS NULL) THEN  
    :new.KFSR := 0;
  END IF;
  IF (:new.KVSR IS NULL) THEN  
    :new.KVSR := 0;
  END IF;
  IF (:new.KVR IS NULL) THEN  
    :new.KVR := 0;
  END IF;
  IF (:new.KCSR IS NULL) THEN  
    :new.KCSR := 0;
  END IF;
  IF (:new.KESR IS NULL) THEN  
    :new.KESR := 0;
  END IF;
  IF (:new.SubKESR IS NULL) THEN  
    :new.SubKESR := 0;
  END IF;
  IF (:new.RegionCLS IS NULL) THEN  
    :new.RegionCLS := 0;
  END IF;
  IF (:new.DirectionCls IS NULL) THEN 
    :new.DirectionCls := 0;
  END IF;
  IF (:new.FundsSource IS NULL) THEN 
    :new.FundsSource := 0;
  END IF;
  IF (:new.KD IS NULL) THEN 
    :new.KD := 0;
  END IF;
  IF (:new.subkd IS NULL) THEN 
    :new.subkd := 0;
  END IF;
  IF (:new.Fact IS NULL) THEN  
    :new.Fact := 0;
  END IF;
  IF (:new.FacialAcc_Cls IS NULL) THEN 
    :new.FacialAcc_Cls := 0;
  END IF;
  IF (:new.KVRCorr IS NULL) THEN 
    :new.KVRCorr := 0;
  END IF;
  IF (:new.KesrCorr IS NULL) THEN 
    :new.KesrCorr := 0;
  END IF;
  IF (:new.AssignmentKind IS NULL) THEN 
    :new.AssignmentKind := 0;
  END IF;
  IF (:new.Quarter1 IS NULL) THEN  
    :new.Quarter1 := 0;
  END IF;
  IF (:new.Quarter2 IS NULL) THEN  
    :new.Quarter2 := 0;
  END IF;
  IF (:new.Quarter3 IS NULL) THEN  
    :new.Quarter3 := 0;
  END IF;
  IF (:new.Quarter4 IS NULL) THEN  
    :new.Quarter4 := 0;
  END IF;
  IF (:new.FinType IS NULL) THEN  
    :new.FinType := 0;
  END IF;
  IF (:new.MeansType IS NULL) THEN  
    :new.MeansType := 0;
  END IF;
  IF (:new.DepartmentCls IS NULL) THEN 
    :new.DepartmentCls := 0;
  END IF;
  /*   .        */
  IF (:new.IFS IS NULL) THEN 
    :new.IFS := 0;
  END IF;
  IF (:new.BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,:new.BuhOperationCLS);
  END IF;
  IF (:new.Month01 IS NULL) THEN  
    :new.Month01 := 0;
  END IF;
  IF (:new.Month02 IS NULL) THEN  
    :new.Month02 := 0;
  END IF;
  IF (:new.Month03 IS NULL) THEN  
    :new.Month03 := 0;
  END IF;
  IF (:new.Month04 IS NULL) THEN  
    :new.Month04 := 0;
  END IF;
  IF (:new.Month05 IS NULL) THEN  
    :new.Month05 := 0;
  END IF;
  IF (:new.Month06 IS NULL) THEN  
    :new.Month06 := 0;
  END IF;
  IF (:new.Month07 IS NULL) THEN  
    :new.Month07 := 0;
  END IF;
  IF (:new.Month08 IS NULL) THEN  
    :new.Month08 := 0;
  END IF;
  IF (:new.Month09 IS NULL) THEN  
    :new.Month09 := 0;
  END IF;
  IF (:new.Month10 IS NULL) THEN  
    :new.Month10 := 0;
  END IF;
  IF (:new.Month11 IS NULL) THEN  
    :new.Month11 := 0;
  END IF;
  IF (:new.Month12 IS NULL) THEN  
    :new.Month12 := 0;
  END IF;
  IF (:new.SummaYear1 IS NULL) THEN  
    :new.SummaYear1 := 0;
  END IF;
  IF (:new.SummaYear2 IS NULL) THEN  
    :new.SummaYear2 := 0;
  END IF;
  IF (:new.SummaYear3 IS NULL) THEN  
    :new.SummaYear3 := 0;
  END IF;
  IF (:new.SummaYear4 IS NULL) THEN  
    :new.SummaYear4 := 0;
  END IF;
  IF (:new.SummaOtherYears IS NULL) THEN  
    :new.SummaOtherYears := 0; 
  END IF;
  IF (:new.DayPlanSumma IS NULL) THEN 
    :new.DayPlanSumma := 0;
  END IF;
  /*     */
  IF (:new.BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((:new.BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN
      RaiseException('Ex_CantModufyBudget');
    END IF;
  END IF;
  BEGIN

    SELECT
    c.BA_LBO_FLAG
    INTO
    BALBOFlag1$  FROM
    BudNotify c
    WHERE
    c.id = :new.RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*   */
  IF (:new.ProgIndex = 262) THEN
    GetIntConst(32, 43,StimateKind1$);
    IF ((StimateKind1$  = 0) OR (StimateKind1$  IS NULL)) THEN
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
         
    ELSE
      IF (StimateKind1$  = 1) THEN
        :new.Quarter1 := :new.SummaYear1;
             
      ELSE
        :new.Quarter1 := :new.Month01 + :new.Month02 +:new.Month03;
        :new.Quarter2 := :new.Month04 + :new.Month05 +:new.Month06;
        :new.Quarter3 := :new.Month07 + :new.Month08 +:new.Month09;
        :new.Quarter4 := :new.Month10 + :new.Month11 +:new.Month12;
        :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
             
      END IF; 
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 260) THEN
    GetIntConst(32, 30,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 264) THEN
    GetIntConst(32, 34,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 32) THEN
    GetIntConst(32, 31,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*          ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 215) THEN
    GetIntConst(32, 35,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*         ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /* 
   IF ((NEW.TransfertOrg_Ref IS NULL) AND (NEW.REGIONCLS <> 0)) THEN
       SELECT Organizations FROM REGIONCLS
         WHERE NEW.REGIONCLS = ID
       INTO NEW.TransfertOrg_Ref;
  *//*    */
  GETTARGETCLS(:old.transfertcls, :new.transfertcls, :old.meanstype, :new.meanstype,
  :new.targetcls,:new.targetcls);

-- - - - - - - - - - - - -
-- BU_100 (TR_BUDGETDATA_BU_100)
-- Version 11.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (:new.ClsType is NULL) then
--     BEGIN
--       select
--       bn.ClsType
--       into
--       CapClsType1$     from
--       BudNotify bn
--       where
--       bn.id = :new.RecordIndex
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     if (CapClsType1$  = 3) then
--       if (:new.IFS <> 0) then
--         :new.ClsType := 1; /*       ClsType */
--             
--       else
--         if (:new.KD <> 0) then
--           :new.ClsType := 2; /* */
--                 
--         else
--           :new.ClsType := 0; /* */
--         END IF;    
--       END IF;
--     else
--       :new.ClsType := CapClsType1$;
--       
--     END IF;
--   END IF;
--   IF ((:new.ClsType = 0) AND ((:new.IFS <> 0)or(:new.KD <> 0))) THEN  /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((:new.ClsType <> 0) AND (
--   (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
--   (:new.KCSR <> 0) OR (:new.KVR <> 0)
--   )) THEN
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   if (((:new.ClsType = 1)and(:new.KD <> 0))or((:new.ClsType = 2)and(:new.IFS <> 0))) then
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((:new.ClsType <> 0) AND (:new.ClsType <> 1) AND (:new.ClsType <> 2)) THEN /*   */
--     RaiseException('EX_WRONGBUDCLSTYPE');
--   END IF;
--   IF (:new.ACC_REF IS NOT NULL) THEN /*    / */
--     BEGIN
--       SELECT oa.ORG_REF
--       INTO OrgRefByAcc1$     FROM ORG_ACCOUNTS oa
--       WHERE (oa.ID = :new.ACC_REF)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     if (:new.FacialAcc_CLS = 0) then 
--       :new.Org_Ref := OrgRefByAcc1$;
--       
--     END IF;
--   END IF;
--   /*  \ ,       \    \,  \ */
--   if (:new.FacialAcc_CLS <> 0) then
--     BEGIN
--       SELECT
--       fac.ORG_REF
--       INTO :new.Org_Ref     FROM
--       FacialACC_CLS fac
--       WHERE
--       (fac.ID = :new.FacialAcc_CLS)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     if (OrgRefByAcc1$<>:new.Org_Ref) then 
--       :new.ACC_REF := null;
--       
--     END IF;
--   END IF;
--   if ((:new.ProgIndex in (252, 253))and(:new.FacialAcc_CLS = 0)) then
--     BEGIN
--       SELECT
--       bn.FacialAccCLS
--       INTO :new.FacialAcc_CLS     FROM
--       BudNotify bn
--       WHERE
--       (bn.ID = :new.RecordIndex)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_BUDGETDATA_BU_200)
-- Version 10.30.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*       32-, 260-, 261-, 262-  , 263-, 268-  , 252-. */
--   if (:new.ProgIndex in (32, 252, 260, 261, 262, 263, 268)) then
--     /*     (32  ()) 
--              :
--            =0     ,
--            =1  ,
--            =2   0  .*//*     260 ()
--              :
--            =2   0  .*/
--     GetIntConst(32, 25,AutoKvrCorr$);
--     if (:new.ProgIndex = 32) then /*  ()*/
--       if (AutoKvrCorr$  = 0) then
--         :new.KvrCorr := :new.Kvr;
--               
--       else
--         if (AutoKvrCorr$  = 2) then
--           :new.KvrCorr := 0;
--         END IF;
--       END IF;
--       /* KESR   */
--       if (AutoKvrCorr$  = 0) then
--         :new.KesrCorr := :new.Kesr;
--               
--       else
--         if (AutoKvrCorr$  = 2) then
--           :new.KesrCorr := 0;
--         END IF;    
--       END IF;
--     else 
--       if ((:new.ProgIndex = 260)and (AutoKvrCorr$  = 2)) then  /* ()*/
--         :new.KvrCorr := 0;
--         --   ,    new.Kvr = 0;
--         /* KESR   */        
--                 
--         :new.KesrCorr := 0;
--         :new.Kesr := 0;     
--               
--       else
--         :new.KvrCorr := :new.Kvr; /*         */
--         /* KESR   */        
--         :new.KesrCorr := :new.Kesr;
--               
--       END IF;  
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_BUDGETDATA_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -
  NULL;
--   IF (:NEW.RVersion IS NULL) THEN
--      :NEW.RVersion := 1;
--   ELSIF ((:NEW.RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
--      :NEW.RVersion := :OLD.RVersion;
--   ELSE
--      :NEW.RVersion := :OLD.RVersion + 1;
--   END IF;

END;
/
-- ALTER TRIGGER TR_BudgetData_BU_700
CREATE OR REPLACE TRIGGER TR_BUDGETDATA_BU
  BEFORE UPDATE
  ON BUDGETDATA
  FOR EACH ROW
DECLARE
  AutoKvrCorr$ NUMBER(10);
  OrgRefByAcc1$ NUMBER(10);
  CapClsType1$ NUMBER(10);
  doubleUse1$ NUMBER(10);
  BALBOFlag1$ NUMBER(10);
  AllowDivideBA1$ NUMBER(10);
  StimateKind1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_BUDGETDATA_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (:new.KFSR IS NULL) THEN  
    :new.KFSR := 0;
  END IF;
  IF (:new.KVSR IS NULL) THEN  
    :new.KVSR := 0;
  END IF;
  IF (:new.KVR IS NULL) THEN  
    :new.KVR := 0;
  END IF;
  IF (:new.KCSR IS NULL) THEN  
    :new.KCSR := 0;
  END IF;
  IF (:new.KESR IS NULL) THEN  
    :new.KESR := 0;
  END IF;
  IF (:new.SubKESR IS NULL) THEN  
    :new.SubKESR := 0;
  END IF;
  IF (:new.RegionCLS IS NULL) THEN  
    :new.RegionCLS := 0;
  END IF;
  IF (:new.DirectionCls IS NULL) THEN 
    :new.DirectionCls := 0;
  END IF;
  IF (:new.FundsSource IS NULL) THEN 
    :new.FundsSource := 0;
  END IF;
  IF (:new.KD IS NULL) THEN 
    :new.KD := 0;
  END IF;
  IF (:new.subkd IS NULL) THEN 
    :new.subkd := 0;
  END IF;
  IF (:new.Fact IS NULL) THEN  
    :new.Fact := 0;
  END IF;
  IF (:new.FacialAcc_Cls IS NULL) THEN 
    :new.FacialAcc_Cls := 0;
  END IF;
  IF (:new.KVRCorr IS NULL) THEN 
    :new.KVRCorr := 0;
  END IF;
  IF (:new.KesrCorr IS NULL) THEN 
    :new.KesrCorr := 0;
  END IF;
  IF (:new.AssignmentKind IS NULL) THEN 
    :new.AssignmentKind := 0;
  END IF;
  IF (:new.Quarter1 IS NULL) THEN  
    :new.Quarter1 := 0;
  END IF;
  IF (:new.Quarter2 IS NULL) THEN  
    :new.Quarter2 := 0;
  END IF;
  IF (:new.Quarter3 IS NULL) THEN  
    :new.Quarter3 := 0;
  END IF;
  IF (:new.Quarter4 IS NULL) THEN  
    :new.Quarter4 := 0;
  END IF;
  IF (:new.FinType IS NULL) THEN  
    :new.FinType := 0;
  END IF;
  IF (:new.MeansType IS NULL) THEN  
    :new.MeansType := 0;
  END IF;
  IF (:new.DepartmentCls IS NULL) THEN 
    :new.DepartmentCls := 0;
  END IF;
  /*   .        */
  IF (:new.IFS IS NULL) THEN 
    :new.IFS := 0;
  END IF;
  IF (:new.BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,:new.BuhOperationCLS);
  END IF;
  IF (:new.Month01 IS NULL) THEN  
    :new.Month01 := 0;
  END IF;
  IF (:new.Month02 IS NULL) THEN  
    :new.Month02 := 0;
  END IF;
  IF (:new.Month03 IS NULL) THEN  
    :new.Month03 := 0;
  END IF;
  IF (:new.Month04 IS NULL) THEN  
    :new.Month04 := 0;
  END IF;
  IF (:new.Month05 IS NULL) THEN  
    :new.Month05 := 0;
  END IF;
  IF (:new.Month06 IS NULL) THEN  
    :new.Month06 := 0;
  END IF;
  IF (:new.Month07 IS NULL) THEN  
    :new.Month07 := 0;
  END IF;
  IF (:new.Month08 IS NULL) THEN  
    :new.Month08 := 0;
  END IF;
  IF (:new.Month09 IS NULL) THEN  
    :new.Month09 := 0;
  END IF;
  IF (:new.Month10 IS NULL) THEN  
    :new.Month10 := 0;
  END IF;
  IF (:new.Month11 IS NULL) THEN  
    :new.Month11 := 0;
  END IF;
  IF (:new.Month12 IS NULL) THEN  
    :new.Month12 := 0;
  END IF;
  IF (:new.SummaYear1 IS NULL) THEN  
    :new.SummaYear1 := 0;
  END IF;
  IF (:new.SummaYear2 IS NULL) THEN  
    :new.SummaYear2 := 0;
  END IF;
  IF (:new.SummaYear3 IS NULL) THEN  
    :new.SummaYear3 := 0;
  END IF;
  IF (:new.SummaYear4 IS NULL) THEN  
    :new.SummaYear4 := 0;
  END IF;
  IF (:new.SummaOtherYears IS NULL) THEN  
    :new.SummaOtherYears := 0; 
  END IF;
  IF (:new.DayPlanSumma IS NULL) THEN 
    :new.DayPlanSumma := 0;
  END IF;
  /*     */
  IF (:new.BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((:new.BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN
      RaiseException('Ex_CantModufyBudget');
    END IF;
  END IF;
  BEGIN

    SELECT
    c.BA_LBO_FLAG
    INTO
    BALBOFlag1$  FROM
    BudNotify c
    WHERE
    c.id = :new.RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*   */
  IF (:new.ProgIndex = 262) THEN
    GetIntConst(32, 43,StimateKind1$);
    IF ((StimateKind1$  = 0) OR (StimateKind1$  IS NULL)) THEN
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
         
    ELSE
      IF (StimateKind1$  = 1) THEN
        :new.Quarter1 := :new.SummaYear1;
             
      ELSE
        :new.Quarter1 := :new.Month01 + :new.Month02 +:new.Month03;
        :new.Quarter2 := :new.Month04 + :new.Month05 +:new.Month06;
        :new.Quarter3 := :new.Month07 + :new.Month08 +:new.Month09;
        :new.Quarter4 := :new.Month10 + :new.Month11 +:new.Month12;
        :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
             
      END IF; 
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 260) THEN
    GetIntConst(32, 30,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 264) THEN
    GetIntConst(32, 34,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 32) THEN
    GetIntConst(32, 31,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*          ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 215) THEN
    GetIntConst(32, 35,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*         ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /* 
   IF ((NEW.TransfertOrg_Ref IS NULL) AND (NEW.REGIONCLS <> 0)) THEN
       SELECT Organizations FROM REGIONCLS
         WHERE NEW.REGIONCLS = ID
       INTO NEW.TransfertOrg_Ref;
  *//*    */
  GETTARGETCLS(:old.transfertcls, :new.transfertcls, :old.meanstype, :new.meanstype,
  :new.targetcls,:new.targetcls);

-- - - - - - - - - - - - -
-- BU_100 (TR_BUDGETDATA_BU_100)
-- Version 11.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (:new.ClsType is NULL) then
--     BEGIN
--       select
--       bn.ClsType
--       into
--       CapClsType1$     from
--       BudNotify bn
--       where
--       bn.id = :new.RecordIndex
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     if (CapClsType1$  = 3) then
--       if (:new.IFS <> 0) then
--         :new.ClsType := 1; /*       ClsType */
--             
--       else
--         if (:new.KD <> 0) then
--           :new.ClsType := 2; /* */
--                 
--         else
--           :new.ClsType := 0; /* */
--         END IF;    
--       END IF;
--     else
--       :new.ClsType := CapClsType1$;
--       
--     END IF;
--   END IF;
--   IF ((:new.ClsType = 0) AND ((:new.IFS <> 0)or(:new.KD <> 0))) THEN  /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((:new.ClsType <> 0) AND (
--   (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
--   (:new.KCSR <> 0) OR (:new.KVR <> 0)
--   )) THEN
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   if (((:new.ClsType = 1)and(:new.KD <> 0))or((:new.ClsType = 2)and(:new.IFS <> 0))) then
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((:new.ClsType <> 0) AND (:new.ClsType <> 1) AND (:new.ClsType <> 2)) THEN /*   */
--     RaiseException('EX_WRONGBUDCLSTYPE');
--   END IF;
--   IF (:new.ACC_REF IS NOT NULL) THEN /*    / */
--     BEGIN
--       SELECT oa.ORG_REF
--       INTO OrgRefByAcc1$     FROM ORG_ACCOUNTS oa
--       WHERE (oa.ID = :new.ACC_REF)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     if (:new.FacialAcc_CLS = 0) then 
--       :new.Org_Ref := OrgRefByAcc1$;
--       
--     END IF;
--   END IF;
--   /*  \ ,       \    \,  \ */
--   if (:new.FacialAcc_CLS <> 0) then
--     BEGIN
--       SELECT
--       fac.ORG_REF
--       INTO :new.Org_Ref     FROM
--       FacialACC_CLS fac
--       WHERE
--       (fac.ID = :new.FacialAcc_CLS)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     if (OrgRefByAcc1$<>:new.Org_Ref) then 
--       :new.ACC_REF := null;
--       
--     END IF;
--   END IF;
--   if ((:new.ProgIndex in (252, 253))and(:new.FacialAcc_CLS = 0)) then
--     BEGIN
--       SELECT
--       bn.FacialAccCLS
--       INTO :new.FacialAcc_CLS     FROM
--       BudNotify bn
--       WHERE
--       (bn.ID = :new.RecordIndex)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_BUDGETDATA_BU_200)
-- Version 10.30.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*       32-, 260-, 261-, 262-  , 263-, 268-  , 252-. */
--   if (:new.ProgIndex in (32, 252, 260, 261, 262, 263, 268)) then
--     /*     (32  ()) 
--              :
--            =0     ,
--            =1  ,
--            =2   0  .*//*     260 ()
--              :
--            =2   0  .*/
--     GetIntConst(32, 25,AutoKvrCorr$);
--     if (:new.ProgIndex = 32) then /*  ()*/
--       if (AutoKvrCorr$  = 0) then
--         :new.KvrCorr := :new.Kvr;
--               
--       else
--         if (AutoKvrCorr$  = 2) then
--           :new.KvrCorr := 0;
--         END IF;
--       END IF;
--       /* KESR   */
--       if (AutoKvrCorr$  = 0) then
--         :new.KesrCorr := :new.Kesr;
--               
--       else
--         if (AutoKvrCorr$  = 2) then
--           :new.KesrCorr := 0;
--         END IF;    
--       END IF;
--     else 
--       if ((:new.ProgIndex = 260)and (AutoKvrCorr$  = 2)) then  /* ()*/
--         :new.KvrCorr := 0;
--         --   ,    new.Kvr = 0;
--         /* KESR   */        
--                 
--         :new.KesrCorr := 0;
--         :new.Kesr := 0;     
--               
--       else
--         :new.KvrCorr := :new.Kvr; /*         */
--         /* KESR   */        
--         :new.KesrCorr := :new.Kesr;
--               
--       END IF;  
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_BUDGETDATA_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

  IF (:NEW.RVersion IS NULL) THEN
     :NEW.RVersion := 1;
  ELSIF ((:NEW.RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
     :NEW.RVersion := :OLD.RVersion;
  ELSE
     :NEW.RVersion := :OLD.RVersion + 1;
  END IF;

END;
/
-- ALTER TRIGGER TR_BUDGETDATA_BU_100
CREATE OR REPLACE TRIGGER TR_BUDGETDATA_BU
  BEFORE UPDATE
  ON BUDGETDATA
  FOR EACH ROW
DECLARE
  AutoKvrCorr$ NUMBER(10);
  OrgRefByAcc1$ NUMBER(10);
  CapClsType1$ NUMBER(10);
  doubleUse1$ NUMBER(10);
  BALBOFlag1$ NUMBER(10);
  AllowDivideBA1$ NUMBER(10);
  StimateKind1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_BUDGETDATA_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (:new.KFSR IS NULL) THEN  
    :new.KFSR := 0;
  END IF;
  IF (:new.KVSR IS NULL) THEN  
    :new.KVSR := 0;
  END IF;
  IF (:new.KVR IS NULL) THEN  
    :new.KVR := 0;
  END IF;
  IF (:new.KCSR IS NULL) THEN  
    :new.KCSR := 0;
  END IF;
  IF (:new.KESR IS NULL) THEN  
    :new.KESR := 0;
  END IF;
  IF (:new.SubKESR IS NULL) THEN  
    :new.SubKESR := 0;
  END IF;
  IF (:new.RegionCLS IS NULL) THEN  
    :new.RegionCLS := 0;
  END IF;
  IF (:new.DirectionCls IS NULL) THEN 
    :new.DirectionCls := 0;
  END IF;
  IF (:new.FundsSource IS NULL) THEN 
    :new.FundsSource := 0;
  END IF;
  IF (:new.KD IS NULL) THEN 
    :new.KD := 0;
  END IF;
  IF (:new.subkd IS NULL) THEN 
    :new.subkd := 0;
  END IF;
  IF (:new.Fact IS NULL) THEN  
    :new.Fact := 0;
  END IF;
  IF (:new.FacialAcc_Cls IS NULL) THEN 
    :new.FacialAcc_Cls := 0;
  END IF;
  IF (:new.KVRCorr IS NULL) THEN 
    :new.KVRCorr := 0;
  END IF;
  IF (:new.KesrCorr IS NULL) THEN 
    :new.KesrCorr := 0;
  END IF;
  IF (:new.AssignmentKind IS NULL) THEN 
    :new.AssignmentKind := 0;
  END IF;
  IF (:new.Quarter1 IS NULL) THEN  
    :new.Quarter1 := 0;
  END IF;
  IF (:new.Quarter2 IS NULL) THEN  
    :new.Quarter2 := 0;
  END IF;
  IF (:new.Quarter3 IS NULL) THEN  
    :new.Quarter3 := 0;
  END IF;
  IF (:new.Quarter4 IS NULL) THEN  
    :new.Quarter4 := 0;
  END IF;
  IF (:new.FinType IS NULL) THEN  
    :new.FinType := 0;
  END IF;
  IF (:new.MeansType IS NULL) THEN  
    :new.MeansType := 0;
  END IF;
  IF (:new.DepartmentCls IS NULL) THEN 
    :new.DepartmentCls := 0;
  END IF;
  /*   .        */
  IF (:new.IFS IS NULL) THEN 
    :new.IFS := 0;
  END IF;
  IF (:new.BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,:new.BuhOperationCLS);
  END IF;
  IF (:new.Month01 IS NULL) THEN  
    :new.Month01 := 0;
  END IF;
  IF (:new.Month02 IS NULL) THEN  
    :new.Month02 := 0;
  END IF;
  IF (:new.Month03 IS NULL) THEN  
    :new.Month03 := 0;
  END IF;
  IF (:new.Month04 IS NULL) THEN  
    :new.Month04 := 0;
  END IF;
  IF (:new.Month05 IS NULL) THEN  
    :new.Month05 := 0;
  END IF;
  IF (:new.Month06 IS NULL) THEN  
    :new.Month06 := 0;
  END IF;
  IF (:new.Month07 IS NULL) THEN  
    :new.Month07 := 0;
  END IF;
  IF (:new.Month08 IS NULL) THEN  
    :new.Month08 := 0;
  END IF;
  IF (:new.Month09 IS NULL) THEN  
    :new.Month09 := 0;
  END IF;
  IF (:new.Month10 IS NULL) THEN  
    :new.Month10 := 0;
  END IF;
  IF (:new.Month11 IS NULL) THEN  
    :new.Month11 := 0;
  END IF;
  IF (:new.Month12 IS NULL) THEN  
    :new.Month12 := 0;
  END IF;
  IF (:new.SummaYear1 IS NULL) THEN  
    :new.SummaYear1 := 0;
  END IF;
  IF (:new.SummaYear2 IS NULL) THEN  
    :new.SummaYear2 := 0;
  END IF;
  IF (:new.SummaYear3 IS NULL) THEN  
    :new.SummaYear3 := 0;
  END IF;
  IF (:new.SummaYear4 IS NULL) THEN  
    :new.SummaYear4 := 0;
  END IF;
  IF (:new.SummaOtherYears IS NULL) THEN  
    :new.SummaOtherYears := 0; 
  END IF;
  IF (:new.DayPlanSumma IS NULL) THEN 
    :new.DayPlanSumma := 0;
  END IF;
  /*     */
  IF (:new.BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((:new.BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN
      RaiseException('Ex_CantModufyBudget');
    END IF;
  END IF;
  BEGIN

    SELECT
    c.BA_LBO_FLAG
    INTO
    BALBOFlag1$  FROM
    BudNotify c
    WHERE
    c.id = :new.RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*   */
  IF (:new.ProgIndex = 262) THEN
    GetIntConst(32, 43,StimateKind1$);
    IF ((StimateKind1$  = 0) OR (StimateKind1$  IS NULL)) THEN
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
         
    ELSE
      IF (StimateKind1$  = 1) THEN
        :new.Quarter1 := :new.SummaYear1;
             
      ELSE
        :new.Quarter1 := :new.Month01 + :new.Month02 +:new.Month03;
        :new.Quarter2 := :new.Month04 + :new.Month05 +:new.Month06;
        :new.Quarter3 := :new.Month07 + :new.Month08 +:new.Month09;
        :new.Quarter4 := :new.Month10 + :new.Month11 +:new.Month12;
        :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
             
      END IF; 
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 260) THEN
    GetIntConst(32, 30,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 264) THEN
    GetIntConst(32, 34,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 32) THEN
    GetIntConst(32, 31,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*          ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 215) THEN
    GetIntConst(32, 35,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*         ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /* 
   IF ((NEW.TransfertOrg_Ref IS NULL) AND (NEW.REGIONCLS <> 0)) THEN
       SELECT Organizations FROM REGIONCLS
         WHERE NEW.REGIONCLS = ID
       INTO NEW.TransfertOrg_Ref;
  *//*    */
  GETTARGETCLS(:old.transfertcls, :new.transfertcls, :old.meanstype, :new.meanstype,
  :new.targetcls,:new.targetcls);

-- - - - - - - - - - - - -
-- BU_100 (TR_BUDGETDATA_BU_100)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if (:new.ClsType is NULL) then
    BEGIN
      select
      bn.ClsType
      into
      CapClsType1$     from
      BudNotify bn
      where
      bn.id = :new.RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (CapClsType1$  = 3) then
      if (:new.IFS <> 0) then
        :new.ClsType := 1; /*       ClsType */
            
      else
        if (:new.KD <> 0) then
          :new.ClsType := 2; /* */
                
        else
          :new.ClsType := 0; /* */
        END IF;    
      END IF;
    else
      :new.ClsType := CapClsType1$;
      
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND ((:new.IFS <> 0)or(:new.KD <> 0))) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0)
  )) THEN
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  if (((:new.ClsType = 1)and(:new.KD <> 0))or((:new.ClsType = 2)and(:new.IFS <> 0))) then
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 1) AND (:new.ClsType <> 2)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;
  IF (:new.ACC_REF IS NOT NULL) THEN /*    / */
    BEGIN
      SELECT oa.ORG_REF
      INTO OrgRefByAcc1$     FROM ORG_ACCOUNTS oa
      WHERE (oa.ID = :new.ACC_REF)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (:new.FacialAcc_CLS = 0) then 
      :new.Org_Ref := OrgRefByAcc1$;
      
    END IF;
  END IF;
  /*  \ ,       \    \,  \ */
  if (:new.FacialAcc_CLS <> 0) then
    BEGIN
      SELECT
      fac.ORG_REF
      INTO :new.Org_Ref     FROM
      FacialACC_CLS fac
      WHERE
      (fac.ID = :new.FacialAcc_CLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (OrgRefByAcc1$<>:new.Org_Ref) then 
      :new.ACC_REF := null;
      
    END IF;
  END IF;
  if ((:new.ProgIndex in (252, 253))and(:new.FacialAcc_CLS = 0)) then
    BEGIN
      SELECT
      bn.FacialAccCLS
      INTO :new.FacialAcc_CLS     FROM
      BudNotify bn
      WHERE
      (bn.ID = :new.RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_BUDGETDATA_BU_200)
-- Version 10.30.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*       32-, 260-, 261-, 262-  , 263-, 268-  , 252-. */
--   if (:new.ProgIndex in (32, 252, 260, 261, 262, 263, 268)) then
--     /*     (32  ()) 
--              :
--            =0     ,
--            =1  ,
--            =2   0  .*//*     260 ()
--              :
--            =2   0  .*/
--     GetIntConst(32, 25,AutoKvrCorr$);
--     if (:new.ProgIndex = 32) then /*  ()*/
--       if (AutoKvrCorr$  = 0) then
--         :new.KvrCorr := :new.Kvr;
--               
--       else
--         if (AutoKvrCorr$  = 2) then
--           :new.KvrCorr := 0;
--         END IF;
--       END IF;
--       /* KESR   */
--       if (AutoKvrCorr$  = 0) then
--         :new.KesrCorr := :new.Kesr;
--               
--       else
--         if (AutoKvrCorr$  = 2) then
--           :new.KesrCorr := 0;
--         END IF;    
--       END IF;
--     else 
--       if ((:new.ProgIndex = 260)and (AutoKvrCorr$  = 2)) then  /* ()*/
--         :new.KvrCorr := 0;
--         --   ,    new.Kvr = 0;
--         /* KESR   */        
--                 
--         :new.KesrCorr := 0;
--         :new.Kesr := 0;     
--               
--       else
--         :new.KvrCorr := :new.Kvr; /*         */
--         /* KESR   */        
--         :new.KesrCorr := :new.Kesr;
--               
--       END IF;  
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_BUDGETDATA_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

  IF (:NEW.RVersion IS NULL) THEN
     :NEW.RVersion := 1;
  ELSIF ((:NEW.RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
     :NEW.RVersion := :OLD.RVersion;
  ELSE
     :NEW.RVersion := :OLD.RVersion + 1;
  END IF;

END;
/
-- ALTER TRIGGER Tr_BudgetData_AU_500
CREATE OR REPLACE TRIGGER TR_BUDGETDATA_AU
  AFTER UPDATE
  ON BUDGETDATA
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- AU_500 (TR_BUDGETDATA_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (:new.ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (26, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=26) and (RecordId=:new.ID);
  end if;

END;
/
-- ALTER TRIGGER TR_BUDGETDATA_BU_200
CREATE OR REPLACE TRIGGER TR_BUDGETDATA_BU
  BEFORE UPDATE
  ON BUDGETDATA
  FOR EACH ROW
DECLARE
  AutoKvrCorr$ NUMBER(10);
  OrgRefByAcc1$ NUMBER(10);
  CapClsType1$ NUMBER(10);
  doubleUse1$ NUMBER(10);
  BALBOFlag1$ NUMBER(10);
  AllowDivideBA1$ NUMBER(10);
  StimateKind1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_BUDGETDATA_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (:new.KFSR IS NULL) THEN  
    :new.KFSR := 0;
  END IF;
  IF (:new.KVSR IS NULL) THEN  
    :new.KVSR := 0;
  END IF;
  IF (:new.KVR IS NULL) THEN  
    :new.KVR := 0;
  END IF;
  IF (:new.KCSR IS NULL) THEN  
    :new.KCSR := 0;
  END IF;
  IF (:new.KESR IS NULL) THEN  
    :new.KESR := 0;
  END IF;
  IF (:new.SubKESR IS NULL) THEN  
    :new.SubKESR := 0;
  END IF;
  IF (:new.RegionCLS IS NULL) THEN  
    :new.RegionCLS := 0;
  END IF;
  IF (:new.DirectionCls IS NULL) THEN 
    :new.DirectionCls := 0;
  END IF;
  IF (:new.FundsSource IS NULL) THEN 
    :new.FundsSource := 0;
  END IF;
  IF (:new.KD IS NULL) THEN 
    :new.KD := 0;
  END IF;
  IF (:new.subkd IS NULL) THEN 
    :new.subkd := 0;
  END IF;
  IF (:new.Fact IS NULL) THEN  
    :new.Fact := 0;
  END IF;
  IF (:new.FacialAcc_Cls IS NULL) THEN 
    :new.FacialAcc_Cls := 0;
  END IF;
  IF (:new.KVRCorr IS NULL) THEN 
    :new.KVRCorr := 0;
  END IF;
  IF (:new.KesrCorr IS NULL) THEN 
    :new.KesrCorr := 0;
  END IF;
  IF (:new.AssignmentKind IS NULL) THEN 
    :new.AssignmentKind := 0;
  END IF;
  IF (:new.Quarter1 IS NULL) THEN  
    :new.Quarter1 := 0;
  END IF;
  IF (:new.Quarter2 IS NULL) THEN  
    :new.Quarter2 := 0;
  END IF;
  IF (:new.Quarter3 IS NULL) THEN  
    :new.Quarter3 := 0;
  END IF;
  IF (:new.Quarter4 IS NULL) THEN  
    :new.Quarter4 := 0;
  END IF;
  IF (:new.FinType IS NULL) THEN  
    :new.FinType := 0;
  END IF;
  IF (:new.MeansType IS NULL) THEN  
    :new.MeansType := 0;
  END IF;
  IF (:new.DepartmentCls IS NULL) THEN 
    :new.DepartmentCls := 0;
  END IF;
  /*   .        */
  IF (:new.IFS IS NULL) THEN 
    :new.IFS := 0;
  END IF;
  IF (:new.BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,:new.BuhOperationCLS);
  END IF;
  IF (:new.Month01 IS NULL) THEN  
    :new.Month01 := 0;
  END IF;
  IF (:new.Month02 IS NULL) THEN  
    :new.Month02 := 0;
  END IF;
  IF (:new.Month03 IS NULL) THEN  
    :new.Month03 := 0;
  END IF;
  IF (:new.Month04 IS NULL) THEN  
    :new.Month04 := 0;
  END IF;
  IF (:new.Month05 IS NULL) THEN  
    :new.Month05 := 0;
  END IF;
  IF (:new.Month06 IS NULL) THEN  
    :new.Month06 := 0;
  END IF;
  IF (:new.Month07 IS NULL) THEN  
    :new.Month07 := 0;
  END IF;
  IF (:new.Month08 IS NULL) THEN  
    :new.Month08 := 0;
  END IF;
  IF (:new.Month09 IS NULL) THEN  
    :new.Month09 := 0;
  END IF;
  IF (:new.Month10 IS NULL) THEN  
    :new.Month10 := 0;
  END IF;
  IF (:new.Month11 IS NULL) THEN  
    :new.Month11 := 0;
  END IF;
  IF (:new.Month12 IS NULL) THEN  
    :new.Month12 := 0;
  END IF;
  IF (:new.SummaYear1 IS NULL) THEN  
    :new.SummaYear1 := 0;
  END IF;
  IF (:new.SummaYear2 IS NULL) THEN  
    :new.SummaYear2 := 0;
  END IF;
  IF (:new.SummaYear3 IS NULL) THEN  
    :new.SummaYear3 := 0;
  END IF;
  IF (:new.SummaYear4 IS NULL) THEN  
    :new.SummaYear4 := 0;
  END IF;
  IF (:new.SummaOtherYears IS NULL) THEN  
    :new.SummaOtherYears := 0; 
  END IF;
  IF (:new.DayPlanSumma IS NULL) THEN 
    :new.DayPlanSumma := 0;
  END IF;
  /*     */
  IF (:new.BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((:new.BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN
      RaiseException('Ex_CantModufyBudget');
    END IF;
  END IF;
  BEGIN

    SELECT
    c.BA_LBO_FLAG
    INTO
    BALBOFlag1$  FROM
    BudNotify c
    WHERE
    c.id = :new.RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*   */
  IF (:new.ProgIndex = 262) THEN
    GetIntConst(32, 43,StimateKind1$);
    IF ((StimateKind1$  = 0) OR (StimateKind1$  IS NULL)) THEN
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
         
    ELSE
      IF (StimateKind1$  = 1) THEN
        :new.Quarter1 := :new.SummaYear1;
             
      ELSE
        :new.Quarter1 := :new.Month01 + :new.Month02 +:new.Month03;
        :new.Quarter2 := :new.Month04 + :new.Month05 +:new.Month06;
        :new.Quarter3 := :new.Month07 + :new.Month08 +:new.Month09;
        :new.Quarter4 := :new.Month10 + :new.Month11 +:new.Month12;
        :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
             
      END IF; 
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 260) THEN
    GetIntConst(32, 30,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /* ()*/
  IF (:new.ProgIndex = 264) THEN
    GetIntConst(32, 34,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*       ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 32) THEN
    GetIntConst(32, 31,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*          ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /*  ()*/
  IF (:new.ProgIndex = 215) THEN
    GetIntConst(32, 35,doubleUse1$);
    GetIntConst(32, 40,AllowDivideBA1$);
    IF ((doubleUse1$=1) AND ((BALBOFlag1$  <> 1) OR (AllowDivideBA1$ = 1))) THEN  /*         ,     */
      :new.SummaYear1 := :new.Quarter1 + :new.Quarter2 + :new.Quarter3 + :new.Quarter4;
     
    END IF;
  END IF;
  /* 
   IF ((NEW.TransfertOrg_Ref IS NULL) AND (NEW.REGIONCLS <> 0)) THEN
       SELECT Organizations FROM REGIONCLS
         WHERE NEW.REGIONCLS = ID
       INTO NEW.TransfertOrg_Ref;
  *//*    */
  GETTARGETCLS(:old.transfertcls, :new.transfertcls, :old.meanstype, :new.meanstype,
  :new.targetcls,:new.targetcls);

-- - - - - - - - - - - - -
-- BU_100 (TR_BUDGETDATA_BU_100)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if (:new.ClsType is NULL) then
    BEGIN
      select
      bn.ClsType
      into
      CapClsType1$     from
      BudNotify bn
      where
      bn.id = :new.RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (CapClsType1$  = 3) then
      if (:new.IFS <> 0) then
        :new.ClsType := 1; /*       ClsType */
            
      else
        if (:new.KD <> 0) then
          :new.ClsType := 2; /* */
                
        else
          :new.ClsType := 0; /* */
        END IF;    
      END IF;
    else
      :new.ClsType := CapClsType1$;
      
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND ((:new.IFS <> 0)or(:new.KD <> 0))) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0)
  )) THEN
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  if (((:new.ClsType = 1)and(:new.KD <> 0))or((:new.ClsType = 2)and(:new.IFS <> 0))) then
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 1) AND (:new.ClsType <> 2)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;
  IF (:new.ACC_REF IS NOT NULL) THEN /*    / */
    BEGIN
      SELECT oa.ORG_REF
      INTO OrgRefByAcc1$     FROM ORG_ACCOUNTS oa
      WHERE (oa.ID = :new.ACC_REF)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (:new.FacialAcc_CLS = 0) then 
      :new.Org_Ref := OrgRefByAcc1$;
      
    END IF;
  END IF;
  /*  \ ,       \    \,  \ */
  if (:new.FacialAcc_CLS <> 0) then
    BEGIN
      SELECT
      fac.ORG_REF
      INTO :new.Org_Ref     FROM
      FacialACC_CLS fac
      WHERE
      (fac.ID = :new.FacialAcc_CLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (OrgRefByAcc1$<>:new.Org_Ref) then 
      :new.ACC_REF := null;
      
    END IF;
  END IF;
  if ((:new.ProgIndex in (252, 253))and(:new.FacialAcc_CLS = 0)) then
    BEGIN
      SELECT
      bn.FacialAccCLS
      INTO :new.FacialAcc_CLS     FROM
      BudNotify bn
      WHERE
      (bn.ID = :new.RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_BUDGETDATA_BU_200)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*       32-, 260-, 261-, 262-  , 263-, 268-  , 252-. */
  if (:new.ProgIndex in (32, 252, 260, 261, 262, 263, 268)) then
    /*     (32  ()) 
             :
           =0     ,
           =1  ,
           =2   0  .*//*     260 ()
             :
           =2   0  .*/
    GetIntConst(32, 25,AutoKvrCorr$);
    if (:new.ProgIndex = 32) then /*  ()*/
      if (AutoKvrCorr$  = 0) then
        :new.KvrCorr := :new.Kvr;
              
      else
        if (AutoKvrCorr$  = 2) then
          :new.KvrCorr := 0;
        END IF;
      END IF;
      /* KESR   */
      if (AutoKvrCorr$  = 0) then
        :new.KesrCorr := :new.Kesr;
              
      else
        if (AutoKvrCorr$  = 2) then
          :new.KesrCorr := 0;
        END IF;    
      END IF;
    else 
      if ((:new.ProgIndex = 260)and (AutoKvrCorr$  = 2)) then  /* ()*/
        :new.KvrCorr := 0;
        --   ,    new.Kvr = 0;
        /* KESR   */        
                
        :new.KesrCorr := 0;
        :new.Kesr := 0;     
              
      else
        :new.KvrCorr := :new.Kvr; /*         */
        /* KESR   */        
        :new.KesrCorr := :new.Kesr;
              
      END IF;  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_BUDGETDATA_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

  IF (:NEW.RVersion IS NULL) THEN
     :NEW.RVersion := 1;
  ELSIF ((:NEW.RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
     :NEW.RVersion := :OLD.RVersion;
  ELSE
     :NEW.RVersion := :OLD.RVersion + 1;
  END IF;

END;
/
ALTER TRIGGER TR_CORRECTIONDETAIL_BU_500 ENABLE
/
ALTER TRIGGER TR_FACIALFINDETAIL_BU_500 ENABLE
/
-- ALTER TRIGGER tr_FacialFinDetail_bu_0
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 12.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*     ,      */ 
--   i_fintype$ := -1 ;
--   IF (new$SourceFintype IS NULL) THEN 
--     BEGIN
--       SELECT constvalue INTO i_fintype$   FROM intconst
--       WHERE (progindex=30) AND (constindex=10) ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     new$SourceFintype := i_fintype$  ;
--      
--   END IF;
--   IF (new$DestFintype IS NULL) THEN 
--     IF (i_fintype$ = -1) THEN
--       BEGIN
--         SELECT constvalue INTO i_fintype$   FROM intconst
--         WHERE (progindex=30) AND (constindex=10) ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--     END IF;
--     new$DestFintype := i_fintype$  ;
--      
--   END IF;
--   IF (new$SourceFacialAcc_CLS IS NULL) THEN 
--     new$SourceFacialAcc_CLS := 0;
--   END IF;
--   /*   */
--   IF (new$SourceKVR IS NULL) THEN 
--     new$SourceKVR := 0;
--   END IF;
--   IF (new$SourceKESR IS NULL) THEN 
--     new$SourceKESR := 0;
--   END IF;
--   IF (new$SourceKVSR IS NULL) THEN 
--     new$SourceKVSR := 0;
--   END IF;
--   IF (new$SourceKFSR IS NULL) THEN 
--     new$SourceKFSR := 0;
--   END IF;
--   IF (new$SourceKCSR IS NULL) THEN 
--     new$SourceKCSR := 0;
--   END IF;
--   IF (new$SourceSubKESR IS NULL) THEN 
--     new$SourceSubKESR := 0;
--   END IF;
--   IF (new$SourceDirectionCls IS NULL) THEN 
--     new$SourceDirectionCls := 0;
--   END IF;
--   IF (new$SourceFact IS NULL) THEN 
--     new$SourceFact := 0;
--   END IF;
--   IF (new$SourceMeansType IS NULL) THEN 
--     new$SourceMeansType := 0;
--   END IF;
--   IF (new$SourceFinSource IS NULL) THEN 
--     new$SourceFinSource := 0;
--   END IF;
--   IF (new$SourceFinType IS NULL) THEN 
--     new$SourceFinType := 0;
--   END IF;
--   IF (new$SourceDocType IS NULL) THEN 
--     new$SourceDocType := 0;
--   END IF;
--   IF (new$Sourceifs IS NULL) THEN 
--     new$Sourceifs := 0;
--   END IF;
--   IF (new$SourceKD IS NULL) THEN 
--     new$SourceKD := 0;
--   END IF;
--   IF (new$SourceFundsSource IS NULL) THEN 
--     new$SourceFundsSource := 0;
--   END IF;
--   IF (new$SourceAssignmentKind IS NULL) THEN 
--     new$SourceAssignmentKind := 0;
--   END IF;
--   IF (new$SourceRegionCLS IS NULL) THEN 
--     new$SourceRegionCLS := 0;
--   END IF;
--   IF (new$DestFacialAcc_CLS IS NULL) THEN 
--     new$DestFacialAcc_CLS := 0;
--   END IF;
--   /*   */
--   IF (new$DestKVR IS NULL) THEN 
--     new$DestKVR := 0;
--   END IF;
--   IF (new$DestKESR IS NULL) THEN 
--     new$DestKESR := 0;
--   END IF;
--   IF (new$DestKVSR IS NULL) THEN 
--     new$DestKVSR := 0;
--   END IF;
--   IF (new$DestKFSR IS NULL) THEN 
--     new$DestKFSR := 0;
--   END IF;
--   IF (new$DestKCSR IS NULL) THEN 
--     new$DestKCSR := 0;
--   END IF;
--   IF (new$DestSubKESR IS NULL) THEN 
--     new$DestSubKESR := 0;
--   END IF;
--   IF (new$DestDirectionCls IS NULL) THEN 
--     new$DestDirectionCls := 0;
--   END IF;
--   IF (new$DestFact IS NULL) THEN 
--     new$DestFact := 0;
--   END IF;
--   IF (new$DestMeansType IS NULL) THEN 
--     new$DestMeansType := 0;
--   END IF;
--   IF (new$DestFinSource IS NULL) THEN 
--     new$DestFinSource := 0;
--   END IF;
--   IF (new$DestFinType IS NULL) THEN 
--     new$DestFinType := 0;
--   END IF;
--   IF (new$DestDocType IS NULL) THEN 
--     new$DestDocType := 0;
--   END IF;
--   IF (new$Destifs IS NULL) THEN 
--     new$Destifs := 0;
--   END IF;
--   IF (new$DestKD IS NULL) THEN 
--     new$DestKD := 0;
--   END IF;
--   IF (new$DestFundsSource IS NULL) THEN 
--     new$DestFundsSource := 0;
--   END IF;
--   IF (new$DestAssignmentKind IS NULL) THEN 
--     new$DestAssignmentKind := 0;
--   END IF;
--   IF (new$DestRegionCLS IS NULL) THEN 
--     new$DestRegionCLS := 0;
--   END IF;
--   /*   :       */
--   if (new$progindex=76) then
--     new$SourceKVR := new$DestKVR;
--     new$SourceKESR := new$DestKESR;
--     new$SourceKVSR := new$DestKVSR;
--     new$SourceKFSR := new$DestKFSR;
--     new$SourceKCSR := new$DestKCSR;
--     new$SourceSubKESR := new$DestSubKESR;
--     new$SourceDirectionCls := new$DestDirectionCls;
--     new$SourceFact := new$DestFact;
--     new$SourceMeansType := new$DestMeansType;
--     new$SourceFinSource := new$DestFinSource;
--     new$SourceFinType := new$DestFinType;
--     new$SourceDocType := new$DestDocType;
--     new$SourceIFS := new$DestIFS;
--     new$SourceKD := new$DestKD;
--     new$SourceRegionCls := new$DestRegionCls;
--     new$SourceDocBase := new$DestDocBase;
--     new$SourceAssignmentKind := new$DestAssignmentKind;
--     new$SourceSubsidyCls := new$DestSubsidyCls;
--     new$SourceTransfertCLS := new$DestTransfertCLS;
--     new$SourceBudAllocationCls := new$DestBudAllocationCls;
--     new$SourcePayPromiseCls := new$DestPayPromiseCls;
--      
--   END IF;
--   IF (new$BuhOperationCLS IS NULL)
--   THEN 
--     GetIntConst(60, 15,new$BuhOperationCLS);
--   END IF;
--   /*    */
--   IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
--   AND (new$SourcePromise <> :old.SourcePromise)
--   OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
--   OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
--   OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
--   AND (new$DestPromise <> :old.DestPromise)
--   OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
--   OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
--     IF (new$progindex IN (63, 64, 73)) THEN
--       new$Promise := new$SourcePromise;
--          
--     ELSE 
--       IF (new$progindex IN (61, 62, 65, 75)) THEN
--         new$Promise := new$DestPromise;
--            
--       ELSE 
--         IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
--         ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
--           new$Promise := new$DestPromise;
--         END IF;
--       END IF; 
--     END IF;/*     */
--   ELSE
--     IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
--     AND (new$Promise <> :old.Promise)
--     OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
--     OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
--       IF (new$progindex IN (63, 64, 73)) THEN
--         new$SourcePromise := new$Promise;
--            
--       ELSE 
--         IF (new$progindex IN (61, 62, 65, 75)) THEN
--           new$DestPromise := new$Promise;
--              
--         ELSE 
--           IF (new$progindex in (66, 67, 76)) THEN
--             new$SourcePromise := new$Promise;
--             new$DestPromise := new$Promise;
--                
--           END IF;
--         END IF; 
--       END IF;
--     END IF;
--   END IF;
--   /*     \   */
--   IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
--   ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
--       INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
--       WHERE (fac.ID = new$SourceFacialAcc_Cls)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
--   ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
--       INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
--       WHERE (fac.ID = new$DestFacialAcc_Cls)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*       */
--   GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
--   new$Sourcetargetcls,new$Sourcetargetcls);
--   GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
--   new$Desttargetcls,new$Desttargetcls);     

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*  60 :  '   .'; source
--           61 :  '      '; dest
--           62 :  '   ';dest
--           63 :  '    '; source
--           64 :  '   '; source
--           65 :  ' , ';dest
--           66 :  '  ,  - '; source dest
--           67 :  '   ';source
--           68 :  '  \ ';dest
--           69 :  '   \ '; dest
--           70 :  '  \ ';source
--           71 :  '   \ '; dest */
-- 
--   /* ClsType*/
--   if ((new$ClsType is NULL) and
--   (
--   ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
--   (new$ProgIndex = 60)
--   )) then
--     new$ClsType := 1; /*       ClsType */
--       
--   else
--     if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
--     (new$ProgIndex in (63,64,66,67,68,70))) then
--       new$ClsType := 2; /*        ClsType */
--           
--     else
--       if (new$ClsType is null) then
--         new$ClsType := 0; /*  -  */
--       END IF;
--     END IF;
--   END IF;
--   IF ((new$ClsType = 0) AND
--   (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
--   (new$ProgIndex in (63,64,66,67,68,70)))
--   ) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$ClsType = 1) AND (
--   (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
--   (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
--   ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$ClsType = 2) AND (
--   (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
--   (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
--   ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   /* DestClsType*/
--   if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
--     new$DestClsType := new$ClsType;
--   END IF;
--   IF ((new$DestClsType = 0) AND
--   (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
--   (new$ProgIndex in (61,62,65,69,71)))
--   ) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$DestClsType = 1) AND (
--   (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
--   (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
--   ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$DestClsType = 2) AND (
--   (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
--   (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
--   ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -
  NULL;
--   /*       */
--   GetIntConst(30, 15,PromiseMode$);
--   /*     */
--   if (PromiseMode$ <> 1) then
--     /*          */
--     if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$SOURCEPROMISE)
--       ;
--       /*    ,  */
--       if (Promise_Count$ = 0) then
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--     /*          */
--     if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$DestPromise)
--       ;
--       /*    ,  */
--       if (Promise_Count$ = 0) then
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--         
--     END IF;/* end  PromiseMode <> 1*/
--   END IF;
--   /*     */
--   if (PromiseMode$ = 1) then
--     /* source  .    */
--     if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
--     (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
--       select max(InnerPromiseNum) 
--       into BPInnerNum$           from PaymentSchedule 
--       where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum$ <> 0) then
--         new$SourceBudgetPromise := BPInnerNum$;
--                 
--       else
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--     /* dest  .     */
--     if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
--     (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
--       select max(InnerPromiseNum) 
--       into BPInnerNum$           from PaymentSchedule
--       where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum$ <> 0) then
--         new$DestBudgetPromise := BPInnerNum$;
--                 
--       else
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--           
--     /*         NULL,    */
--     /* source */
--     if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
--     (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
--       BEGIN
--         select ANumber 
--         into BPInnerNum$           from PaymentSchedule
--         where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       new$SourcePromise := BPInnerNum$;
--       new$Promise := BPInnerNum$;
--             
--     END IF;
--     /* dest */
--     if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
--     (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
--       BEGIN
--         select ANumber 
--         into BPInnerNum$           from PaymentSchedule
--         where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       new$DestPromise := BPInnerNum$;
--       new$Promise := BPInnerNum$;
--             
--     END IF;
--     /*    ,     */
--     if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
--       new$SourcePromise := null;
--       new$Promise := null;
--             
--     END IF;
--     if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
--       new$DestPromise := null;
--       new$Promise := null;
--             
--     END IF;
--     if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$1
--       from PaymentSchedule
--       where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$1<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Source */
--         select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
--         where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');      
--       END IF;
--     END IF;
--     if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$2
--       from PaymentSchedule
--       where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$2<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Dest */
--         select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
--         where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');      
--       END IF;    
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*    ?*/
--   GetIntConst(30, 15,PromiseMode1$);
--   if (PromiseMode1$ = 1) then
--     /*        */
--     if (new$SourcePromise is not null and (
--     (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
--     (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex$ = 308) then
--         new$SourceExecDoc := ExecID$;
--         new$SourceExecInnerNumber := ExecInnerNumber$;
--               
--       else 
--         if (new$SourceExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
--             where
--             Id = new$SourceExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */        
--           new$SourceExecInnerNumber := ExecInnerNumber$;
--                 
--         END IF;    
--       END IF;/*       ,   ,  */
--     else 
--       if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber$       from ExecutionDocumentsCaption
--           where
--           Id = new$SourceExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$SourceExecInnerNumber := ExecInnerNumber$;
--             
--       END IF;
--     END IF;
--     /*     Dest */
-- 
--     /*        */
--     if (new$DestPromise is not null and (
--     (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
--     (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex$ = 308) then
--         new$DestExecDoc := ExecID$;
--         new$DestExecInnerNumber := ExecInnerNumber$;
--               
--       else 
--         if (new$DestExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
--             where
--             Id = new$DestExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */        
--           new$DestExecInnerNumber := ExecInnerNumber$;
--                 
--         END IF;    
--       END IF;/*       ,   ,  */
--     else 
--       if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber$       from ExecutionDocumentsCaption
--           where
--           Id = new$DestExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$DestExecInnerNumber := ExecInnerNumber$;
--             
--       END IF;
--     END IF;
--     if (new$SourceExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls1$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Source */
--         select Accepted
--         into EDAccepted$       from ExecutionDocumentsCaption
--         where id = new$SourceExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');    
--       END IF;
--     END IF;
--     if (new$DestExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls1$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Dest */
--         select Accepted
--         into EDAccepted$       from ExecutionDocumentsCaption
--         where ID = new$DestExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');    
--       END IF;  
--     END IF;/*   " "*/
--   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -
  NULL;
--   /*          (  ) */
--   if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
--     BEGIN
--       select c.AcceptDate into CapAcceptDate$
--       from facialfincaption c
--       where c.id = new$RecordIndex;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN
--         CapAcceptDate$ := NULL;
--     END;
-- 
--     if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
--       new$AcceptDate := new$AcceptDate;
--     else
--       RaiseException('ex_wrongacceptdate');
--     end if;
--   end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -
  NULL;
--    IF (new$RVersion IS NULL) THEN
--       new$RVersion := 1;
--    ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
--       new$RVersion := :OLD.RVersion;
--    ELSE
--       new$RVersion := :OLD.RVersion + 1;
--    END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -
  NULL;
--   if (new$ClsType <> :old.ClsType) then
--     update FacialFinCaption set
--       ClsType = new$ClsType,
--       RVersion = -1
--     where
--       (id = new$RecordIndex)and(ClsType <> new$ClsType);
--   end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -
  NULL;
--   if (new$ID<>:old.ID) then
--     insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
--     delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
--   end if;

END;
/
-- ALTER TRIGGER tr_FacialFinDetail_bu_110
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;
     
  END IF;
  IF (new$DestFintype IS NULL) THEN 
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*       */
  GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
  new$Sourcetargetcls,new$Sourcetargetcls);
  GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
  new$Desttargetcls,new$Desttargetcls);     

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*  60 :  '   .'; source
--           61 :  '      '; dest
--           62 :  '   ';dest
--           63 :  '    '; source
--           64 :  '   '; source
--           65 :  ' , ';dest
--           66 :  '  ,  - '; source dest
--           67 :  '   ';source
--           68 :  '  \ ';dest
--           69 :  '   \ '; dest
--           70 :  '  \ ';source
--           71 :  '   \ '; dest */
-- 
--   /* ClsType*/
--   if ((new$ClsType is NULL) and
--   (
--   ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
--   (new$ProgIndex = 60)
--   )) then
--     new$ClsType := 1; /*       ClsType */
--       
--   else
--     if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
--     (new$ProgIndex in (63,64,66,67,68,70))) then
--       new$ClsType := 2; /*        ClsType */
--           
--     else
--       if (new$ClsType is null) then
--         new$ClsType := 0; /*  -  */
--       END IF;
--     END IF;
--   END IF;
--   IF ((new$ClsType = 0) AND
--   (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
--   (new$ProgIndex in (63,64,66,67,68,70)))
--   ) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$ClsType = 1) AND (
--   (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
--   (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
--   ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$ClsType = 2) AND (
--   (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
--   (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
--   ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   /* DestClsType*/
--   if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
--     new$DestClsType := new$ClsType;
--   END IF;
--   IF ((new$DestClsType = 0) AND
--   (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
--   (new$ProgIndex in (61,62,65,69,71)))
--   ) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$DestClsType = 1) AND (
--   (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
--   (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
--   ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;
--   IF ((new$DestClsType = 2) AND (
--   (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
--   (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
--   ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
--   )) THEN /*   */
--     RaiseException('EX_WRONGBUDCLS');
--   END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -
  NULL;
--   /*       */
--   GetIntConst(30, 15,PromiseMode$);
--   /*     */
--   if (PromiseMode$ <> 1) then
--     /*          */
--     if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$SOURCEPROMISE)
--       ;
--       /*    ,  */
--       if (Promise_Count$ = 0) then
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--     /*          */
--     if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$DestPromise)
--       ;
--       /*    ,  */
--       if (Promise_Count$ = 0) then
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--         
--     END IF;/* end  PromiseMode <> 1*/
--   END IF;
--   /*     */
--   if (PromiseMode$ = 1) then
--     /* source  .    */
--     if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
--     (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
--       select max(InnerPromiseNum) 
--       into BPInnerNum$           from PaymentSchedule 
--       where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum$ <> 0) then
--         new$SourceBudgetPromise := BPInnerNum$;
--                 
--       else
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--     /* dest  .     */
--     if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
--     (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
--       select max(InnerPromiseNum) 
--       into BPInnerNum$           from PaymentSchedule
--       where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum$ <> 0) then
--         new$DestBudgetPromise := BPInnerNum$;
--                 
--       else
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--           
--     /*         NULL,    */
--     /* source */
--     if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
--     (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
--       BEGIN
--         select ANumber 
--         into BPInnerNum$           from PaymentSchedule
--         where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       new$SourcePromise := BPInnerNum$;
--       new$Promise := BPInnerNum$;
--             
--     END IF;
--     /* dest */
--     if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
--     (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
--       BEGIN
--         select ANumber 
--         into BPInnerNum$           from PaymentSchedule
--         where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       new$DestPromise := BPInnerNum$;
--       new$Promise := BPInnerNum$;
--             
--     END IF;
--     /*    ,     */
--     if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
--       new$SourcePromise := null;
--       new$Promise := null;
--             
--     END IF;
--     if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
--       new$DestPromise := null;
--       new$Promise := null;
--             
--     END IF;
--     if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$1
--       from PaymentSchedule
--       where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$1<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Source */
--         select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
--         where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');      
--       END IF;
--     END IF;
--     if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$2
--       from PaymentSchedule
--       where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$2<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Dest */
--         select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
--         where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');      
--       END IF;    
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*    ?*/
--   GetIntConst(30, 15,PromiseMode1$);
--   if (PromiseMode1$ = 1) then
--     /*        */
--     if (new$SourcePromise is not null and (
--     (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
--     (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex$ = 308) then
--         new$SourceExecDoc := ExecID$;
--         new$SourceExecInnerNumber := ExecInnerNumber$;
--               
--       else 
--         if (new$SourceExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
--             where
--             Id = new$SourceExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */        
--           new$SourceExecInnerNumber := ExecInnerNumber$;
--                 
--         END IF;    
--       END IF;/*       ,   ,  */
--     else 
--       if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber$       from ExecutionDocumentsCaption
--           where
--           Id = new$SourceExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$SourceExecInnerNumber := ExecInnerNumber$;
--             
--       END IF;
--     END IF;
--     /*     Dest */
-- 
--     /*        */
--     if (new$DestPromise is not null and (
--     (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
--     (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex$ = 308) then
--         new$DestExecDoc := ExecID$;
--         new$DestExecInnerNumber := ExecInnerNumber$;
--               
--       else 
--         if (new$DestExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
--             where
--             Id = new$DestExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */        
--           new$DestExecInnerNumber := ExecInnerNumber$;
--                 
--         END IF;    
--       END IF;/*       ,   ,  */
--     else 
--       if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber$       from ExecutionDocumentsCaption
--           where
--           Id = new$DestExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$DestExecInnerNumber := ExecInnerNumber$;
--             
--       END IF;
--     END IF;
--     if (new$SourceExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls1$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Source */
--         select Accepted
--         into EDAccepted$       from ExecutionDocumentsCaption
--         where id = new$SourceExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');    
--       END IF;
--     END IF;
--     if (new$DestExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls1$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Dest */
--         select Accepted
--         into EDAccepted$       from ExecutionDocumentsCaption
--         where ID = new$DestExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');    
--       END IF;  
--     END IF;/*   " "*/
--   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -
  NULL;
--   /*          (  ) */
--   if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
--     BEGIN
--       select c.AcceptDate into CapAcceptDate$
--       from facialfincaption c
--       where c.id = new$RecordIndex;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN
--         CapAcceptDate$ := NULL;
--     END;
-- 
--     if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
--       new$AcceptDate := new$AcceptDate;
--     else
--       RaiseException('ex_wrongacceptdate');
--     end if;
--   end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -
  NULL;
--    IF (new$RVersion IS NULL) THEN
--       new$RVersion := 1;
--    ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
--       new$RVersion := :OLD.RVersion;
--    ELSE
--       new$RVersion := :OLD.RVersion + 1;
--    END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -
  NULL;
--   if (new$ClsType <> :old.ClsType) then
--     update FacialFinCaption set
--       ClsType = new$ClsType,
--       RVersion = -1
--     where
--       (id = new$RecordIndex)and(ClsType <> new$ClsType);
--   end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -
  NULL;
--   if (new$ID<>:old.ID) then
--     insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
--     delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
--   end if;

END;
/
-- ALTER TRIGGER TR_FACIALFINDETAIL_BU_120
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;
     
  END IF;
  IF (new$DestFintype IS NULL) THEN 
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*       */
  GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
  new$Sourcetargetcls,new$Sourcetargetcls);
  GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
  new$Desttargetcls,new$Desttargetcls);     

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*  60 :  '   .'; source
          61 :  '      '; dest
          62 :  '   ';dest
          63 :  '    '; source
          64 :  '   '; source
          65 :  ' , ';dest
          66 :  '  ,  - '; source dest
          67 :  '   ';source
          68 :  '  \ ';dest
          69 :  '   \ '; dest
          70 :  '  \ ';source
          71 :  '   \ '; dest */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -
  NULL;
--   /*       */
--   GetIntConst(30, 15,PromiseMode$);
--   /*     */
--   if (PromiseMode$ <> 1) then
--     /*          */
--     if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$SOURCEPROMISE)
--       ;
--       /*    ,  */
--       if (Promise_Count$ = 0) then
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--     /*          */
--     if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$DestPromise)
--       ;
--       /*    ,  */
--       if (Promise_Count$ = 0) then
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--         
--     END IF;/* end  PromiseMode <> 1*/
--   END IF;
--   /*     */
--   if (PromiseMode$ = 1) then
--     /* source  .    */
--     if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
--     (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
--       select max(InnerPromiseNum) 
--       into BPInnerNum$           from PaymentSchedule 
--       where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum$ <> 0) then
--         new$SourceBudgetPromise := BPInnerNum$;
--                 
--       else
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--     /* dest  .     */
--     if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
--     (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
--       select max(InnerPromiseNum) 
--       into BPInnerNum$           from PaymentSchedule
--       where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum$ <> 0) then
--         new$DestBudgetPromise := BPInnerNum$;
--                 
--       else
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--           
--     /*         NULL,    */
--     /* source */
--     if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
--     (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
--       BEGIN
--         select ANumber 
--         into BPInnerNum$           from PaymentSchedule
--         where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       new$SourcePromise := BPInnerNum$;
--       new$Promise := BPInnerNum$;
--             
--     END IF;
--     /* dest */
--     if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
--     (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
--       BEGIN
--         select ANumber 
--         into BPInnerNum$           from PaymentSchedule
--         where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       new$DestPromise := BPInnerNum$;
--       new$Promise := BPInnerNum$;
--             
--     END IF;
--     /*    ,     */
--     if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
--       new$SourcePromise := null;
--       new$Promise := null;
--             
--     END IF;
--     if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
--       new$DestPromise := null;
--       new$Promise := null;
--             
--     END IF;
--     if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$1
--       from PaymentSchedule
--       where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$1<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Source */
--         select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
--         where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');      
--       END IF;
--     END IF;
--     if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$2
--       from PaymentSchedule
--       where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$2<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Dest */
--         select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
--         where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');      
--       END IF;    
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*    ?*/
--   GetIntConst(30, 15,PromiseMode1$);
--   if (PromiseMode1$ = 1) then
--     /*        */
--     if (new$SourcePromise is not null and (
--     (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
--     (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex$ = 308) then
--         new$SourceExecDoc := ExecID$;
--         new$SourceExecInnerNumber := ExecInnerNumber$;
--               
--       else 
--         if (new$SourceExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
--             where
--             Id = new$SourceExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */        
--           new$SourceExecInnerNumber := ExecInnerNumber$;
--                 
--         END IF;    
--       END IF;/*       ,   ,  */
--     else 
--       if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber$       from ExecutionDocumentsCaption
--           where
--           Id = new$SourceExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$SourceExecInnerNumber := ExecInnerNumber$;
--             
--       END IF;
--     END IF;
--     /*     Dest */
-- 
--     /*        */
--     if (new$DestPromise is not null and (
--     (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
--     (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex$ = 308) then
--         new$DestExecDoc := ExecID$;
--         new$DestExecInnerNumber := ExecInnerNumber$;
--               
--       else 
--         if (new$DestExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
--             where
--             Id = new$DestExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */        
--           new$DestExecInnerNumber := ExecInnerNumber$;
--                 
--         END IF;    
--       END IF;/*       ,   ,  */
--     else 
--       if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber$       from ExecutionDocumentsCaption
--           where
--           Id = new$DestExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$DestExecInnerNumber := ExecInnerNumber$;
--             
--       END IF;
--     END IF;
--     if (new$SourceExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls1$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Source */
--         select Accepted
--         into EDAccepted$       from ExecutionDocumentsCaption
--         where id = new$SourceExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');    
--       END IF;
--     END IF;
--     if (new$DestExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls1$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Dest */
--         select Accepted
--         into EDAccepted$       from ExecutionDocumentsCaption
--         where ID = new$DestExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');    
--       END IF;  
--     END IF;/*   " "*/
--   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -
  NULL;
--   /*          (  ) */
--   if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
--     BEGIN
--       select c.AcceptDate into CapAcceptDate$
--       from facialfincaption c
--       where c.id = new$RecordIndex;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN
--         CapAcceptDate$ := NULL;
--     END;
-- 
--     if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
--       new$AcceptDate := new$AcceptDate;
--     else
--       RaiseException('ex_wrongacceptdate');
--     end if;
--   end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -
  NULL;
--    IF (new$RVersion IS NULL) THEN
--       new$RVersion := 1;
--    ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
--       new$RVersion := :OLD.RVersion;
--    ELSE
--       new$RVersion := :OLD.RVersion + 1;
--    END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -
  NULL;
--   if (new$ClsType <> :old.ClsType) then
--     update FacialFinCaption set
--       ClsType = new$ClsType,
--       RVersion = -1
--     where
--       (id = new$RecordIndex)and(ClsType <> new$ClsType);
--   end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -
  NULL;
--   if (new$ID<>:old.ID) then
--     insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
--     delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
--   end if;

END;
/
-- ALTER TRIGGER TR_FACIALFINDETAIL_AU_100
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;
     
  END IF;
  IF (new$DestFintype IS NULL) THEN 
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*       */
  GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
  new$Sourcetargetcls,new$Sourcetargetcls);
  GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
  new$Desttargetcls,new$Desttargetcls);     

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*  60 :  '   .'; source
          61 :  '      '; dest
          62 :  '   ';dest
          63 :  '    '; source
          64 :  '   '; source
          65 :  ' , ';dest
          66 :  '  ,  - '; source dest
          67 :  '   ';source
          68 :  '  \ ';dest
          69 :  '   \ '; dest
          70 :  '  \ ';source
          71 :  '   \ '; dest */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -
  NULL;
--   /*       */
--   GetIntConst(30, 15,PromiseMode$);
--   /*     */
--   if (PromiseMode$ <> 1) then
--     /*          */
--     if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$SOURCEPROMISE)
--       ;
--       /*    ,  */
--       if (Promise_Count$ = 0) then
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--     /*          */
--     if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$DestPromise)
--       ;
--       /*    ,  */
--       if (Promise_Count$ = 0) then
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--         
--     END IF;/* end  PromiseMode <> 1*/
--   END IF;
--   /*     */
--   if (PromiseMode$ = 1) then
--     /* source  .    */
--     if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
--     (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
--       select max(InnerPromiseNum) 
--       into BPInnerNum$           from PaymentSchedule 
--       where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum$ <> 0) then
--         new$SourceBudgetPromise := BPInnerNum$;
--                 
--       else
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--     /* dest  .     */
--     if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
--     (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
--       select max(InnerPromiseNum) 
--       into BPInnerNum$           from PaymentSchedule
--       where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum$ <> 0) then
--         new$DestBudgetPromise := BPInnerNum$;
--                 
--       else
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--           
--     /*         NULL,    */
--     /* source */
--     if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
--     (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
--       BEGIN
--         select ANumber 
--         into BPInnerNum$           from PaymentSchedule
--         where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       new$SourcePromise := BPInnerNum$;
--       new$Promise := BPInnerNum$;
--             
--     END IF;
--     /* dest */
--     if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
--     (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
--       BEGIN
--         select ANumber 
--         into BPInnerNum$           from PaymentSchedule
--         where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       new$DestPromise := BPInnerNum$;
--       new$Promise := BPInnerNum$;
--             
--     END IF;
--     /*    ,     */
--     if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
--       new$SourcePromise := null;
--       new$Promise := null;
--             
--     END IF;
--     if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
--       new$DestPromise := null;
--       new$Promise := null;
--             
--     END IF;
--     if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$1
--       from PaymentSchedule
--       where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$1<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Source */
--         select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
--         where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');      
--       END IF;
--     END IF;
--     if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$2
--       from PaymentSchedule
--       where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$2<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Dest */
--         select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
--         where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');      
--       END IF;    
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*    ?*/
--   GetIntConst(30, 15,PromiseMode1$);
--   if (PromiseMode1$ = 1) then
--     /*        */
--     if (new$SourcePromise is not null and (
--     (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
--     (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex$ = 308) then
--         new$SourceExecDoc := ExecID$;
--         new$SourceExecInnerNumber := ExecInnerNumber$;
--               
--       else 
--         if (new$SourceExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
--             where
--             Id = new$SourceExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */        
--           new$SourceExecInnerNumber := ExecInnerNumber$;
--                 
--         END IF;    
--       END IF;/*       ,   ,  */
--     else 
--       if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber$       from ExecutionDocumentsCaption
--           where
--           Id = new$SourceExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$SourceExecInnerNumber := ExecInnerNumber$;
--             
--       END IF;
--     END IF;
--     /*     Dest */
-- 
--     /*        */
--     if (new$DestPromise is not null and (
--     (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
--     (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex$ = 308) then
--         new$DestExecDoc := ExecID$;
--         new$DestExecInnerNumber := ExecInnerNumber$;
--               
--       else 
--         if (new$DestExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
--             where
--             Id = new$DestExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */        
--           new$DestExecInnerNumber := ExecInnerNumber$;
--                 
--         END IF;    
--       END IF;/*       ,   ,  */
--     else 
--       if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber$       from ExecutionDocumentsCaption
--           where
--           Id = new$DestExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$DestExecInnerNumber := ExecInnerNumber$;
--             
--       END IF;
--     END IF;
--     if (new$SourceExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls1$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Source */
--         select Accepted
--         into EDAccepted$       from ExecutionDocumentsCaption
--         where id = new$SourceExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');    
--       END IF;
--     END IF;
--     if (new$DestExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls1$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Dest */
--         select Accepted
--         into EDAccepted$       from ExecutionDocumentsCaption
--         where ID = new$DestExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');    
--       END IF;  
--     END IF;/*   " "*/
--   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -
  NULL;
--   /*          (  ) */
--   if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
--     BEGIN
--       select c.AcceptDate into CapAcceptDate$
--       from facialfincaption c
--       where c.id = new$RecordIndex;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN
--         CapAcceptDate$ := NULL;
--     END;
-- 
--     if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
--       new$AcceptDate := new$AcceptDate;
--     else
--       RaiseException('ex_wrongacceptdate');
--     end if;
--   end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -
  NULL;
--    IF (new$RVersion IS NULL) THEN
--       new$RVersion := 1;
--    ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
--       new$RVersion := :OLD.RVersion;
--    ELSE
--       new$RVersion := :OLD.RVersion + 1;
--    END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -
  NULL;
--   if (new$ID<>:old.ID) then
--     insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
--     delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
--   end if;

END;
/
-- ALTER TRIGGER TR_FACIALFINDETAIL_BU_700
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;
     
  END IF;
  IF (new$DestFintype IS NULL) THEN 
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*       */
  GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
  new$Sourcetargetcls,new$Sourcetargetcls);
  GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
  new$Desttargetcls,new$Desttargetcls);     

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*  60 :  '   .'; source
          61 :  '      '; dest
          62 :  '   ';dest
          63 :  '    '; source
          64 :  '   '; source
          65 :  ' , ';dest
          66 :  '  ,  - '; source dest
          67 :  '   ';source
          68 :  '  \ ';dest
          69 :  '   \ '; dest
          70 :  '  \ ';source
          71 :  '   \ '; dest */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -
  NULL;
--   /*       */
--   GetIntConst(30, 15,PromiseMode$);
--   /*     */
--   if (PromiseMode$ <> 1) then
--     /*          */
--     if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$SOURCEPROMISE)
--       ;
--       /*    ,  */
--       if (Promise_Count$ = 0) then
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--     /*          */
--     if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$DestPromise)
--       ;
--       /*    ,  */
--       if (Promise_Count$ = 0) then
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--         
--     END IF;/* end  PromiseMode <> 1*/
--   END IF;
--   /*     */
--   if (PromiseMode$ = 1) then
--     /* source  .    */
--     if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
--     (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
--       select max(InnerPromiseNum) 
--       into BPInnerNum$           from PaymentSchedule 
--       where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum$ <> 0) then
--         new$SourceBudgetPromise := BPInnerNum$;
--                 
--       else
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--     /* dest  .     */
--     if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
--     (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
--       select max(InnerPromiseNum) 
--       into BPInnerNum$           from PaymentSchedule
--       where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum$ <> 0) then
--         new$DestBudgetPromise := BPInnerNum$;
--                 
--       else
--         RaiseException('EX_BP_NotExist');      
--       END IF;
--     END IF;
--           
--     /*         NULL,    */
--     /* source */
--     if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
--     (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
--       BEGIN
--         select ANumber 
--         into BPInnerNum$           from PaymentSchedule
--         where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       new$SourcePromise := BPInnerNum$;
--       new$Promise := BPInnerNum$;
--             
--     END IF;
--     /* dest */
--     if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
--     (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
--       BEGIN
--         select ANumber 
--         into BPInnerNum$           from PaymentSchedule
--         where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       new$DestPromise := BPInnerNum$;
--       new$Promise := BPInnerNum$;
--             
--     END IF;
--     /*    ,     */
--     if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
--       new$SourcePromise := null;
--       new$Promise := null;
--             
--     END IF;
--     if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
--       new$DestPromise := null;
--       new$Promise := null;
--             
--     END IF;
--     if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$1
--       from PaymentSchedule
--       where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$1<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Source */
--         select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
--         where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');      
--       END IF;
--     END IF;
--     if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$2
--       from PaymentSchedule
--       where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$2<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Dest */
--         select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
--         where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');      
--       END IF;    
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*    ?*/
--   GetIntConst(30, 15,PromiseMode1$);
--   if (PromiseMode1$ = 1) then
--     /*        */
--     if (new$SourcePromise is not null and (
--     (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
--     (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex$ = 308) then
--         new$SourceExecDoc := ExecID$;
--         new$SourceExecInnerNumber := ExecInnerNumber$;
--               
--       else 
--         if (new$SourceExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
--             where
--             Id = new$SourceExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */        
--           new$SourceExecInnerNumber := ExecInnerNumber$;
--                 
--         END IF;    
--       END IF;/*       ,   ,  */
--     else 
--       if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber$       from ExecutionDocumentsCaption
--           where
--           Id = new$SourceExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$SourceExecInnerNumber := ExecInnerNumber$;
--             
--       END IF;
--     END IF;
--     /*     Dest */
-- 
--     /*        */
--     if (new$DestPromise is not null and (
--     (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
--     (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex$ = 308) then
--         new$DestExecDoc := ExecID$;
--         new$DestExecInnerNumber := ExecInnerNumber$;
--               
--       else 
--         if (new$DestExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
--             where
--             Id = new$DestExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */        
--           new$DestExecInnerNumber := ExecInnerNumber$;
--                 
--         END IF;    
--       END IF;/*       ,   ,  */
--     else 
--       if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber$       from ExecutionDocumentsCaption
--           where
--           Id = new$DestExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$DestExecInnerNumber := ExecInnerNumber$;
--             
--       END IF;
--     END IF;
--     if (new$SourceExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls1$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Source */
--         select Accepted
--         into EDAccepted$       from ExecutionDocumentsCaption
--         where id = new$SourceExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');    
--       END IF;
--     END IF;
--     if (new$DestExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls1$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Dest */
--         select Accepted
--         into EDAccepted$       from ExecutionDocumentsCaption
--         where ID = new$DestExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');    
--       END IF;  
--     END IF;/*   " "*/
--   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -
  NULL;
--   /*          (  ) */
--   if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
--     BEGIN
--       select c.AcceptDate into CapAcceptDate$
--       from facialfincaption c
--       where c.id = new$RecordIndex;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN
--         CapAcceptDate$ := NULL;
--     END;
-- 
--     if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
--       new$AcceptDate := new$AcceptDate;
--     else
--       RaiseException('ex_wrongacceptdate');
--     end if;
--   end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -
  NULL;
--   if (new$ID<>:old.ID) then
--     insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
--     delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
--   end if;

END;
/
-- ALTER TRIGGER TR_FACIALFINDETAIL_BU_200
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;
     
  END IF;
  IF (new$DestFintype IS NULL) THEN 
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*       */
  GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
  new$Sourcetargetcls,new$Sourcetargetcls);
  GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
  new$Desttargetcls,new$Desttargetcls);     

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*  60 :  '   .'; source
          61 :  '      '; dest
          62 :  '   ';dest
          63 :  '    '; source
          64 :  '   '; source
          65 :  ' , ';dest
          66 :  '  ,  - '; source dest
          67 :  '   ';source
          68 :  '  \ ';dest
          69 :  '   \ '; dest
          70 :  '  \ ';source
          71 :  '   \ '; dest */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  /*     */
  if (PromiseMode$ <> 1) then
    /*          */
    if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /*          */
    if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$DestPromise)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
        
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /*     */
  if (PromiseMode$ = 1) then
    /* source  .    */
    if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
    (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule 
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* dest  .     */
    if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
    (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
          
    /*         NULL,    */
    /* source */
    if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
    (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /* dest */
    if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
    (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /*    ,     */
    if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
      new$SourcePromise := null;
      new$Promise := null;
            
    END IF;
    if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
      new$DestPromise := null;
      new$Promise := null;
            
    END IF;
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$1
      from PaymentSchedule
      where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$2
      from PaymentSchedule
      where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*    ?*/
--   GetIntConst(30, 15,PromiseMode1$);
--   if (PromiseMode1$ = 1) then
--     /*        */
--     if (new$SourcePromise is not null and (
--     (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
--     (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex$ = 308) then
--         new$SourceExecDoc := ExecID$;
--         new$SourceExecInnerNumber := ExecInnerNumber$;
--               
--       else 
--         if (new$SourceExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
--             where
--             Id = new$SourceExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */        
--           new$SourceExecInnerNumber := ExecInnerNumber$;
--                 
--         END IF;    
--       END IF;/*       ,   ,  */
--     else 
--       if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber$       from ExecutionDocumentsCaption
--           where
--           Id = new$SourceExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$SourceExecInnerNumber := ExecInnerNumber$;
--             
--       END IF;
--     END IF;
--     /*     Dest */
-- 
--     /*        */
--     if (new$DestPromise is not null and (
--     (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
--     (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex$ = 308) then
--         new$DestExecDoc := ExecID$;
--         new$DestExecInnerNumber := ExecInnerNumber$;
--               
--       else 
--         if (new$DestExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
--             where
--             Id = new$DestExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */        
--           new$DestExecInnerNumber := ExecInnerNumber$;
--                 
--         END IF;    
--       END IF;/*       ,   ,  */
--     else 
--       if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber$       from ExecutionDocumentsCaption
--           where
--           Id = new$DestExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$DestExecInnerNumber := ExecInnerNumber$;
--             
--       END IF;
--     END IF;
--     if (new$SourceExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls1$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Source */
--         select Accepted
--         into EDAccepted$       from ExecutionDocumentsCaption
--         where id = new$SourceExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');    
--       END IF;
--     END IF;
--     if (new$DestExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls1$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Dest */
--         select Accepted
--         into EDAccepted$       from ExecutionDocumentsCaption
--         where ID = new$DestExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');    
--       END IF;  
--     END IF;/*   " "*/
--   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -
  NULL;
--   /*          (  ) */
--   if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
--     BEGIN
--       select c.AcceptDate into CapAcceptDate$
--       from facialfincaption c
--       where c.id = new$RecordIndex;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN
--         CapAcceptDate$ := NULL;
--     END;
-- 
--     if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
--       new$AcceptDate := new$AcceptDate;
--     else
--       RaiseException('ex_wrongacceptdate');
--     end if;
--   end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -
  NULL;
--   if (new$ID<>:old.ID) then
--     insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
--     delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
--   end if;

END;
/
-- ALTER TRIGGER TR_FACIALFINDETAIL_BU_300
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;
     
  END IF;
  IF (new$DestFintype IS NULL) THEN 
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*       */
  GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
  new$Sourcetargetcls,new$Sourcetargetcls);
  GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
  new$Desttargetcls,new$Desttargetcls);     

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*  60 :  '   .'; source
          61 :  '      '; dest
          62 :  '   ';dest
          63 :  '    '; source
          64 :  '   '; source
          65 :  ' , ';dest
          66 :  '  ,  - '; source dest
          67 :  '   ';source
          68 :  '  \ ';dest
          69 :  '   \ '; dest
          70 :  '  \ ';source
          71 :  '   \ '; dest */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  /*     */
  if (PromiseMode$ <> 1) then
    /*          */
    if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /*          */
    if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$DestPromise)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
        
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /*     */
  if (PromiseMode$ = 1) then
    /* source  .    */
    if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
    (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule 
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* dest  .     */
    if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
    (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
          
    /*         NULL,    */
    /* source */
    if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
    (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /* dest */
    if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
    (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /*    ,     */
    if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
      new$SourcePromise := null;
      new$Promise := null;
            
    END IF;
    if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
      new$DestPromise := null;
      new$Promise := null;
            
    END IF;
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$1
      from PaymentSchedule
      where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$2
      from PaymentSchedule
      where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*    ?*/
--   GetIntConst(30, 15,PromiseMode1$);
--   if (PromiseMode1$ = 1) then
--     /*        */
--     if (new$SourcePromise is not null and (
--     (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
--     (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex$ = 308) then
--         new$SourceExecDoc := ExecID$;
--         new$SourceExecInnerNumber := ExecInnerNumber$;
--               
--       else 
--         if (new$SourceExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
--             where
--             Id = new$SourceExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */        
--           new$SourceExecInnerNumber := ExecInnerNumber$;
--                 
--         END IF;    
--       END IF;/*       ,   ,  */
--     else 
--       if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber$       from ExecutionDocumentsCaption
--           where
--           Id = new$SourceExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$SourceExecInnerNumber := ExecInnerNumber$;
--             
--       END IF;
--     END IF;
--     /*     Dest */
-- 
--     /*        */
--     if (new$DestPromise is not null and (
--     (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
--     (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex$ = 308) then
--         new$DestExecDoc := ExecID$;
--         new$DestExecInnerNumber := ExecInnerNumber$;
--               
--       else 
--         if (new$DestExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
--             where
--             Id = new$DestExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */        
--           new$DestExecInnerNumber := ExecInnerNumber$;
--                 
--         END IF;    
--       END IF;/*       ,   ,  */
--     else 
--       if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber$       from ExecutionDocumentsCaption
--           where
--           Id = new$DestExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$DestExecInnerNumber := ExecInnerNumber$;
--             
--       END IF;
--     END IF;
--     if (new$SourceExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls1$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Source */
--         select Accepted
--         into EDAccepted$       from ExecutionDocumentsCaption
--         where id = new$SourceExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');    
--       END IF;
--     END IF;
--     if (new$DestExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls1$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Dest */
--         select Accepted
--         into EDAccepted$       from ExecutionDocumentsCaption
--         where ID = new$DestExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');    
--       END IF;  
--     END IF;/*   " "*/
--   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select c.AcceptDate into CapAcceptDate$
      from facialfincaption c
      where c.id = new$RecordIndex;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        CapAcceptDate$ := NULL;
    END;

    if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
      new$AcceptDate := new$AcceptDate;
    else
      RaiseException('ex_wrongacceptdate');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -
  NULL;
--   if (new$ID<>:old.ID) then
--     insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
--     delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
--   end if;

END;
/
-- ALTER TRIGGER Tr_FacialFinDetail_AU_500
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;
     
  END IF;
  IF (new$DestFintype IS NULL) THEN 
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*       */
  GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
  new$Sourcetargetcls,new$Sourcetargetcls);
  GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
  new$Desttargetcls,new$Desttargetcls);     

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*  60 :  '   .'; source
          61 :  '      '; dest
          62 :  '   ';dest
          63 :  '    '; source
          64 :  '   '; source
          65 :  ' , ';dest
          66 :  '  ,  - '; source dest
          67 :  '   ';source
          68 :  '  \ ';dest
          69 :  '   \ '; dest
          70 :  '  \ ';source
          71 :  '   \ '; dest */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  /*     */
  if (PromiseMode$ <> 1) then
    /*          */
    if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /*          */
    if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$DestPromise)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
        
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /*     */
  if (PromiseMode$ = 1) then
    /* source  .    */
    if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
    (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule 
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* dest  .     */
    if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
    (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
          
    /*         NULL,    */
    /* source */
    if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
    (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /* dest */
    if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
    (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /*    ,     */
    if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
      new$SourcePromise := null;
      new$Promise := null;
            
    END IF;
    if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
      new$DestPromise := null;
      new$Promise := null;
            
    END IF;
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$1
      from PaymentSchedule
      where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$2
      from PaymentSchedule
      where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*    ?*/
--   GetIntConst(30, 15,PromiseMode1$);
--   if (PromiseMode1$ = 1) then
--     /*        */
--     if (new$SourcePromise is not null and (
--     (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
--     (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex$ = 308) then
--         new$SourceExecDoc := ExecID$;
--         new$SourceExecInnerNumber := ExecInnerNumber$;
--               
--       else 
--         if (new$SourceExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
--             where
--             Id = new$SourceExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */        
--           new$SourceExecInnerNumber := ExecInnerNumber$;
--                 
--         END IF;    
--       END IF;/*       ,   ,  */
--     else 
--       if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber$       from ExecutionDocumentsCaption
--           where
--           Id = new$SourceExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$SourceExecInnerNumber := ExecInnerNumber$;
--             
--       END IF;
--     END IF;
--     /*     Dest */
-- 
--     /*        */
--     if (new$DestPromise is not null and (
--     (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
--     (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex$ = 308) then
--         new$DestExecDoc := ExecID$;
--         new$DestExecInnerNumber := ExecInnerNumber$;
--               
--       else 
--         if (new$DestExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
--             where
--             Id = new$DestExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */        
--           new$DestExecInnerNumber := ExecInnerNumber$;
--                 
--         END IF;    
--       END IF;/*       ,   ,  */
--     else 
--       if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber$       from ExecutionDocumentsCaption
--           where
--           Id = new$DestExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$DestExecInnerNumber := ExecInnerNumber$;
--             
--       END IF;
--     END IF;
--     if (new$SourceExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls1$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Source */
--         select Accepted
--         into EDAccepted$       from ExecutionDocumentsCaption
--         where id = new$SourceExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');    
--       END IF;
--     END IF;
--     if (new$DestExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls1$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Dest */
--         select Accepted
--         into EDAccepted$       from ExecutionDocumentsCaption
--         where ID = new$DestExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');    
--       END IF;  
--     END IF;/*   " "*/
--   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select c.AcceptDate into CapAcceptDate$
      from facialfincaption c
      where c.id = new$RecordIndex;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        CapAcceptDate$ := NULL;
    END;

    if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
      new$AcceptDate := new$AcceptDate;
    else
      RaiseException('ex_wrongacceptdate');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
-- ALTER TRIGGER TR_FacialFinDetail_BU_210
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
--
  CapAcceptDate$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate$ NUMBER;
  CaptionRejectCls$ NUMBER(10);
  PromiseAcceptDate$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls1$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*     ,      */ 
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN 
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;
     
  END IF;
  IF (new$DestFintype IS NULL) THEN 
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;
     
  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN 
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN 
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKESR IS NULL) THEN 
    new$SourceKESR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN 
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN 
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN 
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN 
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN 
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN 
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN 
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN 
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN 
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN 
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN 
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN 
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN 
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN 
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN 
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN 
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN 
    new$DestKVR := 0;
  END IF;
  IF (new$DestKESR IS NULL) THEN 
    new$DestKESR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN 
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN 
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN 
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN 
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN 
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN 
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN 
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN 
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN 
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN 
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN 
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN 
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN 
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN 
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN 
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;
     
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;
         
    ELSE 
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;
           
      ELSE 
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF; 
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;
           
      ELSE 
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;
             
        ELSE 
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;
               
          END IF;
        END IF; 
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*       */
  GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
  new$Sourcetargetcls,new$Sourcetargetcls);
  GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
  new$Desttargetcls,new$Desttargetcls);     

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*  60 :  '   .'; source
          61 :  '      '; dest
          62 :  '   ';dest
          63 :  '    '; source
          64 :  '   '; source
          65 :  ' , ';dest
          66 :  '  ,  - '; source dest
          67 :  '   ';source
          68 :  '  \ ';dest
          69 :  '   \ '; dest
          70 :  '  \ ';source
          71 :  '   \ '; dest */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 7.00.02.2
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  /*     */
  if (PromiseMode$ <> 1) then
    /*          */
    if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /*          */
    if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$          from
      promise_detail pr
      where
      (pr.registrnumber = new$DestPromise)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');      
      END IF;
        
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /*     */
  if (PromiseMode$ = 1) then
    /* source  .    */
    if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and 
    (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule 
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
    /* dest  .     */
    if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
    (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
      select max(InnerPromiseNum) 
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;
                
      else
        RaiseException('EX_BP_NotExist');      
      END IF;
    END IF;
          
    /*         NULL,    */
    /* source */
    if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or 
    (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /* dest */
    if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or 
    (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
      BEGIN
        select ANumber 
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;
            
    END IF;
    /*    ,     */
    if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
      new$SourcePromise := null;
      new$Promise := null;
            
    END IF;
    if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
      new$DestPromise := null;
      new$Promise := null;
            
    END IF;
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$1
      from PaymentSchedule
      where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$2
      from PaymentSchedule
      where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate$, CaptionRejectCls$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate$ is not null and (PromiseAcceptDate$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');      
      END IF;    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$SourcePromise is not null and (
    (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
    (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$SourceExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null and (
    (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
    (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;
              
      else 
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */        
          new$DestExecInnerNumber := ExecInnerNumber$;
                
        END IF;    
      END IF;/*       ,   ,  */
    else 
      if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;
            
      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls1$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls1$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');    
      END IF;  
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Create 20.02.2006
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select c.AcceptDate into CapAcceptDate$
      from facialfincaption c
      where c.id = new$RecordIndex;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        CapAcceptDate$ := NULL;
    END;

    if ((new$AcceptDate = CapAcceptDate$) or (CapAcceptDate$ is null)) then
      new$AcceptDate := new$AcceptDate;
    else
      RaiseException('ex_wrongacceptdate');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;    

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
ALTER TRIGGER TR_INCOMES32_BU_500 ENABLE
/
-- ALTER TRIGGER tr_Incomes32_bu_30
CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   IF (new$Fact IS NULL) THEN 
--     new$Fact := 0;
--   END IF;
--   IF (new$DocBase IS NULL) THEN 
--     new$DocBase := 0;
--   END IF;
--   IF (new$Gosni IS NULL) THEN 
--     new$Gosni := 0;
--   END IF;
--   /* 3 -    */
--   IF (new$ProgIndex IS NULL) THEN 
--     new$ProgIndex := 3; 
--   END IF;
--   IF (new$KD IS NULL) THEN 
--     new$KD := 0; 
--   END IF;
--   /*   */
--   IF (new$FACIALACC_CLS IS NULL) THEN 
--     new$FACIALACC_CLS := 0; 
--   END IF;
--   IF (new$MeansType IS NULL) THEN 
--     new$MeansType := 0;
--   END IF;
--   IF (new$Debit IS NULL) THEN 
--     new$Debit := 0;
--   END IF;
--   IF (new$Credit IS NULL) THEN 
--     new$Credit := 0;
--   END IF;
--   IF (new$Org_Ref IS NULL) THEN 
--     new$Org_Ref := 0;
--   END IF;
--   IF (new$AccountIndex IS NULL) THEN 
--     new$AccountIndex := 0; 
--   END IF;
--   IF (new$DocType IS NULL) THEN 
--     new$DocType := 0;
--   END IF;
--   IF (new$SubKD IS NULL) THEN 
--     new$SubKD := 0;
--   END IF;
--   IF (new$RegionCLS IS NULL) THEN 
--     new$RegionCLS := 0;
--   END IF;
--   IF (new$DocCount IS NULL) THEN 
--     new$DocCount := 1;
--   END IF;
--   IF (new$BuhPaymentCLS IS NULL) THEN 
--     new$BuhPaymentCLS := 0;
--   END IF;
--   IF (new$KVSR IS NULL) THEN 
--     new$KVSR := 0;
--   END IF;
--   IF (new$KFSR IS NULL) THEN 
--     new$KFSR := 0;
--   END IF;
--   IF (new$KESR IS NULL) THEN 
--     new$KESR := 0;
--   END IF;
--   IF (new$KVR IS NULL) THEN 
--     new$KVR := 0;
--   END IF;
--   IF (new$KCSR IS NULL) THEN 
--     new$KCSR := 0;
--   END IF;
--   IF (new$OKATO IS NULL) THEN 
--     new$OKATO := 0;
--   END IF;
--   IF (new$FundsSource IS NULL) THEN 
--     new$FundsSource := 0;
--   END IF;
--   IF (new$DirectionCLS IS NULL) THEN 
--     new$DirectionCLS := 0;
--   END IF;
--   IF (new$FinType is null) then 
--     new$FinType := 0;
--   END IF;
--   IF (new$Debit * new$Credit <> 0) THEN
--     RaiseException('ex_FailDebetCretitValue');
--   END IF;
--   /*   .        */
--   IF (new$IFS_CORR IS NULL) THEN 
--     new$Ifs_Corr := 0;
--   END IF;
--   IF (new$IFS IS NULL) THEN 
--     new$Ifs := 0;
--   END IF;
--   IF (new$BuhOperationCLS IS NULL)
--   THEN 
--     GetIntConst(60, 15,new$BuhOperationCLS);
--   END IF;
--   BEGIN
-- 
--     /*     */
--     /*   after   ,*/ 
--     /*      */
--     SELECT ProgIndex, AcceptDate, ReestrNumber
--     INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
--     WHERE
--     (qt.ID = new$RecordIndex)
--     ;
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;
--   /*              
--            (  , , ) */
--   /*   -    () */
--   IF (CapProgIndex2$ = 45)
--   THEN 
--     IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
--     THEN 
--       /*        ,
--                      */            
--       new$FederalFundsRef := new$ID;
--       /* if-then*/
--     ELSE 
--       new$FederalFundsRef := NULL;
--       /* if-else*/  
--     END IF;/* if (CapProgIndex=45) */
--   END IF;
--   /*     */
--   IF (new$BudgetRef <> :old.BudgetRef) THEN
--     IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
--       IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
--         RaiseException('Ex_CantModufyBudget');
--       END IF;
--       IF (new$Progindex = 41) THEN
--         SELECT COUNT(inc.id ) INTO CNT$1
--         FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
--         IF ((CNT$1<> 0)) THEN
--           RaiseException('Ex_CantModufyBudget');
--         END IF;   
--       END IF;
--     END IF;
--   END IF;
--   /*     \*/
--   IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
--   ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
--     BEGIN
--       SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
--       INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
--       WHERE fac.ID = new$FacialACC_Cls
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*    */
--   GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
--   new$targetcls,new$targetcls);  

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
--       new$DocNum := CAST (new$DocNumber AS VARCHAR2);
--    END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -
  NULL;
--   BEGIN
--     SELECT Inn
--      INTO new$Inn
--      FROM Organizations o
--     WHERE (o.ID = new$Org_Ref);
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -
  NULL;
--   /*      */
--   IF (new$ProgIndex <> 42) THEN
--     BEGIN
--       SELECT ProgIndex, DocNumber, AcceptDate
--       INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
--       WHERE
--       (qt.ID = new$RecordIndex)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*   -  ,   */
--   IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
--   THEN 
--     IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
--     (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
--     THEN 
--       BEGIN
--         SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
--         WHERE inc.id = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       IF (Kd_Master$ = new$Kd) THEN 
--         CapAcceptDate$ := new$DOCDATE;
--         CapProgIndex$  := new$ProgIndex;
--         CapDocNumber$  := new$DocNum;
--         /*  */        
--       END IF;/*       (         )*/
--     END IF;
--     IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
--     THEN 
-- 
--       /*      */
--       /* /      Incomes32, ..      ,     */
-- 
--       /*     /   */
--       SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
--       INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
--       WHERE
--       (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
--       ;
--       /*            ,  .*/
--       /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
--                       ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
--                      ) THEN
--                     EXCEPTION EX_CANNOTUPDATENUMBER;*/
--                  
--                 
--       IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
--       then
--         if ((new$DocType <> :old.DocType )
--         or (new$Debit <> :old.Debit )
--         or (new$Credit <> :old.Credit)
--         or (new$org_ref <> :old.org_ref)
--         or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
--         or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
--         )
--         then
--           RaiseException('EX_CANNOTUPDATENUMBER');
--         END IF;
--       END IF;
--                 
-- 
-- 
--       /*           */
--       IF (PayDocCount$ = 0)
--       THEN 
--         /*       */
--         GetIntConst(11, 2,ConstPayQueue$);
--         /*       */
--         GetIntConst(11, 1,ConstSendBy$);
-- 
--         /*    */
--         INSERT INTO PayDoc32
--         (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
--         Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
--         VALUES
--         (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
--         new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
--         /* (new.Debit - new.Credit) --- ..      ,    ,
--                                      */
-- 
--         /* if-then */
--       ELSE 
--         /*     */
--         IF (((new$AccountRef = :old.AccountRef) OR
--         ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
--         AND (new$IncAccount = :old.IncAccount)
--         AND (new$BudgetRef = :old.BudgetRef)
--         AND ((new$Note = :old.Note) OR
--         ((new$Note IS NULL) AND (:old.Note IS NULL)))
--         AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
--         ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
--         AND ((new$TaxNote = :old.TaxNote) OR
--         ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
--         )  THEN
--           new$AccountRef := new$AccountRef;
--                           
--         ELSE
-- 
--           UPDATE PayDoc32 pd
--           SET
--           pd.AccountRef = new$AccountRef,
--           pd.PayerAttrRef = new$IncAccount,
--           pd.AcceptorAttrRef = new$AccountRef,
--           pd.TextNote = new$Note,
--           pd.TaxNote = new$TaxNote,
--           pd.BudgetRef = new$BudgetRef,
--           pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
--           pd.InputDate = CapAcceptDate$,
--           pd.SourceDocNumber = CapDocNumber$,
--           pd.FACIALACC_CLS = new$FACIALACC_CLS
--           WHERE
--           (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
--                           
--         END IF;
--         IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
--         OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
--         THEN  
--           IF (Divided$ > 0)
--           THEN
--             /*  ,      */
--             RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
--           ELSE
--             UPDATE PayDoc32 pd
--             SET
--             pd.Credit = new$Debit - new$Credit
--             WHERE
--             (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
--                           
--           END IF;/* if-then*/            
--         END IF;/* if-else*/
--       END IF;
--       /*     / */
--       /*   :     ,     */
--       /*  ,     */
--       SELECT MAX(pd.AcceptDate)
--       INTO Date_Pd$           FROM PayDoc32 pd
--       WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
--       ;
--       new$Idate := Date_Pd$;
--       /* if-then*/
--     ELSE 
--       /*       
--                           -
--                     . */
--       DELETE FROM PayDoc32 pd
--       WHERE
--       (pd.ProgIndex = new$ProgIndex)
--       AND (pd.RecordIndex = new$id);
--       /* if-else*/  
--     END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
--   END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then 
    BEGIN
      select q.BuildDate 
      into 
      new$DocDate        from QuotesTitle q 
      where q.id = new$RecordIndex 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -
  NULL;
--    /*     */
--    BEGIN
--       SELECT ProgIndex, AcceptDate, ReestrNumber
--         INTO CapProgIndex, CapAcceptDate, CapReestrNumber
--         FROM QuotesTitle qt
--        WHERE (qt.ID = new$RecordIndex);
--    EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--    END;
-- 
--    /*   -    () */
--    IF (CapProgIndex = 45) THEN
--       IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
--          /*        ,
--             */
--          new$FederalFundsRef := new$ID;
--       ELSE
--          new$FederalFundsRef := NULL;
--       END IF;
--    END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ProgIndex = 42)
--   then 
--     /*    */
--     GetVarCharConst(3,0,unkKD$);
--     /*     */
--     GetVarCharConst(3,11,unkVKD$);  
--     BEGIN
-- 
--       select KDValue   into newKD$ from kd where Id=new$kd
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     BEGIN
--       select KDValue   into oldKD$ from kd where Id=:old.kd
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     BEGIN
-- 
--       /*     */
--       select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
--       IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
--       into
--       idKD1$,
--       val_DocCount1$,
--       val_DocType1$,
--       val_Org_Ref1$,
--       val_AccountIndex1$,
--       val_SubKD1$,
--       val_RegionCLS1$,
--       val_GosNI1$,
--       val_IncAccount1$,
--       val_BudgetRef1$,
--       val_MEANSTYPE1$  , 
--       val_FACIALACC_CLS1$,
--       val_TransfertCls1$         from incomes32 where id=new$RecordIndex
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     if (not idKD1$ is null) then
--       if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
--       (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
--         /*   ,    */
--         delete
--         from Incomes32
--         where
--         (ProgIndex=43)and
--         (RecordIndex=:old.id);
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
--       (new$Debit<>0))
--       /*       */
--       then 
--         RaiseException('ex_UnknownRedirect');
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
--       ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
--         /*   ,   ,   */
--         insert into
--         Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
--         Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
--         RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
--         Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
--         val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
--         val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
--         new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
--       and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
--         /*      ,   */
--         update Incomes32
--         set
--         DocNum = new$DocNum,
--         DocCount = val_DocCount1$,
--         iDate = new$iDate,
--         DOCDATE = new$DOCDATE,
--         Debit = 0,
--         Credit = -new$Credit,
--         DocType = val_DocType1$,
--         Org_Ref = val_Org_Ref1$,
--         AccountIndex = val_AccountIndex1$,
--         KD = idKD1$,
--         SubKD = val_SubKD1$,
--         RegionCLS = val_RegionCLS1$,
--         GosNI = val_GosNI1$,
--         ProgIndex = 43,
--         RecordIndex = new$Id,
--         IncAccount = val_IncAccount1$,
--         BudgetRef = val_BudgetRef1$,
--         Note = new$Note,
--         MEANSTYPE = val_MEANSTYPE1$,
--         FACIALACC_CLS = val_FACIALACC_CLS1$,
--         TransfertCls = val_TransfertCls1$,
--         RVersion = -1
--         where
--         (ProgIndex=43)and
--         (RecordIndex=:old.id);
--          
--       END IF; 
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ProgIndex = 41)    /*   () */
--   then 
--     /*    */
--     GetVarCharConst(3,0,unkKD$);
--     /*     */
--     GetVarCharConst(3,11,unkVKD$);  
--     /*       */
--     FOR REC$1 IN (SELECT inc.id
--      AS val_ID42    FROM Incomes32 inc
--     LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
--     WHERE (inc.ProgIndex =  42) and
--     (inc.RecordIndex =  new$id) and
--     (inc.debit = 0) and
--     (not(kd.kdvalue like unkKD$)) and
--     (not(kd.kdvalue like unkVKD$))
--     )
--     LOOP
--       BEGIN
--         /*       */
--         select inc.id
--         into val_ID431$         FROM Incomes32 inc
--         WHERE (inc.ProgIndex =  43) and
--         (inc.RecordIndex =  REC$1.val_ID42)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
-- 
--       /*     ,   Credit, ProgIndex, RecordIndex */
--       update Incomes32
--       set
--       DocNum = new$DocNum,
--       DocCount = new$DocCount,       
--       DOCDATE = new$DOCDATE,
--       Debit = 0,
--       DocType = new$DocType,
--       Org_Ref = new$Org_Ref,
--       AccountIndex = new$AccountIndex,
--       KD = new$Kd,
--       SubKD = new$SubKD,
--       RegionCLS = new$RegionCLS,
--       GosNI = new$GosNI,
--       IncAccount = new$IncAccount,
--       BudgetRef = new$BudgetRef,
--       Note = new$Note,
--       MEANSTYPE = new$MEANSTYPE,
--       FACIALACC_CLS = new$FACIALACC_CLS,
--       FACT = new$FACT,
--       TransfertCls = new$TransfertCls,
--       DirectionCls = new$DirectionCls,
--       rversion = -1
--       where id = val_ID431$;
-- 
--         
--     END LOOP;
--   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
--       new$ClsType := 1;       --       ClsType
--    ELSIF (new$ClsType IS NULL) THEN
--       new$ClsType := 2;                                --  - 
--    END IF;
-- 
--    IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
--       --  
--       RaiseEXCEPTION ('EX_WRONGBUDCLS');
--    END IF;
-- 
--    IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
--       --  
--       RaiseEXCEPTION ('EX_WRONGBUDCLS');
--    END IF;
-- 
--    IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
--       --   
--       RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
--    END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -
  NULL;
--   IsReject$ := -1;
--   if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
--     IsReject$ := 1;
--   elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
--     IsReject$ := 0;
--   end if;  
--   if (IsReject$ <> -1) then
--     update LinkRecords set
--       IsRejected = IsReject$
--     where
--       (ChildID = :new.ID)
--       or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
--   end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (new$RVersion IS NULL) THEN
--       new$RVersion := 1;
--    ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
--       new$RVersion := :OLD.RVersion;
--    ELSE
--       new$RVersion := :OLD.RVersion + 1;
--    END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (NEW$ID <> :OLD.ID) THEN
--       INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
--         VALUES (161, :OLD.ID, SYSDATE);
--       DELETE FROM DelRecIndexes
--         WHERE (TableID = 161) AND (RecordId = NEW$ID);
--    END IF;

END;
/
-- ALTER TRIGGER tr_Incomes32_bu
CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN 
    new$DocBase := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN 
    new$Gosni := 0;
  END IF;
  /* 3 -    */
  IF (new$ProgIndex IS NULL) THEN 
    new$ProgIndex := 3; 
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0; 
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN 
    new$FACIALACC_CLS := 0; 
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN 
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN 
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN 
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN 
    new$AccountIndex := 0; 
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN 
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN 
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN 
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN 
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN 
    new$DirectionCLS := 0;
  END IF;
  IF (new$FinType is null) then 
    new$FinType := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  /*   .        */
  IF (new$IFS_CORR IS NULL) THEN 
    new$Ifs_Corr := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$Ifs := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  BEGIN

    /*     */
    /*   after   ,*/ 
    /*      */
    SELECT ProgIndex, AcceptDate, ReestrNumber
    INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
    WHERE
    (qt.ID = new$RecordIndex)
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*              
           (  , , ) */
  /*   -    () */
  IF (CapProgIndex2$ = 45)
  THEN 
    IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN 
      /*        ,
                     */            
      new$FederalFundsRef := new$ID;
      /* if-then*/
    ELSE 
      new$FederalFundsRef := NULL;
      /* if-else*/  
    END IF;/* if (CapProgIndex=45) */
  END IF;
  /*     */
  IF (new$BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
      IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
        RaiseException('Ex_CantModufyBudget');
      END IF;
      IF (new$Progindex = 41) THEN
        SELECT COUNT(inc.id ) INTO CNT$1
        FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
        IF ((CNT$1<> 0)) THEN
          RaiseException('Ex_CantModufyBudget');
        END IF;   
      END IF;
    END IF;
  END IF;
  /*     \*/
  IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
  ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
  new$targetcls,new$targetcls);  

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
--       new$DocNum := CAST (new$DocNumber AS VARCHAR2);
--    END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -
  NULL;
--   BEGIN
--     SELECT Inn
--      INTO new$Inn
--      FROM Organizations o
--     WHERE (o.ID = new$Org_Ref);
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -
  NULL;
--   /*      */
--   IF (new$ProgIndex <> 42) THEN
--     BEGIN
--       SELECT ProgIndex, DocNumber, AcceptDate
--       INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
--       WHERE
--       (qt.ID = new$RecordIndex)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*   -  ,   */
--   IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
--   THEN 
--     IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
--     (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
--     THEN 
--       BEGIN
--         SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
--         WHERE inc.id = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       IF (Kd_Master$ = new$Kd) THEN 
--         CapAcceptDate$ := new$DOCDATE;
--         CapProgIndex$  := new$ProgIndex;
--         CapDocNumber$  := new$DocNum;
--         /*  */        
--       END IF;/*       (         )*/
--     END IF;
--     IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
--     THEN 
-- 
--       /*      */
--       /* /      Incomes32, ..      ,     */
-- 
--       /*     /   */
--       SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
--       INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
--       WHERE
--       (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
--       ;
--       /*            ,  .*/
--       /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
--                       ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
--                      ) THEN
--                     EXCEPTION EX_CANNOTUPDATENUMBER;*/
--                  
--                 
--       IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
--       then
--         if ((new$DocType <> :old.DocType )
--         or (new$Debit <> :old.Debit )
--         or (new$Credit <> :old.Credit)
--         or (new$org_ref <> :old.org_ref)
--         or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
--         or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
--         )
--         then
--           RaiseException('EX_CANNOTUPDATENUMBER');
--         END IF;
--       END IF;
--                 
-- 
-- 
--       /*           */
--       IF (PayDocCount$ = 0)
--       THEN 
--         /*       */
--         GetIntConst(11, 2,ConstPayQueue$);
--         /*       */
--         GetIntConst(11, 1,ConstSendBy$);
-- 
--         /*    */
--         INSERT INTO PayDoc32
--         (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
--         Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
--         VALUES
--         (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
--         new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
--         /* (new.Debit - new.Credit) --- ..      ,    ,
--                                      */
-- 
--         /* if-then */
--       ELSE 
--         /*     */
--         IF (((new$AccountRef = :old.AccountRef) OR
--         ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
--         AND (new$IncAccount = :old.IncAccount)
--         AND (new$BudgetRef = :old.BudgetRef)
--         AND ((new$Note = :old.Note) OR
--         ((new$Note IS NULL) AND (:old.Note IS NULL)))
--         AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
--         ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
--         AND ((new$TaxNote = :old.TaxNote) OR
--         ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
--         )  THEN
--           new$AccountRef := new$AccountRef;
--                           
--         ELSE
-- 
--           UPDATE PayDoc32 pd
--           SET
--           pd.AccountRef = new$AccountRef,
--           pd.PayerAttrRef = new$IncAccount,
--           pd.AcceptorAttrRef = new$AccountRef,
--           pd.TextNote = new$Note,
--           pd.TaxNote = new$TaxNote,
--           pd.BudgetRef = new$BudgetRef,
--           pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
--           pd.InputDate = CapAcceptDate$,
--           pd.SourceDocNumber = CapDocNumber$,
--           pd.FACIALACC_CLS = new$FACIALACC_CLS
--           WHERE
--           (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
--                           
--         END IF;
--         IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
--         OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
--         THEN  
--           IF (Divided$ > 0)
--           THEN
--             /*  ,      */
--             RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
--           ELSE
--             UPDATE PayDoc32 pd
--             SET
--             pd.Credit = new$Debit - new$Credit
--             WHERE
--             (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
--                           
--           END IF;/* if-then*/            
--         END IF;/* if-else*/
--       END IF;
--       /*     / */
--       /*   :     ,     */
--       /*  ,     */
--       SELECT MAX(pd.AcceptDate)
--       INTO Date_Pd$           FROM PayDoc32 pd
--       WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
--       ;
--       new$Idate := Date_Pd$;
--       /* if-then*/
--     ELSE 
--       /*       
--                           -
--                     . */
--       DELETE FROM PayDoc32 pd
--       WHERE
--       (pd.ProgIndex = new$ProgIndex)
--       AND (pd.RecordIndex = new$id);
--       /* if-else*/  
--     END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
--   END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then 
    BEGIN
      select q.BuildDate 
      into 
      new$DocDate        from QuotesTitle q 
      where q.id = new$RecordIndex 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -
  NULL;
--    /*     */
--    BEGIN
--       SELECT ProgIndex, AcceptDate, ReestrNumber
--         INTO CapProgIndex, CapAcceptDate, CapReestrNumber
--         FROM QuotesTitle qt
--        WHERE (qt.ID = new$RecordIndex);
--    EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--    END;
-- 
--    /*   -    () */
--    IF (CapProgIndex = 45) THEN
--       IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
--          /*        ,
--             */
--          new$FederalFundsRef := new$ID;
--       ELSE
--          new$FederalFundsRef := NULL;
--       END IF;
--    END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ProgIndex = 42)
--   then 
--     /*    */
--     GetVarCharConst(3,0,unkKD$);
--     /*     */
--     GetVarCharConst(3,11,unkVKD$);  
--     BEGIN
-- 
--       select KDValue   into newKD$ from kd where Id=new$kd
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     BEGIN
--       select KDValue   into oldKD$ from kd where Id=:old.kd
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     BEGIN
-- 
--       /*     */
--       select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
--       IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
--       into
--       idKD1$,
--       val_DocCount1$,
--       val_DocType1$,
--       val_Org_Ref1$,
--       val_AccountIndex1$,
--       val_SubKD1$,
--       val_RegionCLS1$,
--       val_GosNI1$,
--       val_IncAccount1$,
--       val_BudgetRef1$,
--       val_MEANSTYPE1$  , 
--       val_FACIALACC_CLS1$,
--       val_TransfertCls1$         from incomes32 where id=new$RecordIndex
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     if (not idKD1$ is null) then
--       if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
--       (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
--         /*   ,    */
--         delete
--         from Incomes32
--         where
--         (ProgIndex=43)and
--         (RecordIndex=:old.id);
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
--       (new$Debit<>0))
--       /*       */
--       then 
--         RaiseException('ex_UnknownRedirect');
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
--       ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
--         /*   ,   ,   */
--         insert into
--         Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
--         Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
--         RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
--         Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
--         val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
--         val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
--         new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
--       and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
--         /*      ,   */
--         update Incomes32
--         set
--         DocNum = new$DocNum,
--         DocCount = val_DocCount1$,
--         iDate = new$iDate,
--         DOCDATE = new$DOCDATE,
--         Debit = 0,
--         Credit = -new$Credit,
--         DocType = val_DocType1$,
--         Org_Ref = val_Org_Ref1$,
--         AccountIndex = val_AccountIndex1$,
--         KD = idKD1$,
--         SubKD = val_SubKD1$,
--         RegionCLS = val_RegionCLS1$,
--         GosNI = val_GosNI1$,
--         ProgIndex = 43,
--         RecordIndex = new$Id,
--         IncAccount = val_IncAccount1$,
--         BudgetRef = val_BudgetRef1$,
--         Note = new$Note,
--         MEANSTYPE = val_MEANSTYPE1$,
--         FACIALACC_CLS = val_FACIALACC_CLS1$,
--         TransfertCls = val_TransfertCls1$,
--         RVersion = -1
--         where
--         (ProgIndex=43)and
--         (RecordIndex=:old.id);
--          
--       END IF; 
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ProgIndex = 41)    /*   () */
--   then 
--     /*    */
--     GetVarCharConst(3,0,unkKD$);
--     /*     */
--     GetVarCharConst(3,11,unkVKD$);  
--     /*       */
--     FOR REC$1 IN (SELECT inc.id
--      AS val_ID42    FROM Incomes32 inc
--     LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
--     WHERE (inc.ProgIndex =  42) and
--     (inc.RecordIndex =  new$id) and
--     (inc.debit = 0) and
--     (not(kd.kdvalue like unkKD$)) and
--     (not(kd.kdvalue like unkVKD$))
--     )
--     LOOP
--       BEGIN
--         /*       */
--         select inc.id
--         into val_ID431$         FROM Incomes32 inc
--         WHERE (inc.ProgIndex =  43) and
--         (inc.RecordIndex =  REC$1.val_ID42)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
-- 
--       /*     ,   Credit, ProgIndex, RecordIndex */
--       update Incomes32
--       set
--       DocNum = new$DocNum,
--       DocCount = new$DocCount,       
--       DOCDATE = new$DOCDATE,
--       Debit = 0,
--       DocType = new$DocType,
--       Org_Ref = new$Org_Ref,
--       AccountIndex = new$AccountIndex,
--       KD = new$Kd,
--       SubKD = new$SubKD,
--       RegionCLS = new$RegionCLS,
--       GosNI = new$GosNI,
--       IncAccount = new$IncAccount,
--       BudgetRef = new$BudgetRef,
--       Note = new$Note,
--       MEANSTYPE = new$MEANSTYPE,
--       FACIALACC_CLS = new$FACIALACC_CLS,
--       FACT = new$FACT,
--       TransfertCls = new$TransfertCls,
--       DirectionCls = new$DirectionCls,
--       rversion = -1
--       where id = val_ID431$;
-- 
--         
--     END LOOP;
--   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
--       new$ClsType := 1;       --       ClsType
--    ELSIF (new$ClsType IS NULL) THEN
--       new$ClsType := 2;                                --  - 
--    END IF;
-- 
--    IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
--       --  
--       RaiseEXCEPTION ('EX_WRONGBUDCLS');
--    END IF;
-- 
--    IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
--       --  
--       RaiseEXCEPTION ('EX_WRONGBUDCLS');
--    END IF;
-- 
--    IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
--       --   
--       RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
--    END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -
  NULL;
--   IsReject$ := -1;
--   if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
--     IsReject$ := 1;
--   elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
--     IsReject$ := 0;
--   end if;  
--   if (IsReject$ <> -1) then
--     update LinkRecords set
--       IsRejected = IsReject$
--     where
--       (ChildID = :new.ID)
--       or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
--   end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (new$RVersion IS NULL) THEN
--       new$RVersion := 1;
--    ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
--       new$RVersion := :OLD.RVersion;
--    ELSE
--       new$RVersion := :OLD.RVersion + 1;
--    END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (NEW$ID <> :OLD.ID) THEN
--       INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
--         VALUES (161, :OLD.ID, SYSDATE);
--       DELETE FROM DelRecIndexes
--         WHERE (TableID = 161) AND (RecordId = NEW$ID);
--    END IF;

END;
/
-- ALTER TRIGGER tr_Incomes32_bu_70
CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN 
    new$DocBase := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN 
    new$Gosni := 0;
  END IF;
  /* 3 -    */
  IF (new$ProgIndex IS NULL) THEN 
    new$ProgIndex := 3; 
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0; 
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN 
    new$FACIALACC_CLS := 0; 
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN 
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN 
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN 
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN 
    new$AccountIndex := 0; 
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN 
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN 
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN 
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN 
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN 
    new$DirectionCLS := 0;
  END IF;
  IF (new$FinType is null) then 
    new$FinType := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  /*   .        */
  IF (new$IFS_CORR IS NULL) THEN 
    new$Ifs_Corr := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$Ifs := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  BEGIN

    /*     */
    /*   after   ,*/ 
    /*      */
    SELECT ProgIndex, AcceptDate, ReestrNumber
    INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
    WHERE
    (qt.ID = new$RecordIndex)
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*              
           (  , , ) */
  /*   -    () */
  IF (CapProgIndex2$ = 45)
  THEN 
    IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN 
      /*        ,
                     */            
      new$FederalFundsRef := new$ID;
      /* if-then*/
    ELSE 
      new$FederalFundsRef := NULL;
      /* if-else*/  
    END IF;/* if (CapProgIndex=45) */
  END IF;
  /*     */
  IF (new$BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
      IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
        RaiseException('Ex_CantModufyBudget');
      END IF;
      IF (new$Progindex = 41) THEN
        SELECT COUNT(inc.id ) INTO CNT$1
        FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
        IF ((CNT$1<> 0)) THEN
          RaiseException('Ex_CantModufyBudget');
        END IF;   
      END IF;
    END IF;
  END IF;
  /*     \*/
  IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
  ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
  new$targetcls,new$targetcls);  

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
--       new$DocNum := CAST (new$DocNumber AS VARCHAR2);
--    END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -
  NULL;
--   BEGIN
--     SELECT Inn
--      INTO new$Inn
--      FROM Organizations o
--     WHERE (o.ID = new$Org_Ref);
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -
  NULL;
--   /*      */
--   IF (new$ProgIndex <> 42) THEN
--     BEGIN
--       SELECT ProgIndex, DocNumber, AcceptDate
--       INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
--       WHERE
--       (qt.ID = new$RecordIndex)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*   -  ,   */
--   IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
--   THEN 
--     IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
--     (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
--     THEN 
--       BEGIN
--         SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
--         WHERE inc.id = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       IF (Kd_Master$ = new$Kd) THEN 
--         CapAcceptDate$ := new$DOCDATE;
--         CapProgIndex$  := new$ProgIndex;
--         CapDocNumber$  := new$DocNum;
--         /*  */        
--       END IF;/*       (         )*/
--     END IF;
--     IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
--     THEN 
-- 
--       /*      */
--       /* /      Incomes32, ..      ,     */
-- 
--       /*     /   */
--       SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
--       INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
--       WHERE
--       (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
--       ;
--       /*            ,  .*/
--       /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
--                       ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
--                      ) THEN
--                     EXCEPTION EX_CANNOTUPDATENUMBER;*/
--                  
--                 
--       IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
--       then
--         if ((new$DocType <> :old.DocType )
--         or (new$Debit <> :old.Debit )
--         or (new$Credit <> :old.Credit)
--         or (new$org_ref <> :old.org_ref)
--         or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
--         or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
--         )
--         then
--           RaiseException('EX_CANNOTUPDATENUMBER');
--         END IF;
--       END IF;
--                 
-- 
-- 
--       /*           */
--       IF (PayDocCount$ = 0)
--       THEN 
--         /*       */
--         GetIntConst(11, 2,ConstPayQueue$);
--         /*       */
--         GetIntConst(11, 1,ConstSendBy$);
-- 
--         /*    */
--         INSERT INTO PayDoc32
--         (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
--         Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
--         VALUES
--         (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
--         new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
--         /* (new.Debit - new.Credit) --- ..      ,    ,
--                                      */
-- 
--         /* if-then */
--       ELSE 
--         /*     */
--         IF (((new$AccountRef = :old.AccountRef) OR
--         ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
--         AND (new$IncAccount = :old.IncAccount)
--         AND (new$BudgetRef = :old.BudgetRef)
--         AND ((new$Note = :old.Note) OR
--         ((new$Note IS NULL) AND (:old.Note IS NULL)))
--         AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
--         ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
--         AND ((new$TaxNote = :old.TaxNote) OR
--         ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
--         )  THEN
--           new$AccountRef := new$AccountRef;
--                           
--         ELSE
-- 
--           UPDATE PayDoc32 pd
--           SET
--           pd.AccountRef = new$AccountRef,
--           pd.PayerAttrRef = new$IncAccount,
--           pd.AcceptorAttrRef = new$AccountRef,
--           pd.TextNote = new$Note,
--           pd.TaxNote = new$TaxNote,
--           pd.BudgetRef = new$BudgetRef,
--           pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
--           pd.InputDate = CapAcceptDate$,
--           pd.SourceDocNumber = CapDocNumber$,
--           pd.FACIALACC_CLS = new$FACIALACC_CLS
--           WHERE
--           (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
--                           
--         END IF;
--         IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
--         OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
--         THEN  
--           IF (Divided$ > 0)
--           THEN
--             /*  ,      */
--             RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
--           ELSE
--             UPDATE PayDoc32 pd
--             SET
--             pd.Credit = new$Debit - new$Credit
--             WHERE
--             (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
--                           
--           END IF;/* if-then*/            
--         END IF;/* if-else*/
--       END IF;
--       /*     / */
--       /*   :     ,     */
--       /*  ,     */
--       SELECT MAX(pd.AcceptDate)
--       INTO Date_Pd$           FROM PayDoc32 pd
--       WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
--       ;
--       new$Idate := Date_Pd$;
--       /* if-then*/
--     ELSE 
--       /*       
--                           -
--                     . */
--       DELETE FROM PayDoc32 pd
--       WHERE
--       (pd.ProgIndex = new$ProgIndex)
--       AND (pd.RecordIndex = new$id);
--       /* if-else*/  
--     END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
--   END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then 
    BEGIN
      select q.BuildDate 
      into 
      new$DocDate        from QuotesTitle q 
      where q.id = new$RecordIndex 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
            */
         new$FederalFundsRef := new$ID;
      ELSE
         new$FederalFundsRef := NULL;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ProgIndex = 42)
--   then 
--     /*    */
--     GetVarCharConst(3,0,unkKD$);
--     /*     */
--     GetVarCharConst(3,11,unkVKD$);  
--     BEGIN
-- 
--       select KDValue   into newKD$ from kd where Id=new$kd
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     BEGIN
--       select KDValue   into oldKD$ from kd where Id=:old.kd
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     BEGIN
-- 
--       /*     */
--       select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
--       IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
--       into
--       idKD1$,
--       val_DocCount1$,
--       val_DocType1$,
--       val_Org_Ref1$,
--       val_AccountIndex1$,
--       val_SubKD1$,
--       val_RegionCLS1$,
--       val_GosNI1$,
--       val_IncAccount1$,
--       val_BudgetRef1$,
--       val_MEANSTYPE1$  , 
--       val_FACIALACC_CLS1$,
--       val_TransfertCls1$         from incomes32 where id=new$RecordIndex
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     if (not idKD1$ is null) then
--       if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
--       (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
--         /*   ,    */
--         delete
--         from Incomes32
--         where
--         (ProgIndex=43)and
--         (RecordIndex=:old.id);
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
--       (new$Debit<>0))
--       /*       */
--       then 
--         RaiseException('ex_UnknownRedirect');
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
--       ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
--         /*   ,   ,   */
--         insert into
--         Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
--         Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
--         RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
--         Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
--         val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
--         val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
--         new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
--       and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
--         /*      ,   */
--         update Incomes32
--         set
--         DocNum = new$DocNum,
--         DocCount = val_DocCount1$,
--         iDate = new$iDate,
--         DOCDATE = new$DOCDATE,
--         Debit = 0,
--         Credit = -new$Credit,
--         DocType = val_DocType1$,
--         Org_Ref = val_Org_Ref1$,
--         AccountIndex = val_AccountIndex1$,
--         KD = idKD1$,
--         SubKD = val_SubKD1$,
--         RegionCLS = val_RegionCLS1$,
--         GosNI = val_GosNI1$,
--         ProgIndex = 43,
--         RecordIndex = new$Id,
--         IncAccount = val_IncAccount1$,
--         BudgetRef = val_BudgetRef1$,
--         Note = new$Note,
--         MEANSTYPE = val_MEANSTYPE1$,
--         FACIALACC_CLS = val_FACIALACC_CLS1$,
--         TransfertCls = val_TransfertCls1$,
--         RVersion = -1
--         where
--         (ProgIndex=43)and
--         (RecordIndex=:old.id);
--          
--       END IF; 
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ProgIndex = 41)    /*   () */
--   then 
--     /*    */
--     GetVarCharConst(3,0,unkKD$);
--     /*     */
--     GetVarCharConst(3,11,unkVKD$);  
--     /*       */
--     FOR REC$1 IN (SELECT inc.id
--      AS val_ID42    FROM Incomes32 inc
--     LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
--     WHERE (inc.ProgIndex =  42) and
--     (inc.RecordIndex =  new$id) and
--     (inc.debit = 0) and
--     (not(kd.kdvalue like unkKD$)) and
--     (not(kd.kdvalue like unkVKD$))
--     )
--     LOOP
--       BEGIN
--         /*       */
--         select inc.id
--         into val_ID431$         FROM Incomes32 inc
--         WHERE (inc.ProgIndex =  43) and
--         (inc.RecordIndex =  REC$1.val_ID42)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
-- 
--       /*     ,   Credit, ProgIndex, RecordIndex */
--       update Incomes32
--       set
--       DocNum = new$DocNum,
--       DocCount = new$DocCount,       
--       DOCDATE = new$DOCDATE,
--       Debit = 0,
--       DocType = new$DocType,
--       Org_Ref = new$Org_Ref,
--       AccountIndex = new$AccountIndex,
--       KD = new$Kd,
--       SubKD = new$SubKD,
--       RegionCLS = new$RegionCLS,
--       GosNI = new$GosNI,
--       IncAccount = new$IncAccount,
--       BudgetRef = new$BudgetRef,
--       Note = new$Note,
--       MEANSTYPE = new$MEANSTYPE,
--       FACIALACC_CLS = new$FACIALACC_CLS,
--       FACT = new$FACT,
--       TransfertCls = new$TransfertCls,
--       DirectionCls = new$DirectionCls,
--       rversion = -1
--       where id = val_ID431$;
-- 
--         
--     END LOOP;
--   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
--       new$ClsType := 1;       --       ClsType
--    ELSIF (new$ClsType IS NULL) THEN
--       new$ClsType := 2;                                --  - 
--    END IF;
-- 
--    IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
--       --  
--       RaiseEXCEPTION ('EX_WRONGBUDCLS');
--    END IF;
-- 
--    IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
--       --  
--       RaiseEXCEPTION ('EX_WRONGBUDCLS');
--    END IF;
-- 
--    IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
--       --   
--       RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
--    END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -
  NULL;
--   IsReject$ := -1;
--   if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
--     IsReject$ := 1;
--   elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
--     IsReject$ := 0;
--   end if;  
--   if (IsReject$ <> -1) then
--     update LinkRecords set
--       IsRejected = IsReject$
--     where
--       (ChildID = :new.ID)
--       or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
--   end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (new$RVersion IS NULL) THEN
--       new$RVersion := 1;
--    ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
--       new$RVersion := :OLD.RVersion;
--    ELSE
--       new$RVersion := :OLD.RVersion + 1;
--    END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (NEW$ID <> :OLD.ID) THEN
--       INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
--         VALUES (161, :OLD.ID, SYSDATE);
--       DELETE FROM DelRecIndexes
--         WHERE (TableID = 161) AND (RecordId = NEW$ID);
--    END IF;

END;
/
-- ALTER TRIGGER TR_INCOMES32_BU_700
CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN 
    new$DocBase := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN 
    new$Gosni := 0;
  END IF;
  /* 3 -    */
  IF (new$ProgIndex IS NULL) THEN 
    new$ProgIndex := 3; 
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0; 
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN 
    new$FACIALACC_CLS := 0; 
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN 
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN 
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN 
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN 
    new$AccountIndex := 0; 
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN 
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN 
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN 
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN 
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN 
    new$DirectionCLS := 0;
  END IF;
  IF (new$FinType is null) then 
    new$FinType := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  /*   .        */
  IF (new$IFS_CORR IS NULL) THEN 
    new$Ifs_Corr := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$Ifs := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  BEGIN

    /*     */
    /*   after   ,*/ 
    /*      */
    SELECT ProgIndex, AcceptDate, ReestrNumber
    INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
    WHERE
    (qt.ID = new$RecordIndex)
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*              
           (  , , ) */
  /*   -    () */
  IF (CapProgIndex2$ = 45)
  THEN 
    IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN 
      /*        ,
                     */            
      new$FederalFundsRef := new$ID;
      /* if-then*/
    ELSE 
      new$FederalFundsRef := NULL;
      /* if-else*/  
    END IF;/* if (CapProgIndex=45) */
  END IF;
  /*     */
  IF (new$BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
      IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
        RaiseException('Ex_CantModufyBudget');
      END IF;
      IF (new$Progindex = 41) THEN
        SELECT COUNT(inc.id ) INTO CNT$1
        FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
        IF ((CNT$1<> 0)) THEN
          RaiseException('Ex_CantModufyBudget');
        END IF;   
      END IF;
    END IF;
  END IF;
  /*     \*/
  IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
  ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
  new$targetcls,new$targetcls);  

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
--       new$DocNum := CAST (new$DocNumber AS VARCHAR2);
--    END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -
  NULL;
--   BEGIN
--     SELECT Inn
--      INTO new$Inn
--      FROM Organizations o
--     WHERE (o.ID = new$Org_Ref);
--   EXCEPTION
--     WHEN NO_DATA_FOUND THEN NULL;
--   END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -
  NULL;
--   /*      */
--   IF (new$ProgIndex <> 42) THEN
--     BEGIN
--       SELECT ProgIndex, DocNumber, AcceptDate
--       INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
--       WHERE
--       (qt.ID = new$RecordIndex)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*   -  ,   */
--   IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
--   THEN 
--     IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
--     (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
--     THEN 
--       BEGIN
--         SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
--         WHERE inc.id = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       IF (Kd_Master$ = new$Kd) THEN 
--         CapAcceptDate$ := new$DOCDATE;
--         CapProgIndex$  := new$ProgIndex;
--         CapDocNumber$  := new$DocNum;
--         /*  */        
--       END IF;/*       (         )*/
--     END IF;
--     IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
--     THEN 
-- 
--       /*      */
--       /* /      Incomes32, ..      ,     */
-- 
--       /*     /   */
--       SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
--       INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
--       WHERE
--       (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
--       ;
--       /*            ,  .*/
--       /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
--                       ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
--                      ) THEN
--                     EXCEPTION EX_CANNOTUPDATENUMBER;*/
--                  
--                 
--       IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
--       then
--         if ((new$DocType <> :old.DocType )
--         or (new$Debit <> :old.Debit )
--         or (new$Credit <> :old.Credit)
--         or (new$org_ref <> :old.org_ref)
--         or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
--         or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
--         )
--         then
--           RaiseException('EX_CANNOTUPDATENUMBER');
--         END IF;
--       END IF;
--                 
-- 
-- 
--       /*           */
--       IF (PayDocCount$ = 0)
--       THEN 
--         /*       */
--         GetIntConst(11, 2,ConstPayQueue$);
--         /*       */
--         GetIntConst(11, 1,ConstSendBy$);
-- 
--         /*    */
--         INSERT INTO PayDoc32
--         (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
--         Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
--         VALUES
--         (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
--         new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
--         /* (new.Debit - new.Credit) --- ..      ,    ,
--                                      */
-- 
--         /* if-then */
--       ELSE 
--         /*     */
--         IF (((new$AccountRef = :old.AccountRef) OR
--         ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
--         AND (new$IncAccount = :old.IncAccount)
--         AND (new$BudgetRef = :old.BudgetRef)
--         AND ((new$Note = :old.Note) OR
--         ((new$Note IS NULL) AND (:old.Note IS NULL)))
--         AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
--         ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
--         AND ((new$TaxNote = :old.TaxNote) OR
--         ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
--         )  THEN
--           new$AccountRef := new$AccountRef;
--                           
--         ELSE
-- 
--           UPDATE PayDoc32 pd
--           SET
--           pd.AccountRef = new$AccountRef,
--           pd.PayerAttrRef = new$IncAccount,
--           pd.AcceptorAttrRef = new$AccountRef,
--           pd.TextNote = new$Note,
--           pd.TaxNote = new$TaxNote,
--           pd.BudgetRef = new$BudgetRef,
--           pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
--           pd.InputDate = CapAcceptDate$,
--           pd.SourceDocNumber = CapDocNumber$,
--           pd.FACIALACC_CLS = new$FACIALACC_CLS
--           WHERE
--           (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
--                           
--         END IF;
--         IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
--         OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
--         THEN  
--           IF (Divided$ > 0)
--           THEN
--             /*  ,      */
--             RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
--           ELSE
--             UPDATE PayDoc32 pd
--             SET
--             pd.Credit = new$Debit - new$Credit
--             WHERE
--             (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
--                           
--           END IF;/* if-then*/            
--         END IF;/* if-else*/
--       END IF;
--       /*     / */
--       /*   :     ,     */
--       /*  ,     */
--       SELECT MAX(pd.AcceptDate)
--       INTO Date_Pd$           FROM PayDoc32 pd
--       WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
--       ;
--       new$Idate := Date_Pd$;
--       /* if-then*/
--     ELSE 
--       /*       
--                           -
--                     . */
--       DELETE FROM PayDoc32 pd
--       WHERE
--       (pd.ProgIndex = new$ProgIndex)
--       AND (pd.RecordIndex = new$id);
--       /* if-else*/  
--     END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
--   END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then 
    BEGIN
      select q.BuildDate 
      into 
      new$DocDate        from QuotesTitle q 
      where q.id = new$RecordIndex 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
            */
         new$FederalFundsRef := new$ID;
      ELSE
         new$FederalFundsRef := NULL;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ProgIndex = 42)
--   then 
--     /*    */
--     GetVarCharConst(3,0,unkKD$);
--     /*     */
--     GetVarCharConst(3,11,unkVKD$);  
--     BEGIN
-- 
--       select KDValue   into newKD$ from kd where Id=new$kd
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     BEGIN
--       select KDValue   into oldKD$ from kd where Id=:old.kd
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     BEGIN
-- 
--       /*     */
--       select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
--       IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
--       into
--       idKD1$,
--       val_DocCount1$,
--       val_DocType1$,
--       val_Org_Ref1$,
--       val_AccountIndex1$,
--       val_SubKD1$,
--       val_RegionCLS1$,
--       val_GosNI1$,
--       val_IncAccount1$,
--       val_BudgetRef1$,
--       val_MEANSTYPE1$  , 
--       val_FACIALACC_CLS1$,
--       val_TransfertCls1$         from incomes32 where id=new$RecordIndex
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     if (not idKD1$ is null) then
--       if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
--       (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
--         /*   ,    */
--         delete
--         from Incomes32
--         where
--         (ProgIndex=43)and
--         (RecordIndex=:old.id);
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
--       (new$Debit<>0))
--       /*       */
--       then 
--         RaiseException('ex_UnknownRedirect');
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
--       ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
--         /*   ,   ,   */
--         insert into
--         Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
--         Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
--         RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
--         Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
--         val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
--         val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
--         new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
--       and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
--         /*      ,   */
--         update Incomes32
--         set
--         DocNum = new$DocNum,
--         DocCount = val_DocCount1$,
--         iDate = new$iDate,
--         DOCDATE = new$DOCDATE,
--         Debit = 0,
--         Credit = -new$Credit,
--         DocType = val_DocType1$,
--         Org_Ref = val_Org_Ref1$,
--         AccountIndex = val_AccountIndex1$,
--         KD = idKD1$,
--         SubKD = val_SubKD1$,
--         RegionCLS = val_RegionCLS1$,
--         GosNI = val_GosNI1$,
--         ProgIndex = 43,
--         RecordIndex = new$Id,
--         IncAccount = val_IncAccount1$,
--         BudgetRef = val_BudgetRef1$,
--         Note = new$Note,
--         MEANSTYPE = val_MEANSTYPE1$,
--         FACIALACC_CLS = val_FACIALACC_CLS1$,
--         TransfertCls = val_TransfertCls1$,
--         RVersion = -1
--         where
--         (ProgIndex=43)and
--         (RecordIndex=:old.id);
--          
--       END IF; 
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ProgIndex = 41)    /*   () */
--   then 
--     /*    */
--     GetVarCharConst(3,0,unkKD$);
--     /*     */
--     GetVarCharConst(3,11,unkVKD$);  
--     /*       */
--     FOR REC$1 IN (SELECT inc.id
--      AS val_ID42    FROM Incomes32 inc
--     LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
--     WHERE (inc.ProgIndex =  42) and
--     (inc.RecordIndex =  new$id) and
--     (inc.debit = 0) and
--     (not(kd.kdvalue like unkKD$)) and
--     (not(kd.kdvalue like unkVKD$))
--     )
--     LOOP
--       BEGIN
--         /*       */
--         select inc.id
--         into val_ID431$         FROM Incomes32 inc
--         WHERE (inc.ProgIndex =  43) and
--         (inc.RecordIndex =  REC$1.val_ID42)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
-- 
--       /*     ,   Credit, ProgIndex, RecordIndex */
--       update Incomes32
--       set
--       DocNum = new$DocNum,
--       DocCount = new$DocCount,       
--       DOCDATE = new$DOCDATE,
--       Debit = 0,
--       DocType = new$DocType,
--       Org_Ref = new$Org_Ref,
--       AccountIndex = new$AccountIndex,
--       KD = new$Kd,
--       SubKD = new$SubKD,
--       RegionCLS = new$RegionCLS,
--       GosNI = new$GosNI,
--       IncAccount = new$IncAccount,
--       BudgetRef = new$BudgetRef,
--       Note = new$Note,
--       MEANSTYPE = new$MEANSTYPE,
--       FACIALACC_CLS = new$FACIALACC_CLS,
--       FACT = new$FACT,
--       TransfertCls = new$TransfertCls,
--       DirectionCls = new$DirectionCls,
--       rversion = -1
--       where id = val_ID431$;
-- 
--         
--     END LOOP;
--   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
--       new$ClsType := 1;       --       ClsType
--    ELSIF (new$ClsType IS NULL) THEN
--       new$ClsType := 2;                                --  - 
--    END IF;
-- 
--    IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
--       --  
--       RaiseEXCEPTION ('EX_WRONGBUDCLS');
--    END IF;
-- 
--    IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
--       --  
--       RaiseEXCEPTION ('EX_WRONGBUDCLS');
--    END IF;
-- 
--    IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
--       --   
--       RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
--    END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -
  NULL;
--   IsReject$ := -1;
--   if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
--     IsReject$ := 1;
--   elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
--     IsReject$ := 0;
--   end if;  
--   if (IsReject$ <> -1) then
--     update LinkRecords set
--       IsRejected = IsReject$
--     where
--       (ChildID = :new.ID)
--       or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
--   end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (NEW$ID <> :OLD.ID) THEN
--       INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
--         VALUES (161, :OLD.ID, SYSDATE);
--       DELETE FROM DelRecIndexes
--         WHERE (TableID = 161) AND (RecordId = NEW$ID);
--    END IF;

END;
/
-- ALTER TRIGGER tr_Incomes32_bu_0
CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN 
    new$DocBase := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN 
    new$Gosni := 0;
  END IF;
  /* 3 -    */
  IF (new$ProgIndex IS NULL) THEN 
    new$ProgIndex := 3; 
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0; 
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN 
    new$FACIALACC_CLS := 0; 
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN 
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN 
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN 
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN 
    new$AccountIndex := 0; 
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN 
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN 
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN 
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN 
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN 
    new$DirectionCLS := 0;
  END IF;
  IF (new$FinType is null) then 
    new$FinType := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  /*   .        */
  IF (new$IFS_CORR IS NULL) THEN 
    new$Ifs_Corr := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$Ifs := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  BEGIN

    /*     */
    /*   after   ,*/ 
    /*      */
    SELECT ProgIndex, AcceptDate, ReestrNumber
    INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
    WHERE
    (qt.ID = new$RecordIndex)
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*              
           (  , , ) */
  /*   -    () */
  IF (CapProgIndex2$ = 45)
  THEN 
    IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN 
      /*        ,
                     */            
      new$FederalFundsRef := new$ID;
      /* if-then*/
    ELSE 
      new$FederalFundsRef := NULL;
      /* if-else*/  
    END IF;/* if (CapProgIndex=45) */
  END IF;
  /*     */
  IF (new$BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
      IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
        RaiseException('Ex_CantModufyBudget');
      END IF;
      IF (new$Progindex = 41) THEN
        SELECT COUNT(inc.id ) INTO CNT$1
        FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
        IF ((CNT$1<> 0)) THEN
          RaiseException('Ex_CantModufyBudget');
        END IF;   
      END IF;
    END IF;
  END IF;
  /*     \*/
  IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
  ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
  new$targetcls,new$targetcls);  

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
--       new$DocNum := CAST (new$DocNumber AS VARCHAR2);
--    END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

  BEGIN
    SELECT Inn
     INTO new$Inn
     FROM Organizations o
    WHERE (o.ID = new$Org_Ref);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -
  NULL;
--   /*      */
--   IF (new$ProgIndex <> 42) THEN
--     BEGIN
--       SELECT ProgIndex, DocNumber, AcceptDate
--       INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
--       WHERE
--       (qt.ID = new$RecordIndex)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*   -  ,   */
--   IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
--   THEN 
--     IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
--     (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
--     THEN 
--       BEGIN
--         SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
--         WHERE inc.id = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       IF (Kd_Master$ = new$Kd) THEN 
--         CapAcceptDate$ := new$DOCDATE;
--         CapProgIndex$  := new$ProgIndex;
--         CapDocNumber$  := new$DocNum;
--         /*  */        
--       END IF;/*       (         )*/
--     END IF;
--     IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
--     THEN 
-- 
--       /*      */
--       /* /      Incomes32, ..      ,     */
-- 
--       /*     /   */
--       SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
--       INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
--       WHERE
--       (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
--       ;
--       /*            ,  .*/
--       /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
--                       ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
--                      ) THEN
--                     EXCEPTION EX_CANNOTUPDATENUMBER;*/
--                  
--                 
--       IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
--       then
--         if ((new$DocType <> :old.DocType )
--         or (new$Debit <> :old.Debit )
--         or (new$Credit <> :old.Credit)
--         or (new$org_ref <> :old.org_ref)
--         or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
--         or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
--         )
--         then
--           RaiseException('EX_CANNOTUPDATENUMBER');
--         END IF;
--       END IF;
--                 
-- 
-- 
--       /*           */
--       IF (PayDocCount$ = 0)
--       THEN 
--         /*       */
--         GetIntConst(11, 2,ConstPayQueue$);
--         /*       */
--         GetIntConst(11, 1,ConstSendBy$);
-- 
--         /*    */
--         INSERT INTO PayDoc32
--         (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
--         Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
--         VALUES
--         (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
--         new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
--         /* (new.Debit - new.Credit) --- ..      ,    ,
--                                      */
-- 
--         /* if-then */
--       ELSE 
--         /*     */
--         IF (((new$AccountRef = :old.AccountRef) OR
--         ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
--         AND (new$IncAccount = :old.IncAccount)
--         AND (new$BudgetRef = :old.BudgetRef)
--         AND ((new$Note = :old.Note) OR
--         ((new$Note IS NULL) AND (:old.Note IS NULL)))
--         AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
--         ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
--         AND ((new$TaxNote = :old.TaxNote) OR
--         ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
--         )  THEN
--           new$AccountRef := new$AccountRef;
--                           
--         ELSE
-- 
--           UPDATE PayDoc32 pd
--           SET
--           pd.AccountRef = new$AccountRef,
--           pd.PayerAttrRef = new$IncAccount,
--           pd.AcceptorAttrRef = new$AccountRef,
--           pd.TextNote = new$Note,
--           pd.TaxNote = new$TaxNote,
--           pd.BudgetRef = new$BudgetRef,
--           pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
--           pd.InputDate = CapAcceptDate$,
--           pd.SourceDocNumber = CapDocNumber$,
--           pd.FACIALACC_CLS = new$FACIALACC_CLS
--           WHERE
--           (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
--                           
--         END IF;
--         IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
--         OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
--         THEN  
--           IF (Divided$ > 0)
--           THEN
--             /*  ,      */
--             RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
--           ELSE
--             UPDATE PayDoc32 pd
--             SET
--             pd.Credit = new$Debit - new$Credit
--             WHERE
--             (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
--                           
--           END IF;/* if-then*/            
--         END IF;/* if-else*/
--       END IF;
--       /*     / */
--       /*   :     ,     */
--       /*  ,     */
--       SELECT MAX(pd.AcceptDate)
--       INTO Date_Pd$           FROM PayDoc32 pd
--       WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
--       ;
--       new$Idate := Date_Pd$;
--       /* if-then*/
--     ELSE 
--       /*       
--                           -
--                     . */
--       DELETE FROM PayDoc32 pd
--       WHERE
--       (pd.ProgIndex = new$ProgIndex)
--       AND (pd.RecordIndex = new$id);
--       /* if-else*/  
--     END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
--   END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then 
    BEGIN
      select q.BuildDate 
      into 
      new$DocDate        from QuotesTitle q 
      where q.id = new$RecordIndex 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
            */
         new$FederalFundsRef := new$ID;
      ELSE
         new$FederalFundsRef := NULL;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ProgIndex = 42)
--   then 
--     /*    */
--     GetVarCharConst(3,0,unkKD$);
--     /*     */
--     GetVarCharConst(3,11,unkVKD$);  
--     BEGIN
-- 
--       select KDValue   into newKD$ from kd where Id=new$kd
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     BEGIN
--       select KDValue   into oldKD$ from kd where Id=:old.kd
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     BEGIN
-- 
--       /*     */
--       select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
--       IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
--       into
--       idKD1$,
--       val_DocCount1$,
--       val_DocType1$,
--       val_Org_Ref1$,
--       val_AccountIndex1$,
--       val_SubKD1$,
--       val_RegionCLS1$,
--       val_GosNI1$,
--       val_IncAccount1$,
--       val_BudgetRef1$,
--       val_MEANSTYPE1$  , 
--       val_FACIALACC_CLS1$,
--       val_TransfertCls1$         from incomes32 where id=new$RecordIndex
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     if (not idKD1$ is null) then
--       if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
--       (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
--         /*   ,    */
--         delete
--         from Incomes32
--         where
--         (ProgIndex=43)and
--         (RecordIndex=:old.id);
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
--       (new$Debit<>0))
--       /*       */
--       then 
--         RaiseException('ex_UnknownRedirect');
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
--       ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
--         /*   ,   ,   */
--         insert into
--         Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
--         Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
--         RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
--         Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
--         val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
--         val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
--         new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
--       and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
--         /*      ,   */
--         update Incomes32
--         set
--         DocNum = new$DocNum,
--         DocCount = val_DocCount1$,
--         iDate = new$iDate,
--         DOCDATE = new$DOCDATE,
--         Debit = 0,
--         Credit = -new$Credit,
--         DocType = val_DocType1$,
--         Org_Ref = val_Org_Ref1$,
--         AccountIndex = val_AccountIndex1$,
--         KD = idKD1$,
--         SubKD = val_SubKD1$,
--         RegionCLS = val_RegionCLS1$,
--         GosNI = val_GosNI1$,
--         ProgIndex = 43,
--         RecordIndex = new$Id,
--         IncAccount = val_IncAccount1$,
--         BudgetRef = val_BudgetRef1$,
--         Note = new$Note,
--         MEANSTYPE = val_MEANSTYPE1$,
--         FACIALACC_CLS = val_FACIALACC_CLS1$,
--         TransfertCls = val_TransfertCls1$,
--         RVersion = -1
--         where
--         (ProgIndex=43)and
--         (RecordIndex=:old.id);
--          
--       END IF; 
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ProgIndex = 41)    /*   () */
--   then 
--     /*    */
--     GetVarCharConst(3,0,unkKD$);
--     /*     */
--     GetVarCharConst(3,11,unkVKD$);  
--     /*       */
--     FOR REC$1 IN (SELECT inc.id
--      AS val_ID42    FROM Incomes32 inc
--     LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
--     WHERE (inc.ProgIndex =  42) and
--     (inc.RecordIndex =  new$id) and
--     (inc.debit = 0) and
--     (not(kd.kdvalue like unkKD$)) and
--     (not(kd.kdvalue like unkVKD$))
--     )
--     LOOP
--       BEGIN
--         /*       */
--         select inc.id
--         into val_ID431$         FROM Incomes32 inc
--         WHERE (inc.ProgIndex =  43) and
--         (inc.RecordIndex =  REC$1.val_ID42)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
-- 
--       /*     ,   Credit, ProgIndex, RecordIndex */
--       update Incomes32
--       set
--       DocNum = new$DocNum,
--       DocCount = new$DocCount,       
--       DOCDATE = new$DOCDATE,
--       Debit = 0,
--       DocType = new$DocType,
--       Org_Ref = new$Org_Ref,
--       AccountIndex = new$AccountIndex,
--       KD = new$Kd,
--       SubKD = new$SubKD,
--       RegionCLS = new$RegionCLS,
--       GosNI = new$GosNI,
--       IncAccount = new$IncAccount,
--       BudgetRef = new$BudgetRef,
--       Note = new$Note,
--       MEANSTYPE = new$MEANSTYPE,
--       FACIALACC_CLS = new$FACIALACC_CLS,
--       FACT = new$FACT,
--       TransfertCls = new$TransfertCls,
--       DirectionCls = new$DirectionCls,
--       rversion = -1
--       where id = val_ID431$;
-- 
--         
--     END LOOP;
--   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
--       new$ClsType := 1;       --       ClsType
--    ELSIF (new$ClsType IS NULL) THEN
--       new$ClsType := 2;                                --  - 
--    END IF;
-- 
--    IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
--       --  
--       RaiseEXCEPTION ('EX_WRONGBUDCLS');
--    END IF;
-- 
--    IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
--       --  
--       RaiseEXCEPTION ('EX_WRONGBUDCLS');
--    END IF;
-- 
--    IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
--       --   
--       RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
--    END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -
  NULL;
--   IsReject$ := -1;
--   if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
--     IsReject$ := 1;
--   elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
--     IsReject$ := 0;
--   end if;  
--   if (IsReject$ <> -1) then
--     update LinkRecords set
--       IsRejected = IsReject$
--     where
--       (ChildID = :new.ID)
--       or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
--   end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (NEW$ID <> :OLD.ID) THEN
--       INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
--         VALUES (161, :OLD.ID, SYSDATE);
--       DELETE FROM DelRecIndexes
--         WHERE (TableID = 161) AND (RecordId = NEW$ID);
--    END IF;

END;
/
-- ALTER TRIGGER TR_Incomes_BU_5
CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN 
    new$DocBase := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN 
    new$Gosni := 0;
  END IF;
  /* 3 -    */
  IF (new$ProgIndex IS NULL) THEN 
    new$ProgIndex := 3; 
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0; 
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN 
    new$FACIALACC_CLS := 0; 
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN 
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN 
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN 
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN 
    new$AccountIndex := 0; 
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN 
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN 
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN 
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN 
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN 
    new$DirectionCLS := 0;
  END IF;
  IF (new$FinType is null) then 
    new$FinType := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  /*   .        */
  IF (new$IFS_CORR IS NULL) THEN 
    new$Ifs_Corr := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$Ifs := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  BEGIN

    /*     */
    /*   after   ,*/ 
    /*      */
    SELECT ProgIndex, AcceptDate, ReestrNumber
    INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
    WHERE
    (qt.ID = new$RecordIndex)
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*              
           (  , , ) */
  /*   -    () */
  IF (CapProgIndex2$ = 45)
  THEN 
    IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN 
      /*        ,
                     */            
      new$FederalFundsRef := new$ID;
      /* if-then*/
    ELSE 
      new$FederalFundsRef := NULL;
      /* if-else*/  
    END IF;/* if (CapProgIndex=45) */
  END IF;
  /*     */
  IF (new$BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
      IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
        RaiseException('Ex_CantModufyBudget');
      END IF;
      IF (new$Progindex = 41) THEN
        SELECT COUNT(inc.id ) INTO CNT$1
        FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
        IF ((CNT$1<> 0)) THEN
          RaiseException('Ex_CantModufyBudget');
        END IF;   
      END IF;
    END IF;
  END IF;
  /*     \*/
  IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
  ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
  new$targetcls,new$targetcls);  

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

  BEGIN
    SELECT Inn
     INTO new$Inn
     FROM Organizations o
    WHERE (o.ID = new$Org_Ref);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -
  NULL;
--   /*      */
--   IF (new$ProgIndex <> 42) THEN
--     BEGIN
--       SELECT ProgIndex, DocNumber, AcceptDate
--       INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
--       WHERE
--       (qt.ID = new$RecordIndex)
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--   END IF;
--   /*   -  ,   */
--   IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
--   THEN 
--     IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
--     (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
--     THEN 
--       BEGIN
--         SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
--         WHERE inc.id = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       IF (Kd_Master$ = new$Kd) THEN 
--         CapAcceptDate$ := new$DOCDATE;
--         CapProgIndex$  := new$ProgIndex;
--         CapDocNumber$  := new$DocNum;
--         /*  */        
--       END IF;/*       (         )*/
--     END IF;
--     IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
--     THEN 
-- 
--       /*      */
--       /* /      Incomes32, ..      ,     */
-- 
--       /*     /   */
--       SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
--       INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
--       WHERE
--       (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
--       ;
--       /*            ,  .*/
--       /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
--                       ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
--                      ) THEN
--                     EXCEPTION EX_CANNOTUPDATENUMBER;*/
--                  
--                 
--       IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
--       then
--         if ((new$DocType <> :old.DocType )
--         or (new$Debit <> :old.Debit )
--         or (new$Credit <> :old.Credit)
--         or (new$org_ref <> :old.org_ref)
--         or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
--         or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
--         )
--         then
--           RaiseException('EX_CANNOTUPDATENUMBER');
--         END IF;
--       END IF;
--                 
-- 
-- 
--       /*           */
--       IF (PayDocCount$ = 0)
--       THEN 
--         /*       */
--         GetIntConst(11, 2,ConstPayQueue$);
--         /*       */
--         GetIntConst(11, 1,ConstSendBy$);
-- 
--         /*    */
--         INSERT INTO PayDoc32
--         (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
--         Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
--         VALUES
--         (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
--         new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
--         /* (new.Debit - new.Credit) --- ..      ,    ,
--                                      */
-- 
--         /* if-then */
--       ELSE 
--         /*     */
--         IF (((new$AccountRef = :old.AccountRef) OR
--         ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
--         AND (new$IncAccount = :old.IncAccount)
--         AND (new$BudgetRef = :old.BudgetRef)
--         AND ((new$Note = :old.Note) OR
--         ((new$Note IS NULL) AND (:old.Note IS NULL)))
--         AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
--         ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
--         AND ((new$TaxNote = :old.TaxNote) OR
--         ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
--         )  THEN
--           new$AccountRef := new$AccountRef;
--                           
--         ELSE
-- 
--           UPDATE PayDoc32 pd
--           SET
--           pd.AccountRef = new$AccountRef,
--           pd.PayerAttrRef = new$IncAccount,
--           pd.AcceptorAttrRef = new$AccountRef,
--           pd.TextNote = new$Note,
--           pd.TaxNote = new$TaxNote,
--           pd.BudgetRef = new$BudgetRef,
--           pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
--           pd.InputDate = CapAcceptDate$,
--           pd.SourceDocNumber = CapDocNumber$,
--           pd.FACIALACC_CLS = new$FACIALACC_CLS
--           WHERE
--           (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
--                           
--         END IF;
--         IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
--         OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
--         THEN  
--           IF (Divided$ > 0)
--           THEN
--             /*  ,      */
--             RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
--           ELSE
--             UPDATE PayDoc32 pd
--             SET
--             pd.Credit = new$Debit - new$Credit
--             WHERE
--             (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
--                           
--           END IF;/* if-then*/            
--         END IF;/* if-else*/
--       END IF;
--       /*     / */
--       /*   :     ,     */
--       /*  ,     */
--       SELECT MAX(pd.AcceptDate)
--       INTO Date_Pd$           FROM PayDoc32 pd
--       WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
--       ;
--       new$Idate := Date_Pd$;
--       /* if-then*/
--     ELSE 
--       /*       
--                           -
--                     . */
--       DELETE FROM PayDoc32 pd
--       WHERE
--       (pd.ProgIndex = new$ProgIndex)
--       AND (pd.RecordIndex = new$id);
--       /* if-else*/  
--     END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
--   END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then 
    BEGIN
      select q.BuildDate 
      into 
      new$DocDate        from QuotesTitle q 
      where q.id = new$RecordIndex 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
            */
         new$FederalFundsRef := new$ID;
      ELSE
         new$FederalFundsRef := NULL;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ProgIndex = 42)
--   then 
--     /*    */
--     GetVarCharConst(3,0,unkKD$);
--     /*     */
--     GetVarCharConst(3,11,unkVKD$);  
--     BEGIN
-- 
--       select KDValue   into newKD$ from kd where Id=new$kd
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     BEGIN
--       select KDValue   into oldKD$ from kd where Id=:old.kd
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     BEGIN
-- 
--       /*     */
--       select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
--       IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
--       into
--       idKD1$,
--       val_DocCount1$,
--       val_DocType1$,
--       val_Org_Ref1$,
--       val_AccountIndex1$,
--       val_SubKD1$,
--       val_RegionCLS1$,
--       val_GosNI1$,
--       val_IncAccount1$,
--       val_BudgetRef1$,
--       val_MEANSTYPE1$  , 
--       val_FACIALACC_CLS1$,
--       val_TransfertCls1$         from incomes32 where id=new$RecordIndex
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     if (not idKD1$ is null) then
--       if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
--       (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
--         /*   ,    */
--         delete
--         from Incomes32
--         where
--         (ProgIndex=43)and
--         (RecordIndex=:old.id);
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
--       (new$Debit<>0))
--       /*       */
--       then 
--         RaiseException('ex_UnknownRedirect');
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
--       ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
--         /*   ,   ,   */
--         insert into
--         Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
--         Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
--         RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
--         Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
--         val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
--         val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
--         new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
--       and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
--         /*      ,   */
--         update Incomes32
--         set
--         DocNum = new$DocNum,
--         DocCount = val_DocCount1$,
--         iDate = new$iDate,
--         DOCDATE = new$DOCDATE,
--         Debit = 0,
--         Credit = -new$Credit,
--         DocType = val_DocType1$,
--         Org_Ref = val_Org_Ref1$,
--         AccountIndex = val_AccountIndex1$,
--         KD = idKD1$,
--         SubKD = val_SubKD1$,
--         RegionCLS = val_RegionCLS1$,
--         GosNI = val_GosNI1$,
--         ProgIndex = 43,
--         RecordIndex = new$Id,
--         IncAccount = val_IncAccount1$,
--         BudgetRef = val_BudgetRef1$,
--         Note = new$Note,
--         MEANSTYPE = val_MEANSTYPE1$,
--         FACIALACC_CLS = val_FACIALACC_CLS1$,
--         TransfertCls = val_TransfertCls1$,
--         RVersion = -1
--         where
--         (ProgIndex=43)and
--         (RecordIndex=:old.id);
--          
--       END IF; 
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ProgIndex = 41)    /*   () */
--   then 
--     /*    */
--     GetVarCharConst(3,0,unkKD$);
--     /*     */
--     GetVarCharConst(3,11,unkVKD$);  
--     /*       */
--     FOR REC$1 IN (SELECT inc.id
--      AS val_ID42    FROM Incomes32 inc
--     LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
--     WHERE (inc.ProgIndex =  42) and
--     (inc.RecordIndex =  new$id) and
--     (inc.debit = 0) and
--     (not(kd.kdvalue like unkKD$)) and
--     (not(kd.kdvalue like unkVKD$))
--     )
--     LOOP
--       BEGIN
--         /*       */
--         select inc.id
--         into val_ID431$         FROM Incomes32 inc
--         WHERE (inc.ProgIndex =  43) and
--         (inc.RecordIndex =  REC$1.val_ID42)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
-- 
--       /*     ,   Credit, ProgIndex, RecordIndex */
--       update Incomes32
--       set
--       DocNum = new$DocNum,
--       DocCount = new$DocCount,       
--       DOCDATE = new$DOCDATE,
--       Debit = 0,
--       DocType = new$DocType,
--       Org_Ref = new$Org_Ref,
--       AccountIndex = new$AccountIndex,
--       KD = new$Kd,
--       SubKD = new$SubKD,
--       RegionCLS = new$RegionCLS,
--       GosNI = new$GosNI,
--       IncAccount = new$IncAccount,
--       BudgetRef = new$BudgetRef,
--       Note = new$Note,
--       MEANSTYPE = new$MEANSTYPE,
--       FACIALACC_CLS = new$FACIALACC_CLS,
--       FACT = new$FACT,
--       TransfertCls = new$TransfertCls,
--       DirectionCls = new$DirectionCls,
--       rversion = -1
--       where id = val_ID431$;
-- 
--         
--     END LOOP;
--   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
--       new$ClsType := 1;       --       ClsType
--    ELSIF (new$ClsType IS NULL) THEN
--       new$ClsType := 2;                                --  - 
--    END IF;
-- 
--    IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
--       --  
--       RaiseEXCEPTION ('EX_WRONGBUDCLS');
--    END IF;
-- 
--    IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
--       --  
--       RaiseEXCEPTION ('EX_WRONGBUDCLS');
--    END IF;
-- 
--    IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
--       --   
--       RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
--    END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -
  NULL;
--   IsReject$ := -1;
--   if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
--     IsReject$ := 1;
--   elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
--     IsReject$ := 0;
--   end if;  
--   if (IsReject$ <> -1) then
--     update LinkRecords set
--       IsRejected = IsReject$
--     where
--       (ChildID = :new.ID)
--       or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
--   end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (NEW$ID <> :OLD.ID) THEN
--       INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
--         VALUES (161, :OLD.ID, SYSDATE);
--       DELETE FROM DelRecIndexes
--         WHERE (TableID = 161) AND (RecordId = NEW$ID);
--    END IF;

END;
/
-- ALTER TRIGGER t_Incomes32_bu_20
CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN 
    new$DocBase := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN 
    new$Gosni := 0;
  END IF;
  /* 3 -    */
  IF (new$ProgIndex IS NULL) THEN 
    new$ProgIndex := 3; 
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0; 
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN 
    new$FACIALACC_CLS := 0; 
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN 
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN 
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN 
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN 
    new$AccountIndex := 0; 
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN 
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN 
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN 
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN 
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN 
    new$DirectionCLS := 0;
  END IF;
  IF (new$FinType is null) then 
    new$FinType := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  /*   .        */
  IF (new$IFS_CORR IS NULL) THEN 
    new$Ifs_Corr := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$Ifs := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  BEGIN

    /*     */
    /*   after   ,*/ 
    /*      */
    SELECT ProgIndex, AcceptDate, ReestrNumber
    INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
    WHERE
    (qt.ID = new$RecordIndex)
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*              
           (  , , ) */
  /*   -    () */
  IF (CapProgIndex2$ = 45)
  THEN 
    IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN 
      /*        ,
                     */            
      new$FederalFundsRef := new$ID;
      /* if-then*/
    ELSE 
      new$FederalFundsRef := NULL;
      /* if-else*/  
    END IF;/* if (CapProgIndex=45) */
  END IF;
  /*     */
  IF (new$BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
      IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
        RaiseException('Ex_CantModufyBudget');
      END IF;
      IF (new$Progindex = 41) THEN
        SELECT COUNT(inc.id ) INTO CNT$1
        FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
        IF ((CNT$1<> 0)) THEN
          RaiseException('Ex_CantModufyBudget');
        END IF;   
      END IF;
    END IF;
  END IF;
  /*     \*/
  IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
  ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
  new$targetcls,new$targetcls);  

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

  BEGIN
    SELECT Inn
     INTO new$Inn
     FROM Organizations o
    WHERE (o.ID = new$Org_Ref);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*      */
  IF (new$ProgIndex <> 42) THEN
    BEGIN
      SELECT ProgIndex, DocNumber, AcceptDate
      INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
      WHERE
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*   -  ,   */
  IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
  THEN 
    IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
    (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
    THEN 
      BEGIN
        SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
        WHERE inc.id = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (Kd_Master$ = new$Kd) THEN 
        CapAcceptDate$ := new$DOCDATE;
        CapProgIndex$  := new$ProgIndex;
        CapDocNumber$  := new$DocNum;
        /*  */        
      END IF;/*       (         )*/
    END IF;
    IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
    THEN 

      /*      */
      /* /      Incomes32, ..      ,     */

      /*     /   */
      SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
      INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
      ;
      /*            ,  .*/
      /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
                      ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
                     ) THEN
                    EXCEPTION EX_CANNOTUPDATENUMBER;*/
                 
                
      IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
      then
        if ((new$DocType <> :old.DocType )
        or (new$Debit <> :old.Debit )
        or (new$Credit <> :old.Credit)
        or (new$org_ref <> :old.org_ref)
        or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
        or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
        )
        then
          RaiseException('EX_CANNOTUPDATENUMBER');
        END IF;
      END IF;
                


      /*           */
      IF (PayDocCount$ = 0)
      THEN 
        /*       */
        GetIntConst(11, 2,ConstPayQueue$);
        /*       */
        GetIntConst(11, 1,ConstSendBy$);

        /*    */
        INSERT INTO PayDoc32
        (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
        Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
        VALUES
        (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
        new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
        /* (new.Debit - new.Credit) --- ..      ,    ,
                                     */

        /* if-then */
      ELSE 
        /*     */
        IF (((new$AccountRef = :old.AccountRef) OR
        ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
        AND (new$IncAccount = :old.IncAccount)
        AND (new$BudgetRef = :old.BudgetRef)
        AND ((new$Note = :old.Note) OR
        ((new$Note IS NULL) AND (:old.Note IS NULL)))
        AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
        ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
        AND ((new$TaxNote = :old.TaxNote) OR
        ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
        )  THEN
          new$AccountRef := new$AccountRef;
                          
        ELSE

          UPDATE PayDoc32 pd
          SET
          pd.AccountRef = new$AccountRef,
          pd.PayerAttrRef = new$IncAccount,
          pd.AcceptorAttrRef = new$AccountRef,
          pd.TextNote = new$Note,
          pd.TaxNote = new$TaxNote,
          pd.BudgetRef = new$BudgetRef,
          pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
          pd.InputDate = CapAcceptDate$,
          pd.SourceDocNumber = CapDocNumber$,
          pd.FACIALACC_CLS = new$FACIALACC_CLS
          WHERE
          (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
        END IF;
        IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
        OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
        THEN  
          IF (Divided$ > 0)
          THEN
            /*  ,      */
            RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
          ELSE
            UPDATE PayDoc32 pd
            SET
            pd.Credit = new$Debit - new$Credit
            WHERE
            (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
          END IF;/* if-then*/            
        END IF;/* if-else*/
      END IF;
      /*     / */
      /*   :     ,     */
      /*  ,     */
      SELECT MAX(pd.AcceptDate)
      INTO Date_Pd$           FROM PayDoc32 pd
      WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
      ;
      new$Idate := Date_Pd$;
      /* if-then*/
    ELSE 
      /*       
                          -
                    . */
      DELETE FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex = new$ProgIndex)
      AND (pd.RecordIndex = new$id);
      /* if-else*/  
    END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then 
    BEGIN
      select q.BuildDate 
      into 
      new$DocDate        from QuotesTitle q 
      where q.id = new$RecordIndex 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
            */
         new$FederalFundsRef := new$ID;
      ELSE
         new$FederalFundsRef := NULL;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ProgIndex = 42)
--   then 
--     /*    */
--     GetVarCharConst(3,0,unkKD$);
--     /*     */
--     GetVarCharConst(3,11,unkVKD$);  
--     BEGIN
-- 
--       select KDValue   into newKD$ from kd where Id=new$kd
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     BEGIN
--       select KDValue   into oldKD$ from kd where Id=:old.kd
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     BEGIN
-- 
--       /*     */
--       select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
--       IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
--       into
--       idKD1$,
--       val_DocCount1$,
--       val_DocType1$,
--       val_Org_Ref1$,
--       val_AccountIndex1$,
--       val_SubKD1$,
--       val_RegionCLS1$,
--       val_GosNI1$,
--       val_IncAccount1$,
--       val_BudgetRef1$,
--       val_MEANSTYPE1$  , 
--       val_FACIALACC_CLS1$,
--       val_TransfertCls1$         from incomes32 where id=new$RecordIndex
--       ;
--     EXCEPTION
--       WHEN NO_DATA_FOUND THEN NULL;
--     END;
--     if (not idKD1$ is null) then
--       if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
--       (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
--         /*   ,    */
--         delete
--         from Incomes32
--         where
--         (ProgIndex=43)and
--         (RecordIndex=:old.id);
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
--       (new$Debit<>0))
--       /*       */
--       then 
--         RaiseException('ex_UnknownRedirect');
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
--       ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
--         /*   ,   ,   */
--         insert into
--         Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
--         Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
--         RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
--         Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
--         val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
--         val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
--         new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
--       END IF;
--       if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
--       and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
--         /*      ,   */
--         update Incomes32
--         set
--         DocNum = new$DocNum,
--         DocCount = val_DocCount1$,
--         iDate = new$iDate,
--         DOCDATE = new$DOCDATE,
--         Debit = 0,
--         Credit = -new$Credit,
--         DocType = val_DocType1$,
--         Org_Ref = val_Org_Ref1$,
--         AccountIndex = val_AccountIndex1$,
--         KD = idKD1$,
--         SubKD = val_SubKD1$,
--         RegionCLS = val_RegionCLS1$,
--         GosNI = val_GosNI1$,
--         ProgIndex = 43,
--         RecordIndex = new$Id,
--         IncAccount = val_IncAccount1$,
--         BudgetRef = val_BudgetRef1$,
--         Note = new$Note,
--         MEANSTYPE = val_MEANSTYPE1$,
--         FACIALACC_CLS = val_FACIALACC_CLS1$,
--         TransfertCls = val_TransfertCls1$,
--         RVersion = -1
--         where
--         (ProgIndex=43)and
--         (RecordIndex=:old.id);
--          
--       END IF; 
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ProgIndex = 41)    /*   () */
--   then 
--     /*    */
--     GetVarCharConst(3,0,unkKD$);
--     /*     */
--     GetVarCharConst(3,11,unkVKD$);  
--     /*       */
--     FOR REC$1 IN (SELECT inc.id
--      AS val_ID42    FROM Incomes32 inc
--     LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
--     WHERE (inc.ProgIndex =  42) and
--     (inc.RecordIndex =  new$id) and
--     (inc.debit = 0) and
--     (not(kd.kdvalue like unkKD$)) and
--     (not(kd.kdvalue like unkVKD$))
--     )
--     LOOP
--       BEGIN
--         /*       */
--         select inc.id
--         into val_ID431$         FROM Incomes32 inc
--         WHERE (inc.ProgIndex =  43) and
--         (inc.RecordIndex =  REC$1.val_ID42)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
-- 
--       /*     ,   Credit, ProgIndex, RecordIndex */
--       update Incomes32
--       set
--       DocNum = new$DocNum,
--       DocCount = new$DocCount,       
--       DOCDATE = new$DOCDATE,
--       Debit = 0,
--       DocType = new$DocType,
--       Org_Ref = new$Org_Ref,
--       AccountIndex = new$AccountIndex,
--       KD = new$Kd,
--       SubKD = new$SubKD,
--       RegionCLS = new$RegionCLS,
--       GosNI = new$GosNI,
--       IncAccount = new$IncAccount,
--       BudgetRef = new$BudgetRef,
--       Note = new$Note,
--       MEANSTYPE = new$MEANSTYPE,
--       FACIALACC_CLS = new$FACIALACC_CLS,
--       FACT = new$FACT,
--       TransfertCls = new$TransfertCls,
--       DirectionCls = new$DirectionCls,
--       rversion = -1
--       where id = val_ID431$;
-- 
--         
--     END LOOP;
--   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
--       new$ClsType := 1;       --       ClsType
--    ELSIF (new$ClsType IS NULL) THEN
--       new$ClsType := 2;                                --  - 
--    END IF;
-- 
--    IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
--       --  
--       RaiseEXCEPTION ('EX_WRONGBUDCLS');
--    END IF;
-- 
--    IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
--       --  
--       RaiseEXCEPTION ('EX_WRONGBUDCLS');
--    END IF;
-- 
--    IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
--       --   
--       RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
--    END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -
  NULL;
--   IsReject$ := -1;
--   if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
--     IsReject$ := 1;
--   elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
--     IsReject$ := 0;
--   end if;  
--   if (IsReject$ <> -1) then
--     update LinkRecords set
--       IsRejected = IsReject$
--     where
--       (ChildID = :new.ID)
--       or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
--   end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (NEW$ID <> :OLD.ID) THEN
--       INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
--         VALUES (161, :OLD.ID, SYSDATE);
--       DELETE FROM DelRecIndexes
--         WHERE (TableID = 161) AND (RecordId = NEW$ID);
--    END IF;

END;
/
-- ALTER TRIGGER tr_Incomes32_bu_100
CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN 
    new$DocBase := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN 
    new$Gosni := 0;
  END IF;
  /* 3 -    */
  IF (new$ProgIndex IS NULL) THEN 
    new$ProgIndex := 3; 
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0; 
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN 
    new$FACIALACC_CLS := 0; 
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN 
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN 
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN 
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN 
    new$AccountIndex := 0; 
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN 
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN 
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN 
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN 
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN 
    new$DirectionCLS := 0;
  END IF;
  IF (new$FinType is null) then 
    new$FinType := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  /*   .        */
  IF (new$IFS_CORR IS NULL) THEN 
    new$Ifs_Corr := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$Ifs := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  BEGIN

    /*     */
    /*   after   ,*/ 
    /*      */
    SELECT ProgIndex, AcceptDate, ReestrNumber
    INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
    WHERE
    (qt.ID = new$RecordIndex)
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*              
           (  , , ) */
  /*   -    () */
  IF (CapProgIndex2$ = 45)
  THEN 
    IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN 
      /*        ,
                     */            
      new$FederalFundsRef := new$ID;
      /* if-then*/
    ELSE 
      new$FederalFundsRef := NULL;
      /* if-else*/  
    END IF;/* if (CapProgIndex=45) */
  END IF;
  /*     */
  IF (new$BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
      IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
        RaiseException('Ex_CantModufyBudget');
      END IF;
      IF (new$Progindex = 41) THEN
        SELECT COUNT(inc.id ) INTO CNT$1
        FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
        IF ((CNT$1<> 0)) THEN
          RaiseException('Ex_CantModufyBudget');
        END IF;   
      END IF;
    END IF;
  END IF;
  /*     \*/
  IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
  ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
  new$targetcls,new$targetcls);  

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

  BEGIN
    SELECT Inn
     INTO new$Inn
     FROM Organizations o
    WHERE (o.ID = new$Org_Ref);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*      */
  IF (new$ProgIndex <> 42) THEN
    BEGIN
      SELECT ProgIndex, DocNumber, AcceptDate
      INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
      WHERE
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*   -  ,   */
  IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
  THEN 
    IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
    (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
    THEN 
      BEGIN
        SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
        WHERE inc.id = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (Kd_Master$ = new$Kd) THEN 
        CapAcceptDate$ := new$DOCDATE;
        CapProgIndex$  := new$ProgIndex;
        CapDocNumber$  := new$DocNum;
        /*  */        
      END IF;/*       (         )*/
    END IF;
    IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
    THEN 

      /*      */
      /* /      Incomes32, ..      ,     */

      /*     /   */
      SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
      INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
      ;
      /*            ,  .*/
      /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
                      ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
                     ) THEN
                    EXCEPTION EX_CANNOTUPDATENUMBER;*/
                 
                
      IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
      then
        if ((new$DocType <> :old.DocType )
        or (new$Debit <> :old.Debit )
        or (new$Credit <> :old.Credit)
        or (new$org_ref <> :old.org_ref)
        or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
        or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
        )
        then
          RaiseException('EX_CANNOTUPDATENUMBER');
        END IF;
      END IF;
                


      /*           */
      IF (PayDocCount$ = 0)
      THEN 
        /*       */
        GetIntConst(11, 2,ConstPayQueue$);
        /*       */
        GetIntConst(11, 1,ConstSendBy$);

        /*    */
        INSERT INTO PayDoc32
        (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
        Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
        VALUES
        (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
        new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
        /* (new.Debit - new.Credit) --- ..      ,    ,
                                     */

        /* if-then */
      ELSE 
        /*     */
        IF (((new$AccountRef = :old.AccountRef) OR
        ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
        AND (new$IncAccount = :old.IncAccount)
        AND (new$BudgetRef = :old.BudgetRef)
        AND ((new$Note = :old.Note) OR
        ((new$Note IS NULL) AND (:old.Note IS NULL)))
        AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
        ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
        AND ((new$TaxNote = :old.TaxNote) OR
        ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
        )  THEN
          new$AccountRef := new$AccountRef;
                          
        ELSE

          UPDATE PayDoc32 pd
          SET
          pd.AccountRef = new$AccountRef,
          pd.PayerAttrRef = new$IncAccount,
          pd.AcceptorAttrRef = new$AccountRef,
          pd.TextNote = new$Note,
          pd.TaxNote = new$TaxNote,
          pd.BudgetRef = new$BudgetRef,
          pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
          pd.InputDate = CapAcceptDate$,
          pd.SourceDocNumber = CapDocNumber$,
          pd.FACIALACC_CLS = new$FACIALACC_CLS
          WHERE
          (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
        END IF;
        IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
        OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
        THEN  
          IF (Divided$ > 0)
          THEN
            /*  ,      */
            RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
          ELSE
            UPDATE PayDoc32 pd
            SET
            pd.Credit = new$Debit - new$Credit
            WHERE
            (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
          END IF;/* if-then*/            
        END IF;/* if-else*/
      END IF;
      /*     / */
      /*   :     ,     */
      /*  ,     */
      SELECT MAX(pd.AcceptDate)
      INTO Date_Pd$           FROM PayDoc32 pd
      WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
      ;
      new$Idate := Date_Pd$;
      /* if-then*/
    ELSE 
      /*       
                          -
                    . */
      DELETE FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex = new$ProgIndex)
      AND (pd.RecordIndex = new$id);
      /* if-else*/  
    END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then 
    BEGIN
      select q.BuildDate 
      into 
      new$DocDate        from QuotesTitle q 
      where q.id = new$RecordIndex 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
            */
         new$FederalFundsRef := new$ID;
      ELSE
         new$FederalFundsRef := NULL;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN
      select KDValue   into oldKD$ from kd where Id=:old.kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN

      /*     */
      select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
      IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
      into
      idKD1$,
      val_DocCount1$,
      val_DocType1$,
      val_Org_Ref1$,
      val_AccountIndex1$,
      val_SubKD1$,
      val_RegionCLS1$,
      val_GosNI1$,
      val_IncAccount1$,
      val_BudgetRef1$,
      val_MEANSTYPE1$  , 
      val_FACIALACC_CLS1$,
      val_TransfertCls1$         from incomes32 where id=new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not idKD1$ is null) then
      if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
      (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
        /*   ,    */
        delete
        from Incomes32
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      (new$Debit<>0))
      /*       */
      then 
        RaiseException('ex_UnknownRedirect');
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
        /*   ,   ,   */
        insert into
        Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
        Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
        val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
        val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
        new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
      END IF;
      if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
      and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
        /*      ,   */
        update Incomes32
        set
        DocNum = new$DocNum,
        DocCount = val_DocCount1$,
        iDate = new$iDate,
        DOCDATE = new$DOCDATE,
        Debit = 0,
        Credit = -new$Credit,
        DocType = val_DocType1$,
        Org_Ref = val_Org_Ref1$,
        AccountIndex = val_AccountIndex1$,
        KD = idKD1$,
        SubKD = val_SubKD1$,
        RegionCLS = val_RegionCLS1$,
        GosNI = val_GosNI1$,
        ProgIndex = 43,
        RecordIndex = new$Id,
        IncAccount = val_IncAccount1$,
        BudgetRef = val_BudgetRef1$,
        Note = new$Note,
        MEANSTYPE = val_MEANSTYPE1$,
        FACIALACC_CLS = val_FACIALACC_CLS1$,
        TransfertCls = val_TransfertCls1$,
        RVersion = -1
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
         
      END IF; 
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ProgIndex = 41)    /*   () */
--   then 
--     /*    */
--     GetVarCharConst(3,0,unkKD$);
--     /*     */
--     GetVarCharConst(3,11,unkVKD$);  
--     /*       */
--     FOR REC$1 IN (SELECT inc.id
--      AS val_ID42    FROM Incomes32 inc
--     LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
--     WHERE (inc.ProgIndex =  42) and
--     (inc.RecordIndex =  new$id) and
--     (inc.debit = 0) and
--     (not(kd.kdvalue like unkKD$)) and
--     (not(kd.kdvalue like unkVKD$))
--     )
--     LOOP
--       BEGIN
--         /*       */
--         select inc.id
--         into val_ID431$         FROM Incomes32 inc
--         WHERE (inc.ProgIndex =  43) and
--         (inc.RecordIndex =  REC$1.val_ID42)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
-- 
--       /*     ,   Credit, ProgIndex, RecordIndex */
--       update Incomes32
--       set
--       DocNum = new$DocNum,
--       DocCount = new$DocCount,       
--       DOCDATE = new$DOCDATE,
--       Debit = 0,
--       DocType = new$DocType,
--       Org_Ref = new$Org_Ref,
--       AccountIndex = new$AccountIndex,
--       KD = new$Kd,
--       SubKD = new$SubKD,
--       RegionCLS = new$RegionCLS,
--       GosNI = new$GosNI,
--       IncAccount = new$IncAccount,
--       BudgetRef = new$BudgetRef,
--       Note = new$Note,
--       MEANSTYPE = new$MEANSTYPE,
--       FACIALACC_CLS = new$FACIALACC_CLS,
--       FACT = new$FACT,
--       TransfertCls = new$TransfertCls,
--       DirectionCls = new$DirectionCls,
--       rversion = -1
--       where id = val_ID431$;
-- 
--         
--     END LOOP;
--   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -
  NULL;
--    IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
--       new$ClsType := 1;       --       ClsType
--    ELSIF (new$ClsType IS NULL) THEN
--       new$ClsType := 2;                                --  - 
--    END IF;
-- 
--    IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
--       --  
--       RaiseEXCEPTION ('EX_WRONGBUDCLS');
--    END IF;
-- 
--    IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
--       --  
--       RaiseEXCEPTION ('EX_WRONGBUDCLS');
--    END IF;
-- 
--    IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
--       --   
--       RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
--    END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -
  NULL;
--   IsReject$ := -1;
--   if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
--     IsReject$ := 1;
--   elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
--     IsReject$ := 0;
--   end if;  
--   if (IsReject$ <> -1) then
--     update LinkRecords set
--       IsRejected = IsReject$
--     where
--       (ChildID = :new.ID)
--       or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
--   end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (NEW$ID <> :OLD.ID) THEN
--       INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
--         VALUES (161, :OLD.ID, SYSDATE);
--       DELETE FROM DelRecIndexes
--         WHERE (TableID = 161) AND (RecordId = NEW$ID);
--    END IF;

END;
/
-- ALTER TRIGGER TR_INCOMES32_BU_110
CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN 
    new$DocBase := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN 
    new$Gosni := 0;
  END IF;
  /* 3 -    */
  IF (new$ProgIndex IS NULL) THEN 
    new$ProgIndex := 3; 
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0; 
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN 
    new$FACIALACC_CLS := 0; 
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN 
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN 
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN 
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN 
    new$AccountIndex := 0; 
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN 
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN 
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN 
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN 
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN 
    new$DirectionCLS := 0;
  END IF;
  IF (new$FinType is null) then 
    new$FinType := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  /*   .        */
  IF (new$IFS_CORR IS NULL) THEN 
    new$Ifs_Corr := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$Ifs := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  BEGIN

    /*     */
    /*   after   ,*/ 
    /*      */
    SELECT ProgIndex, AcceptDate, ReestrNumber
    INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
    WHERE
    (qt.ID = new$RecordIndex)
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*              
           (  , , ) */
  /*   -    () */
  IF (CapProgIndex2$ = 45)
  THEN 
    IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN 
      /*        ,
                     */            
      new$FederalFundsRef := new$ID;
      /* if-then*/
    ELSE 
      new$FederalFundsRef := NULL;
      /* if-else*/  
    END IF;/* if (CapProgIndex=45) */
  END IF;
  /*     */
  IF (new$BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
      IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
        RaiseException('Ex_CantModufyBudget');
      END IF;
      IF (new$Progindex = 41) THEN
        SELECT COUNT(inc.id ) INTO CNT$1
        FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
        IF ((CNT$1<> 0)) THEN
          RaiseException('Ex_CantModufyBudget');
        END IF;   
      END IF;
    END IF;
  END IF;
  /*     \*/
  IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
  ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
  new$targetcls,new$targetcls);  

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

  BEGIN
    SELECT Inn
     INTO new$Inn
     FROM Organizations o
    WHERE (o.ID = new$Org_Ref);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*      */
  IF (new$ProgIndex <> 42) THEN
    BEGIN
      SELECT ProgIndex, DocNumber, AcceptDate
      INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
      WHERE
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*   -  ,   */
  IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
  THEN 
    IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
    (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
    THEN 
      BEGIN
        SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
        WHERE inc.id = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (Kd_Master$ = new$Kd) THEN 
        CapAcceptDate$ := new$DOCDATE;
        CapProgIndex$  := new$ProgIndex;
        CapDocNumber$  := new$DocNum;
        /*  */        
      END IF;/*       (         )*/
    END IF;
    IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
    THEN 

      /*      */
      /* /      Incomes32, ..      ,     */

      /*     /   */
      SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
      INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
      ;
      /*            ,  .*/
      /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
                      ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
                     ) THEN
                    EXCEPTION EX_CANNOTUPDATENUMBER;*/
                 
                
      IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
      then
        if ((new$DocType <> :old.DocType )
        or (new$Debit <> :old.Debit )
        or (new$Credit <> :old.Credit)
        or (new$org_ref <> :old.org_ref)
        or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
        or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
        )
        then
          RaiseException('EX_CANNOTUPDATENUMBER');
        END IF;
      END IF;
                


      /*           */
      IF (PayDocCount$ = 0)
      THEN 
        /*       */
        GetIntConst(11, 2,ConstPayQueue$);
        /*       */
        GetIntConst(11, 1,ConstSendBy$);

        /*    */
        INSERT INTO PayDoc32
        (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
        Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
        VALUES
        (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
        new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
        /* (new.Debit - new.Credit) --- ..      ,    ,
                                     */

        /* if-then */
      ELSE 
        /*     */
        IF (((new$AccountRef = :old.AccountRef) OR
        ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
        AND (new$IncAccount = :old.IncAccount)
        AND (new$BudgetRef = :old.BudgetRef)
        AND ((new$Note = :old.Note) OR
        ((new$Note IS NULL) AND (:old.Note IS NULL)))
        AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
        ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
        AND ((new$TaxNote = :old.TaxNote) OR
        ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
        )  THEN
          new$AccountRef := new$AccountRef;
                          
        ELSE

          UPDATE PayDoc32 pd
          SET
          pd.AccountRef = new$AccountRef,
          pd.PayerAttrRef = new$IncAccount,
          pd.AcceptorAttrRef = new$AccountRef,
          pd.TextNote = new$Note,
          pd.TaxNote = new$TaxNote,
          pd.BudgetRef = new$BudgetRef,
          pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
          pd.InputDate = CapAcceptDate$,
          pd.SourceDocNumber = CapDocNumber$,
          pd.FACIALACC_CLS = new$FACIALACC_CLS
          WHERE
          (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
        END IF;
        IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
        OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
        THEN  
          IF (Divided$ > 0)
          THEN
            /*  ,      */
            RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
          ELSE
            UPDATE PayDoc32 pd
            SET
            pd.Credit = new$Debit - new$Credit
            WHERE
            (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
          END IF;/* if-then*/            
        END IF;/* if-else*/
      END IF;
      /*     / */
      /*   :     ,     */
      /*  ,     */
      SELECT MAX(pd.AcceptDate)
      INTO Date_Pd$           FROM PayDoc32 pd
      WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
      ;
      new$Idate := Date_Pd$;
      /* if-then*/
    ELSE 
      /*       
                          -
                    . */
      DELETE FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex = new$ProgIndex)
      AND (pd.RecordIndex = new$id);
      /* if-else*/  
    END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then 
    BEGIN
      select q.BuildDate 
      into 
      new$DocDate        from QuotesTitle q 
      where q.id = new$RecordIndex 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
            */
         new$FederalFundsRef := new$ID;
      ELSE
         new$FederalFundsRef := NULL;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN
      select KDValue   into oldKD$ from kd where Id=:old.kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN

      /*     */
      select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
      IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
      into
      idKD1$,
      val_DocCount1$,
      val_DocType1$,
      val_Org_Ref1$,
      val_AccountIndex1$,
      val_SubKD1$,
      val_RegionCLS1$,
      val_GosNI1$,
      val_IncAccount1$,
      val_BudgetRef1$,
      val_MEANSTYPE1$  , 
      val_FACIALACC_CLS1$,
      val_TransfertCls1$         from incomes32 where id=new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not idKD1$ is null) then
      if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
      (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
        /*   ,    */
        delete
        from Incomes32
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      (new$Debit<>0))
      /*       */
      then 
        RaiseException('ex_UnknownRedirect');
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
        /*   ,   ,   */
        insert into
        Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
        Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
        val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
        val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
        new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
      END IF;
      if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
      and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
        /*      ,   */
        update Incomes32
        set
        DocNum = new$DocNum,
        DocCount = val_DocCount1$,
        iDate = new$iDate,
        DOCDATE = new$DOCDATE,
        Debit = 0,
        Credit = -new$Credit,
        DocType = val_DocType1$,
        Org_Ref = val_Org_Ref1$,
        AccountIndex = val_AccountIndex1$,
        KD = idKD1$,
        SubKD = val_SubKD1$,
        RegionCLS = val_RegionCLS1$,
        GosNI = val_GosNI1$,
        ProgIndex = 43,
        RecordIndex = new$Id,
        IncAccount = val_IncAccount1$,
        BudgetRef = val_BudgetRef1$,
        Note = new$Note,
        MEANSTYPE = val_MEANSTYPE1$,
        FACIALACC_CLS = val_FACIALACC_CLS1$,
        TransfertCls = val_TransfertCls1$,
        RVersion = -1
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
         
      END IF; 
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ProgIndex = 41)    /*   () */
--   then 
--     /*    */
--     GetVarCharConst(3,0,unkKD$);
--     /*     */
--     GetVarCharConst(3,11,unkVKD$);  
--     /*       */
--     FOR REC$1 IN (SELECT inc.id
--      AS val_ID42    FROM Incomes32 inc
--     LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
--     WHERE (inc.ProgIndex =  42) and
--     (inc.RecordIndex =  new$id) and
--     (inc.debit = 0) and
--     (not(kd.kdvalue like unkKD$)) and
--     (not(kd.kdvalue like unkVKD$))
--     )
--     LOOP
--       BEGIN
--         /*       */
--         select inc.id
--         into val_ID431$         FROM Incomes32 inc
--         WHERE (inc.ProgIndex =  43) and
--         (inc.RecordIndex =  REC$1.val_ID42)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
-- 
--       /*     ,   Credit, ProgIndex, RecordIndex */
--       update Incomes32
--       set
--       DocNum = new$DocNum,
--       DocCount = new$DocCount,       
--       DOCDATE = new$DOCDATE,
--       Debit = 0,
--       DocType = new$DocType,
--       Org_Ref = new$Org_Ref,
--       AccountIndex = new$AccountIndex,
--       KD = new$Kd,
--       SubKD = new$SubKD,
--       RegionCLS = new$RegionCLS,
--       GosNI = new$GosNI,
--       IncAccount = new$IncAccount,
--       BudgetRef = new$BudgetRef,
--       Note = new$Note,
--       MEANSTYPE = new$MEANSTYPE,
--       FACIALACC_CLS = new$FACIALACC_CLS,
--       FACT = new$FACT,
--       TransfertCls = new$TransfertCls,
--       DirectionCls = new$DirectionCls,
--       rversion = -1
--       where id = val_ID431$;
-- 
--         
--     END LOOP;
--   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       --       ClsType
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                --  - 
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      --   
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -
  NULL;
--   IsReject$ := -1;
--   if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
--     IsReject$ := 1;
--   elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
--     IsReject$ := 0;
--   end if;  
--   if (IsReject$ <> -1) then
--     update LinkRecords set
--       IsRejected = IsReject$
--     where
--       (ChildID = :new.ID)
--       or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
--   end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -
  NULL;
--    IF (NEW$ID <> :OLD.ID) THEN
--       INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
--         VALUES (161, :OLD.ID, SYSDATE);
--       DELETE FROM DelRecIndexes
--         WHERE (TableID = 161) AND (RecordId = NEW$ID);
--    END IF;

END;
/
-- ALTER TRIGGER tr_Incomes32_au_500
CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN 
    new$DocBase := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN 
    new$Gosni := 0;
  END IF;
  /* 3 -    */
  IF (new$ProgIndex IS NULL) THEN 
    new$ProgIndex := 3; 
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0; 
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN 
    new$FACIALACC_CLS := 0; 
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN 
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN 
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN 
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN 
    new$AccountIndex := 0; 
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN 
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN 
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN 
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN 
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN 
    new$DirectionCLS := 0;
  END IF;
  IF (new$FinType is null) then 
    new$FinType := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  /*   .        */
  IF (new$IFS_CORR IS NULL) THEN 
    new$Ifs_Corr := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$Ifs := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  BEGIN

    /*     */
    /*   after   ,*/ 
    /*      */
    SELECT ProgIndex, AcceptDate, ReestrNumber
    INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
    WHERE
    (qt.ID = new$RecordIndex)
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*              
           (  , , ) */
  /*   -    () */
  IF (CapProgIndex2$ = 45)
  THEN 
    IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN 
      /*        ,
                     */            
      new$FederalFundsRef := new$ID;
      /* if-then*/
    ELSE 
      new$FederalFundsRef := NULL;
      /* if-else*/  
    END IF;/* if (CapProgIndex=45) */
  END IF;
  /*     */
  IF (new$BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
      IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
        RaiseException('Ex_CantModufyBudget');
      END IF;
      IF (new$Progindex = 41) THEN
        SELECT COUNT(inc.id ) INTO CNT$1
        FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
        IF ((CNT$1<> 0)) THEN
          RaiseException('Ex_CantModufyBudget');
        END IF;   
      END IF;
    END IF;
  END IF;
  /*     \*/
  IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
  ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
  new$targetcls,new$targetcls);  

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

  BEGIN
    SELECT Inn
     INTO new$Inn
     FROM Organizations o
    WHERE (o.ID = new$Org_Ref);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*      */
  IF (new$ProgIndex <> 42) THEN
    BEGIN
      SELECT ProgIndex, DocNumber, AcceptDate
      INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
      WHERE
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*   -  ,   */
  IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
  THEN 
    IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
    (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
    THEN 
      BEGIN
        SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
        WHERE inc.id = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (Kd_Master$ = new$Kd) THEN 
        CapAcceptDate$ := new$DOCDATE;
        CapProgIndex$  := new$ProgIndex;
        CapDocNumber$  := new$DocNum;
        /*  */        
      END IF;/*       (         )*/
    END IF;
    IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
    THEN 

      /*      */
      /* /      Incomes32, ..      ,     */

      /*     /   */
      SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
      INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
      ;
      /*            ,  .*/
      /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
                      ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
                     ) THEN
                    EXCEPTION EX_CANNOTUPDATENUMBER;*/
                 
                
      IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
      then
        if ((new$DocType <> :old.DocType )
        or (new$Debit <> :old.Debit )
        or (new$Credit <> :old.Credit)
        or (new$org_ref <> :old.org_ref)
        or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
        or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
        )
        then
          RaiseException('EX_CANNOTUPDATENUMBER');
        END IF;
      END IF;
                


      /*           */
      IF (PayDocCount$ = 0)
      THEN 
        /*       */
        GetIntConst(11, 2,ConstPayQueue$);
        /*       */
        GetIntConst(11, 1,ConstSendBy$);

        /*    */
        INSERT INTO PayDoc32
        (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
        Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
        VALUES
        (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
        new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
        /* (new.Debit - new.Credit) --- ..      ,    ,
                                     */

        /* if-then */
      ELSE 
        /*     */
        IF (((new$AccountRef = :old.AccountRef) OR
        ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
        AND (new$IncAccount = :old.IncAccount)
        AND (new$BudgetRef = :old.BudgetRef)
        AND ((new$Note = :old.Note) OR
        ((new$Note IS NULL) AND (:old.Note IS NULL)))
        AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
        ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
        AND ((new$TaxNote = :old.TaxNote) OR
        ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
        )  THEN
          new$AccountRef := new$AccountRef;
                          
        ELSE

          UPDATE PayDoc32 pd
          SET
          pd.AccountRef = new$AccountRef,
          pd.PayerAttrRef = new$IncAccount,
          pd.AcceptorAttrRef = new$AccountRef,
          pd.TextNote = new$Note,
          pd.TaxNote = new$TaxNote,
          pd.BudgetRef = new$BudgetRef,
          pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
          pd.InputDate = CapAcceptDate$,
          pd.SourceDocNumber = CapDocNumber$,
          pd.FACIALACC_CLS = new$FACIALACC_CLS
          WHERE
          (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
        END IF;
        IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
        OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
        THEN  
          IF (Divided$ > 0)
          THEN
            /*  ,      */
            RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
          ELSE
            UPDATE PayDoc32 pd
            SET
            pd.Credit = new$Debit - new$Credit
            WHERE
            (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
          END IF;/* if-then*/            
        END IF;/* if-else*/
      END IF;
      /*     / */
      /*   :     ,     */
      /*  ,     */
      SELECT MAX(pd.AcceptDate)
      INTO Date_Pd$           FROM PayDoc32 pd
      WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
      ;
      new$Idate := Date_Pd$;
      /* if-then*/
    ELSE 
      /*       
                          -
                    . */
      DELETE FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex = new$ProgIndex)
      AND (pd.RecordIndex = new$id);
      /* if-else*/  
    END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then 
    BEGIN
      select q.BuildDate 
      into 
      new$DocDate        from QuotesTitle q 
      where q.id = new$RecordIndex 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
            */
         new$FederalFundsRef := new$ID;
      ELSE
         new$FederalFundsRef := NULL;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN
      select KDValue   into oldKD$ from kd where Id=:old.kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN

      /*     */
      select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
      IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
      into
      idKD1$,
      val_DocCount1$,
      val_DocType1$,
      val_Org_Ref1$,
      val_AccountIndex1$,
      val_SubKD1$,
      val_RegionCLS1$,
      val_GosNI1$,
      val_IncAccount1$,
      val_BudgetRef1$,
      val_MEANSTYPE1$  , 
      val_FACIALACC_CLS1$,
      val_TransfertCls1$         from incomes32 where id=new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not idKD1$ is null) then
      if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
      (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
        /*   ,    */
        delete
        from Incomes32
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      (new$Debit<>0))
      /*       */
      then 
        RaiseException('ex_UnknownRedirect');
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
        /*   ,   ,   */
        insert into
        Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
        Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
        val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
        val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
        new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
      END IF;
      if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
      and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
        /*      ,   */
        update Incomes32
        set
        DocNum = new$DocNum,
        DocCount = val_DocCount1$,
        iDate = new$iDate,
        DOCDATE = new$DOCDATE,
        Debit = 0,
        Credit = -new$Credit,
        DocType = val_DocType1$,
        Org_Ref = val_Org_Ref1$,
        AccountIndex = val_AccountIndex1$,
        KD = idKD1$,
        SubKD = val_SubKD1$,
        RegionCLS = val_RegionCLS1$,
        GosNI = val_GosNI1$,
        ProgIndex = 43,
        RecordIndex = new$Id,
        IncAccount = val_IncAccount1$,
        BudgetRef = val_BudgetRef1$,
        Note = new$Note,
        MEANSTYPE = val_MEANSTYPE1$,
        FACIALACC_CLS = val_FACIALACC_CLS1$,
        TransfertCls = val_TransfertCls1$,
        RVersion = -1
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
         
      END IF; 
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -
  NULL;
--   if (new$ProgIndex = 41)    /*   () */
--   then 
--     /*    */
--     GetVarCharConst(3,0,unkKD$);
--     /*     */
--     GetVarCharConst(3,11,unkVKD$);  
--     /*       */
--     FOR REC$1 IN (SELECT inc.id
--      AS val_ID42    FROM Incomes32 inc
--     LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
--     WHERE (inc.ProgIndex =  42) and
--     (inc.RecordIndex =  new$id) and
--     (inc.debit = 0) and
--     (not(kd.kdvalue like unkKD$)) and
--     (not(kd.kdvalue like unkVKD$))
--     )
--     LOOP
--       BEGIN
--         /*       */
--         select inc.id
--         into val_ID431$         FROM Incomes32 inc
--         WHERE (inc.ProgIndex =  43) and
--         (inc.RecordIndex =  REC$1.val_ID42)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
-- 
--       /*     ,   Credit, ProgIndex, RecordIndex */
--       update Incomes32
--       set
--       DocNum = new$DocNum,
--       DocCount = new$DocCount,       
--       DOCDATE = new$DOCDATE,
--       Debit = 0,
--       DocType = new$DocType,
--       Org_Ref = new$Org_Ref,
--       AccountIndex = new$AccountIndex,
--       KD = new$Kd,
--       SubKD = new$SubKD,
--       RegionCLS = new$RegionCLS,
--       GosNI = new$GosNI,
--       IncAccount = new$IncAccount,
--       BudgetRef = new$BudgetRef,
--       Note = new$Note,
--       MEANSTYPE = new$MEANSTYPE,
--       FACIALACC_CLS = new$FACIALACC_CLS,
--       FACT = new$FACT,
--       TransfertCls = new$TransfertCls,
--       DirectionCls = new$DirectionCls,
--       rversion = -1
--       where id = val_ID431$;
-- 
--         
--     END LOOP;
--   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       --       ClsType
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                --  - 
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      --   
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -
  NULL;
--   IsReject$ := -1;
--   if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
--     IsReject$ := 1;
--   elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
--     IsReject$ := 0;
--   end if;  
--   if (IsReject$ <> -1) then
--     update LinkRecords set
--       IsRejected = IsReject$
--     where
--       (ChildID = :new.ID)
--       or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
--   end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   IF (NEW$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (161, :OLD.ID, SYSDATE);
      DELETE FROM DelRecIndexes
        WHERE (TableID = 161) AND (RecordId = NEW$ID);
   END IF;

END;
/
-- ALTER TRIGGER TR_INCOMES32_BU_105
CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN 
    new$DocBase := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN 
    new$Gosni := 0;
  END IF;
  /* 3 -    */
  IF (new$ProgIndex IS NULL) THEN 
    new$ProgIndex := 3; 
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0; 
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN 
    new$FACIALACC_CLS := 0; 
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN 
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN 
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN 
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN 
    new$AccountIndex := 0; 
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN 
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN 
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN 
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN 
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN 
    new$DirectionCLS := 0;
  END IF;
  IF (new$FinType is null) then 
    new$FinType := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  /*   .        */
  IF (new$IFS_CORR IS NULL) THEN 
    new$Ifs_Corr := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$Ifs := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  BEGIN

    /*     */
    /*   after   ,*/ 
    /*      */
    SELECT ProgIndex, AcceptDate, ReestrNumber
    INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
    WHERE
    (qt.ID = new$RecordIndex)
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*              
           (  , , ) */
  /*   -    () */
  IF (CapProgIndex2$ = 45)
  THEN 
    IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN 
      /*        ,
                     */            
      new$FederalFundsRef := new$ID;
      /* if-then*/
    ELSE 
      new$FederalFundsRef := NULL;
      /* if-else*/  
    END IF;/* if (CapProgIndex=45) */
  END IF;
  /*     */
  IF (new$BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
      IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
        RaiseException('Ex_CantModufyBudget');
      END IF;
      IF (new$Progindex = 41) THEN
        SELECT COUNT(inc.id ) INTO CNT$1
        FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
        IF ((CNT$1<> 0)) THEN
          RaiseException('Ex_CantModufyBudget');
        END IF;   
      END IF;
    END IF;
  END IF;
  /*     \*/
  IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
  ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
  new$targetcls,new$targetcls);  

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

  BEGIN
    SELECT Inn
     INTO new$Inn
     FROM Organizations o
    WHERE (o.ID = new$Org_Ref);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*      */
  IF (new$ProgIndex <> 42) THEN
    BEGIN
      SELECT ProgIndex, DocNumber, AcceptDate
      INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
      WHERE
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*   -  ,   */
  IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
  THEN 
    IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
    (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
    THEN 
      BEGIN
        SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
        WHERE inc.id = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (Kd_Master$ = new$Kd) THEN 
        CapAcceptDate$ := new$DOCDATE;
        CapProgIndex$  := new$ProgIndex;
        CapDocNumber$  := new$DocNum;
        /*  */        
      END IF;/*       (         )*/
    END IF;
    IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
    THEN 

      /*      */
      /* /      Incomes32, ..      ,     */

      /*     /   */
      SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
      INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
      ;
      /*            ,  .*/
      /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
                      ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
                     ) THEN
                    EXCEPTION EX_CANNOTUPDATENUMBER;*/
                 
                
      IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
      then
        if ((new$DocType <> :old.DocType )
        or (new$Debit <> :old.Debit )
        or (new$Credit <> :old.Credit)
        or (new$org_ref <> :old.org_ref)
        or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
        or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
        )
        then
          RaiseException('EX_CANNOTUPDATENUMBER');
        END IF;
      END IF;
                


      /*           */
      IF (PayDocCount$ = 0)
      THEN 
        /*       */
        GetIntConst(11, 2,ConstPayQueue$);
        /*       */
        GetIntConst(11, 1,ConstSendBy$);

        /*    */
        INSERT INTO PayDoc32
        (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
        Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
        VALUES
        (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
        new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
        /* (new.Debit - new.Credit) --- ..      ,    ,
                                     */

        /* if-then */
      ELSE 
        /*     */
        IF (((new$AccountRef = :old.AccountRef) OR
        ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
        AND (new$IncAccount = :old.IncAccount)
        AND (new$BudgetRef = :old.BudgetRef)
        AND ((new$Note = :old.Note) OR
        ((new$Note IS NULL) AND (:old.Note IS NULL)))
        AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
        ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
        AND ((new$TaxNote = :old.TaxNote) OR
        ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
        )  THEN
          new$AccountRef := new$AccountRef;
                          
        ELSE

          UPDATE PayDoc32 pd
          SET
          pd.AccountRef = new$AccountRef,
          pd.PayerAttrRef = new$IncAccount,
          pd.AcceptorAttrRef = new$AccountRef,
          pd.TextNote = new$Note,
          pd.TaxNote = new$TaxNote,
          pd.BudgetRef = new$BudgetRef,
          pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
          pd.InputDate = CapAcceptDate$,
          pd.SourceDocNumber = CapDocNumber$,
          pd.FACIALACC_CLS = new$FACIALACC_CLS
          WHERE
          (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
        END IF;
        IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
        OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
        THEN  
          IF (Divided$ > 0)
          THEN
            /*  ,      */
            RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
          ELSE
            UPDATE PayDoc32 pd
            SET
            pd.Credit = new$Debit - new$Credit
            WHERE
            (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
          END IF;/* if-then*/            
        END IF;/* if-else*/
      END IF;
      /*     / */
      /*   :     ,     */
      /*  ,     */
      SELECT MAX(pd.AcceptDate)
      INTO Date_Pd$           FROM PayDoc32 pd
      WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
      ;
      new$Idate := Date_Pd$;
      /* if-then*/
    ELSE 
      /*       
                          -
                    . */
      DELETE FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex = new$ProgIndex)
      AND (pd.RecordIndex = new$id);
      /* if-else*/  
    END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then 
    BEGIN
      select q.BuildDate 
      into 
      new$DocDate        from QuotesTitle q 
      where q.id = new$RecordIndex 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
            */
         new$FederalFundsRef := new$ID;
      ELSE
         new$FederalFundsRef := NULL;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN
      select KDValue   into oldKD$ from kd where Id=:old.kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN

      /*     */
      select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
      IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
      into
      idKD1$,
      val_DocCount1$,
      val_DocType1$,
      val_Org_Ref1$,
      val_AccountIndex1$,
      val_SubKD1$,
      val_RegionCLS1$,
      val_GosNI1$,
      val_IncAccount1$,
      val_BudgetRef1$,
      val_MEANSTYPE1$  , 
      val_FACIALACC_CLS1$,
      val_TransfertCls1$         from incomes32 where id=new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not idKD1$ is null) then
      if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
      (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
        /*   ,    */
        delete
        from Incomes32
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      (new$Debit<>0))
      /*       */
      then 
        RaiseException('ex_UnknownRedirect');
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
        /*   ,   ,   */
        insert into
        Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
        Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
        val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
        val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
        new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
      END IF;
      if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
      and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
        /*      ,   */
        update Incomes32
        set
        DocNum = new$DocNum,
        DocCount = val_DocCount1$,
        iDate = new$iDate,
        DOCDATE = new$DOCDATE,
        Debit = 0,
        Credit = -new$Credit,
        DocType = val_DocType1$,
        Org_Ref = val_Org_Ref1$,
        AccountIndex = val_AccountIndex1$,
        KD = idKD1$,
        SubKD = val_SubKD1$,
        RegionCLS = val_RegionCLS1$,
        GosNI = val_GosNI1$,
        ProgIndex = 43,
        RecordIndex = new$Id,
        IncAccount = val_IncAccount1$,
        BudgetRef = val_BudgetRef1$,
        Note = new$Note,
        MEANSTYPE = val_MEANSTYPE1$,
        FACIALACC_CLS = val_FACIALACC_CLS1$,
        TransfertCls = val_TransfertCls1$,
        RVersion = -1
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
         
      END IF; 
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 41)    /*   () */
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    /*       */
    FOR REC$1 IN (SELECT inc.id
     AS val_ID42    FROM Incomes32 inc
    LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
    WHERE (inc.ProgIndex =  42) and
    (inc.RecordIndex =  new$id) and
    (inc.debit = 0) and
    (not(kd.kdvalue like unkKD$)) and
    (not(kd.kdvalue like unkVKD$))
    )
    LOOP
      BEGIN
        /*       */
        select inc.id
        into val_ID431$         FROM Incomes32 inc
        WHERE (inc.ProgIndex =  43) and
        (inc.RecordIndex =  REC$1.val_ID42)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      /*     ,   Credit, ProgIndex, RecordIndex */
      update Incomes32
      set
      DocNum = new$DocNum,
      DocCount = new$DocCount,       
      DOCDATE = new$DOCDATE,
      Debit = 0,
      DocType = new$DocType,
      Org_Ref = new$Org_Ref,
      AccountIndex = new$AccountIndex,
      KD = new$Kd,
      SubKD = new$SubKD,
      RegionCLS = new$RegionCLS,
      GosNI = new$GosNI,
      IncAccount = new$IncAccount,
      BudgetRef = new$BudgetRef,
      Note = new$Note,
      MEANSTYPE = new$MEANSTYPE,
      FACIALACC_CLS = new$FACIALACC_CLS,
      FACT = new$FACT,
      TransfertCls = new$TransfertCls,
      DirectionCls = new$DirectionCls,
      rversion = -1
      where id = val_ID431$;

        
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       --       ClsType
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                --  - 
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      --   
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -
  NULL;
--   IsReject$ := -1;
--   if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
--     IsReject$ := 1;
--   elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
--     IsReject$ := 0;
--   end if;  
--   if (IsReject$ <> -1) then
--     update LinkRecords set
--       IsRejected = IsReject$
--     where
--       (ChildID = :new.ID)
--       or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
--   end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   IF (NEW$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (161, :OLD.ID, SYSDATE);
      DELETE FROM DelRecIndexes
        WHERE (TableID = 161) AND (RecordId = NEW$ID);
   END IF;

END;
/
-- ALTER TRIGGER TR_INCOMES32_BU_300
CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (new$Fact IS NULL) THEN 
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN 
    new$DocBase := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN 
    new$Gosni := 0;
  END IF;
  /* 3 -    */
  IF (new$ProgIndex IS NULL) THEN 
    new$ProgIndex := 3; 
  END IF;
  IF (new$KD IS NULL) THEN 
    new$KD := 0; 
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN 
    new$FACIALACC_CLS := 0; 
  END IF;
  IF (new$MeansType IS NULL) THEN 
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN 
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN 
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN 
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN 
    new$AccountIndex := 0; 
  END IF;
  IF (new$DocType IS NULL) THEN 
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN 
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN 
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN 
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN 
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN 
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN 
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN 
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN 
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN 
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN 
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN 
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN 
    new$DirectionCLS := 0;
  END IF;
  IF (new$FinType is null) then 
    new$FinType := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  /*   .        */
  IF (new$IFS_CORR IS NULL) THEN 
    new$Ifs_Corr := 0;
  END IF;
  IF (new$IFS IS NULL) THEN 
    new$Ifs := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN 
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  BEGIN

    /*     */
    /*   after   ,*/ 
    /*      */
    SELECT ProgIndex, AcceptDate, ReestrNumber
    INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
    WHERE
    (qt.ID = new$RecordIndex)
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*              
           (  , , ) */
  /*   -    () */
  IF (CapProgIndex2$ = 45)
  THEN 
    IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN 
      /*        ,
                     */            
      new$FederalFundsRef := new$ID;
      /* if-then*/
    ELSE 
      new$FederalFundsRef := NULL;
      /* if-else*/  
    END IF;/* if (CapProgIndex=45) */
  END IF;
  /*     */
  IF (new$BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN 
      IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN 
        RaiseException('Ex_CantModufyBudget');
      END IF;
      IF (new$Progindex = 41) THEN
        SELECT COUNT(inc.id ) INTO CNT$1
        FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
        IF ((CNT$1<> 0)) THEN
          RaiseException('Ex_CantModufyBudget');
        END IF;   
      END IF;
    END IF;
  END IF;
  /*     \*/
  IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
  ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
  new$targetcls,new$targetcls);  

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

  BEGIN
    SELECT Inn
     INTO new$Inn
     FROM Organizations o
    WHERE (o.ID = new$Org_Ref);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*      */
  IF (new$ProgIndex <> 42) THEN
    BEGIN
      SELECT ProgIndex, DocNumber, AcceptDate
      INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
      WHERE
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*   -  ,   */
  IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
  THEN 
    IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
    (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
    THEN 
      BEGIN
        SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
        WHERE inc.id = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (Kd_Master$ = new$Kd) THEN 
        CapAcceptDate$ := new$DOCDATE;
        CapProgIndex$  := new$ProgIndex;
        CapDocNumber$  := new$DocNum;
        /*  */        
      END IF;/*       (         )*/
    END IF;
    IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
    THEN 

      /*      */
      /* /      Incomes32, ..      ,     */

      /*     /   */
      SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
      INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
      ;
      /*            ,  .*/
      /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
                      ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
                     ) THEN
                    EXCEPTION EX_CANNOTUPDATENUMBER;*/
                 
                
      IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
      then
        if ((new$DocType <> :old.DocType )
        or (new$Debit <> :old.Debit )
        or (new$Credit <> :old.Credit)
        or (new$org_ref <> :old.org_ref)
        or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
        or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
        )
        then
          RaiseException('EX_CANNOTUPDATENUMBER');
        END IF;
      END IF;
                


      /*           */
      IF (PayDocCount$ = 0)
      THEN 
        /*       */
        GetIntConst(11, 2,ConstPayQueue$);
        /*       */
        GetIntConst(11, 1,ConstSendBy$);

        /*    */
        INSERT INTO PayDoc32
        (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
        Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
        VALUES
        (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
        new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
        /* (new.Debit - new.Credit) --- ..      ,    ,
                                     */

        /* if-then */
      ELSE 
        /*     */
        IF (((new$AccountRef = :old.AccountRef) OR
        ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
        AND (new$IncAccount = :old.IncAccount)
        AND (new$BudgetRef = :old.BudgetRef)
        AND ((new$Note = :old.Note) OR
        ((new$Note IS NULL) AND (:old.Note IS NULL)))
        AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
        ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
        AND ((new$TaxNote = :old.TaxNote) OR
        ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
        )  THEN
          new$AccountRef := new$AccountRef;
                          
        ELSE

          UPDATE PayDoc32 pd
          SET
          pd.AccountRef = new$AccountRef,
          pd.PayerAttrRef = new$IncAccount,
          pd.AcceptorAttrRef = new$AccountRef,
          pd.TextNote = new$Note,
          pd.TaxNote = new$TaxNote,
          pd.BudgetRef = new$BudgetRef,
          pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
          pd.InputDate = CapAcceptDate$,
          pd.SourceDocNumber = CapDocNumber$,
          pd.FACIALACC_CLS = new$FACIALACC_CLS
          WHERE
          (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
        END IF;
        IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
        OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
        THEN  
          IF (Divided$ > 0)
          THEN
            /*  ,      */
            RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
          ELSE
            UPDATE PayDoc32 pd
            SET
            pd.Credit = new$Debit - new$Credit
            WHERE
            (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);
                          
          END IF;/* if-then*/            
        END IF;/* if-else*/
      END IF;
      /*     / */
      /*   :     ,     */
      /*  ,     */
      SELECT MAX(pd.AcceptDate)
      INTO Date_Pd$           FROM PayDoc32 pd
      WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
      ;
      new$Idate := Date_Pd$;
      /* if-then*/
    ELSE 
      /*       
                          -
                    . */
      DELETE FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex = new$ProgIndex)
      AND (pd.RecordIndex = new$id);
      /* if-else*/  
    END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then 
    BEGIN
      select q.BuildDate 
      into 
      new$DocDate        from QuotesTitle q 
      where q.id = new$RecordIndex 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
            */
         new$FederalFundsRef := new$ID;
      ELSE
         new$FederalFundsRef := NULL;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN
      select KDValue   into oldKD$ from kd where Id=:old.kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN

      /*     */
      select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
      IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
      into
      idKD1$,
      val_DocCount1$,
      val_DocType1$,
      val_Org_Ref1$,
      val_AccountIndex1$,
      val_SubKD1$,
      val_RegionCLS1$,
      val_GosNI1$,
      val_IncAccount1$,
      val_BudgetRef1$,
      val_MEANSTYPE1$  , 
      val_FACIALACC_CLS1$,
      val_TransfertCls1$         from incomes32 where id=new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not idKD1$ is null) then
      if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
      (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
        /*   ,    */
        delete
        from Incomes32
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      (new$Debit<>0))
      /*       */
      then 
        RaiseException('ex_UnknownRedirect');
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
        /*   ,   ,   */
        insert into
        Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
        Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
        val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
        val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$, 
        new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
      END IF;
      if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
      and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
        /*      ,   */
        update Incomes32
        set
        DocNum = new$DocNum,
        DocCount = val_DocCount1$,
        iDate = new$iDate,
        DOCDATE = new$DOCDATE,
        Debit = 0,
        Credit = -new$Credit,
        DocType = val_DocType1$,
        Org_Ref = val_Org_Ref1$,
        AccountIndex = val_AccountIndex1$,
        KD = idKD1$,
        SubKD = val_SubKD1$,
        RegionCLS = val_RegionCLS1$,
        GosNI = val_GosNI1$,
        ProgIndex = 43,
        RecordIndex = new$Id,
        IncAccount = val_IncAccount1$,
        BudgetRef = val_BudgetRef1$,
        Note = new$Note,
        MEANSTYPE = val_MEANSTYPE1$,
        FACIALACC_CLS = val_FACIALACC_CLS1$,
        TransfertCls = val_TransfertCls1$,
        RVersion = -1
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
         
      END IF; 
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 41)    /*   () */
  then 
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);  
    /*       */
    FOR REC$1 IN (SELECT inc.id
     AS val_ID42    FROM Incomes32 inc
    LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
    WHERE (inc.ProgIndex =  42) and
    (inc.RecordIndex =  new$id) and
    (inc.debit = 0) and
    (not(kd.kdvalue like unkKD$)) and
    (not(kd.kdvalue like unkVKD$))
    )
    LOOP
      BEGIN
        /*       */
        select inc.id
        into val_ID431$         FROM Incomes32 inc
        WHERE (inc.ProgIndex =  43) and
        (inc.RecordIndex =  REC$1.val_ID42)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      /*     ,   Credit, ProgIndex, RecordIndex */
      update Incomes32
      set
      DocNum = new$DocNum,
      DocCount = new$DocCount,       
      DOCDATE = new$DOCDATE,
      Debit = 0,
      DocType = new$DocType,
      Org_Ref = new$Org_Ref,
      AccountIndex = new$AccountIndex,
      KD = new$Kd,
      SubKD = new$SubKD,
      RegionCLS = new$RegionCLS,
      GosNI = new$GosNI,
      IncAccount = new$IncAccount,
      BudgetRef = new$BudgetRef,
      Note = new$Note,
      MEANSTYPE = new$MEANSTYPE,
      FACIALACC_CLS = new$FACIALACC_CLS,
      FACT = new$FACT,
      TransfertCls = new$TransfertCls,
      DirectionCls = new$DirectionCls,
      rversion = -1
      where id = val_ID431$;

        
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       --       ClsType
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                --  - 
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      --   
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;  
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   IF (NEW$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (161, :OLD.ID, SYSDATE);
      DELETE FROM DelRecIndexes
        WHERE (TableID = 161) AND (RecordId = NEW$ID);
   END IF;

END;
/
ALTER TRIGGER TR_LIMITFINDETAIL_BU_500 ENABLE
/
ALTER TRIGGER TR_PAYMENTSCHEDULE_BU_500 ENABLE
/
ALTER TRIGGER TR_REPCLSDETAILINFO_BU_500 ENABLE
/
ALTER TRIGGER TR_TENDERPRODUCT_BU_500 ENABLE
/
-- ALTER TRIGGER TR_WRITEXECUTIONDETAIL_BU_500
CREATE OR REPLACE TRIGGER TR_WRITEXECUTIONDETAIL_BU_500
  BEFORE UPDATE
  ON WRITEXECUTIONDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_500 (TR_WRITEXECUTIONDETAIL_BU_500)
-- - - - - - - - - - - - -

  :new.Updatedate := SYSDATE;
  :new.UpdaterUser := user;

END;
/
commit work 
/

-- #########################################################
-- #########################################################
-- BudStruct
-- #########################################################
-- #########################################################


DROP TRIGGER TR_BUDSTRUCT_BD
/
DROP TRIGGER TR_BUDSTRUCT_BI
/
DROP TRIGGER TR_BUDSTRUCT_BU
/
DROP TRIGGER TR_BUDSTRUCT_BU_500
/
DROP TRIGGER TR_BUDSTRUCT_AD
/
DROP TRIGGER TR_BUDSTRUCT_AU
/

RENAME BudStruct TO TB_BudStruct
/
CREATE OR REPLACE TRIGGER TR_BUDSTRUCT_BU_500
  BEFORE UPDATE
  ON TB_BudStruct
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_500 (TR_BUDSTRUCT_BU_500)
-- - - - - - - - - - - - -

    :new.Updatedate := sysdate;
    :new.UpdaterUser := user;

END;
/

CREATE OR REPLACE VIEW BudStruct (
  ID,
  KFSR,
  KVSR,
  KCSR,
  KVR,
  KESR,
  SUBKESR,
  REGIONCLS,
  FACT,
  FINTYPE,
  MEANSTYPE,
  ACTUALDATE,
  CREATEDATE,
  CREATERUSER,
  UPDATEDATE,
  UPDATERUSER,
  DIRECTIONCLS,
  BUDGETREF,
  TRANSFERTCLS,
  STARTDATE,
  ISLIMITSPEND,
  BUDALLOCATIONCLS,
  PAYPROMISECLS,
  SUBSIDYCLS,
  ASSIGNMENTKIND)
AS
  SELECT
    ID,
    KFSR,
    KVSR,
    KCSR,
    KVR,
    KESR,
    SUBKESR,
    REGIONCLS,
    FACT,
    FINTYPE,
    MEANSTYPE,
    ACTUALDATE,
    CREATEDATE,
    CREATERUSER,
    UPDATEDATE,
    UPDATERUSER,
    DIRECTIONCLS,
    BUDGETREF,
    TRANSFERTCLS,
    STARTDATE,
    ISLIMITSPEND,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    SUBSIDYCLS,
    ASSIGNMENTKIND
  FROM TB_BudStruct
/

GRANT SELECT, INSERT, UPDATE, DELETE ON BudStruct TO BUDGET_USERS
/
CREATE OR REPLACE TRIGGER TR_BudStruct_II
  INSTEAD OF INSERT
  ON BudStruct
  FOR EACH ROW
DECLARE
  new$ID BudStruct.ID%TYPE := :NEW.ID;
  new$KFSR BudStruct.KFSR%TYPE := :NEW.KFSR;
  new$KVSR BudStruct.KVSR%TYPE := :NEW.KVSR;
  new$KCSR BudStruct.KCSR%TYPE := :NEW.KCSR;
  new$KVR BudStruct.KVR%TYPE := :NEW.KVR;
  new$KESR BudStruct.KESR%TYPE := :NEW.KESR;
  new$SUBKESR BudStruct.SUBKESR%TYPE := :NEW.SUBKESR;
  new$REGIONCLS BudStruct.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$FACT BudStruct.FACT%TYPE := :NEW.FACT;
  new$FINTYPE BudStruct.FINTYPE%TYPE := :NEW.FINTYPE;
  new$MEANSTYPE BudStruct.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$ACTUALDATE BudStruct.ACTUALDATE%TYPE := :NEW.ACTUALDATE;
  new$CREATEDATE BudStruct.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$CREATERUSER BudStruct.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATEDATE BudStruct.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER BudStruct.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$DIRECTIONCLS BudStruct.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$BUDGETREF BudStruct.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$TRANSFERTCLS BudStruct.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$STARTDATE BudStruct.STARTDATE%TYPE := :NEW.STARTDATE;
  new$ISLIMITSPEND BudStruct.ISLIMITSPEND%TYPE := :NEW.ISLIMITSPEND;
  new$BUDALLOCATIONCLS BudStruct.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS BudStruct.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$SUBSIDYCLS BudStruct.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$ASSIGNMENTKIND BudStruct.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
--
  CNT$1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_BUDSTRUCT_BI_0)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$BudgetRef is null) then
    new$BudgetRef := 0;
  END IF;
  if (new$KVSR is null) then
    new$KVSR := 0;
  END IF;
  if (new$KCSR is null) then
    new$KCSR := 0;
  END IF;
  if (new$KFSR is null) then
    new$KFSR := 0;
  END IF;
  if (new$KVR is null) then
    new$KVR := 0;
  END IF;
  if (new$KESR is null) then
    new$KESR := 0;
  END IF;
  if (new$SubKESR is null) then
    new$SubKESR := 0;
  END IF;
  if (new$RegionCls is null) then
    new$RegionCls := 0;
  END IF;
  if (new$DirectionCls is null) then
    new$DirectionCls := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$FinType is null) then
    new$FinType := 0;
  END IF;
  if (new$MeansType is null) then
    new$MeansType := 0;
  END IF;
  if (new$AssignMentKind is null) then
    new$AssignMentKind := 0;
  END IF;
  if (new$IsLimitSpend is null) then
    new$IsLimitSpend := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (tr_budstruct_bi_100)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(id ) INTO CNT$1$
  from BudStruct
  where
  (        (BUDGETREF = new$BUDGETREF) and
  (KFSR = new$KFSR) and
  (KVSR = new$KVSR) and
  (KCSR = new$KCSR) and
  (KVR = new$KVR) and
  (KESR = new$KESR) and
  (SUBKESR = new$SUBKESR) and
  (REGIONCLS = new$REGIONCLS) and
  (FACT = new$FACT) and
  (FINTYPE = new$FINTYPE) and
  (MEANSTYPE = new$MEANSTYPE) and
  (DIRECTIONCLS = new$DIRECTIONCLS) and
  ((TRANSFERTCLS = new$TRANSFERTCLS) or ((TRANSFERTCLS is null) and (new$TRANSFERTCLS is null))) and
  ((BUDALLOCATIONCLS = new$BUDALLOCATIONCLS) or ((BUDALLOCATIONCLS is null) and (new$BUDALLOCATIONCLS is null))) and
  ((PAYPROMISECLS = new$PAYPROMISECLS) or ((PAYPROMISECLS is null) and (new$PAYPROMISECLS is null))) and
  ((SUBSIDYCLS = new$SUBSIDYCLS) or ((SUBSIDYCLS is null) and (new$SUBSIDYCLS is null))) and
  (ASSIGNMENTKIND = new$ASSIGNMENTKIND)
  ) AND (ROWNUM = 1)      ;
  if ((CNT$1$<> 0))
  then
    RaiseException('EX_BUDSTRUCT_UNIQUE');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_BUDSTRUCT_BI_500)
-- Last update 22.02.2004
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_BudStruct (
    ID,
    KFSR,
    KVSR,
    KCSR,
    KVR,
    KESR,
    SUBKESR,
    REGIONCLS,
    FACT,
    FINTYPE,
    MEANSTYPE,
    ACTUALDATE,
    CREATEDATE,
    CREATERUSER,
    UPDATEDATE,
    UPDATERUSER,
    DIRECTIONCLS,
    BUDGETREF,
    TRANSFERTCLS,
    STARTDATE,
    ISLIMITSPEND,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    SUBSIDYCLS,
    ASSIGNMENTKIND
  ) VALUES (
    new$ID,
    new$KFSR,
    new$KVSR,
    new$KCSR,
    new$KVR,
    new$KESR,
    new$SUBKESR,
    new$REGIONCLS,
    new$FACT,
    new$FINTYPE,
    new$MEANSTYPE,
    new$ACTUALDATE,
    new$CREATEDATE,
    new$CREATERUSER,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$DIRECTIONCLS,
    new$BUDGETREF,
    new$TRANSFERTCLS,
    new$STARTDATE,
    new$ISLIMITSPEND,
    new$BUDALLOCATIONCLS,
    new$PAYPROMISECLS,
    new$SUBSIDYCLS,
    new$ASSIGNMENTKIND);

END;
/

CREATE OR REPLACE TRIGGER TR_BudStruct_IU
  INSTEAD OF UPDATE
  ON BudStruct
  FOR EACH ROW
DECLARE
  new$ID BudStruct.ID%TYPE := :NEW.ID;
  new$KFSR BudStruct.KFSR%TYPE := :NEW.KFSR;
  new$KVSR BudStruct.KVSR%TYPE := :NEW.KVSR;
  new$KCSR BudStruct.KCSR%TYPE := :NEW.KCSR;
  new$KVR BudStruct.KVR%TYPE := :NEW.KVR;
  new$KESR BudStruct.KESR%TYPE := :NEW.KESR;
  new$SUBKESR BudStruct.SUBKESR%TYPE := :NEW.SUBKESR;
  new$REGIONCLS BudStruct.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$FACT BudStruct.FACT%TYPE := :NEW.FACT;
  new$FINTYPE BudStruct.FINTYPE%TYPE := :NEW.FINTYPE;
  new$MEANSTYPE BudStruct.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$ACTUALDATE BudStruct.ACTUALDATE%TYPE := :NEW.ACTUALDATE;
  new$CREATEDATE BudStruct.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$CREATERUSER BudStruct.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATEDATE BudStruct.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER BudStruct.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$DIRECTIONCLS BudStruct.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$BUDGETREF BudStruct.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$TRANSFERTCLS BudStruct.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$STARTDATE BudStruct.STARTDATE%TYPE := :NEW.STARTDATE;
  new$ISLIMITSPEND BudStruct.ISLIMITSPEND%TYPE := :NEW.ISLIMITSPEND;
  new$BUDALLOCATIONCLS BudStruct.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS BudStruct.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$SUBSIDYCLS BudStruct.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$ASSIGNMENTKIND BudStruct.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
--
  CNT$1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_BUDSTRUCT_BU_0)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (new$BudgetRef is null) then
    new$BudgetRef := 0;
  END IF;
  if (new$KVSR is null) then
    new$KVSR := 0;
  END IF;
  if (new$KCSR is null) then
    new$KCSR := 0;
  END IF;
  if (new$KFSR is null) then
    new$KFSR := 0;
  END IF;
  if (new$KVR is null) then
    new$KVR := 0;
  END IF;
  if (new$KESR is null) then
    new$KESR := 0;
  END IF;
  if (new$SubKESR is null) then
    new$SubKESR := 0;
  END IF;
  if (new$RegionCls is null) then
    new$RegionCls := 0;
  END IF;
  if (new$DirectionCls is null) then
    new$DirectionCls := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$FinType is null) then
    new$FinType := 0;
  END IF;
  if (new$MeansType is null) then
    new$MeansType := 0;
  END IF;
  if (new$AssignMentKind is null) then
    new$AssignMentKind := 0;
  END IF;
  if (new$IsLimitSpend is null) then
    new$IsLimitSpend := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (tr_budstruct_bu_100)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(id ) INTO CNT$1$
  from BudStruct
  where
  (        (BUDGETREF = new$BUDGETREF) and
  (KFSR = new$KFSR) and
  (KVSR = new$KVSR) and
  (KCSR = new$KCSR) and
  (KVR = new$KVR) and
  (KESR = new$KESR) and
  (SUBKESR = new$SUBKESR) and
  (REGIONCLS = new$REGIONCLS) and
  (FACT = new$FACT) and
  (FINTYPE = new$FINTYPE) and
  (MEANSTYPE = new$MEANSTYPE) and
  (DIRECTIONCLS = new$DIRECTIONCLS) and
  ((TRANSFERTCLS = new$TRANSFERTCLS) or ((TRANSFERTCLS is null) and (new$TRANSFERTCLS is null))) and
  ((BUDALLOCATIONCLS = new$BUDALLOCATIONCLS) or ((BUDALLOCATIONCLS is null) and (new$BUDALLOCATIONCLS is null))) and
  ((PAYPROMISECLS = new$PAYPROMISECLS) or ((PAYPROMISECLS is null) and (new$PAYPROMISECLS is null))) and
  ((SUBSIDYCLS = new$SUBSIDYCLS) or ((SUBSIDYCLS is null) and (new$SUBSIDYCLS is null))) and
  (ASSIGNMENTKIND = new$ASSIGNMENTKIND) and
  (id <> :old.id)
  ) AND (ROWNUM = 1)      ;
  if ((CNT$1$<> 0))
  then
    RaiseException('EX_BUDSTRUCT_UNIQUE');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_BudStruct SET
    ID = new$ID,
    KFSR = new$KFSR,
    KVSR = new$KVSR,
    KCSR = new$KCSR,
    KVR = new$KVR,
    KESR = new$KESR,
    SUBKESR = new$SUBKESR,
    REGIONCLS = new$REGIONCLS,
    FACT = new$FACT,
    FINTYPE = new$FINTYPE,
    MEANSTYPE = new$MEANSTYPE,
    ACTUALDATE = new$ACTUALDATE,
    CREATEDATE = new$CREATEDATE,
    CREATERUSER = new$CREATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    DIRECTIONCLS = new$DIRECTIONCLS,
    BUDGETREF = new$BUDGETREF,
    TRANSFERTCLS = new$TRANSFERTCLS,
    STARTDATE = new$STARTDATE,
    ISLIMITSPEND = new$ISLIMITSPEND,
    BUDALLOCATIONCLS = new$BUDALLOCATIONCLS,
    PAYPROMISECLS = new$PAYPROMISECLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    ASSIGNMENTKIND = new$ASSIGNMENTKIND
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_BUDSTRUCT_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (141, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=141) and (RecordId=new$ID);
  end if;

END;
/

CREATE OR REPLACE TRIGGER TR_BudStruct_ID
  INSTEAD OF DELETE
  ON BudStruct
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_BUDSTRUCT_BD_0)
-- - - - - - - - - - - - -

--      BudStrLink
  delete from BudStrLink
  where BudStruct = :old.Id;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_BudStruct
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_500 (TR_BUDSTRUCT_AD_500)
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordId, DeleteDate)
    values(141, :old.ID, SYSDATE);

END;
/

COMMIT WORK
/

-- #########################################################
-- #########################################################
-- Alter_FacialFinCaption_ModifyField.sql
-- #########################################################
-- #########################################################


/*
     SOURCESTOREDPAYMENTPROPS  4000 
     StoredPaymentNote  2000 
     DocOsn  2000 
*/
ALTER TABLE TB_FACIALFINCAPTION 
 MODIFY (
  SOURCESTOREDPAYMENTPROPS VARCHAR2 (4000)
 )
/

ALTER TABLE TB_FACIALFINCAPTION 
 MODIFY (
  STOREDPAYMENTNOTE VARCHAR2 (2000)
 )
/

ALTER TABLE TB_FACIALFINCAPTION 
 MODIFY (
  DOCOSN VARCHAR2 (2000)
 )
/

commit work
/



-- #########################################################
-- #########################################################
-- Alter_Fact_Ext.sql
-- #########################################################
-- #########################################################

/*              */
ALTER TABLE Fact ADD (
  ExtID2 VARCHAR2(50),/*     */
  ExtID3 VARCHAR2(50)/*      */
)
/
commit work
/



-- #########################################################
-- #########################################################
-- Add_Agreements_TenderRef.sql
-- #########################################################
-- #########################################################

/*    Agreements  TenderRef  TenderInnerNumber, 
      30.   TenderCaption */
ALTER TABLE TB_Agreements ADD (
  TenderRef NUMBER(10),/*    30.,     */
    CHECK((TenderRef<=2147483647)AND(TenderRef>-2147483648)),
  TenderInnerNumber NUMBER(10),/*   30.,     */
    CHECK((TenderInnerNumber<=2147483647)AND(TenderInnerNumber>-2147483648)),
  constraint FK_Agreements_TenderRef foreign key (TenderRef) references TB_TenderCaption(id)
)
/
CREATE INDEX FK_Agreements_TenderRef ON TB_Agreements(TenderRef)
/

CREATE OR REPLACE VIEW Agreements (
  ID,
  SUMMA,
  AGREEMENTDATE,
  AGREEMENTENDDATE,
  EXECUTER_REF,
  CLIENT_REF,
  FACIALACC_CLS,
  AGREEMENTTYPE,
  ACCEPTED,
  ACCEPTDATE,
  CARDADVANCEPERCENT,
  CARDADVANCE,
  CLOSEDOC,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  BUDGETREF,
  LASTADJUSTMENT,
  LASTACCEPTED,
  FACT,
  REGION,
  CLOSEDATE,
  DELIVERYRULES,
  AGREEMENTSUMMA,
  AGREEMENTFINSUMMA,
  ADJUSTMENTREF,
  REESTRNUMBER,
  PAYMENTDATE,
  AGREEMENTCARDADVANCE,
  FINCARDADVANCE,
  STATEORDERREF,
  REJECTCLS,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  AGREEMENTBEGINDATE,
  PROTOCOLNUMBER,
  PROTOCOLDATE,
  REVIEWNOTE,
  DOCSTATEREF,
  RVERSION,
  EXPORTDATE,
  FSORGAN,
  FSBUDGETNAME,
  FSOFFBUDGET,
  RNYEAR,
  RNNUMBER,
  RNDATE,
  PROTOCOLNOTICE,
  PROTOCOLRESULTDATE,
  PROTOCOLDOCTYPE,
  PROTOCOLSALETYPE,
  NOTIFYDATE,
  EXECUTERACCREF,
  DOCBASEDATE,
  DOCBASENOTIFYDATE,
  DOCBASETEXT,
  DOCBASETYPE,
  DOCBASESUMMA,
  UNKNOWNAMOUNT,
  PROTOCOLREASON,
  DOCNUMBER,
  ADJUSTMENTDOCNUMBER,
  OLDDOCNUMBER,
  LOTMAXSUM,
  CLIENT_INN,
  CLIENT_INN20,
  CLIENT_NAME,
  EXECUTER_INN,
  EXECUTER_INN20,
  EXECUTER_NAME,
  EXECUTER_STATUS,
  EXECUTER_COUNTRY,
  EXECUTER_ADDRESS,
  EXECUTER_PHONE,
  REALID,
  ADJUSTMENTNUMBER,
  INNERNUMBER,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  REESTRVERSION,
  DOCTYPE,
  RNCLIENTID,
  INFONUMBER,
  STATEORDERINNERNUMBER,
  PROGINDEX,
  NOTE,
  PURPORTDOC,
  REESTRRECORDNUMBER,
  EXECUTERSTOREDPROPS,
  AUTOSANCTION,
  PURCHASECODE,
  DOCUMENTNUMBER,
  REJECTCAUSE,
  TENDERREF,
  TENDERINNERNUMBER)
AS
  SELECT
    ID,
    SUMMA,
    AGREEMENTDATE,
    AGREEMENTENDDATE,
    EXECUTER_REF,
    CLIENT_REF,
    FACIALACC_CLS,
    AGREEMENTTYPE,
    ACCEPTED,
    ACCEPTDATE,
    CARDADVANCEPERCENT,
    CARDADVANCE,
    CLOSEDOC,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    LASTADJUSTMENT,
    LASTACCEPTED,
    FACT,
    REGION,
    CLOSEDATE,
    DELIVERYRULES,
    AGREEMENTSUMMA,
    AGREEMENTFINSUMMA,
    ADJUSTMENTREF,
    REESTRNUMBER,
    PAYMENTDATE,
    AGREEMENTCARDADVANCE,
    FINCARDADVANCE,
    STATEORDERREF,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    AGREEMENTBEGINDATE,
    PROTOCOLNUMBER,
    PROTOCOLDATE,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXPORTDATE,
    FSORGAN,
    FSBUDGETNAME,
    FSOFFBUDGET,
    RNYEAR,
    RNNUMBER,
    RNDATE,
    PROTOCOLNOTICE,
    PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE,
    NOTIFYDATE,
    EXECUTERACCREF,
    DOCBASEDATE,
    DOCBASENOTIFYDATE,
    DOCBASETEXT,
    DOCBASETYPE,
    DOCBASESUMMA,
    UNKNOWNAMOUNT,
    PROTOCOLREASON,
    DOCNUMBER,
    ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER,
    LOTMAXSUM,
    CLIENT_INN,
    CLIENT_INN20,
    CLIENT_NAME,
    EXECUTER_INN,
    EXECUTER_INN20,
    EXECUTER_NAME,
    EXECUTER_STATUS,
    EXECUTER_COUNTRY,
    EXECUTER_ADDRESS,
    EXECUTER_PHONE,
    REALID,
    ADJUSTMENTNUMBER,
    INNERNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REESTRVERSION,
    DOCTYPE,
    RNCLIENTID,
    INFONUMBER,
    STATEORDERINNERNUMBER,
    PROGINDEX,
    NOTE,
    PURPORTDOC,
    REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS,
    AUTOSANCTION,
    PURCHASECODE,
    DOCUMENTNUMBER,
    REJECTCAUSE,
    TENDERREF,
    TENDERINNERNUMBER
  FROM TB_Agreements
/

CREATE OR REPLACE TRIGGER TR_AGREEMENTS_ID
  INSTEAD OF DELETE
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  cnt1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_AGREEMENTS_BD)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*   5.0*/
  select count(id) into cnt1$ from agreements where (adjustmentref = :old.id) ;
  /*  .       .*/
  if (cnt1$ = 0) then
    delete from estimate where (recordindex = :old.id);
    delete from agreementsteps where (recordindex = :old.id);
    delete from paymentschedule where agreementref = :old.id;

  else
    RaiseException('ex_agr_cantdeladjustmented');
  END IF;

-- - - - - - - - - - - - -
-- BD_20 (TR_AGREEMENTS_BD_20)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  /*          */
  if ((:old.ProgIndex = 305)and(:old.AdjustmentNumber = 0)) then
    update tenderresultcaption set
    StateOrder = null
    where
    StateOrder = :old.ID;
  END IF;
  if ((:old.ProgIndex = 314)and(:old.AdjustmentNumber = 0)) then
    update tenderresultcaption set
    StateOrder = null,
    Agreement = null
    where
    StateOrder = :old.ID;
  END IF;
  if ((:old.ProgIndex = 304)and(:old.AdjustmentNumber = 0)) then
    update tenderresultcaption set
    Agreement = null
    where
    Agreement = :old.ID;
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_AGREEMENTS
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_10 (TR_AGREEMENTS_AD_10)
-- Last update 05.02.2010
-- - - - - - - - - - - - -

/*   5.0*/
    /*   LastAdjustment     */
    if ((:old.AdjustmentNumber > 0) and (:old.LastAdjustment = 1)) then
        update Agreements set
            LastAdjustment = 1,
            RVersion = -1
        where (ID = :old.AdjustmentRef);
    end if;
    /*   LastAccepted     */
    if ((:old.AdjustmentNumber > 0) and (:old.LastAccepted = 1)) then
        update Agreements set
            LastAccepted = 1,
            RVersion = -1
        where (ID = :old.AdjustmentRef);
    end if;

-- - - - - - - - - - - - -
-- AD_200 (TR_AGREEMENTS_AD_200)
-- Create 04.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

  /*        */
  delete from StateJumpHistory where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_AGREEMENTS_AD_500)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordId, DeleteDate, Summa, ProgIndex)
  values (110, :old.ID, SYSDATE, :old.AgreementSumma, :old.ProgIndex);

END;
/

CREATE OR REPLACE TRIGGER TR_AGREEMENTS_II
  INSTEAD OF INSERT
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  new$ID AGREEMENTS.ID%TYPE := :NEW.ID;
  new$SUMMA AGREEMENTS.SUMMA%TYPE := :NEW.SUMMA;
  new$AGREEMENTDATE AGREEMENTS.AGREEMENTDATE%TYPE := :NEW.AGREEMENTDATE;
  new$AGREEMENTENDDATE AGREEMENTS.AGREEMENTENDDATE%TYPE := :NEW.AGREEMENTENDDATE;
  new$EXECUTER_REF AGREEMENTS.EXECUTER_REF%TYPE := :NEW.EXECUTER_REF;
  new$CLIENT_REF AGREEMENTS.CLIENT_REF%TYPE := :NEW.CLIENT_REF;
  new$FACIALACC_CLS AGREEMENTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$AGREEMENTTYPE AGREEMENTS.AGREEMENTTYPE%TYPE := :NEW.AGREEMENTTYPE;
  new$ACCEPTED AGREEMENTS.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$ACCEPTDATE AGREEMENTS.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$CARDADVANCEPERCENT AGREEMENTS.CARDADVANCEPERCENT%TYPE := :NEW.CARDADVANCEPERCENT;
  new$CARDADVANCE AGREEMENTS.CARDADVANCE%TYPE := :NEW.CARDADVANCE;
  new$CLOSEDOC AGREEMENTS.CLOSEDOC%TYPE := :NEW.CLOSEDOC;
  new$CREATERUSER AGREEMENTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE AGREEMENTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE AGREEMENTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER AGREEMENTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF AGREEMENTS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$LASTADJUSTMENT AGREEMENTS.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED AGREEMENTS.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$FACT AGREEMENTS.FACT%TYPE := :NEW.FACT;
  new$REGION AGREEMENTS.REGION%TYPE := :NEW.REGION;
  new$CLOSEDATE AGREEMENTS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$DELIVERYRULES AGREEMENTS.DELIVERYRULES%TYPE := :NEW.DELIVERYRULES;
  new$AGREEMENTSUMMA AGREEMENTS.AGREEMENTSUMMA%TYPE := :NEW.AGREEMENTSUMMA;
  new$AGREEMENTFINSUMMA AGREEMENTS.AGREEMENTFINSUMMA%TYPE := :NEW.AGREEMENTFINSUMMA;
  new$ADJUSTMENTREF AGREEMENTS.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$REESTRNUMBER AGREEMENTS.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$PAYMENTDATE AGREEMENTS.PAYMENTDATE%TYPE := :NEW.PAYMENTDATE;
  new$AGREEMENTCARDADVANCE AGREEMENTS.AGREEMENTCARDADVANCE%TYPE := :NEW.AGREEMENTCARDADVANCE;
  new$FINCARDADVANCE AGREEMENTS.FINCARDADVANCE%TYPE := :NEW.FINCARDADVANCE;
  new$STATEORDERREF AGREEMENTS.STATEORDERREF%TYPE := :NEW.STATEORDERREF;
  new$REJECTCLS AGREEMENTS.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS AGREEMENTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID AGREEMENTS.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID AGREEMENTS.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$AGREEMENTBEGINDATE AGREEMENTS.AGREEMENTBEGINDATE%TYPE := :NEW.AGREEMENTBEGINDATE;
  new$PROTOCOLNUMBER AGREEMENTS.PROTOCOLNUMBER%TYPE := :NEW.PROTOCOLNUMBER;
  new$PROTOCOLDATE AGREEMENTS.PROTOCOLDATE%TYPE := :NEW.PROTOCOLDATE;
  new$REVIEWNOTE AGREEMENTS.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF AGREEMENTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION AGREEMENTS.RVERSION%TYPE := :NEW.RVERSION;
  new$EXPORTDATE AGREEMENTS.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$FSORGAN AGREEMENTS.FSORGAN%TYPE := :NEW.FSORGAN;
  new$FSBUDGETNAME AGREEMENTS.FSBUDGETNAME%TYPE := :NEW.FSBUDGETNAME;
  new$FSOFFBUDGET AGREEMENTS.FSOFFBUDGET%TYPE := :NEW.FSOFFBUDGET;
  new$RNYEAR AGREEMENTS.RNYEAR%TYPE := :NEW.RNYEAR;
  new$RNNUMBER AGREEMENTS.RNNUMBER%TYPE := :NEW.RNNUMBER;
  new$RNDATE AGREEMENTS.RNDATE%TYPE := :NEW.RNDATE;
  new$PROTOCOLNOTICE AGREEMENTS.PROTOCOLNOTICE%TYPE := :NEW.PROTOCOLNOTICE;
  new$PROTOCOLRESULTDATE AGREEMENTS.PROTOCOLRESULTDATE%TYPE := :NEW.PROTOCOLRESULTDATE;
  new$PROTOCOLDOCTYPE AGREEMENTS.PROTOCOLDOCTYPE%TYPE := :NEW.PROTOCOLDOCTYPE;
  new$PROTOCOLSALETYPE AGREEMENTS.PROTOCOLSALETYPE%TYPE := :NEW.PROTOCOLSALETYPE;
  new$NOTIFYDATE AGREEMENTS.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$EXECUTERACCREF AGREEMENTS.EXECUTERACCREF%TYPE := :NEW.EXECUTERACCREF;
  new$DOCBASEDATE AGREEMENTS.DOCBASEDATE%TYPE := :NEW.DOCBASEDATE;
  new$DOCBASENOTIFYDATE AGREEMENTS.DOCBASENOTIFYDATE%TYPE := :NEW.DOCBASENOTIFYDATE;
  new$DOCBASETEXT AGREEMENTS.DOCBASETEXT%TYPE := :NEW.DOCBASETEXT;
  new$DOCBASETYPE AGREEMENTS.DOCBASETYPE%TYPE := :NEW.DOCBASETYPE;
  new$DOCBASESUMMA AGREEMENTS.DOCBASESUMMA%TYPE := :NEW.DOCBASESUMMA;
  new$UNKNOWNAMOUNT AGREEMENTS.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PROTOCOLREASON AGREEMENTS.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$DOCNUMBER AGREEMENTS.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$ADJUSTMENTDOCNUMBER AGREEMENTS.ADJUSTMENTDOCNUMBER%TYPE := :NEW.ADJUSTMENTDOCNUMBER;
  new$OLDDOCNUMBER AGREEMENTS.OLDDOCNUMBER%TYPE := :NEW.OLDDOCNUMBER;
  new$LOTMAXSUM AGREEMENTS.LOTMAXSUM%TYPE := :NEW.LOTMAXSUM;
  new$CLIENT_INN AGREEMENTS.CLIENT_INN%TYPE := :NEW.CLIENT_INN;
  new$CLIENT_INN20 AGREEMENTS.CLIENT_INN20%TYPE := :NEW.CLIENT_INN20;
  new$CLIENT_NAME AGREEMENTS.CLIENT_NAME%TYPE := :NEW.CLIENT_NAME;
  new$EXECUTER_INN AGREEMENTS.EXECUTER_INN%TYPE := :NEW.EXECUTER_INN;
  new$EXECUTER_INN20 AGREEMENTS.EXECUTER_INN20%TYPE := :NEW.EXECUTER_INN20;
  new$EXECUTER_NAME AGREEMENTS.EXECUTER_NAME%TYPE := :NEW.EXECUTER_NAME;
  new$EXECUTER_STATUS AGREEMENTS.EXECUTER_STATUS%TYPE := :NEW.EXECUTER_STATUS;
  new$EXECUTER_COUNTRY AGREEMENTS.EXECUTER_COUNTRY%TYPE := :NEW.EXECUTER_COUNTRY;
  new$EXECUTER_ADDRESS AGREEMENTS.EXECUTER_ADDRESS%TYPE := :NEW.EXECUTER_ADDRESS;
  new$EXECUTER_PHONE AGREEMENTS.EXECUTER_PHONE%TYPE := :NEW.EXECUTER_PHONE;
  new$REALID AGREEMENTS.REALID%TYPE := :NEW.REALID;
  new$ADJUSTMENTNUMBER AGREEMENTS.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$INNERNUMBER AGREEMENTS.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$SENDERIDKEY AGREEMENTS.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY AGREEMENTS.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REESTRVERSION AGREEMENTS.REESTRVERSION%TYPE := :NEW.REESTRVERSION;
  new$DOCTYPE AGREEMENTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$RNCLIENTID AGREEMENTS.RNCLIENTID%TYPE := :NEW.RNCLIENTID;
  new$INFONUMBER AGREEMENTS.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$STATEORDERINNERNUMBER AGREEMENTS.STATEORDERINNERNUMBER%TYPE := :NEW.STATEORDERINNERNUMBER;
  new$PROGINDEX AGREEMENTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE AGREEMENTS.NOTE%TYPE := :NEW.NOTE;
  new$PURPORTDOC AGREEMENTS.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$REESTRRECORDNUMBER AGREEMENTS.REESTRRECORDNUMBER%TYPE := :NEW.REESTRRECORDNUMBER;
  new$EXECUTERSTOREDPROPS AGREEMENTS.EXECUTERSTOREDPROPS%TYPE := :NEW.EXECUTERSTOREDPROPS;
  new$AUTOSANCTION AGREEMENTS.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$PURCHASECODE AGREEMENTS.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$DOCUMENTNUMBER AGREEMENTS.DOCUMENTNUMBER%TYPE := :NEW.DOCUMENTNUMBER;
  new$REJECTCAUSE AGREEMENTS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$TENDERREF AGREEMENTS.TENDERREF%TYPE := :NEW.TENDERREF;
  new$TENDERINNERNUMBER AGREEMENTS.TENDERINNERNUMBER%TYPE := :NEW.TENDERINNERNUMBER;
--
  CurVal$ NUMBER (10);
  CountAcc$ NUMBER(10);
  rnClientID1$ VARCHAR2(15);
  rnYear1$ VARCHAR2(15);
  rnNumber1$ VARCHAR2(15);
  ReestrVersion1$ VARCHAR2(15);
  Tmp$ NUMBER(10);
  AdjID$ NUMBER(10);
  AdjDocNum$ VARCHAR2(150);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_AGREEMENTS_BI)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   3.1.2*/
  /*    -*/
  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$CardAdvancePercent is null) then
    new$CardAdvancePercent := 0;
  END IF;
  if (new$CardAdvance is null) then
    new$CardAdvance := 0;
  END IF;
  if (new$AgreementCardAdvance is null) then
    new$AgreementCardAdvance := 0;
  END IF;
  if (new$FinCardAdvance is null) then
    new$FinCardAdvance := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$AgreementSumma is null) then
    new$AgreementSumma := 0;
  END IF;
  if (new$AgreementFinSumma is null) then
    new$AgreementFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$Region is null) then
    new$Region := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  if (new$client_ref is null) then
    new$client_ref := 0;
  END IF;

  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    BEGIN
      select fa.BudgetRef     into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;

  /*    
         -   InnerNumber*/
  if (((new$ProgIndex = 305) or (new$ProgIndex = 304) or (new$ProgIndex = 314)) and (new$InnerNumber is null)) then
    new$InnerNumber := GEN_ID('G_AgreementNumber',1);
  END IF;
  /*   */
  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  /*    .  */

  new$stateorderinnernumber := null;
  if (new$stateorderref is not null) then
    BEGIN
      select
      innernumber
      into new$stateorderinnernumber     from agreements
      where
      id = new$stateorderref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_AGREEMENTS_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_AGREEMENTS_BI_10)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  /*   5.0*/

  /*    .*/
  if (new$InnerNumber is null) then
    RaiseException('EX_AGR_InnerNumsIsNull');
  END IF;

  /*    */
  select max(AdjustmentNumber)
  into Tmp$         from Agreements
  where (InnerNumber = new$InnerNumber)
  ;
  /*      ,   0*/
  if (Tmp$ is null) then
    new$AdjustmentNumber := 0;

  else
    new$AdjustmentNumber := Tmp$ + 1;
  END IF;
  /*        */
  if (((new$AgreementType = 0) and (new$AdjustmentNumber > 0)) or
  ((new$AgreementType = 1) and (new$AdjustmentNumber = 0))) then
    RaiseException('EX_AGR_AgrTypeViolation');
  END IF;
  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;

  else
    new$LastAdjustment := 1;
  END IF;
  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then
    new$LastAccepted := 1;

  else
    new$LastAccepted := 0;
  END IF;
  /*    */
  if (new$AdjustmentNumber > 0) then
    /*      -    */
    select count(ID), max(ID), max(DocNumber)
    into Tmp$, AdjID$, AdjDocNum$             from Agreements
    where (InnerNumber = new$InnerNumber) and (LastAccepted = 1)
    ;
    /*   ,  */
    if (Tmp$ <> 1) then
      RaiseException('EX_AGR_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID)
    into Tmp$             from Agreements
    where (InnerNumber = new$InnerNumber) and (AcceptDate is null)
    ;
    if (Tmp$ > 0) then
      RaiseException('EX_AGR_AdjustDuplicate');
    END IF;
    /* ,    ,    */
    new$AdjustmentRef := AdjID$;
    new$AdjustmentDocNumber := AdjDocNum$;

  else /*     */
    /*       (    )*/
    new$AdjustmentRef := null;
    new$AdjustmentDocNumber := null;

  END IF;

-- - - - - - - - - - - - -
-- BI_20 (TR_AGREEMENTS_BI_20)
-- Create 21.05.2009
-- - - - - - - - - - - - -

  /*    -,     */
  if ((new$Client_INN   is null) and
      (new$Client_INN20 is null) and
      (new$Client_Name  is null))then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name
      into
        new$Client_INN,
        new$Client_INN20,
        new$Client_Name
      from Organizations o
      where o.Id=new$Client_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Client_INN := NULL;
        new$Client_INN20 := NULL;
        new$Client_Name := NULL;
    END;
  END IF;

  /*    -,     */
  if ((new$Executer_INN     is null) and
      (new$Executer_INN20   is null) and
      (new$Executer_Name    is null) and
      (new$Executer_Status  is null) and
      (new$Executer_Country is null) and
      (new$Executer_Address is null) and
      (new$Executer_Phone   is null))then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name,
        o.SupplierStatus,
        o.Country,
        o.Address,
        o.Phone
      into
        new$Executer_INN,
        new$Executer_INN20,
        new$Executer_Name,
        new$Executer_Status,
        new$Executer_Country,
        new$Executer_Address,
        new$Executer_Phone
      from Organizations o
      where o.Id=new$Executer_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Executer_INN := NULL;
        new$Executer_INN20 := NULL;
        new$Executer_Name := NULL;
        new$Executer_Status := NULL;
        new$Executer_Country := NULL;
        new$Executer_Address := NULL;
        new$Executer_Phone := NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_40 (TR_AGREEMENTS_BI_40)
-- Create 06.08.2010
-- - - - - - - - - - - - -

  /*       */
  if (new$senderId is null) then
    new$senderIdKey := -1;
  else
    new$senderIdKey := new$senderId;
  end if;

  if (new$SenderRecordID is null)then
    new$SenderRecordIDKey := new$ID;
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  end if;

-- - - - - - - - - - - - -
-- BI_50 (TR_AGREEMENTS_BI_50)
-- Create 06.08.2010
-- - - - - - - - - - - - -

    if (new$InnerNumber is not null) then
        CurVal$ := gen_id('G_AgreementNumber', 0);
        if (CurVal$ < new$InnerNumber) then
          CurVal$ := gen_id('G_AgreementNumber', new$InnerNumber - CurVal$);
        end if;
    end if;

-- - - - - - - - - - - - -
-- BI_300 (tr_agreements_bi_300)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$ExecuterAccRef is not null) then
    select count(ID)
    into CountAcc$     from org_accounts oa
    where oa.id = new$ExecuterAccRef and oa.Org_ref = new$Executer_Ref
    ;
    if (CountAcc$ = 0) then
      RaiseException('EX_AGR_ACCORGCHECK');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_400 (TR_AGREEMENTS_BI_400)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if ((new$rnClientID is not null) and (new$rnYear is not null) and (new$rnNumber is not null)) then

    rnClientID1$ := new$rnClientID;
    rnYear1$ := new$rnYear;
    rnNumber1$ := new$rnNumber;
    ReestrVersion1$ := new$ReestrVersion;
    while (LENGTH(rnClientID1$) < 11) LOOP
      rnClientID1$ := '0' || rnClientID1$;
    END LOOP;
    while (LENGTH(rnNumber1$) < 6) LOOP
      rnNumber1$ := '0' || rnNumber1$;
    END LOOP;
    if (LENGTH(ReestrVersion1$) < 2) then
      ReestrVersion1$ := '0' || ReestrVersion1$;
    END IF;
    /*  ReestrRecordNumber*/
    if (new$ReestrVersion is null) then
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$;

    else
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$ || ReestrVersion1$;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_AGREEMENTS_BI_500)
-- Last update 19.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- BI_600 (agreements_realid_bi_600)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_AGREEMENTS (
    ID,
    SUMMA,
    AGREEMENTDATE,
    AGREEMENTENDDATE,
    EXECUTER_REF,
    CLIENT_REF,
    FACIALACC_CLS,
    AGREEMENTTYPE,
    ACCEPTED,
    ACCEPTDATE,
    CARDADVANCEPERCENT,
    CARDADVANCE,
    CLOSEDOC,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    LASTADJUSTMENT,
    LASTACCEPTED,
    FACT,
    REGION,
    CLOSEDATE,
    DELIVERYRULES,
    AGREEMENTSUMMA,
    AGREEMENTFINSUMMA,
    ADJUSTMENTREF,
    REESTRNUMBER,
    PAYMENTDATE,
    AGREEMENTCARDADVANCE,
    FINCARDADVANCE,
    STATEORDERREF,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    AGREEMENTBEGINDATE,
    PROTOCOLNUMBER,
    PROTOCOLDATE,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXPORTDATE,
    FSORGAN,
    FSBUDGETNAME,
    FSOFFBUDGET,
    RNYEAR,
    RNNUMBER,
    RNDATE,
    PROTOCOLNOTICE,
    PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE,
    NOTIFYDATE,
    EXECUTERACCREF,
    DOCBASEDATE,
    DOCBASENOTIFYDATE,
    DOCBASETEXT,
    DOCBASETYPE,
    DOCBASESUMMA,
    UNKNOWNAMOUNT,
    PROTOCOLREASON,
    DOCNUMBER,
    ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER,
    LOTMAXSUM,
    CLIENT_INN,
    CLIENT_INN20,
    CLIENT_NAME,
    EXECUTER_INN,
    EXECUTER_INN20,
    EXECUTER_NAME,
    EXECUTER_STATUS,
    EXECUTER_COUNTRY,
    EXECUTER_ADDRESS,
    EXECUTER_PHONE,
    REALID,
    ADJUSTMENTNUMBER,
    INNERNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REESTRVERSION,
    DOCTYPE,
    RNCLIENTID,
    INFONUMBER,
    STATEORDERINNERNUMBER,
    PROGINDEX,
    NOTE,
    PURPORTDOC,
    REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS,
    AUTOSANCTION,
    PURCHASECODE,
    DOCUMENTNUMBER,
    REJECTCAUSE,
    TENDERREF,
    TENDERINNERNUMBER
  ) VALUES (
    new$ID,
    new$SUMMA,
    new$AGREEMENTDATE,
    new$AGREEMENTENDDATE,
    new$EXECUTER_REF,
    new$CLIENT_REF,
    new$FACIALACC_CLS,
    new$AGREEMENTTYPE,
    new$ACCEPTED,
    new$ACCEPTDATE,
    new$CARDADVANCEPERCENT,
    new$CARDADVANCE,
    new$CLOSEDOC,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$LASTADJUSTMENT,
    new$LASTACCEPTED,
    new$FACT,
    new$REGION,
    new$CLOSEDATE,
    new$DELIVERYRULES,
    new$AGREEMENTSUMMA,
    new$AGREEMENTFINSUMMA,
    new$ADJUSTMENTREF,
    new$REESTRNUMBER,
    new$PAYMENTDATE,
    new$AGREEMENTCARDADVANCE,
    new$FINCARDADVANCE,
    new$STATEORDERREF,
    new$REJECTCLS,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$AGREEMENTBEGINDATE,
    new$PROTOCOLNUMBER,
    new$PROTOCOLDATE,
    new$REVIEWNOTE,
    new$DOCSTATEREF,
    new$RVERSION,
    new$EXPORTDATE,
    new$FSORGAN,
    new$FSBUDGETNAME,
    new$FSOFFBUDGET,
    new$RNYEAR,
    new$RNNUMBER,
    new$RNDATE,
    new$PROTOCOLNOTICE,
    new$PROTOCOLRESULTDATE,
    new$PROTOCOLDOCTYPE,
    new$PROTOCOLSALETYPE,
    new$NOTIFYDATE,
    new$EXECUTERACCREF,
    new$DOCBASEDATE,
    new$DOCBASENOTIFYDATE,
    new$DOCBASETEXT,
    new$DOCBASETYPE,
    new$DOCBASESUMMA,
    new$UNKNOWNAMOUNT,
    new$PROTOCOLREASON,
    new$DOCNUMBER,
    new$ADJUSTMENTDOCNUMBER,
    new$OLDDOCNUMBER,
    new$LOTMAXSUM,
    new$CLIENT_INN,
    new$CLIENT_INN20,
    new$CLIENT_NAME,
    new$EXECUTER_INN,
    new$EXECUTER_INN20,
    new$EXECUTER_NAME,
    new$EXECUTER_STATUS,
    new$EXECUTER_COUNTRY,
    new$EXECUTER_ADDRESS,
    new$EXECUTER_PHONE,
    new$REALID,
    new$ADJUSTMENTNUMBER,
    new$INNERNUMBER,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$REESTRVERSION,
    new$DOCTYPE,
    new$RNCLIENTID,
    new$INFONUMBER,
    new$STATEORDERINNERNUMBER,
    new$PROGINDEX,
    new$NOTE,
    new$PURPORTDOC,
    new$REESTRRECORDNUMBER,
    new$EXECUTERSTOREDPROPS,
    new$AUTOSANCTION,
    new$PURCHASECODE,
    new$DOCUMENTNUMBER,
    new$REJECTCAUSE,
    new$TENDERREF,
    new$TENDERINNERNUMBER);

-- - - - - - - - - - - - -
-- AI_10 (TR_AGREEMENTS_AI_10)
-- Last update 05.02.2010
-- - - - - - - - - - - - -

/*   5.0*/
    if ((new$AdjustmentNumber > 0) and (new$LastAdjustment = 1)) then
        update Agreements set
            LastAdjustment = 0,
            RVersion = -1
        where (ID = new$AdjustmentRef);
        if (new$LastAccepted = 1) then
            update Agreements set
                LastAccepted = 0,
                RVersion = -1
            where (ID = new$AdjustmentRef);
        end if;
    end if;

-- - - - - - - - - - - - -
-- AI_500 (TR_AGREEMENTS_AI_500)
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 110) AND (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_AGREEMENTS_IU
  INSTEAD OF UPDATE
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  new$ID AGREEMENTS.ID%TYPE := :NEW.ID;
  new$SUMMA AGREEMENTS.SUMMA%TYPE := :NEW.SUMMA;
  new$AGREEMENTDATE AGREEMENTS.AGREEMENTDATE%TYPE := :NEW.AGREEMENTDATE;
  new$AGREEMENTENDDATE AGREEMENTS.AGREEMENTENDDATE%TYPE := :NEW.AGREEMENTENDDATE;
  new$EXECUTER_REF AGREEMENTS.EXECUTER_REF%TYPE := :NEW.EXECUTER_REF;
  new$CLIENT_REF AGREEMENTS.CLIENT_REF%TYPE := :NEW.CLIENT_REF;
  new$FACIALACC_CLS AGREEMENTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$AGREEMENTTYPE AGREEMENTS.AGREEMENTTYPE%TYPE := :NEW.AGREEMENTTYPE;
  new$ACCEPTED AGREEMENTS.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$ACCEPTDATE AGREEMENTS.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$CARDADVANCEPERCENT AGREEMENTS.CARDADVANCEPERCENT%TYPE := :NEW.CARDADVANCEPERCENT;
  new$CARDADVANCE AGREEMENTS.CARDADVANCE%TYPE := :NEW.CARDADVANCE;
  new$CLOSEDOC AGREEMENTS.CLOSEDOC%TYPE := :NEW.CLOSEDOC;
  new$CREATERUSER AGREEMENTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE AGREEMENTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE AGREEMENTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER AGREEMENTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF AGREEMENTS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$LASTADJUSTMENT AGREEMENTS.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED AGREEMENTS.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$FACT AGREEMENTS.FACT%TYPE := :NEW.FACT;
  new$REGION AGREEMENTS.REGION%TYPE := :NEW.REGION;
  new$CLOSEDATE AGREEMENTS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$DELIVERYRULES AGREEMENTS.DELIVERYRULES%TYPE := :NEW.DELIVERYRULES;
  new$AGREEMENTSUMMA AGREEMENTS.AGREEMENTSUMMA%TYPE := :NEW.AGREEMENTSUMMA;
  new$AGREEMENTFINSUMMA AGREEMENTS.AGREEMENTFINSUMMA%TYPE := :NEW.AGREEMENTFINSUMMA;
  new$ADJUSTMENTREF AGREEMENTS.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$REESTRNUMBER AGREEMENTS.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$PAYMENTDATE AGREEMENTS.PAYMENTDATE%TYPE := :NEW.PAYMENTDATE;
  new$AGREEMENTCARDADVANCE AGREEMENTS.AGREEMENTCARDADVANCE%TYPE := :NEW.AGREEMENTCARDADVANCE;
  new$FINCARDADVANCE AGREEMENTS.FINCARDADVANCE%TYPE := :NEW.FINCARDADVANCE;
  new$STATEORDERREF AGREEMENTS.STATEORDERREF%TYPE := :NEW.STATEORDERREF;
  new$REJECTCLS AGREEMENTS.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS AGREEMENTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID AGREEMENTS.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID AGREEMENTS.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$AGREEMENTBEGINDATE AGREEMENTS.AGREEMENTBEGINDATE%TYPE := :NEW.AGREEMENTBEGINDATE;
  new$PROTOCOLNUMBER AGREEMENTS.PROTOCOLNUMBER%TYPE := :NEW.PROTOCOLNUMBER;
  new$PROTOCOLDATE AGREEMENTS.PROTOCOLDATE%TYPE := :NEW.PROTOCOLDATE;
  new$REVIEWNOTE AGREEMENTS.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF AGREEMENTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION AGREEMENTS.RVERSION%TYPE := :NEW.RVERSION;
  new$EXPORTDATE AGREEMENTS.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$FSORGAN AGREEMENTS.FSORGAN%TYPE := :NEW.FSORGAN;
  new$FSBUDGETNAME AGREEMENTS.FSBUDGETNAME%TYPE := :NEW.FSBUDGETNAME;
  new$FSOFFBUDGET AGREEMENTS.FSOFFBUDGET%TYPE := :NEW.FSOFFBUDGET;
  new$RNYEAR AGREEMENTS.RNYEAR%TYPE := :NEW.RNYEAR;
  new$RNNUMBER AGREEMENTS.RNNUMBER%TYPE := :NEW.RNNUMBER;
  new$RNDATE AGREEMENTS.RNDATE%TYPE := :NEW.RNDATE;
  new$PROTOCOLNOTICE AGREEMENTS.PROTOCOLNOTICE%TYPE := :NEW.PROTOCOLNOTICE;
  new$PROTOCOLRESULTDATE AGREEMENTS.PROTOCOLRESULTDATE%TYPE := :NEW.PROTOCOLRESULTDATE;
  new$PROTOCOLDOCTYPE AGREEMENTS.PROTOCOLDOCTYPE%TYPE := :NEW.PROTOCOLDOCTYPE;
  new$PROTOCOLSALETYPE AGREEMENTS.PROTOCOLSALETYPE%TYPE := :NEW.PROTOCOLSALETYPE;
  new$NOTIFYDATE AGREEMENTS.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$EXECUTERACCREF AGREEMENTS.EXECUTERACCREF%TYPE := :NEW.EXECUTERACCREF;
  new$DOCBASEDATE AGREEMENTS.DOCBASEDATE%TYPE := :NEW.DOCBASEDATE;
  new$DOCBASENOTIFYDATE AGREEMENTS.DOCBASENOTIFYDATE%TYPE := :NEW.DOCBASENOTIFYDATE;
  new$DOCBASETEXT AGREEMENTS.DOCBASETEXT%TYPE := :NEW.DOCBASETEXT;
  new$DOCBASETYPE AGREEMENTS.DOCBASETYPE%TYPE := :NEW.DOCBASETYPE;
  new$DOCBASESUMMA AGREEMENTS.DOCBASESUMMA%TYPE := :NEW.DOCBASESUMMA;
  new$UNKNOWNAMOUNT AGREEMENTS.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PROTOCOLREASON AGREEMENTS.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$DOCNUMBER AGREEMENTS.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$ADJUSTMENTDOCNUMBER AGREEMENTS.ADJUSTMENTDOCNUMBER%TYPE := :NEW.ADJUSTMENTDOCNUMBER;
  new$OLDDOCNUMBER AGREEMENTS.OLDDOCNUMBER%TYPE := :NEW.OLDDOCNUMBER;
  new$LOTMAXSUM AGREEMENTS.LOTMAXSUM%TYPE := :NEW.LOTMAXSUM;
  new$CLIENT_INN AGREEMENTS.CLIENT_INN%TYPE := :NEW.CLIENT_INN;
  new$CLIENT_INN20 AGREEMENTS.CLIENT_INN20%TYPE := :NEW.CLIENT_INN20;
  new$CLIENT_NAME AGREEMENTS.CLIENT_NAME%TYPE := :NEW.CLIENT_NAME;
  new$EXECUTER_INN AGREEMENTS.EXECUTER_INN%TYPE := :NEW.EXECUTER_INN;
  new$EXECUTER_INN20 AGREEMENTS.EXECUTER_INN20%TYPE := :NEW.EXECUTER_INN20;
  new$EXECUTER_NAME AGREEMENTS.EXECUTER_NAME%TYPE := :NEW.EXECUTER_NAME;
  new$EXECUTER_STATUS AGREEMENTS.EXECUTER_STATUS%TYPE := :NEW.EXECUTER_STATUS;
  new$EXECUTER_COUNTRY AGREEMENTS.EXECUTER_COUNTRY%TYPE := :NEW.EXECUTER_COUNTRY;
  new$EXECUTER_ADDRESS AGREEMENTS.EXECUTER_ADDRESS%TYPE := :NEW.EXECUTER_ADDRESS;
  new$EXECUTER_PHONE AGREEMENTS.EXECUTER_PHONE%TYPE := :NEW.EXECUTER_PHONE;
  new$REALID AGREEMENTS.REALID%TYPE := :NEW.REALID;
  new$ADJUSTMENTNUMBER AGREEMENTS.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$INNERNUMBER AGREEMENTS.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$SENDERIDKEY AGREEMENTS.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY AGREEMENTS.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REESTRVERSION AGREEMENTS.REESTRVERSION%TYPE := :NEW.REESTRVERSION;
  new$DOCTYPE AGREEMENTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$RNCLIENTID AGREEMENTS.RNCLIENTID%TYPE := :NEW.RNCLIENTID;
  new$INFONUMBER AGREEMENTS.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$STATEORDERINNERNUMBER AGREEMENTS.STATEORDERINNERNUMBER%TYPE := :NEW.STATEORDERINNERNUMBER;
  new$PROGINDEX AGREEMENTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE AGREEMENTS.NOTE%TYPE := :NEW.NOTE;
  new$PURPORTDOC AGREEMENTS.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$REESTRRECORDNUMBER AGREEMENTS.REESTRRECORDNUMBER%TYPE := :NEW.REESTRRECORDNUMBER;
  new$EXECUTERSTOREDPROPS AGREEMENTS.EXECUTERSTOREDPROPS%TYPE := :NEW.EXECUTERSTOREDPROPS;
  new$AUTOSANCTION AGREEMENTS.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$PURCHASECODE AGREEMENTS.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$DOCUMENTNUMBER AGREEMENTS.DOCUMENTNUMBER%TYPE := :NEW.DOCUMENTNUMBER;
  new$REJECTCAUSE AGREEMENTS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$TENDERREF AGREEMENTS.TENDERREF%TYPE := :NEW.TENDERREF;
  new$TENDERINNERNUMBER AGREEMENTS.TENDERINNERNUMBER%TYPE := :NEW.TENDERINNERNUMBER;
--
  MaxNumber$ NUMBER (10);
  CurVal$ NUMBER (10);
  CNT$1 NUMBER(10);
  DetCount$ NUMBER(10);
  CountAcc$ NUMBER(10);
  rnClientID1$ VARCHAR2(15);
  rnYear1$ VARCHAR2(15);
  rnNumber1$ VARCHAR2(15);
  ReestrVersion1$ VARCHAR2(15);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_AGREEMENTS_BU)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   3.1*/
  /*    -*/
  if (new$CardAdvancePercent is null) then
    new$CardAdvancePercent := 0;
  END IF;
  if (new$CardAdvance is null) then
    new$CardAdvance := 0;
  END IF;
  if (new$AgreementCardAdvance is null) then
    new$AgreementCardAdvance := 0;
  END IF;
  if (new$FinCardAdvance is null) then
    new$FinCardAdvance := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$AgreementSumma is null) then
    new$AgreementSumma := 0;
  END IF;
  if (new$AgreementFinSumma is null) then
    new$AgreementFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$Region is null) then
    new$Region := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$client_ref is null) then
    new$client_ref := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount$ from AgreementSteps where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      select count(ID)       into DetCount$ from Estimate where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*         -   InnerNumber*/
  if (((new$ProgIndex = 305) or (new$ProgIndex = 304) or (new$ProgIndex = 314)) and (new$InnerNumber is null)) then
    new$InnerNumber := GEN_ID('G_AgreementNumber',1);
  END IF;
  /*   */
  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  /*    .  */

  new$stateorderinnernumber := null;
  if (new$stateorderref is not null) then
    BEGIN
      select
      innernumber
      into new$stateorderinnernumber     from agreements
      where
      id = new$stateorderref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_3 (TR_AGREEMENTS_BU_3)
-- Create 03.12.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*            */
   new$AdjustmentRef := :OLD.AdjustmentRef;

-- - - - - - - - - - - - -
-- BU_5 (TR_AGREEMENTS_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_AGREEMENTS_BU_10)
-- Last update 08.02.2010
-- - - - - - - - - - - - -

/*   5.0*/
    /* ,      ,   */
    if ((new$InnerNumber <> :old.InnerNumber) or
        (new$AdjustmentNumber <> :old.AdjustmentNumber) or
        (new$AgreementType <> :old.AgreementType)) then
        RaiseException('EX_AGR_ChangeInnerNums');
    end if;

    /*    !!!*/
    if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and
        ((new$Accepted = 1) or (new$AcceptDate is null))) then
        RaiseException('EX_RollbackCancel');
    end if;

    /*   ,     LastAccepted*/
    if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) or
        ((:old.Accepted = 0) and (new$Accepted = 1) and (new$AcceptDate is not null))) then
        /*  LastAccepted         */
        if (new$LastAdjustment = 1) then
            new$LastAccepted := 1;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;
    end if;

    /*    ,     LastAccepted*/
    if (((:old.AcceptDate is not null) and (:old.Accepted = 1)) and
        ((new$Accepted = 0) or (new$AcceptDate is null))) then
        /*  LastAccepted         */
        if (new$LastAdjustment = 1) then
            new$LastAccepted := 0;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;
    end if;

    /*   ,     LastAdjustment*/
    if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 0)) or
        ((:old.Accepted = 1) and (new$Accepted = 0) and (new$AcceptDate is not null))) then

        if (new$LastAdjustment = 1) then
            new$LastAdjustment := 0;
            new$LastAccepted := 0;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;

        SELECT Max(AdjustmentNumber) INTO MaxNumber$ FROm AgreementS
        WHERE (InnerNumber = new$InnerNumber);
        /*    ,     */
        if ((new$adjustmentNumber=0) and (MaxNumber$<>0)) then
          RaiseException('EX_Agr_PrimaryAgrHasNotify');
        end if;
    end if;

-- - - - - - - - - - - - -
-- BU_20 (TR_AGREEMENTS_BU_20)
-- Create 21.05.2009
-- - - - - - - - - - - - -

  /*    -,      */
  if ((new$Client_Ref <> :old.Client_Ref) and
      (((new$Client_INN is null) and
        (:old.Client_INN is null)) or
       (new$Client_INN = :old.Client_INN)) and
      (((new$Client_INN20 is null) and
        (:old.Client_INN20 is null)) or
       (new$Client_INN20 = :old.Client_INN20)) and
      (new$Client_Name = :old.Client_Name)) then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name
      into
        new$Client_INN,
        new$Client_INN20,
        new$Client_Name
      from Organizations o
      where o.Id=new$Client_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Client_INN := NULL;
        new$Client_INN20 := NULL;
        new$Client_Name := NULL;
    END;
  END IF;

  /*    -,      */
  if ((new$Executer_Ref <> :old.Executer_Ref) and
      (((new$Executer_INN is null) and
        (:old.Executer_INN is null)) or
       (new$Executer_INN = :old.Executer_INN)) and
      (((new$Executer_INN20 is null) and
        (:old.Executer_INN20 is null)) or
       (new$Executer_INN20 = :old.Executer_INN20)) and
      (new$Executer_Name = :old.Executer_Name) and
      (((new$Executer_Status is null) and
        (:old.Executer_Status is null)) or
       (new$Executer_Status = :old.Executer_Status)) and
      (((new$Executer_Country is null) and
        (:old.Executer_Country is null)) or
       (new$Executer_Country = :old.Executer_Country)) and
      (((new$Executer_Address is null) and
        (:old.Executer_Address is null)) or
       (new$Executer_Address = :old.Executer_Address)) and
      (((new$Executer_Phone is null) and
        (:old.Executer_Phone is null)) or
       (new$Executer_Phone = :old.Executer_Phone))) then
     BEGIN
      select
        o.INN,
        o.INN20,
        o.Name,
        o.SupplierStatus,
        o.Country,
        o.Address,
        o.Phone
      into
        new$Executer_INN,
        new$Executer_INN20,
        new$Executer_Name,
        new$Executer_Status,
        new$Executer_Country,
        new$Executer_Address,
        new$Executer_Phone
      from Organizations o
      where o.Id=new$Executer_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Executer_INN := NULL;
        new$Executer_INN20 := NULL;
        new$Executer_Name := NULL;
        new$Executer_Status := NULL;
        new$Executer_Country := NULL;
        new$Executer_Address := NULL;
        new$Executer_Phone := NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_50 (TR_AGREEMENTS_BU_50)
-- Create 06.08.2010
-- - - - - - - - - - - - -

    if (new$InnerNumber is not null) then
        CurVal$ := gen_id('G_AgreementNumber', 0);
        if (CurVal$ < new$InnerNumber) then
          CurVal$ := gen_id('G_AgreementNumber', new$InnerNumber - CurVal$);
        end if;
    end if;

-- - - - - - - - - - - - -
-- BU_60 (tr_agreements_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*        ,     */
  if (:old.accepted = 1 and new$accepted = 0 and new$acceptdate is not null and new$adjustmentnumber = 0) then
    SELECT COUNT(*) INTO CNT$1
    from executiondocumentscaption
    where
    (            agreementinnernumber = new$innernumber
    and (accepted <> 0 or acceptdate is null)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_Agr_CannotReject');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_AGREEMENTS_BU_200)
-- Create 04.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$id, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (tr_agreements_bu_300)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$ExecuterAccRef is not null) then
    select count(ID)
    into CountAcc$     from org_accounts oa
    where oa.id = new$ExecuterAccRef and oa.Org_ref = new$Executer_Ref
    ;
    if (CountAcc$ = 0) then
      RaiseException('EX_AGR_ACCORGCHECK');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (TR_AGREEMENTS_BU_400)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (((new$rnClientID <> :old.rnClientID) or (new$rnYear <> :old.rnYear) or
  (new$rnNumber <> :old.rnNumber) or (new$ReestrVersion <> :old.ReestrVersion)) and
  (new$rnClientID is not null) and (new$rnYear is not null) and (new$rnNumber is not null)) then

    rnClientID1$ := new$rnClientID;
    rnYear1$ := new$rnYear;
    rnNumber1$ := new$rnNumber;
    ReestrVersion1$ := new$ReestrVersion;
    while (LENGTH(rnClientID1$) < 11) LOOP
      rnClientID1$ := '0' || rnClientID1$;
    END LOOP;
    while (LENGTH(rnNumber1$) < 6) LOOP
      rnNumber1$ := '0' || rnNumber1$;
    END LOOP;
    if (LENGTH(ReestrVersion1$) < 2) then
      ReestrVersion1$ := '0' || ReestrVersion1$;
    END IF;
    /*  ReestrRecordNumber*/
    if (new$ReestrVersion is null) then
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$;

    else
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$ || ReestrVersion1$;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_600 (agreements_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_AGREEMENTS_BU_700)
-- Create 14.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_AGREEMENTS SET
    ID = new$ID,
    SUMMA = new$SUMMA,
    AGREEMENTDATE = new$AGREEMENTDATE,
    AGREEMENTENDDATE = new$AGREEMENTENDDATE,
    EXECUTER_REF = new$EXECUTER_REF,
    CLIENT_REF = new$CLIENT_REF,
    FACIALACC_CLS = new$FACIALACC_CLS,
    AGREEMENTTYPE = new$AGREEMENTTYPE,
    ACCEPTED = new$ACCEPTED,
    ACCEPTDATE = new$ACCEPTDATE,
    CARDADVANCEPERCENT = new$CARDADVANCEPERCENT,
    CARDADVANCE = new$CARDADVANCE,
    CLOSEDOC = new$CLOSEDOC,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    FACT = new$FACT,
    REGION = new$REGION,
    CLOSEDATE = new$CLOSEDATE,
    DELIVERYRULES = new$DELIVERYRULES,
    AGREEMENTSUMMA = new$AGREEMENTSUMMA,
    AGREEMENTFINSUMMA = new$AGREEMENTFINSUMMA,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    REESTRNUMBER = new$REESTRNUMBER,
    PAYMENTDATE = new$PAYMENTDATE,
    AGREEMENTCARDADVANCE = new$AGREEMENTCARDADVANCE,
    FINCARDADVANCE = new$FINCARDADVANCE,
    STATEORDERREF = new$STATEORDERREF,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    AGREEMENTBEGINDATE = new$AGREEMENTBEGINDATE,
    PROTOCOLNUMBER = new$PROTOCOLNUMBER,
    PROTOCOLDATE = new$PROTOCOLDATE,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXPORTDATE = new$EXPORTDATE,
    FSORGAN = new$FSORGAN,
    FSBUDGETNAME = new$FSBUDGETNAME,
    FSOFFBUDGET = new$FSOFFBUDGET,
    RNYEAR = new$RNYEAR,
    RNNUMBER = new$RNNUMBER,
    RNDATE = new$RNDATE,
    PROTOCOLNOTICE = new$PROTOCOLNOTICE,
    PROTOCOLRESULTDATE = new$PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE = new$PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE = new$PROTOCOLSALETYPE,
    NOTIFYDATE = new$NOTIFYDATE,
    EXECUTERACCREF = new$EXECUTERACCREF,
    DOCBASEDATE = new$DOCBASEDATE,
    DOCBASENOTIFYDATE = new$DOCBASENOTIFYDATE,
    DOCBASETEXT = new$DOCBASETEXT,
    DOCBASETYPE = new$DOCBASETYPE,
    DOCBASESUMMA = new$DOCBASESUMMA,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PROTOCOLREASON = new$PROTOCOLREASON,
    DOCNUMBER = new$DOCNUMBER,
    ADJUSTMENTDOCNUMBER = new$ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER = new$OLDDOCNUMBER,
    LOTMAXSUM = new$LOTMAXSUM,
    CLIENT_INN = new$CLIENT_INN,
    CLIENT_INN20 = new$CLIENT_INN20,
    CLIENT_NAME = new$CLIENT_NAME,
    EXECUTER_INN = new$EXECUTER_INN,
    EXECUTER_INN20 = new$EXECUTER_INN20,
    EXECUTER_NAME = new$EXECUTER_NAME,
    EXECUTER_STATUS = new$EXECUTER_STATUS,
    EXECUTER_COUNTRY = new$EXECUTER_COUNTRY,
    EXECUTER_ADDRESS = new$EXECUTER_ADDRESS,
    EXECUTER_PHONE = new$EXECUTER_PHONE,
    REALID = new$REALID,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    INNERNUMBER = new$INNERNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REESTRVERSION = new$REESTRVERSION,
    DOCTYPE = new$DOCTYPE,
    RNCLIENTID = new$RNCLIENTID,
    INFONUMBER = new$INFONUMBER,
    STATEORDERINNERNUMBER = new$STATEORDERINNERNUMBER,
    PROGINDEX = new$PROGINDEX,
    NOTE = new$NOTE,
    PURPORTDOC = new$PURPORTDOC,
    REESTRRECORDNUMBER = new$REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS = new$EXECUTERSTOREDPROPS,
    AUTOSANCTION = new$AUTOSANCTION,
    PURCHASECODE = new$PURCHASECODE,
    DOCUMENTNUMBER = new$DOCUMENTNUMBER,
    REJECTCAUSE = new$REJECTCAUSE,
    TENDERREF = new$TENDERREF,
    TENDERINNERNUMBER = new$TENDERINNERNUMBER
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_AGREEMENTS_AU_10)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   6.0*/
  /*      */
  /*     ,       */
  if ((new$AdjustmentNumber > 0) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update Agreements set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentNumber > 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update Agreements set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*          */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 304)or(new$ProgIndex = 314)))then
    update Estimate
    set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    (RecordIndex = new$Id);
  END IF;
  /*         */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 305) or (new$ProgIndex = 314))) then
    update paymentschedule set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    AgreementRef = new$ID and
    ProgIndex in (317, 318);

  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_AGREEMENTS_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*      */
  if ((new$ProgIndex = 305) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null
    where
    StateOrder = :old.ID;
  END IF;
  /*      */
  if ((new$ProgIndex = 314) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null,
    Agreement = null
    where
    StateOrder = :old.ID;
  END IF;
  /*     */
  if ((:old.ProgIndex = 304) and (new$AdjustmentNumber = 0) and (new$Accepted = 0) and
  (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    Agreement = null
    where
    Agreement = :old.ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_AGREEMENTS_AU_30)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$ProgIndex = 304) or (new$ProgIndex = 314)) and
  ((new$Accepted <> :old.Accepted) or
  (new$AcceptDate is not null and :old.AcceptDate is null) or
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where AgreementRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_AGREEMENTS_AU_500)
-- Create 28.04.2005
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes
                  (TableID, RecordId, DeleteDate
                  )
           VALUES (110, :OLD.ID, SYSDATE
                  );

      DELETE FROM DelRecIndexes
            WHERE (TableID = 110) AND (RecordId = new$ID);
   END IF;

END;
/
/*       30. */
create index IDX_Agreements_TenderInnerNum on TB_Agreements (TenderInnerNumber)
/
commit work
/
-- CREATE TRIGGER tr_agreements_bi
CREATE OR REPLACE TRIGGER TR_AGREEMENTS_II
  INSTEAD OF INSERT
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  new$ID AGREEMENTS.ID%TYPE := :NEW.ID;
  new$SUMMA AGREEMENTS.SUMMA%TYPE := :NEW.SUMMA;
  new$AGREEMENTDATE AGREEMENTS.AGREEMENTDATE%TYPE := :NEW.AGREEMENTDATE;
  new$AGREEMENTENDDATE AGREEMENTS.AGREEMENTENDDATE%TYPE := :NEW.AGREEMENTENDDATE;
  new$EXECUTER_REF AGREEMENTS.EXECUTER_REF%TYPE := :NEW.EXECUTER_REF;
  new$CLIENT_REF AGREEMENTS.CLIENT_REF%TYPE := :NEW.CLIENT_REF;
  new$FACIALACC_CLS AGREEMENTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$AGREEMENTTYPE AGREEMENTS.AGREEMENTTYPE%TYPE := :NEW.AGREEMENTTYPE;
  new$ACCEPTED AGREEMENTS.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$ACCEPTDATE AGREEMENTS.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$CARDADVANCEPERCENT AGREEMENTS.CARDADVANCEPERCENT%TYPE := :NEW.CARDADVANCEPERCENT;
  new$CARDADVANCE AGREEMENTS.CARDADVANCE%TYPE := :NEW.CARDADVANCE;
  new$CLOSEDOC AGREEMENTS.CLOSEDOC%TYPE := :NEW.CLOSEDOC;
  new$CREATERUSER AGREEMENTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE AGREEMENTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE AGREEMENTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER AGREEMENTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF AGREEMENTS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$LASTADJUSTMENT AGREEMENTS.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED AGREEMENTS.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$FACT AGREEMENTS.FACT%TYPE := :NEW.FACT;
  new$REGION AGREEMENTS.REGION%TYPE := :NEW.REGION;
  new$CLOSEDATE AGREEMENTS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$DELIVERYRULES AGREEMENTS.DELIVERYRULES%TYPE := :NEW.DELIVERYRULES;
  new$AGREEMENTSUMMA AGREEMENTS.AGREEMENTSUMMA%TYPE := :NEW.AGREEMENTSUMMA;
  new$AGREEMENTFINSUMMA AGREEMENTS.AGREEMENTFINSUMMA%TYPE := :NEW.AGREEMENTFINSUMMA;
  new$ADJUSTMENTREF AGREEMENTS.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$REESTRNUMBER AGREEMENTS.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$PAYMENTDATE AGREEMENTS.PAYMENTDATE%TYPE := :NEW.PAYMENTDATE;
  new$AGREEMENTCARDADVANCE AGREEMENTS.AGREEMENTCARDADVANCE%TYPE := :NEW.AGREEMENTCARDADVANCE;
  new$FINCARDADVANCE AGREEMENTS.FINCARDADVANCE%TYPE := :NEW.FINCARDADVANCE;
  new$STATEORDERREF AGREEMENTS.STATEORDERREF%TYPE := :NEW.STATEORDERREF;
  new$REJECTCLS AGREEMENTS.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS AGREEMENTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID AGREEMENTS.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID AGREEMENTS.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$AGREEMENTBEGINDATE AGREEMENTS.AGREEMENTBEGINDATE%TYPE := :NEW.AGREEMENTBEGINDATE;
  new$PROTOCOLNUMBER AGREEMENTS.PROTOCOLNUMBER%TYPE := :NEW.PROTOCOLNUMBER;
  new$PROTOCOLDATE AGREEMENTS.PROTOCOLDATE%TYPE := :NEW.PROTOCOLDATE;
  new$REVIEWNOTE AGREEMENTS.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF AGREEMENTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION AGREEMENTS.RVERSION%TYPE := :NEW.RVERSION;
  new$EXPORTDATE AGREEMENTS.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$FSORGAN AGREEMENTS.FSORGAN%TYPE := :NEW.FSORGAN;
  new$FSBUDGETNAME AGREEMENTS.FSBUDGETNAME%TYPE := :NEW.FSBUDGETNAME;
  new$FSOFFBUDGET AGREEMENTS.FSOFFBUDGET%TYPE := :NEW.FSOFFBUDGET;
  new$RNYEAR AGREEMENTS.RNYEAR%TYPE := :NEW.RNYEAR;
  new$RNNUMBER AGREEMENTS.RNNUMBER%TYPE := :NEW.RNNUMBER;
  new$RNDATE AGREEMENTS.RNDATE%TYPE := :NEW.RNDATE;
  new$PROTOCOLNOTICE AGREEMENTS.PROTOCOLNOTICE%TYPE := :NEW.PROTOCOLNOTICE;
  new$PROTOCOLRESULTDATE AGREEMENTS.PROTOCOLRESULTDATE%TYPE := :NEW.PROTOCOLRESULTDATE;
  new$PROTOCOLDOCTYPE AGREEMENTS.PROTOCOLDOCTYPE%TYPE := :NEW.PROTOCOLDOCTYPE;
  new$PROTOCOLSALETYPE AGREEMENTS.PROTOCOLSALETYPE%TYPE := :NEW.PROTOCOLSALETYPE;
  new$NOTIFYDATE AGREEMENTS.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$EXECUTERACCREF AGREEMENTS.EXECUTERACCREF%TYPE := :NEW.EXECUTERACCREF;
  new$DOCBASEDATE AGREEMENTS.DOCBASEDATE%TYPE := :NEW.DOCBASEDATE;
  new$DOCBASENOTIFYDATE AGREEMENTS.DOCBASENOTIFYDATE%TYPE := :NEW.DOCBASENOTIFYDATE;
  new$DOCBASETEXT AGREEMENTS.DOCBASETEXT%TYPE := :NEW.DOCBASETEXT;
  new$DOCBASETYPE AGREEMENTS.DOCBASETYPE%TYPE := :NEW.DOCBASETYPE;
  new$DOCBASESUMMA AGREEMENTS.DOCBASESUMMA%TYPE := :NEW.DOCBASESUMMA;
  new$UNKNOWNAMOUNT AGREEMENTS.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PROTOCOLREASON AGREEMENTS.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$DOCNUMBER AGREEMENTS.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$ADJUSTMENTDOCNUMBER AGREEMENTS.ADJUSTMENTDOCNUMBER%TYPE := :NEW.ADJUSTMENTDOCNUMBER;
  new$OLDDOCNUMBER AGREEMENTS.OLDDOCNUMBER%TYPE := :NEW.OLDDOCNUMBER;
  new$LOTMAXSUM AGREEMENTS.LOTMAXSUM%TYPE := :NEW.LOTMAXSUM;
  new$CLIENT_INN AGREEMENTS.CLIENT_INN%TYPE := :NEW.CLIENT_INN;
  new$CLIENT_INN20 AGREEMENTS.CLIENT_INN20%TYPE := :NEW.CLIENT_INN20;
  new$CLIENT_NAME AGREEMENTS.CLIENT_NAME%TYPE := :NEW.CLIENT_NAME;
  new$EXECUTER_INN AGREEMENTS.EXECUTER_INN%TYPE := :NEW.EXECUTER_INN;
  new$EXECUTER_INN20 AGREEMENTS.EXECUTER_INN20%TYPE := :NEW.EXECUTER_INN20;
  new$EXECUTER_NAME AGREEMENTS.EXECUTER_NAME%TYPE := :NEW.EXECUTER_NAME;
  new$EXECUTER_STATUS AGREEMENTS.EXECUTER_STATUS%TYPE := :NEW.EXECUTER_STATUS;
  new$EXECUTER_COUNTRY AGREEMENTS.EXECUTER_COUNTRY%TYPE := :NEW.EXECUTER_COUNTRY;
  new$EXECUTER_ADDRESS AGREEMENTS.EXECUTER_ADDRESS%TYPE := :NEW.EXECUTER_ADDRESS;
  new$EXECUTER_PHONE AGREEMENTS.EXECUTER_PHONE%TYPE := :NEW.EXECUTER_PHONE;
  new$REALID AGREEMENTS.REALID%TYPE := :NEW.REALID;
  new$ADJUSTMENTNUMBER AGREEMENTS.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$INNERNUMBER AGREEMENTS.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$SENDERIDKEY AGREEMENTS.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY AGREEMENTS.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REESTRVERSION AGREEMENTS.REESTRVERSION%TYPE := :NEW.REESTRVERSION;
  new$DOCTYPE AGREEMENTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$RNCLIENTID AGREEMENTS.RNCLIENTID%TYPE := :NEW.RNCLIENTID;
  new$INFONUMBER AGREEMENTS.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$STATEORDERINNERNUMBER AGREEMENTS.STATEORDERINNERNUMBER%TYPE := :NEW.STATEORDERINNERNUMBER;
  new$PROGINDEX AGREEMENTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE AGREEMENTS.NOTE%TYPE := :NEW.NOTE;
  new$PURPORTDOC AGREEMENTS.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$REESTRRECORDNUMBER AGREEMENTS.REESTRRECORDNUMBER%TYPE := :NEW.REESTRRECORDNUMBER;
  new$EXECUTERSTOREDPROPS AGREEMENTS.EXECUTERSTOREDPROPS%TYPE := :NEW.EXECUTERSTOREDPROPS;
  new$AUTOSANCTION AGREEMENTS.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$PURCHASECODE AGREEMENTS.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$DOCUMENTNUMBER AGREEMENTS.DOCUMENTNUMBER%TYPE := :NEW.DOCUMENTNUMBER;
  new$REJECTCAUSE AGREEMENTS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$TENDERREF AGREEMENTS.TENDERREF%TYPE := :NEW.TENDERREF;
  new$TENDERINNERNUMBER AGREEMENTS.TENDERINNERNUMBER%TYPE := :NEW.TENDERINNERNUMBER;
--
  CurVal$ NUMBER (10);
  CountAcc$ NUMBER(10);
  rnClientID1$ VARCHAR2(15);
  rnYear1$ VARCHAR2(15);
  rnNumber1$ VARCHAR2(15);
  ReestrVersion1$ VARCHAR2(15);
  Tmp$ NUMBER(10);
  AdjID$ NUMBER(10);
  AdjDocNum$ VARCHAR2(150);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_AGREEMENTS_BI)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*   12.0*/
  /*    -*/
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$CardAdvancePercent is null) then 
    new$CardAdvancePercent := 0;
  END IF;
  if (new$CardAdvance is null) then 
    new$CardAdvance := 0;
  END IF;
  if (new$AgreementCardAdvance is null) then 
    new$AgreementCardAdvance := 0;
  END IF;
  if (new$FinCardAdvance is null) then 
    new$FinCardAdvance := 0;
  END IF;
  if (new$Summa is null) then 
    new$Summa := 0;
  END IF;
  if (new$AgreementSumma is null) then 
    new$AgreementSumma := 0;
  END IF;
  if (new$AgreementFinSumma is null) then 
    new$AgreementFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Fact is null) then 
    new$Fact := 0;
  END IF;
  if (new$Region is null) then 
    new$Region := 0;
  END IF;
  if (new$UnknownAmount is null) then 
    new$UnknownAmount := 0;
  END IF;
  if (new$Accepted is null) then 
    new$Accepted := 1;
  END IF;
  if (new$client_ref is null) then 
    new$client_ref := 0;
  END IF;
    
  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    BEGIN
      select fa.BudgetRef     into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) 
  then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
    
  /*     
         -   InnerNumber*/
  if (((new$ProgIndex = 305) or (new$ProgIndex = 304) or (new$ProgIndex = 314)) and (new$InnerNumber is null)) then
    new$InnerNumber := GEN_ID('G_AgreementNumber',1);
  END IF;
  /*   */
  if (new$DocType is null) then 
    new$DocType := 0;
  END IF;
  /*    .  */
    
  new$stateorderinnernumber := null;
  if (new$stateorderref is not null) then
    BEGIN
      select
      innernumber
      into new$stateorderinnernumber     from agreements
      where
      id = new$stateorderref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*     30.  id */
    
  new$TenderInnerNumber := null;
  if (new$TenderRef is not null) then
    BEGIN
      select InnerNumber 
      into new$TenderInnerNumber     from TenderCaption
      where id = new$TenderRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_AGREEMENTS_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_AGREEMENTS_BI_10)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  /*   5.0*/

  /*    .*/
  if (new$InnerNumber is null) then
    RaiseException('EX_AGR_InnerNumsIsNull');
  END IF;

  /*    */
  select max(AdjustmentNumber)
  into Tmp$         from Agreements
  where (InnerNumber = new$InnerNumber)
  ;
  /*      ,   0*/
  if (Tmp$ is null) then
    new$AdjustmentNumber := 0;

  else
    new$AdjustmentNumber := Tmp$ + 1;
  END IF;
  /*        */
  if (((new$AgreementType = 0) and (new$AdjustmentNumber > 0)) or
  ((new$AgreementType = 1) and (new$AdjustmentNumber = 0))) then
    RaiseException('EX_AGR_AgrTypeViolation');
  END IF;
  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;

  else
    new$LastAdjustment := 1;
  END IF;
  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then
    new$LastAccepted := 1;

  else
    new$LastAccepted := 0;
  END IF;
  /*    */
  if (new$AdjustmentNumber > 0) then
    /*      -    */
    select count(ID), max(ID), max(DocNumber)
    into Tmp$, AdjID$, AdjDocNum$             from Agreements
    where (InnerNumber = new$InnerNumber) and (LastAccepted = 1)
    ;
    /*   ,  */
    if (Tmp$ <> 1) then
      RaiseException('EX_AGR_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID)
    into Tmp$             from Agreements
    where (InnerNumber = new$InnerNumber) and (AcceptDate is null)
    ;
    if (Tmp$ > 0) then
      RaiseException('EX_AGR_AdjustDuplicate');
    END IF;
    /* ,    ,    */
    new$AdjustmentRef := AdjID$;
    new$AdjustmentDocNumber := AdjDocNum$;

  else /*     */
    /*       (    )*/
    new$AdjustmentRef := null;
    new$AdjustmentDocNumber := null;

  END IF;

-- - - - - - - - - - - - -
-- BI_20 (TR_AGREEMENTS_BI_20)
-- Create 21.05.2009
-- - - - - - - - - - - - -

  /*    -,     */
  if ((new$Client_INN   is null) and
      (new$Client_INN20 is null) and
      (new$Client_Name  is null))then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name
      into
        new$Client_INN,
        new$Client_INN20,
        new$Client_Name
      from Organizations o
      where o.Id=new$Client_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Client_INN := NULL;
        new$Client_INN20 := NULL;
        new$Client_Name := NULL;
    END;
  END IF;

  /*    -,     */
  if ((new$Executer_INN     is null) and
      (new$Executer_INN20   is null) and
      (new$Executer_Name    is null) and
      (new$Executer_Status  is null) and
      (new$Executer_Country is null) and
      (new$Executer_Address is null) and
      (new$Executer_Phone   is null))then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name,
        o.SupplierStatus,
        o.Country,
        o.Address,
        o.Phone
      into
        new$Executer_INN,
        new$Executer_INN20,
        new$Executer_Name,
        new$Executer_Status,
        new$Executer_Country,
        new$Executer_Address,
        new$Executer_Phone
      from Organizations o
      where o.Id=new$Executer_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Executer_INN := NULL;
        new$Executer_INN20 := NULL;
        new$Executer_Name := NULL;
        new$Executer_Status := NULL;
        new$Executer_Country := NULL;
        new$Executer_Address := NULL;
        new$Executer_Phone := NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_40 (TR_AGREEMENTS_BI_40)
-- Create 06.08.2010
-- - - - - - - - - - - - -

  /*       */
  if (new$senderId is null) then
    new$senderIdKey := -1;
  else
    new$senderIdKey := new$senderId;
  end if;

  if (new$SenderRecordID is null)then
    new$SenderRecordIDKey := new$ID;
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  end if;

-- - - - - - - - - - - - -
-- BI_50 (TR_AGREEMENTS_BI_50)
-- Create 06.08.2010
-- - - - - - - - - - - - -

    if (new$InnerNumber is not null) then
        CurVal$ := gen_id('G_AgreementNumber', 0);
        if (CurVal$ < new$InnerNumber) then
          CurVal$ := gen_id('G_AgreementNumber', new$InnerNumber - CurVal$);
        end if;
    end if;

-- - - - - - - - - - - - -
-- BI_300 (tr_agreements_bi_300)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$ExecuterAccRef is not null) then
    select count(ID)
    into CountAcc$     from org_accounts oa
    where oa.id = new$ExecuterAccRef and oa.Org_ref = new$Executer_Ref
    ;
    if (CountAcc$ = 0) then
      RaiseException('EX_AGR_ACCORGCHECK');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_400 (TR_AGREEMENTS_BI_400)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if ((new$rnClientID is not null) and (new$rnYear is not null) and (new$rnNumber is not null)) then

    rnClientID1$ := new$rnClientID;
    rnYear1$ := new$rnYear;
    rnNumber1$ := new$rnNumber;
    ReestrVersion1$ := new$ReestrVersion;
    while (LENGTH(rnClientID1$) < 11) LOOP
      rnClientID1$ := '0' || rnClientID1$;
    END LOOP;
    while (LENGTH(rnNumber1$) < 6) LOOP
      rnNumber1$ := '0' || rnNumber1$;
    END LOOP;
    if (LENGTH(ReestrVersion1$) < 2) then
      ReestrVersion1$ := '0' || ReestrVersion1$;
    END IF;
    /*  ReestrRecordNumber*/
    if (new$ReestrVersion is null) then
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$;

    else
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$ || ReestrVersion1$;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_AGREEMENTS_BI_500)
-- Last update 19.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- BI_600 (agreements_realid_bi_600)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_AGREEMENTS (
    ID,
    SUMMA,
    AGREEMENTDATE,
    AGREEMENTENDDATE,
    EXECUTER_REF,
    CLIENT_REF,
    FACIALACC_CLS,
    AGREEMENTTYPE,
    ACCEPTED,
    ACCEPTDATE,
    CARDADVANCEPERCENT,
    CARDADVANCE,
    CLOSEDOC,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    LASTADJUSTMENT,
    LASTACCEPTED,
    FACT,
    REGION,
    CLOSEDATE,
    DELIVERYRULES,
    AGREEMENTSUMMA,
    AGREEMENTFINSUMMA,
    ADJUSTMENTREF,
    REESTRNUMBER,
    PAYMENTDATE,
    AGREEMENTCARDADVANCE,
    FINCARDADVANCE,
    STATEORDERREF,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    AGREEMENTBEGINDATE,
    PROTOCOLNUMBER,
    PROTOCOLDATE,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXPORTDATE,
    FSORGAN,
    FSBUDGETNAME,
    FSOFFBUDGET,
    RNYEAR,
    RNNUMBER,
    RNDATE,
    PROTOCOLNOTICE,
    PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE,
    NOTIFYDATE,
    EXECUTERACCREF,
    DOCBASEDATE,
    DOCBASENOTIFYDATE,
    DOCBASETEXT,
    DOCBASETYPE,
    DOCBASESUMMA,
    UNKNOWNAMOUNT,
    PROTOCOLREASON,
    DOCNUMBER,
    ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER,
    LOTMAXSUM,
    CLIENT_INN,
    CLIENT_INN20,
    CLIENT_NAME,
    EXECUTER_INN,
    EXECUTER_INN20,
    EXECUTER_NAME,
    EXECUTER_STATUS,
    EXECUTER_COUNTRY,
    EXECUTER_ADDRESS,
    EXECUTER_PHONE,
    REALID,
    ADJUSTMENTNUMBER,
    INNERNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REESTRVERSION,
    DOCTYPE,
    RNCLIENTID,
    INFONUMBER,
    STATEORDERINNERNUMBER,
    PROGINDEX,
    NOTE,
    PURPORTDOC,
    REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS,
    AUTOSANCTION,
    PURCHASECODE,
    DOCUMENTNUMBER,
    REJECTCAUSE,
    TENDERREF,
    TENDERINNERNUMBER
  ) VALUES (
    new$ID,
    new$SUMMA,
    new$AGREEMENTDATE,
    new$AGREEMENTENDDATE,
    new$EXECUTER_REF,
    new$CLIENT_REF,
    new$FACIALACC_CLS,
    new$AGREEMENTTYPE,
    new$ACCEPTED,
    new$ACCEPTDATE,
    new$CARDADVANCEPERCENT,
    new$CARDADVANCE,
    new$CLOSEDOC,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$LASTADJUSTMENT,
    new$LASTACCEPTED,
    new$FACT,
    new$REGION,
    new$CLOSEDATE,
    new$DELIVERYRULES,
    new$AGREEMENTSUMMA,
    new$AGREEMENTFINSUMMA,
    new$ADJUSTMENTREF,
    new$REESTRNUMBER,
    new$PAYMENTDATE,
    new$AGREEMENTCARDADVANCE,
    new$FINCARDADVANCE,
    new$STATEORDERREF,
    new$REJECTCLS,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$AGREEMENTBEGINDATE,
    new$PROTOCOLNUMBER,
    new$PROTOCOLDATE,
    new$REVIEWNOTE,
    new$DOCSTATEREF,
    new$RVERSION,
    new$EXPORTDATE,
    new$FSORGAN,
    new$FSBUDGETNAME,
    new$FSOFFBUDGET,
    new$RNYEAR,
    new$RNNUMBER,
    new$RNDATE,
    new$PROTOCOLNOTICE,
    new$PROTOCOLRESULTDATE,
    new$PROTOCOLDOCTYPE,
    new$PROTOCOLSALETYPE,
    new$NOTIFYDATE,
    new$EXECUTERACCREF,
    new$DOCBASEDATE,
    new$DOCBASENOTIFYDATE,
    new$DOCBASETEXT,
    new$DOCBASETYPE,
    new$DOCBASESUMMA,
    new$UNKNOWNAMOUNT,
    new$PROTOCOLREASON,
    new$DOCNUMBER,
    new$ADJUSTMENTDOCNUMBER,
    new$OLDDOCNUMBER,
    new$LOTMAXSUM,
    new$CLIENT_INN,
    new$CLIENT_INN20,
    new$CLIENT_NAME,
    new$EXECUTER_INN,
    new$EXECUTER_INN20,
    new$EXECUTER_NAME,
    new$EXECUTER_STATUS,
    new$EXECUTER_COUNTRY,
    new$EXECUTER_ADDRESS,
    new$EXECUTER_PHONE,
    new$REALID,
    new$ADJUSTMENTNUMBER,
    new$INNERNUMBER,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$REESTRVERSION,
    new$DOCTYPE,
    new$RNCLIENTID,
    new$INFONUMBER,
    new$STATEORDERINNERNUMBER,
    new$PROGINDEX,
    new$NOTE,
    new$PURPORTDOC,
    new$REESTRRECORDNUMBER,
    new$EXECUTERSTOREDPROPS,
    new$AUTOSANCTION,
    new$PURCHASECODE,
    new$DOCUMENTNUMBER,
    new$REJECTCAUSE,
    new$TENDERREF,
    new$TENDERINNERNUMBER);

-- - - - - - - - - - - - -
-- AI_10 (TR_AGREEMENTS_AI_10)
-- Last update 05.02.2010
-- - - - - - - - - - - - -

/*   5.0*/
    if ((new$AdjustmentNumber > 0) and (new$LastAdjustment = 1)) then
        update Agreements set
            LastAdjustment = 0,
            RVersion = -1
        where (ID = new$AdjustmentRef);
        if (new$LastAccepted = 1) then
            update Agreements set
                LastAccepted = 0,
                RVersion = -1
            where (ID = new$AdjustmentRef);
        end if;
    end if;

-- - - - - - - - - - - - -
-- AI_500 (TR_AGREEMENTS_AI_500)
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 110) AND (RecordID = new$ID);

END;
/
-- CREATE TRIGGER tr_agreements_bu
CREATE OR REPLACE TRIGGER TR_AGREEMENTS_IU
  INSTEAD OF UPDATE
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  new$ID AGREEMENTS.ID%TYPE := :NEW.ID;
  new$SUMMA AGREEMENTS.SUMMA%TYPE := :NEW.SUMMA;
  new$AGREEMENTDATE AGREEMENTS.AGREEMENTDATE%TYPE := :NEW.AGREEMENTDATE;
  new$AGREEMENTENDDATE AGREEMENTS.AGREEMENTENDDATE%TYPE := :NEW.AGREEMENTENDDATE;
  new$EXECUTER_REF AGREEMENTS.EXECUTER_REF%TYPE := :NEW.EXECUTER_REF;
  new$CLIENT_REF AGREEMENTS.CLIENT_REF%TYPE := :NEW.CLIENT_REF;
  new$FACIALACC_CLS AGREEMENTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$AGREEMENTTYPE AGREEMENTS.AGREEMENTTYPE%TYPE := :NEW.AGREEMENTTYPE;
  new$ACCEPTED AGREEMENTS.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$ACCEPTDATE AGREEMENTS.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$CARDADVANCEPERCENT AGREEMENTS.CARDADVANCEPERCENT%TYPE := :NEW.CARDADVANCEPERCENT;
  new$CARDADVANCE AGREEMENTS.CARDADVANCE%TYPE := :NEW.CARDADVANCE;
  new$CLOSEDOC AGREEMENTS.CLOSEDOC%TYPE := :NEW.CLOSEDOC;
  new$CREATERUSER AGREEMENTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE AGREEMENTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE AGREEMENTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER AGREEMENTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF AGREEMENTS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$LASTADJUSTMENT AGREEMENTS.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED AGREEMENTS.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$FACT AGREEMENTS.FACT%TYPE := :NEW.FACT;
  new$REGION AGREEMENTS.REGION%TYPE := :NEW.REGION;
  new$CLOSEDATE AGREEMENTS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$DELIVERYRULES AGREEMENTS.DELIVERYRULES%TYPE := :NEW.DELIVERYRULES;
  new$AGREEMENTSUMMA AGREEMENTS.AGREEMENTSUMMA%TYPE := :NEW.AGREEMENTSUMMA;
  new$AGREEMENTFINSUMMA AGREEMENTS.AGREEMENTFINSUMMA%TYPE := :NEW.AGREEMENTFINSUMMA;
  new$ADJUSTMENTREF AGREEMENTS.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$REESTRNUMBER AGREEMENTS.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$PAYMENTDATE AGREEMENTS.PAYMENTDATE%TYPE := :NEW.PAYMENTDATE;
  new$AGREEMENTCARDADVANCE AGREEMENTS.AGREEMENTCARDADVANCE%TYPE := :NEW.AGREEMENTCARDADVANCE;
  new$FINCARDADVANCE AGREEMENTS.FINCARDADVANCE%TYPE := :NEW.FINCARDADVANCE;
  new$STATEORDERREF AGREEMENTS.STATEORDERREF%TYPE := :NEW.STATEORDERREF;
  new$REJECTCLS AGREEMENTS.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS AGREEMENTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID AGREEMENTS.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID AGREEMENTS.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$AGREEMENTBEGINDATE AGREEMENTS.AGREEMENTBEGINDATE%TYPE := :NEW.AGREEMENTBEGINDATE;
  new$PROTOCOLNUMBER AGREEMENTS.PROTOCOLNUMBER%TYPE := :NEW.PROTOCOLNUMBER;
  new$PROTOCOLDATE AGREEMENTS.PROTOCOLDATE%TYPE := :NEW.PROTOCOLDATE;
  new$REVIEWNOTE AGREEMENTS.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF AGREEMENTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION AGREEMENTS.RVERSION%TYPE := :NEW.RVERSION;
  new$EXPORTDATE AGREEMENTS.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$FSORGAN AGREEMENTS.FSORGAN%TYPE := :NEW.FSORGAN;
  new$FSBUDGETNAME AGREEMENTS.FSBUDGETNAME%TYPE := :NEW.FSBUDGETNAME;
  new$FSOFFBUDGET AGREEMENTS.FSOFFBUDGET%TYPE := :NEW.FSOFFBUDGET;
  new$RNYEAR AGREEMENTS.RNYEAR%TYPE := :NEW.RNYEAR;
  new$RNNUMBER AGREEMENTS.RNNUMBER%TYPE := :NEW.RNNUMBER;
  new$RNDATE AGREEMENTS.RNDATE%TYPE := :NEW.RNDATE;
  new$PROTOCOLNOTICE AGREEMENTS.PROTOCOLNOTICE%TYPE := :NEW.PROTOCOLNOTICE;
  new$PROTOCOLRESULTDATE AGREEMENTS.PROTOCOLRESULTDATE%TYPE := :NEW.PROTOCOLRESULTDATE;
  new$PROTOCOLDOCTYPE AGREEMENTS.PROTOCOLDOCTYPE%TYPE := :NEW.PROTOCOLDOCTYPE;
  new$PROTOCOLSALETYPE AGREEMENTS.PROTOCOLSALETYPE%TYPE := :NEW.PROTOCOLSALETYPE;
  new$NOTIFYDATE AGREEMENTS.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$EXECUTERACCREF AGREEMENTS.EXECUTERACCREF%TYPE := :NEW.EXECUTERACCREF;
  new$DOCBASEDATE AGREEMENTS.DOCBASEDATE%TYPE := :NEW.DOCBASEDATE;
  new$DOCBASENOTIFYDATE AGREEMENTS.DOCBASENOTIFYDATE%TYPE := :NEW.DOCBASENOTIFYDATE;
  new$DOCBASETEXT AGREEMENTS.DOCBASETEXT%TYPE := :NEW.DOCBASETEXT;
  new$DOCBASETYPE AGREEMENTS.DOCBASETYPE%TYPE := :NEW.DOCBASETYPE;
  new$DOCBASESUMMA AGREEMENTS.DOCBASESUMMA%TYPE := :NEW.DOCBASESUMMA;
  new$UNKNOWNAMOUNT AGREEMENTS.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PROTOCOLREASON AGREEMENTS.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$DOCNUMBER AGREEMENTS.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$ADJUSTMENTDOCNUMBER AGREEMENTS.ADJUSTMENTDOCNUMBER%TYPE := :NEW.ADJUSTMENTDOCNUMBER;
  new$OLDDOCNUMBER AGREEMENTS.OLDDOCNUMBER%TYPE := :NEW.OLDDOCNUMBER;
  new$LOTMAXSUM AGREEMENTS.LOTMAXSUM%TYPE := :NEW.LOTMAXSUM;
  new$CLIENT_INN AGREEMENTS.CLIENT_INN%TYPE := :NEW.CLIENT_INN;
  new$CLIENT_INN20 AGREEMENTS.CLIENT_INN20%TYPE := :NEW.CLIENT_INN20;
  new$CLIENT_NAME AGREEMENTS.CLIENT_NAME%TYPE := :NEW.CLIENT_NAME;
  new$EXECUTER_INN AGREEMENTS.EXECUTER_INN%TYPE := :NEW.EXECUTER_INN;
  new$EXECUTER_INN20 AGREEMENTS.EXECUTER_INN20%TYPE := :NEW.EXECUTER_INN20;
  new$EXECUTER_NAME AGREEMENTS.EXECUTER_NAME%TYPE := :NEW.EXECUTER_NAME;
  new$EXECUTER_STATUS AGREEMENTS.EXECUTER_STATUS%TYPE := :NEW.EXECUTER_STATUS;
  new$EXECUTER_COUNTRY AGREEMENTS.EXECUTER_COUNTRY%TYPE := :NEW.EXECUTER_COUNTRY;
  new$EXECUTER_ADDRESS AGREEMENTS.EXECUTER_ADDRESS%TYPE := :NEW.EXECUTER_ADDRESS;
  new$EXECUTER_PHONE AGREEMENTS.EXECUTER_PHONE%TYPE := :NEW.EXECUTER_PHONE;
  new$REALID AGREEMENTS.REALID%TYPE := :NEW.REALID;
  new$ADJUSTMENTNUMBER AGREEMENTS.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$INNERNUMBER AGREEMENTS.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$SENDERIDKEY AGREEMENTS.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY AGREEMENTS.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REESTRVERSION AGREEMENTS.REESTRVERSION%TYPE := :NEW.REESTRVERSION;
  new$DOCTYPE AGREEMENTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$RNCLIENTID AGREEMENTS.RNCLIENTID%TYPE := :NEW.RNCLIENTID;
  new$INFONUMBER AGREEMENTS.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$STATEORDERINNERNUMBER AGREEMENTS.STATEORDERINNERNUMBER%TYPE := :NEW.STATEORDERINNERNUMBER;
  new$PROGINDEX AGREEMENTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE AGREEMENTS.NOTE%TYPE := :NEW.NOTE;
  new$PURPORTDOC AGREEMENTS.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$REESTRRECORDNUMBER AGREEMENTS.REESTRRECORDNUMBER%TYPE := :NEW.REESTRRECORDNUMBER;
  new$EXECUTERSTOREDPROPS AGREEMENTS.EXECUTERSTOREDPROPS%TYPE := :NEW.EXECUTERSTOREDPROPS;
  new$AUTOSANCTION AGREEMENTS.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$PURCHASECODE AGREEMENTS.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$DOCUMENTNUMBER AGREEMENTS.DOCUMENTNUMBER%TYPE := :NEW.DOCUMENTNUMBER;
  new$REJECTCAUSE AGREEMENTS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$TENDERREF AGREEMENTS.TENDERREF%TYPE := :NEW.TENDERREF;
  new$TENDERINNERNUMBER AGREEMENTS.TENDERINNERNUMBER%TYPE := :NEW.TENDERINNERNUMBER;
--
  MaxNumber$ NUMBER (10);
  CurVal$ NUMBER (10);
  CNT$1 NUMBER(10);
  CountAcc$ NUMBER(10);
  rnClientID1$ VARCHAR2(15);
  rnYear1$ VARCHAR2(15);
  rnNumber1$ VARCHAR2(15);
  ReestrVersion1$ VARCHAR2(15);
  DetCount1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_AGREEMENTS_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*   12.0*/
  /*    -*/
  if (new$CardAdvancePercent is null) then 
    new$CardAdvancePercent := 0;
  END IF;
  if (new$CardAdvance is null) then 
    new$CardAdvance := 0;
  END IF;
  if (new$AgreementCardAdvance is null) then 
    new$AgreementCardAdvance := 0;
  END IF;
  if (new$FinCardAdvance is null) then 
    new$FinCardAdvance := 0;    
  END IF;
  if (new$Summa is null) then 
    new$Summa := 0;
  END IF;
  if (new$AgreementSumma is null) then 
    new$AgreementSumma := 0;
  END IF;
  if (new$AgreementFinSumma is null) then 
    new$AgreementFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Fact is null) then 
    new$Fact := 0;
  END IF;
  if (new$Region is null) then 
    new$Region := 0;
  END IF;
  if (new$UnknownAmount is null) then 
    new$UnknownAmount := 0;
  END IF;
  if (new$client_ref is null) then 
    new$client_ref := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount1$ from AgreementSteps where RecordIndex = :old.ID
      ;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      select count(ID)       into DetCount1$ from Estimate where RecordIndex = :old.ID
      ;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');    
      END IF;
    END IF;
  END IF;
  /*         -   InnerNumber*/
  if (((new$ProgIndex = 305) or (new$ProgIndex = 304) or (new$ProgIndex = 314)) and (new$InnerNumber is null)) then
    new$InnerNumber := GEN_ID('G_AgreementNumber',1);
  END IF;
  /*   */
  if (new$DocType is null) then 
    new$DocType := 0;
  END IF;
  /*    .  */
    
  new$stateorderinnernumber := null;
  if (new$stateorderref is not null) then
    BEGIN
      select
      innernumber
      into new$stateorderinnernumber     from agreements
      where
      id = new$stateorderref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*     30.  id */
    
  new$TenderInnerNumber := null;
  if (new$TenderRef is not null) then
    BEGIN
      select InnerNumber 
      into new$TenderInnerNumber     from TenderCaption
      where id = new$TenderRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_3 (TR_AGREEMENTS_BU_3)
-- Create 03.12.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*            */
   new$AdjustmentRef := :OLD.AdjustmentRef;

-- - - - - - - - - - - - -
-- BU_5 (TR_AGREEMENTS_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_AGREEMENTS_BU_10)
-- Last update 08.02.2010
-- - - - - - - - - - - - -

/*   5.0*/
    /* ,      ,   */
    if ((new$InnerNumber <> :old.InnerNumber) or
        (new$AdjustmentNumber <> :old.AdjustmentNumber) or
        (new$AgreementType <> :old.AgreementType)) then
        RaiseException('EX_AGR_ChangeInnerNums');
    end if;

    /*    !!!*/
    if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and
        ((new$Accepted = 1) or (new$AcceptDate is null))) then
        RaiseException('EX_RollbackCancel');
    end if;

    /*   ,     LastAccepted*/
    if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) or
        ((:old.Accepted = 0) and (new$Accepted = 1) and (new$AcceptDate is not null))) then
        /*  LastAccepted         */
        if (new$LastAdjustment = 1) then
            new$LastAccepted := 1;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;
    end if;

    /*    ,     LastAccepted*/
    if (((:old.AcceptDate is not null) and (:old.Accepted = 1)) and
        ((new$Accepted = 0) or (new$AcceptDate is null))) then
        /*  LastAccepted         */
        if (new$LastAdjustment = 1) then
            new$LastAccepted := 0;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;
    end if;

    /*   ,     LastAdjustment*/
    if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 0)) or
        ((:old.Accepted = 1) and (new$Accepted = 0) and (new$AcceptDate is not null))) then

        if (new$LastAdjustment = 1) then
            new$LastAdjustment := 0;
            new$LastAccepted := 0;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;

        SELECT Max(AdjustmentNumber) INTO MaxNumber$ FROm AgreementS
        WHERE (InnerNumber = new$InnerNumber);
        /*    ,     */
        if ((new$adjustmentNumber=0) and (MaxNumber$<>0)) then
          RaiseException('EX_Agr_PrimaryAgrHasNotify');
        end if;
    end if;

-- - - - - - - - - - - - -
-- BU_20 (TR_AGREEMENTS_BU_20)
-- Create 21.05.2009
-- - - - - - - - - - - - -

  /*    -,      */
  if ((new$Client_Ref <> :old.Client_Ref) and
      (((new$Client_INN is null) and
        (:old.Client_INN is null)) or
       (new$Client_INN = :old.Client_INN)) and
      (((new$Client_INN20 is null) and
        (:old.Client_INN20 is null)) or
       (new$Client_INN20 = :old.Client_INN20)) and
      (new$Client_Name = :old.Client_Name)) then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name
      into
        new$Client_INN,
        new$Client_INN20,
        new$Client_Name
      from Organizations o
      where o.Id=new$Client_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Client_INN := NULL;
        new$Client_INN20 := NULL;
        new$Client_Name := NULL;
    END;
  END IF;

  /*    -,      */
  if ((new$Executer_Ref <> :old.Executer_Ref) and
      (((new$Executer_INN is null) and
        (:old.Executer_INN is null)) or
       (new$Executer_INN = :old.Executer_INN)) and
      (((new$Executer_INN20 is null) and
        (:old.Executer_INN20 is null)) or
       (new$Executer_INN20 = :old.Executer_INN20)) and
      (new$Executer_Name = :old.Executer_Name) and
      (((new$Executer_Status is null) and
        (:old.Executer_Status is null)) or
       (new$Executer_Status = :old.Executer_Status)) and
      (((new$Executer_Country is null) and
        (:old.Executer_Country is null)) or
       (new$Executer_Country = :old.Executer_Country)) and
      (((new$Executer_Address is null) and
        (:old.Executer_Address is null)) or
       (new$Executer_Address = :old.Executer_Address)) and
      (((new$Executer_Phone is null) and
        (:old.Executer_Phone is null)) or
       (new$Executer_Phone = :old.Executer_Phone))) then
     BEGIN
      select
        o.INN,
        o.INN20,
        o.Name,
        o.SupplierStatus,
        o.Country,
        o.Address,
        o.Phone
      into
        new$Executer_INN,
        new$Executer_INN20,
        new$Executer_Name,
        new$Executer_Status,
        new$Executer_Country,
        new$Executer_Address,
        new$Executer_Phone
      from Organizations o
      where o.Id=new$Executer_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Executer_INN := NULL;
        new$Executer_INN20 := NULL;
        new$Executer_Name := NULL;
        new$Executer_Status := NULL;
        new$Executer_Country := NULL;
        new$Executer_Address := NULL;
        new$Executer_Phone := NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_50 (TR_AGREEMENTS_BU_50)
-- Create 06.08.2010
-- - - - - - - - - - - - -

    if (new$InnerNumber is not null) then
        CurVal$ := gen_id('G_AgreementNumber', 0);
        if (CurVal$ < new$InnerNumber) then
          CurVal$ := gen_id('G_AgreementNumber', new$InnerNumber - CurVal$);
        end if;
    end if;

-- - - - - - - - - - - - -
-- BU_60 (tr_agreements_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*        ,     */
  if (:old.accepted = 1 and new$accepted = 0 and new$acceptdate is not null and new$adjustmentnumber = 0) then
    SELECT COUNT(*) INTO CNT$1
    from executiondocumentscaption
    where
    (            agreementinnernumber = new$innernumber
    and (accepted <> 0 or acceptdate is null)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_Agr_CannotReject');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_AGREEMENTS_BU_200)
-- Create 04.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$id, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (tr_agreements_bu_300)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$ExecuterAccRef is not null) then
    select count(ID)
    into CountAcc$     from org_accounts oa
    where oa.id = new$ExecuterAccRef and oa.Org_ref = new$Executer_Ref
    ;
    if (CountAcc$ = 0) then
      RaiseException('EX_AGR_ACCORGCHECK');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (TR_AGREEMENTS_BU_400)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (((new$rnClientID <> :old.rnClientID) or (new$rnYear <> :old.rnYear) or
  (new$rnNumber <> :old.rnNumber) or (new$ReestrVersion <> :old.ReestrVersion)) and
  (new$rnClientID is not null) and (new$rnYear is not null) and (new$rnNumber is not null)) then

    rnClientID1$ := new$rnClientID;
    rnYear1$ := new$rnYear;
    rnNumber1$ := new$rnNumber;
    ReestrVersion1$ := new$ReestrVersion;
    while (LENGTH(rnClientID1$) < 11) LOOP
      rnClientID1$ := '0' || rnClientID1$;
    END LOOP;
    while (LENGTH(rnNumber1$) < 6) LOOP
      rnNumber1$ := '0' || rnNumber1$;
    END LOOP;
    if (LENGTH(ReestrVersion1$) < 2) then
      ReestrVersion1$ := '0' || ReestrVersion1$;
    END IF;
    /*  ReestrRecordNumber*/
    if (new$ReestrVersion is null) then
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$;

    else
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$ || ReestrVersion1$;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_600 (agreements_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_AGREEMENTS_BU_700)
-- Create 14.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_AGREEMENTS SET
    ID = new$ID,
    SUMMA = new$SUMMA,
    AGREEMENTDATE = new$AGREEMENTDATE,
    AGREEMENTENDDATE = new$AGREEMENTENDDATE,
    EXECUTER_REF = new$EXECUTER_REF,
    CLIENT_REF = new$CLIENT_REF,
    FACIALACC_CLS = new$FACIALACC_CLS,
    AGREEMENTTYPE = new$AGREEMENTTYPE,
    ACCEPTED = new$ACCEPTED,
    ACCEPTDATE = new$ACCEPTDATE,
    CARDADVANCEPERCENT = new$CARDADVANCEPERCENT,
    CARDADVANCE = new$CARDADVANCE,
    CLOSEDOC = new$CLOSEDOC,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    FACT = new$FACT,
    REGION = new$REGION,
    CLOSEDATE = new$CLOSEDATE,
    DELIVERYRULES = new$DELIVERYRULES,
    AGREEMENTSUMMA = new$AGREEMENTSUMMA,
    AGREEMENTFINSUMMA = new$AGREEMENTFINSUMMA,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    REESTRNUMBER = new$REESTRNUMBER,
    PAYMENTDATE = new$PAYMENTDATE,
    AGREEMENTCARDADVANCE = new$AGREEMENTCARDADVANCE,
    FINCARDADVANCE = new$FINCARDADVANCE,
    STATEORDERREF = new$STATEORDERREF,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    AGREEMENTBEGINDATE = new$AGREEMENTBEGINDATE,
    PROTOCOLNUMBER = new$PROTOCOLNUMBER,
    PROTOCOLDATE = new$PROTOCOLDATE,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXPORTDATE = new$EXPORTDATE,
    FSORGAN = new$FSORGAN,
    FSBUDGETNAME = new$FSBUDGETNAME,
    FSOFFBUDGET = new$FSOFFBUDGET,
    RNYEAR = new$RNYEAR,
    RNNUMBER = new$RNNUMBER,
    RNDATE = new$RNDATE,
    PROTOCOLNOTICE = new$PROTOCOLNOTICE,
    PROTOCOLRESULTDATE = new$PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE = new$PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE = new$PROTOCOLSALETYPE,
    NOTIFYDATE = new$NOTIFYDATE,
    EXECUTERACCREF = new$EXECUTERACCREF,
    DOCBASEDATE = new$DOCBASEDATE,
    DOCBASENOTIFYDATE = new$DOCBASENOTIFYDATE,
    DOCBASETEXT = new$DOCBASETEXT,
    DOCBASETYPE = new$DOCBASETYPE,
    DOCBASESUMMA = new$DOCBASESUMMA,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PROTOCOLREASON = new$PROTOCOLREASON,
    DOCNUMBER = new$DOCNUMBER,
    ADJUSTMENTDOCNUMBER = new$ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER = new$OLDDOCNUMBER,
    LOTMAXSUM = new$LOTMAXSUM,
    CLIENT_INN = new$CLIENT_INN,
    CLIENT_INN20 = new$CLIENT_INN20,
    CLIENT_NAME = new$CLIENT_NAME,
    EXECUTER_INN = new$EXECUTER_INN,
    EXECUTER_INN20 = new$EXECUTER_INN20,
    EXECUTER_NAME = new$EXECUTER_NAME,
    EXECUTER_STATUS = new$EXECUTER_STATUS,
    EXECUTER_COUNTRY = new$EXECUTER_COUNTRY,
    EXECUTER_ADDRESS = new$EXECUTER_ADDRESS,
    EXECUTER_PHONE = new$EXECUTER_PHONE,
    REALID = new$REALID,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    INNERNUMBER = new$INNERNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REESTRVERSION = new$REESTRVERSION,
    DOCTYPE = new$DOCTYPE,
    RNCLIENTID = new$RNCLIENTID,
    INFONUMBER = new$INFONUMBER,
    STATEORDERINNERNUMBER = new$STATEORDERINNERNUMBER,
    PROGINDEX = new$PROGINDEX,
    NOTE = new$NOTE,
    PURPORTDOC = new$PURPORTDOC,
    REESTRRECORDNUMBER = new$REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS = new$EXECUTERSTOREDPROPS,
    AUTOSANCTION = new$AUTOSANCTION,
    PURCHASECODE = new$PURCHASECODE,
    DOCUMENTNUMBER = new$DOCUMENTNUMBER,
    REJECTCAUSE = new$REJECTCAUSE,
    TENDERREF = new$TENDERREF,
    TENDERINNERNUMBER = new$TENDERINNERNUMBER
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_AGREEMENTS_AU_10)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   6.0*/
  /*      */
  /*     ,       */
  if ((new$AdjustmentNumber > 0) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update Agreements set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentNumber > 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update Agreements set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*          */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 304)or(new$ProgIndex = 314)))then
    update Estimate
    set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    (RecordIndex = new$Id);
  END IF;
  /*         */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 305) or (new$ProgIndex = 314))) then
    update paymentschedule set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    AgreementRef = new$ID and
    ProgIndex in (317, 318);

  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_AGREEMENTS_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*      */
  if ((new$ProgIndex = 305) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null
    where
    StateOrder = :old.ID;
  END IF;
  /*      */
  if ((new$ProgIndex = 314) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null,
    Agreement = null
    where
    StateOrder = :old.ID;
  END IF;
  /*     */
  if ((:old.ProgIndex = 304) and (new$AdjustmentNumber = 0) and (new$Accepted = 0) and
  (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    Agreement = null
    where
    Agreement = :old.ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_AGREEMENTS_AU_30)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$ProgIndex = 304) or (new$ProgIndex = 314)) and
  ((new$Accepted <> :old.Accepted) or
  (new$AcceptDate is not null and :old.AcceptDate is null) or
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where AgreementRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_AGREEMENTS_AU_500)
-- Create 28.04.2005
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes
                  (TableID, RecordId, DeleteDate
                  )
           VALUES (110, :OLD.ID, SYSDATE
                  );

      DELETE FROM DelRecIndexes
            WHERE (TableID = 110) AND (RecordId = new$ID);
   END IF;

END;
/
commit work
/

-- #########################################################
-- #########################################################
-- Alter_Organizations_BlockField.sql
-- #########################################################
-- #########################################################

/*       */
ALTER TABLE TB_organizations ADD (
  BlockedDate NUMBER,/*    */
  BlockedCause VARCHAR2(255),/*    */
  UNBLOCKEDDATE NUMBER,/*    */
  UNBLOCKEDCAUSE VARCHAR2(255)/*    */
)
/

CREATE OR REPLACE VIEW organizations (
  ID,
  NAME,
  GOSNI,
  CITY,
  COUNTRY,
  PHONE,
  ADDRESS,
  ORG_CLS,
  INN20,
  SUBINN,
  FACIALACC,
  REGIONCLS,
  DIRNAME,
  BUGNAME,
  DIRPHONE,
  BUGPHONE,
  RCORG,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  INN,
  OKATO,
  EMAIL,
  WEBSITE,
  UFKCODE,
  ADDOKATO,
  SHORTNAME,
  RVERSION,
  SENDERID,
  KVSR,
  OKFS,
  OKOPF,
  OPENDATE,
  CLOSEDATE,
  CHANGEDATE,
  GENERALORG_REF,
  FEDERALREGIONCODE,
  ORG_TYPE,
  BUDGETREF,
  SUPPLIERSTATUS,
  COUNTRYCODE,
  DATECLOSE,
  ORGCODE,
  COSTAUTHORITY,
  INCOMEAUTHORITY,
  DEBTAUTHORITY,
  SVRAUTHORITY,
  CLIENTID,
  DATEOPEN,
  FUID,
  OKPO,
  OKTMO,
  DOCSTATEREF,
  CRYPTOSTATUS,
  OGRN,
  REJECT_CLS,
  EXTID,
  EXTOWNER,
  EXTSYNCDATE,
  REMOTEPBSCODE,
  REMOTENOTPBSCODE,
  USECHECK_CARD,
  EXTROOTID,
  EXTVERSION,
  EXTVERSIONDATE,
  RECORDOWNERORGREF,
  REJECTCAUSE,
  BLOCKEDDATE,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE)
AS
  SELECT
    ID,
    NAME,
    GOSNI,
    CITY,
    COUNTRY,
    PHONE,
    ADDRESS,
    ORG_CLS,
    INN20,
    SUBINN,
    FACIALACC,
    REGIONCLS,
    DIRNAME,
    BUGNAME,
    DIRPHONE,
    BUGPHONE,
    RCORG,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    INN,
    OKATO,
    EMAIL,
    WEBSITE,
    UFKCODE,
    ADDOKATO,
    SHORTNAME,
    RVERSION,
    SENDERID,
    KVSR,
    OKFS,
    OKOPF,
    OPENDATE,
    CLOSEDATE,
    CHANGEDATE,
    GENERALORG_REF,
    FEDERALREGIONCODE,
    ORG_TYPE,
    BUDGETREF,
    SUPPLIERSTATUS,
    COUNTRYCODE,
    DATECLOSE,
    ORGCODE,
    COSTAUTHORITY,
    INCOMEAUTHORITY,
    DEBTAUTHORITY,
    SVRAUTHORITY,
    CLIENTID,
    DATEOPEN,
    FUID,
    OKPO,
    OKTMO,
    DOCSTATEREF,
    CRYPTOSTATUS,
    OGRN,
    REJECT_CLS,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    REMOTEPBSCODE,
    REMOTENOTPBSCODE,
    USECHECK_CARD,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    RECORDOWNERORGREF,
    REJECTCAUSE,
    BLOCKEDDATE,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE
  FROM TB_organizations
/

CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_ID
  INSTEAD OF DELETE
  ON ORGANIZATIONS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_ORGANIZATIONS_BD)
-- Last update 09.06.2008
-- - - - - - - - - - - - -

  if (:old.ID = 0) then
    RaiseException('ex_CantDelUnknownOrg');
  end if;

  delete from Org_Accounts where org_ref = :old.id;
  delete from Banks where id = :old.id;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_ORGANIZATIONS
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_200 (TR_ORGANIZATIONS_AD_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

update Organizations set
    GeneralOrg_Ref = id
  where
    GeneralOrg_Ref = :old.id;

-- - - - - - - - - - - - -
-- AD_210 (TR_ORGANIZATIONS_AD_210)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*       */
  delete 
  from 
  StateJumpHistory
  where 
  DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_ORGANIZATIONS_AD_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate) values(27, :old.ID ,SYSDATE);

END;
/

CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_II
  INSTEAD OF INSERT
  ON ORGANIZATIONS
  FOR EACH ROW
DECLARE
  new$ID ORGANIZATIONS.ID%TYPE := :NEW.ID;
  new$NAME ORGANIZATIONS.NAME%TYPE := :NEW.NAME;
  new$GOSNI ORGANIZATIONS.GOSNI%TYPE := :NEW.GOSNI;
  new$CITY ORGANIZATIONS.CITY%TYPE := :NEW.CITY;
  new$COUNTRY ORGANIZATIONS.COUNTRY%TYPE := :NEW.COUNTRY;
  new$PHONE ORGANIZATIONS.PHONE%TYPE := :NEW.PHONE;
  new$ADDRESS ORGANIZATIONS.ADDRESS%TYPE := :NEW.ADDRESS;
  new$ORG_CLS ORGANIZATIONS.ORG_CLS%TYPE := :NEW.ORG_CLS;
  new$INN20 ORGANIZATIONS.INN20%TYPE := :NEW.INN20;
  new$SUBINN ORGANIZATIONS.SUBINN%TYPE := :NEW.SUBINN;
  new$FACIALACC ORGANIZATIONS.FACIALACC%TYPE := :NEW.FACIALACC;
  new$REGIONCLS ORGANIZATIONS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$DIRNAME ORGANIZATIONS.DIRNAME%TYPE := :NEW.DIRNAME;
  new$BUGNAME ORGANIZATIONS.BUGNAME%TYPE := :NEW.BUGNAME;
  new$DIRPHONE ORGANIZATIONS.DIRPHONE%TYPE := :NEW.DIRPHONE;
  new$BUGPHONE ORGANIZATIONS.BUGPHONE%TYPE := :NEW.BUGPHONE;
  new$RCORG ORGANIZATIONS.RCORG%TYPE := :NEW.RCORG;
  new$CREATERUSER ORGANIZATIONS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ORGANIZATIONS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ORGANIZATIONS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ORGANIZATIONS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$INN ORGANIZATIONS.INN%TYPE := :NEW.INN;
  new$OKATO ORGANIZATIONS.OKATO%TYPE := :NEW.OKATO;
  new$EMAIL ORGANIZATIONS.EMAIL%TYPE := :NEW.EMAIL;
  new$WEBSITE ORGANIZATIONS.WEBSITE%TYPE := :NEW.WEBSITE;
  new$UFKCODE ORGANIZATIONS.UFKCODE%TYPE := :NEW.UFKCODE;
  new$ADDOKATO ORGANIZATIONS.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$SHORTNAME ORGANIZATIONS.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$RVERSION ORGANIZATIONS.RVERSION%TYPE := :NEW.RVERSION;
  new$SENDERID ORGANIZATIONS.SENDERID%TYPE := :NEW.SENDERID;
  new$KVSR ORGANIZATIONS.KVSR%TYPE := :NEW.KVSR;
  new$OKFS ORGANIZATIONS.OKFS%TYPE := :NEW.OKFS;
  new$OKOPF ORGANIZATIONS.OKOPF%TYPE := :NEW.OKOPF;
  new$OPENDATE ORGANIZATIONS.OPENDATE%TYPE := :NEW.OPENDATE;
  new$CLOSEDATE ORGANIZATIONS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$CHANGEDATE ORGANIZATIONS.CHANGEDATE%TYPE := :NEW.CHANGEDATE;
  new$GENERALORG_REF ORGANIZATIONS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$FEDERALREGIONCODE ORGANIZATIONS.FEDERALREGIONCODE%TYPE := :NEW.FEDERALREGIONCODE;
  new$ORG_TYPE ORGANIZATIONS.ORG_TYPE%TYPE := :NEW.ORG_TYPE;
  new$BUDGETREF ORGANIZATIONS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUPPLIERSTATUS ORGANIZATIONS.SUPPLIERSTATUS%TYPE := :NEW.SUPPLIERSTATUS;
  new$COUNTRYCODE ORGANIZATIONS.COUNTRYCODE%TYPE := :NEW.COUNTRYCODE;
  new$DATECLOSE ORGANIZATIONS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$ORGCODE ORGANIZATIONS.ORGCODE%TYPE := :NEW.ORGCODE;
  new$COSTAUTHORITY ORGANIZATIONS.COSTAUTHORITY%TYPE := :NEW.COSTAUTHORITY;
  new$INCOMEAUTHORITY ORGANIZATIONS.INCOMEAUTHORITY%TYPE := :NEW.INCOMEAUTHORITY;
  new$DEBTAUTHORITY ORGANIZATIONS.DEBTAUTHORITY%TYPE := :NEW.DEBTAUTHORITY;
  new$SVRAUTHORITY ORGANIZATIONS.SVRAUTHORITY%TYPE := :NEW.SVRAUTHORITY;
  new$CLIENTID ORGANIZATIONS.CLIENTID%TYPE := :NEW.CLIENTID;
  new$DATEOPEN ORGANIZATIONS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$FUID ORGANIZATIONS.FUID%TYPE := :NEW.FUID;
  new$OKPO ORGANIZATIONS.OKPO%TYPE := :NEW.OKPO;
  new$OKTMO ORGANIZATIONS.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCSTATEREF ORGANIZATIONS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ORGANIZATIONS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$OGRN ORGANIZATIONS.OGRN%TYPE := :NEW.OGRN;
  new$REJECT_CLS ORGANIZATIONS.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$EXTID ORGANIZATIONS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER ORGANIZATIONS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE ORGANIZATIONS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$REMOTEPBSCODE ORGANIZATIONS.REMOTEPBSCODE%TYPE := :NEW.REMOTEPBSCODE;
  new$REMOTENOTPBSCODE ORGANIZATIONS.REMOTENOTPBSCODE%TYPE := :NEW.REMOTENOTPBSCODE;
  new$USECHECK_CARD ORGANIZATIONS.USECHECK_CARD%TYPE := :NEW.USECHECK_CARD;
  new$EXTROOTID ORGANIZATIONS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION ORGANIZATIONS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE ORGANIZATIONS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$RECORDOWNERORGREF ORGANIZATIONS.RECORDOWNERORGREF%TYPE := :NEW.RECORDOWNERORGREF;
  new$REJECTCAUSE ORGANIZATIONS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$BLOCKEDDATE ORGANIZATIONS.BLOCKEDDATE%TYPE := :NEW.BLOCKEDDATE;
  new$BLOCKEDCAUSE ORGANIZATIONS.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE ORGANIZATIONS.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE ORGANIZATIONS.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
--
  CNT$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (tr_Organizations_bi)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$FUID is null) then
    new$FUID := new$id;
  END IF;
  if (new$GOSNI is null) then
    new$GOSNI := 0;
  END IF;
  if (new$Name is null) then
    new$Name := '  ';
  END IF;
  if (new$City is null) then
    GetVarcharConst(-1,7,new$City);
  END IF;
  if (new$COUNTRY is null) then
    new$COUNTRY := '';
  END IF;
  if (new$CountryCode is null) then
    new$CountryCode := 643;
  END IF;
  if (new$ORG_CLS is NULL) then
    new$ORG_CLS:= 0;
  END IF;
  if (new$SubINN is null) then
    new$SubINN:= 0;
  END IF;
  if (new$INN20 is null) then
    new$INN20:= '';
  END IF;
  if (new$RCOrg is null) then
    new$RCOrg := 0;
  END IF;
  if (new$RegionCls is null) then
    new$RegionCls := 0;
  END IF;
  if (new$OKATO is null) then
    new$OKATO := 0;
  END IF;
  if (new$KVSR is null) then
    new$KVSR := 0;
  END IF;
  if (new$OKFS is null) then
    new$OKFS := 0;
  END IF;
  if (new$OKOPF is null) then
    new$OKOPF := 0;
  END IF;
  if (new$FederalRegionCode is null) then
    GetIntConst(-1, 27,new$FederalRegionCode);
  END IF;
  if (new$FederalRegionCode is null) then
    new$FederalRegionCode := 0;
  END IF;
  if (new$BudgetRef is null) then
    new$BudgetRef := 0;
  END IF;
  /*    - */
  if (new$org_type is null) then
    new$org_type := 20000;
  END IF;
  /*        */
  if ((new$generalorg_ref is null) or (new$org_type < 10000) or (new$org_type >= 20000)) then
    new$generalorg_ref := new$id;
  END IF;
  /*    10 ,      */
  if ((new$INN > 9999999999.9) and (new$INN20 <> '') and (new$INN20 is not null)) then
    RaiseException('EX_WRONGKPP');
  END IF;
  check_unique_organization(new$inn,  new$inn20);
  if (new$CostAuthority is null) then
    new$CostAuthority:= 0;
  END IF;
  if (new$IncomeAuthority is null) then
    new$IncomeAuthority := 0;
  END IF;
  if (new$DebtAuthority is null) then
    new$DebtAuthority := 0;
  END IF;
  if (new$SVRAuthority is null) then
    new$SVRAuthority := 0;
  END IF;
  /*        */
  if (new$Org_Type is not null)
  then
    if (new$Org_Type between 10100 and 10299) then
      new$CostAuthority:= 1;
    END IF;
    if (new$Org_Type between 10300 and 10399) then
      new$CostAuthority:= 2;
    END IF;
    if (new$Org_Type between 10400 and 10499) then
      new$CostAuthority:= 4;
    END IF;
    if (((new$Org_Type between 10500 and 10599) and (new$CostAuthority<>16)) or
    (((new$Org_Type between 10000 and 10099) or (new$Org_Type between 10600 and 10799))
    and (new$CostAuthority=0))) then
      new$CostAuthority:= 8;

    END IF;
  END IF;
  if (new$UseCheck_Card is null) then
    new$UseCheck_Card := 0;
  END IF;
  if (new$RecordOwnerOrgRef is null) then
    new$RecordOwnerOrgRef := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_ORGANIZATIONS_BI_10)
-- Last update 19.10.2006
-- - - - - - - - - - - - -

  if (new$FacialAcc is not null) then
    select count(id) into cnt$ from Organizations where (FacialAcc = new$FacialAcc) AND (ROWNUM = 1);
    if (cnt$ <> 0) then RaiseException('ex_DublicateFacialAcc'); end if;
  end if;

-- - - - - - - - - - - - -
-- BI_200 (TR_ORGANIZATIONS_BI_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

  if (new$id <> new$GeneralOrg_Ref) then
    select count(*) into cnt$
    from Organizations o where (o.id = new$GeneralOrg_Ref) AND (ROWNUM = 1);

    if cnt$ = 0 then
      RaiseException('ex_GeneralOrgNotFound');
    end if;

    /*       ,     */
    if (new$KVSR = 0) then
      select o.KVSR into new$KVSR
      from Organizations o
      where o.id = new$GeneralOrg_Ref;
    end if;
  end if;

-- - - - - - - - - - - - -
-- BI_500 (TR_ORGANIZATIONS_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_ORGANIZATIONS (
    ID,
    NAME,
    GOSNI,
    CITY,
    COUNTRY,
    PHONE,
    ADDRESS,
    ORG_CLS,
    INN20,
    SUBINN,
    FACIALACC,
    REGIONCLS,
    DIRNAME,
    BUGNAME,
    DIRPHONE,
    BUGPHONE,
    RCORG,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    INN,
    OKATO,
    EMAIL,
    WEBSITE,
    UFKCODE,
    ADDOKATO,
    SHORTNAME,
    RVERSION,
    SENDERID,
    KVSR,
    OKFS,
    OKOPF,
    OPENDATE,
    CLOSEDATE,
    CHANGEDATE,
    GENERALORG_REF,
    FEDERALREGIONCODE,
    ORG_TYPE,
    BUDGETREF,
    SUPPLIERSTATUS,
    COUNTRYCODE,
    DATECLOSE,
    ORGCODE,
    COSTAUTHORITY,
    INCOMEAUTHORITY,
    DEBTAUTHORITY,
    SVRAUTHORITY,
    CLIENTID,
    DATEOPEN,
    FUID,
    OKPO,
    OKTMO,
    DOCSTATEREF,
    CRYPTOSTATUS,
    OGRN,
    REJECT_CLS,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    REMOTEPBSCODE,
    REMOTENOTPBSCODE,
    USECHECK_CARD,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    RECORDOWNERORGREF,
    REJECTCAUSE,
    BLOCKEDDATE,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE
  ) VALUES (
    new$ID,
    new$NAME,
    new$GOSNI,
    new$CITY,
    new$COUNTRY,
    new$PHONE,
    new$ADDRESS,
    new$ORG_CLS,
    new$INN20,
    new$SUBINN,
    new$FACIALACC,
    new$REGIONCLS,
    new$DIRNAME,
    new$BUGNAME,
    new$DIRPHONE,
    new$BUGPHONE,
    new$RCORG,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$INN,
    new$OKATO,
    new$EMAIL,
    new$WEBSITE,
    new$UFKCODE,
    new$ADDOKATO,
    new$SHORTNAME,
    new$RVERSION,
    new$SENDERID,
    new$KVSR,
    new$OKFS,
    new$OKOPF,
    new$OPENDATE,
    new$CLOSEDATE,
    new$CHANGEDATE,
    new$GENERALORG_REF,
    new$FEDERALREGIONCODE,
    new$ORG_TYPE,
    new$BUDGETREF,
    new$SUPPLIERSTATUS,
    new$COUNTRYCODE,
    new$DATECLOSE,
    new$ORGCODE,
    new$COSTAUTHORITY,
    new$INCOMEAUTHORITY,
    new$DEBTAUTHORITY,
    new$SVRAUTHORITY,
    new$CLIENTID,
    new$DATEOPEN,
    new$FUID,
    new$OKPO,
    new$OKTMO,
    new$DOCSTATEREF,
    new$CRYPTOSTATUS,
    new$OGRN,
    new$REJECT_CLS,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$REMOTEPBSCODE,
    new$REMOTENOTPBSCODE,
    new$USECHECK_CARD,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$RECORDOWNERORGREF,
    new$REJECTCAUSE,
    new$BLOCKEDDATE,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE);

-- - - - - - - - - - - - -
-- AI_500 (TR_ORGANIZATIONS_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 27) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_IU
  INSTEAD OF UPDATE
  ON ORGANIZATIONS
  FOR EACH ROW
DECLARE
  new$ID ORGANIZATIONS.ID%TYPE := :NEW.ID;
  new$NAME ORGANIZATIONS.NAME%TYPE := :NEW.NAME;
  new$GOSNI ORGANIZATIONS.GOSNI%TYPE := :NEW.GOSNI;
  new$CITY ORGANIZATIONS.CITY%TYPE := :NEW.CITY;
  new$COUNTRY ORGANIZATIONS.COUNTRY%TYPE := :NEW.COUNTRY;
  new$PHONE ORGANIZATIONS.PHONE%TYPE := :NEW.PHONE;
  new$ADDRESS ORGANIZATIONS.ADDRESS%TYPE := :NEW.ADDRESS;
  new$ORG_CLS ORGANIZATIONS.ORG_CLS%TYPE := :NEW.ORG_CLS;
  new$INN20 ORGANIZATIONS.INN20%TYPE := :NEW.INN20;
  new$SUBINN ORGANIZATIONS.SUBINN%TYPE := :NEW.SUBINN;
  new$FACIALACC ORGANIZATIONS.FACIALACC%TYPE := :NEW.FACIALACC;
  new$REGIONCLS ORGANIZATIONS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$DIRNAME ORGANIZATIONS.DIRNAME%TYPE := :NEW.DIRNAME;
  new$BUGNAME ORGANIZATIONS.BUGNAME%TYPE := :NEW.BUGNAME;
  new$DIRPHONE ORGANIZATIONS.DIRPHONE%TYPE := :NEW.DIRPHONE;
  new$BUGPHONE ORGANIZATIONS.BUGPHONE%TYPE := :NEW.BUGPHONE;
  new$RCORG ORGANIZATIONS.RCORG%TYPE := :NEW.RCORG;
  new$CREATERUSER ORGANIZATIONS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ORGANIZATIONS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ORGANIZATIONS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ORGANIZATIONS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$INN ORGANIZATIONS.INN%TYPE := :NEW.INN;
  new$OKATO ORGANIZATIONS.OKATO%TYPE := :NEW.OKATO;
  new$EMAIL ORGANIZATIONS.EMAIL%TYPE := :NEW.EMAIL;
  new$WEBSITE ORGANIZATIONS.WEBSITE%TYPE := :NEW.WEBSITE;
  new$UFKCODE ORGANIZATIONS.UFKCODE%TYPE := :NEW.UFKCODE;
  new$ADDOKATO ORGANIZATIONS.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$SHORTNAME ORGANIZATIONS.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$RVERSION ORGANIZATIONS.RVERSION%TYPE := :NEW.RVERSION;
  new$SENDERID ORGANIZATIONS.SENDERID%TYPE := :NEW.SENDERID;
  new$KVSR ORGANIZATIONS.KVSR%TYPE := :NEW.KVSR;
  new$OKFS ORGANIZATIONS.OKFS%TYPE := :NEW.OKFS;
  new$OKOPF ORGANIZATIONS.OKOPF%TYPE := :NEW.OKOPF;
  new$OPENDATE ORGANIZATIONS.OPENDATE%TYPE := :NEW.OPENDATE;
  new$CLOSEDATE ORGANIZATIONS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$CHANGEDATE ORGANIZATIONS.CHANGEDATE%TYPE := :NEW.CHANGEDATE;
  new$GENERALORG_REF ORGANIZATIONS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$FEDERALREGIONCODE ORGANIZATIONS.FEDERALREGIONCODE%TYPE := :NEW.FEDERALREGIONCODE;
  new$ORG_TYPE ORGANIZATIONS.ORG_TYPE%TYPE := :NEW.ORG_TYPE;
  new$BUDGETREF ORGANIZATIONS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUPPLIERSTATUS ORGANIZATIONS.SUPPLIERSTATUS%TYPE := :NEW.SUPPLIERSTATUS;
  new$COUNTRYCODE ORGANIZATIONS.COUNTRYCODE%TYPE := :NEW.COUNTRYCODE;
  new$DATECLOSE ORGANIZATIONS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$ORGCODE ORGANIZATIONS.ORGCODE%TYPE := :NEW.ORGCODE;
  new$COSTAUTHORITY ORGANIZATIONS.COSTAUTHORITY%TYPE := :NEW.COSTAUTHORITY;
  new$INCOMEAUTHORITY ORGANIZATIONS.INCOMEAUTHORITY%TYPE := :NEW.INCOMEAUTHORITY;
  new$DEBTAUTHORITY ORGANIZATIONS.DEBTAUTHORITY%TYPE := :NEW.DEBTAUTHORITY;
  new$SVRAUTHORITY ORGANIZATIONS.SVRAUTHORITY%TYPE := :NEW.SVRAUTHORITY;
  new$CLIENTID ORGANIZATIONS.CLIENTID%TYPE := :NEW.CLIENTID;
  new$DATEOPEN ORGANIZATIONS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$FUID ORGANIZATIONS.FUID%TYPE := :NEW.FUID;
  new$OKPO ORGANIZATIONS.OKPO%TYPE := :NEW.OKPO;
  new$OKTMO ORGANIZATIONS.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCSTATEREF ORGANIZATIONS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ORGANIZATIONS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$OGRN ORGANIZATIONS.OGRN%TYPE := :NEW.OGRN;
  new$REJECT_CLS ORGANIZATIONS.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$EXTID ORGANIZATIONS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER ORGANIZATIONS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE ORGANIZATIONS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$REMOTEPBSCODE ORGANIZATIONS.REMOTEPBSCODE%TYPE := :NEW.REMOTEPBSCODE;
  new$REMOTENOTPBSCODE ORGANIZATIONS.REMOTENOTPBSCODE%TYPE := :NEW.REMOTENOTPBSCODE;
  new$USECHECK_CARD ORGANIZATIONS.USECHECK_CARD%TYPE := :NEW.USECHECK_CARD;
  new$EXTROOTID ORGANIZATIONS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION ORGANIZATIONS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE ORGANIZATIONS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$RECORDOWNERORGREF ORGANIZATIONS.RECORDOWNERORGREF%TYPE := :NEW.RECORDOWNERORGREF;
  new$REJECTCAUSE ORGANIZATIONS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$BLOCKEDDATE ORGANIZATIONS.BLOCKEDDATE%TYPE := :NEW.BLOCKEDDATE;
  new$BLOCKEDCAUSE ORGANIZATIONS.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE ORGANIZATIONS.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE ORGANIZATIONS.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
--
  CNT$ NUMBER(10);
  c1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (tr_organizations_bu)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (new$gosni is null) then
    new$gosni := 0;
  END IF;
  if (new$city is null) then
    getvarcharconst(-1,7,new$city);
  END IF;
  if (new$country is null) then
    new$country := '';
  END IF;
  if (new$countrycode is null) then
    new$countrycode := 643;
  END IF;
  if (new$org_cls is null) then
    new$org_cls:= 0;
  END IF;
  if (new$inn20 is null) then
    new$inn20:= '';
  END IF;
  if (new$rcorg is null) then
    new$rcorg := 0;
  END IF;
  if (new$regioncls is null) then
    new$regioncls := 0;
  END IF;
  if (new$okato is null) then
    new$okato := 0;
  END IF;
  if (new$kvsr is null) then
    new$kvsr := 0;
  END IF;
  if (new$okfs is null) then
    new$okfs := 0;
  END IF;
  if (new$okopf is null) then
    new$okopf := 0;
  END IF;
  if (new$federalregioncode is null) then
    getintconst(-1, 27,new$federalregioncode);
  END IF;
  if (new$federalregioncode is null) then
    new$federalregioncode := 0;
  END IF;
  if (new$budgetref is null) then
    new$budgetref := 0;
  END IF;
  /*    - */
  if (new$org_type is null) then
    new$org_type := 20000;
  END IF;
  /*        */
  if ((new$generalorg_ref is null) or (new$org_type < 10000) or (new$org_type >= 20000)) then
    new$generalorg_ref := new$id;
  END IF;

  /*    10 ,      */
  if ((new$inn <> :old.inn) or ((:old.inn is null) and (new$inn is not null))) then
    if ((new$inn > 9999999999.9) and (new$inn20 <> '')) then
      RaiseException('ex_wrongkpp');
    END IF;
  END IF;
  if ( ((new$inn <> :old.inn) or ((:old.inn is null) and (new$inn is not null)))
  or ( (new$inn20 <> :old.inn20) or ((:old.inn20 is null) and (new$inn20 is not null))) )
  then
    check_unique_organization(new$inn,  new$inn20);
  END IF;

  if (new$regioncls <> :old.regioncls) then
    update dfaccountsbuhtable set
    regioncls = new$regioncls
    where id = any (select id from org_accounts where org_ref = new$id);
  END IF;
  /*      */
  if (:old.id = 0) then
    RaiseException('ex_cantmodifyunknownorg');
  END IF;
  /*        */
  if ((new$org_type<>:old.org_type) or (new$costauthority<>:old.costauthority))
  then
    c1$ := new$costauthority;
    if (new$org_type between 10100 and 10299) then
      new$costauthority:= 1;
    END IF;
    if (new$org_type between 10300 and 10399) then
      new$costauthority:= 2;
    END IF;
    if (new$org_type between 10400 and 10499) then
      new$costauthority:= 4;
    END IF;
    if (((new$org_type between 10500 and 10599) and (new$costauthority<>16)) or
    (((new$org_type between 10000 and 10099) or (new$org_type between 10600 and 10799))
    and (new$costauthority=0))) then
      new$costauthority:= 8;
    END IF;
    if ((new$org_type=:old.org_type) and (c1$<>new$costauthority)) then
      RaiseException('ex_wrongcostauthority');
    END IF;
  END IF;
  /*    RegionCls  ,  
         */
  if (new$regioncls <> :old.regioncls) then
    update facialacc_cls fac set
    fac.regioncls = new$regioncls
    where
    new$id = fac.org_ref;

  END IF;
  if (new$UseCheck_Card is null) then
    new$UseCheck_Card := 0;
  END IF;
  if (new$RecordOwnerOrgRef is null) then
    new$RecordOwnerOrgRef := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_ORGANIZATIONS_BU_10)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$FacialAcc <> :old.FacialAcc) then
    select count(id) into CNT$ from Organizations
      where (FacialAcc = new$FacialAcc) and (id <> new$id) AND (ROWNUM = 1);
    if (CNT$ <> 0) then
      RaiseException('ex_DublicateFacialAcc');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_100 (TR_ORGANIZATIONS_BU_100)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*   */
  if ((new$DateClose is not null) and (:old.DateClose is null)) then
    /*        */
    update Org_Accounts set
    DateClose = new$DateClose,
    CloseCode = CloseCode + 10
    where Org_Ref = new$Id;

  END IF;
  /*  /      */
  if (((new$DateClose is not null) and (:old.DateClose is null)) or (new$DateClose <> :old.DateClose)) then
    /*     / */
    update FacialAcc_Cls set
    DateClose = new$DateClose,
    CloseCode = CloseCode + 10
    where Org_ref = new$Id;
  END IF;
  /*   */
  if ((new$DateClose is null) and (:old.DateClose is not null)) then
    update Org_Accounts set
    CloseCode = CloseCode - 10
    where Org_Ref = new$Id;

    /*     / */
    update FacialAcc_Cls set
    DateClose = new$DateClose,
    CloseCode = CloseCode - 10
    where Org_ref = new$Id;

  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_ORGANIZATIONS_BU_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

  if (new$id <> new$GeneralOrg_Ref) then
    select count(*) into cnt$
    from Organizations o where (o.id = new$GeneralOrg_Ref) AND (ROWNUM = 1);

    if cnt$ = 0 then
      RaiseException('ex_GeneralOrgNotFound');
    end if;
  end if;

  if (new$GeneralOrg_Ref <> :old.GeneralOrg_Ref) then
    update FacialAcc_CLS set
      GeneralOrg_Ref = new$GeneralOrg_Ref
    where
      Org_Ref = new$id;
  end if;

-- - - - - - - - - - - - -
-- BU_210 (TR_ORGANIZATIONS_BU_210)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$DOCSTATEREF <> :old.DOCSTATEREF) then
    insert into StateJumpHistory(DocID, BeginStateRef, EndStateRef)
    values(new$id, :old.DOCSTATEREF, new$DOCSTATEREF);
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_ORGANIZATIONS_BU_700)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  IF (new$RVersion IS NULL) THEN
    new$RVersion := 1;
  ELSIF ( (new$RVersion = -1) AND (:OLD.RVersion <> -1) ) THEN
    new$RVersion := :OLD.RVersion;
  ELSE
    new$RVersion := :OLD.RVersion + 1;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_ORGANIZATIONS SET
    ID = new$ID,
    NAME = new$NAME,
    GOSNI = new$GOSNI,
    CITY = new$CITY,
    COUNTRY = new$COUNTRY,
    PHONE = new$PHONE,
    ADDRESS = new$ADDRESS,
    ORG_CLS = new$ORG_CLS,
    INN20 = new$INN20,
    SUBINN = new$SUBINN,
    FACIALACC = new$FACIALACC,
    REGIONCLS = new$REGIONCLS,
    DIRNAME = new$DIRNAME,
    BUGNAME = new$BUGNAME,
    DIRPHONE = new$DIRPHONE,
    BUGPHONE = new$BUGPHONE,
    RCORG = new$RCORG,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    INN = new$INN,
    OKATO = new$OKATO,
    EMAIL = new$EMAIL,
    WEBSITE = new$WEBSITE,
    UFKCODE = new$UFKCODE,
    ADDOKATO = new$ADDOKATO,
    SHORTNAME = new$SHORTNAME,
    RVERSION = new$RVERSION,
    SENDERID = new$SENDERID,
    KVSR = new$KVSR,
    OKFS = new$OKFS,
    OKOPF = new$OKOPF,
    OPENDATE = new$OPENDATE,
    CLOSEDATE = new$CLOSEDATE,
    CHANGEDATE = new$CHANGEDATE,
    GENERALORG_REF = new$GENERALORG_REF,
    FEDERALREGIONCODE = new$FEDERALREGIONCODE,
    ORG_TYPE = new$ORG_TYPE,
    BUDGETREF = new$BUDGETREF,
    SUPPLIERSTATUS = new$SUPPLIERSTATUS,
    COUNTRYCODE = new$COUNTRYCODE,
    DATECLOSE = new$DATECLOSE,
    ORGCODE = new$ORGCODE,
    COSTAUTHORITY = new$COSTAUTHORITY,
    INCOMEAUTHORITY = new$INCOMEAUTHORITY,
    DEBTAUTHORITY = new$DEBTAUTHORITY,
    SVRAUTHORITY = new$SVRAUTHORITY,
    CLIENTID = new$CLIENTID,
    DATEOPEN = new$DATEOPEN,
    FUID = new$FUID,
    OKPO = new$OKPO,
    OKTMO = new$OKTMO,
    DOCSTATEREF = new$DOCSTATEREF,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    OGRN = new$OGRN,
    REJECT_CLS = new$REJECT_CLS,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    REMOTEPBSCODE = new$REMOTEPBSCODE,
    REMOTENOTPBSCODE = new$REMOTENOTPBSCODE,
    USECHECK_CARD = new$USECHECK_CARD,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    RECORDOWNERORGREF = new$RECORDOWNERORGREF,
    REJECTCAUSE = new$REJECTCAUSE,
    BLOCKEDDATE = new$BLOCKEDDATE,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AU_100 (TR_ORGANIZATIONS_AU_100)
-- Create 27.07.2007
-- - - - - - - - - - - - -

-- Comment   / 


  /*    */
  if ((new$DateClose is not null) and (:old.DateClose is null)) then
    update Banks set DateClose = new$DateClose where (id = new$ID) and (DateClose is null);
  end if;

  /*    */
  if ((new$DateClose is null) and (:old.DateClose is not null)) then
    update Banks set DateClose = null where (id = new$ID) and (DateClose is not null);
  end if;

-- - - - - - - - - - - - -
-- AU_200 (TR_ORGANIZATIONS_AU_200)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$BudgetRef <> :old.BudgetRef) then
    update FacialAcc_CLS set
    BudgetRef = new$BudgetRef
    where
    (ORG_REF = new$id)and((BudgetRef = :old.BudgetRef)or(BudgetRef<>0));
  END IF;
  /*     ,    */
  if ((new$KVSR <> :old.KVSR)and(new$Org_Type >= 10100)and(new$Org_Type <= 10299)) then
    update KVSR set
    Org_Ref = new$id
    where
    id = new$KVSR;
  END IF;
  if (new$KVSR <> :old.KVSR) then
    update FacialAcc_CLS set
    KVSR = new$KVSR
    where
    (ORG_REF = new$id) and (KVSR = :old.KVSR);
  END IF;
  if (new$BudgetRef <> :old.BudgetRef) then
    update organizations set
    BudgetRef = new$BudgetRef
    where
    (generalorg_ref = new$id) and (id <> new$id);
  END IF;
  if (new$KVSR <> :old.KVSR) then
    update organizations set
    KVSR = new$KVSR
    where
    (generalorg_ref = new$id) and (id <> new$id);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_ORGANIZATIONS_AU_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (27, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=27) and (RecordId=new$ID);
  end if;

END;
/
commit work
/


-- #########################################################
-- #########################################################
-- Add_DBUsers_PassChanged.sql
-- #########################################################
-- #########################################################

/*       
*/
ALTER TABLE TB_DBUsers ADD (
  PassChanged DATE/*       */
)
/

CREATE OR REPLACE VIEW DBUsers (
  ID,
  USERNAME,
  FIRSTNAME,
  MIDDLENAME,
  LASTNAME,
  NOTE,
  PHONE,
  DESCRIPTION,
  DEPARTMENTCLS,
  REMOTECLIENTREF,
  REMOTEID,
  CREATEDATE,
  UPDATEDATE,
  CRYPTOPARAMS,
  CRYPTOID,
  ORG_REF,
  NOTE2,
  EMAILADDRESS,
  PRINCIPALNAME,
  USERGUID,
  CREATERUSER,
  UPDATERUSER,
  PASSCHANGED)
AS
  SELECT
    ID,
    USERNAME,
    FIRSTNAME,
    MIDDLENAME,
    LASTNAME,
    NOTE,
    PHONE,
    DESCRIPTION,
    DEPARTMENTCLS,
    REMOTECLIENTREF,
    REMOTEID,
    CREATEDATE,
    UPDATEDATE,
    CRYPTOPARAMS,
    CRYPTOID,
    ORG_REF,
    NOTE2,
    EMAILADDRESS,
    PRINCIPALNAME,
    USERGUID,
    CREATERUSER,
    UPDATERUSER,
    PASSCHANGED
  FROM TB_DBUsers
/

CREATE OR REPLACE TRIGGER TR_DBUSERS_ID
  INSTEAD OF DELETE
  ON DBUSERS
  FOR EACH ROW
DECLARE
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_DBUSERS_BD)
-- - - - - - - - - - - - -

        --    SYSDBA
        if (:old.id = 0) then
                RaiseException('EX_CANTDELETETHIS');
        end if;

-- - - - - - - - - - - - -
-- BD_1 (TR_DBUSERS_BD_1)
-- - - - - - - - - - - - -

/*     */
        delete from User_Workplaces     where Users_ref = :old.id;
    delete from ReportsPermissions where Userid = :old.id;
    delete from UsersInGroups  where UserRef = :old.id;
    delete from UsersRights  where UserRef = :old.id;
    delete from DualRights  where (UserRef = :old.id) and (IsGroup = 0);

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_DBUSERS
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_10 (TR_DBUSERS_AD_10)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*    RemoteClients  DBUsers */
  if (:old.RemoteClientRef is not null) then
    SELECT COUNT(dbu.ID ) INTO CNT$1
    from DBUsers dbu where (dbu.RemoteClientRef = :old.RemoteClientRef) AND (ROWNUM = 1);
    /*     DBUsers     RemoteClient,   ,     */
    if (not (CNT$1<> 0)) then
      delete from RemoteClient where ID = :old.RemoteClientRef;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AD_20 (TR_DBUSERS_AD_20)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*         DBUsers */
  delete from LayerData
  where LayerRef in(select ID from Layers where Alias in('..','..')) and STRFIELD00 = :old.UserName;
  delete from LayerData
  where LayerRef = (select ID from Layers where Alias = '..') and STRFIELD01 = :old.UserName;
  delete from LayerData
  where LayerRef = (select ID from Layers where Alias = '..') and STRFIELD02 = :old.UserName;

-- - - - - - - - - - - - -
-- AD_30 (tr_dbusers_ad_30)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  update DepartmentCls set
  User_Ref = null
  where
  User_Ref = :old.Id;

-- - - - - - - - - - - - -
-- AD_500 (TR_DBUSERS_AD_500)
-- - - - - - - - - - - - -

/*      */
  insert into DelRecIndexes(TableID,RecordId,DeleteDate)
       values(100,:old.ID, sysdate);

END;
/

CREATE OR REPLACE TRIGGER TR_DBUSERS_II
  INSTEAD OF INSERT
  ON DBUSERS
  FOR EACH ROW
DECLARE
  new$ID DBUSERS.ID%TYPE := :NEW.ID;
  new$USERNAME DBUSERS.USERNAME%TYPE := :NEW.USERNAME;
  new$FIRSTNAME DBUSERS.FIRSTNAME%TYPE := :NEW.FIRSTNAME;
  new$MIDDLENAME DBUSERS.MIDDLENAME%TYPE := :NEW.MIDDLENAME;
  new$LASTNAME DBUSERS.LASTNAME%TYPE := :NEW.LASTNAME;
  new$NOTE DBUSERS.NOTE%TYPE := :NEW.NOTE;
  new$PHONE DBUSERS.PHONE%TYPE := :NEW.PHONE;
  new$DESCRIPTION DBUSERS.DESCRIPTION%TYPE := :NEW.DESCRIPTION;
  new$DEPARTMENTCLS DBUSERS.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$REMOTECLIENTREF DBUSERS.REMOTECLIENTREF%TYPE := :NEW.REMOTECLIENTREF;
  new$REMOTEID DBUSERS.REMOTEID%TYPE := :NEW.REMOTEID;
  new$CREATEDATE DBUSERS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE DBUSERS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CRYPTOPARAMS DBUSERS.CRYPTOPARAMS%TYPE := :NEW.CRYPTOPARAMS;
  new$CRYPTOID DBUSERS.CRYPTOID%TYPE := :NEW.CRYPTOID;
  new$ORG_REF DBUSERS.ORG_REF%TYPE := :NEW.ORG_REF;
  new$NOTE2 DBUSERS.NOTE2%TYPE := :NEW.NOTE2;
  new$EMAILADDRESS DBUSERS.EMAILADDRESS%TYPE := :NEW.EMAILADDRESS;
  new$PRINCIPALNAME DBUSERS.PRINCIPALNAME%TYPE := :NEW.PRINCIPALNAME;
  new$USERGUID DBUSERS.USERGUID%TYPE := :NEW.USERGUID;
  new$CREATERUSER DBUSERS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER DBUSERS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$PASSCHANGED DBUSERS.PASSCHANGED%TYPE := :NEW.PASSCHANGED;
--
  cGroupID$ NUMBER(10);
  acc1$ NUMBER(10);
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_DBUSERS_BI)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  new$UserName := Upper(new$UserName);
  if (new$RemoteClientRef is null) then 
    new$RemoteID := -1;
     
  else 
    new$RemoteID := new$RemoteClientRef;
  END IF;
  if (new$Org_Ref is null) then
    GetIntConst(-1, 2,acc1$);
    BEGIN
      select
      o.id
      into
      new$Org_Ref    from
      organizations o
      left join org_accounts oa on (oa.org_ref = o.id)
      where
      (oa.id = acc1$)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$Org_Ref is null) then
      new$Org_Ref := 0;
     
    END IF;
  END IF;
  if (new$RemoteClientRef is not null) then
    new$PrincipalName := null;
  END IF;
  if (new$PrincipalName is not null) then
    SELECT COUNT(id ) INTO CNT$1
    from dbUsers where (PrincipalName = new$PrincipalName) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_DBUSERS_DUBLICATENAME');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_DBUSERS_BI_500)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_DBUSERS (
    ID,
    USERNAME,
    FIRSTNAME,
    MIDDLENAME,
    LASTNAME,
    NOTE,
    PHONE,
    DESCRIPTION,
    DEPARTMENTCLS,
    REMOTECLIENTREF,
    REMOTEID,
    CREATEDATE,
    UPDATEDATE,
    CRYPTOPARAMS,
    CRYPTOID,
    ORG_REF,
    NOTE2,
    EMAILADDRESS,
    PRINCIPALNAME,
    USERGUID,
    CREATERUSER,
    UPDATERUSER,
    PASSCHANGED
  ) VALUES (
    new$ID,
    new$USERNAME,
    new$FIRSTNAME,
    new$MIDDLENAME,
    new$LASTNAME,
    new$NOTE,
    new$PHONE,
    new$DESCRIPTION,
    new$DEPARTMENTCLS,
    new$REMOTECLIENTREF,
    new$REMOTEID,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$CRYPTOPARAMS,
    new$CRYPTOID,
    new$ORG_REF,
    new$NOTE2,
    new$EMAILADDRESS,
    new$PRINCIPALNAME,
    new$USERGUID,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$PASSCHANGED);

-- - - - - - - - - - - - -
-- AI_0 (TR_DBUSERS_AI)
-- Last update 30.03.2006
-- - - - - - - - - - - - -

 insert into UsersInGroups (UserRef, GroupRef)
      values (new$id, 0);

 /*     */
 if (new$RemoteID = -1) then
     /*  ID  */
     select max(ID) into cGroupID$ from DBGroups where (Name = '');
     if (not (cGroupID$ is null)) then
        insert into UsersInGroups (UserRef, GroupRef)
        values (new$ID, cGroupID$);
     end if;
 /*     */
 else
     /*  ID   */
     select max(ID) into cGroupID$ from DBGroups where (Name = '');
     if (not (cGroupID$ is null)) then
        insert into UsersInGroups (UserRef, GroupRef)
        values (new$ID, cGroupID$);
     end if;
 end if;

-- - - - - - - - - - - - -
-- AI_500 (TR_DBUSERS_AI_500)
-- Last update 18.02.2004
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 100) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_DBUSERS_IU
  INSTEAD OF UPDATE
  ON DBUSERS
  FOR EACH ROW
DECLARE
  new$ID DBUSERS.ID%TYPE := :NEW.ID;
  new$USERNAME DBUSERS.USERNAME%TYPE := :NEW.USERNAME;
  new$FIRSTNAME DBUSERS.FIRSTNAME%TYPE := :NEW.FIRSTNAME;
  new$MIDDLENAME DBUSERS.MIDDLENAME%TYPE := :NEW.MIDDLENAME;
  new$LASTNAME DBUSERS.LASTNAME%TYPE := :NEW.LASTNAME;
  new$NOTE DBUSERS.NOTE%TYPE := :NEW.NOTE;
  new$PHONE DBUSERS.PHONE%TYPE := :NEW.PHONE;
  new$DESCRIPTION DBUSERS.DESCRIPTION%TYPE := :NEW.DESCRIPTION;
  new$DEPARTMENTCLS DBUSERS.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$REMOTECLIENTREF DBUSERS.REMOTECLIENTREF%TYPE := :NEW.REMOTECLIENTREF;
  new$REMOTEID DBUSERS.REMOTEID%TYPE := :NEW.REMOTEID;
  new$CREATEDATE DBUSERS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE DBUSERS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CRYPTOPARAMS DBUSERS.CRYPTOPARAMS%TYPE := :NEW.CRYPTOPARAMS;
  new$CRYPTOID DBUSERS.CRYPTOID%TYPE := :NEW.CRYPTOID;
  new$ORG_REF DBUSERS.ORG_REF%TYPE := :NEW.ORG_REF;
  new$NOTE2 DBUSERS.NOTE2%TYPE := :NEW.NOTE2;
  new$EMAILADDRESS DBUSERS.EMAILADDRESS%TYPE := :NEW.EMAILADDRESS;
  new$PRINCIPALNAME DBUSERS.PRINCIPALNAME%TYPE := :NEW.PRINCIPALNAME;
  new$USERGUID DBUSERS.USERGUID%TYPE := :NEW.USERGUID;
  new$CREATERUSER DBUSERS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER DBUSERS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$PASSCHANGED DBUSERS.PASSCHANGED%TYPE := :NEW.PASSCHANGED;
--
  cGroupID1$ NUMBER(10);
  acc$ NUMBER(10);
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_DBUSERS_BU)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  new$UserName := Upper(new$UserName);
  if (new$RemoteClientRef is null) then
    new$RemoteID := -1;
     
  else 
    new$RemoteID := new$RemoteClientRef;
  END IF;
  /*     ,       */
  if ((:old.RemoteID > 0) and (new$RemoteID = -1)) then
    select max(ID)       into cGroupID1$ from DBGroups where (Name = '')
    ;
    if (not (cGroupID1$ is null)) then
      update UsersInGroups uig set uig.GroupRef = cGroupID1$

      where (uig.UserRef = :old.ID) and
      ((select Name from DBGroups dbg where dbg.ID = uig.GroupRef) = '');
     
    END IF;
  END IF;
  /*     ,       */
  if ((:old.RemoteID = -1) and (new$RemoteID > 0)) then
    select max(ID)       into cGroupID1$ from DBGroups where (Name = '')
    ;
    if (not (cGroupID1$ is null)) then
      update UsersInGroups uig set uig.GroupRef = cGroupID1$

      where (uig.UserRef = :old.ID) and
      ((select Name from DBGroups dbg where dbg.ID = uig.GroupRef) = '');
     
    END IF;
  END IF;
  if (new$Org_Ref is null) then
    GetIntConst(-1, 2,acc$);
    BEGIN
      select
      o.id
      into
      new$Org_Ref    from
      organizations o
      left join org_accounts oa on (oa.org_ref = o.id)
      where
      (oa.id = acc$)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$Org_Ref is null) then
      new$Org_Ref := 0;
     
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_1 (TR_DBUSERS_BU_1)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if ((:old.id = 0) and (new$UserName <> :old.UserName)) then 
    RaiseException('ex_CantUpdateThis');
  END IF;
  if (new$RemoteClientRef is not null) then
    new$PrincipalName := null;
  END IF;
  if (new$PrincipalName is not null) then
    SELECT COUNT(id ) INTO CNT$1
    from dbUsers where ((PrincipalName = new$PrincipalName) and id <> new$ID) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_DBUSERS_DUBLICATENAME');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_DBUSERS SET
    ID = new$ID,
    USERNAME = new$USERNAME,
    FIRSTNAME = new$FIRSTNAME,
    MIDDLENAME = new$MIDDLENAME,
    LASTNAME = new$LASTNAME,
    NOTE = new$NOTE,
    PHONE = new$PHONE,
    DESCRIPTION = new$DESCRIPTION,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    REMOTECLIENTREF = new$REMOTECLIENTREF,
    REMOTEID = new$REMOTEID,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    CRYPTOPARAMS = new$CRYPTOPARAMS,
    CRYPTOID = new$CRYPTOID,
    ORG_REF = new$ORG_REF,
    NOTE2 = new$NOTE2,
    EMAILADDRESS = new$EMAILADDRESS,
    PRINCIPALNAME = new$PRINCIPALNAME,
    USERGUID = new$USERGUID,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    PASSCHANGED = new$PASSCHANGED
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_DBUSERS_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (100, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=100) and (RecordId=new$ID);
  end if;

END;
/
commit work 
/

-- #########################################################
-- #########################################################
-- Add_TenderCaption_CascadeTriggers.sql
-- #########################################################
-- #########################################################

/*           (30.10) ->  (30.11), (30.05) -> (30.06)
     /:      ,      /    
     /:       /

   TenderCaption:      */
-- CREATE TRIGGER tr_TenderCaption_au_30
CREATE OR REPLACE TRIGGER TR_TENDERCAPTION_IU
  INSTEAD OF UPDATE
  ON TENDERCAPTION
  FOR EACH ROW
DECLARE
  new$ID TENDERCAPTION.ID%TYPE := :NEW.ID;
  new$BUDGETREF TENDERCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FACIALACCCLS TENDERCAPTION.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$MULTIPURPOSE TENDERCAPTION.MULTIPURPOSE%TYPE := :NEW.MULTIPURPOSE;
  new$DOCUMENTDATE TENDERCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE TENDERCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PERIOD TENDERCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$ACCEPTSUMMA TENDERCAPTION.ACCEPTSUMMA%TYPE := :NEW.ACCEPTSUMMA;
  new$SALETYPE TENDERCAPTION.SALETYPE%TYPE := :NEW.SALETYPE;
  new$REJECTCLS TENDERCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS TENDERCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID TENDERCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID TENDERCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCSTATEREF TENDERCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CREATERUSER TENDERCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TENDERCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE TENDERCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER TENDERCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$LASTADJUSTMENT TENDERCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED TENDERCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$ADJUSTMENTREF TENDERCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ACCEPTED TENDERCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$EXPORTDATE TENDERCAPTION.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$YEARACCEPTSUMMA TENDERCAPTION.YEARACCEPTSUMMA%TYPE := :NEW.YEARACCEPTSUMMA;
  new$TENDEROPTION TENDERCAPTION.TENDEROPTION%TYPE := :NEW.TENDEROPTION;
  new$TENDERTARGET TENDERCAPTION.TENDERTARGET%TYPE := :NEW.TENDERTARGET;
  new$RVERSION TENDERCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$ALLOWANCE TENDERCAPTION.ALLOWANCE%TYPE := :NEW.ALLOWANCE;
  new$REFINEMENTCAUSE TENDERCAPTION.REFINEMENTCAUSE%TYPE := :NEW.REFINEMENTCAUSE;
  new$PREFERENCE TENDERCAPTION.PREFERENCE%TYPE := :NEW.PREFERENCE;
  new$PREFERENCESIZE TENDERCAPTION.PREFERENCESIZE%TYPE := :NEW.PREFERENCESIZE;
  new$SECURITY TENDERCAPTION.SECURITY%TYPE := :NEW.SECURITY;
  new$UNKNOWNAMOUNT TENDERCAPTION.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PERIODYEAR TENDERCAPTION.PERIODYEAR%TYPE := :NEW.PERIODYEAR;
  new$SUPPORTUNDERTAKER TENDERCAPTION.SUPPORTUNDERTAKER%TYPE := :NEW.SUPPORTUNDERTAKER;
  new$AYEAR TENDERCAPTION.AYEAR%TYPE := :NEW.AYEAR;
  new$REWORKCAUSE TENDERCAPTION.REWORKCAUSE%TYPE := :NEW.REWORKCAUSE;
  new$NOTE TENDERCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$REALID TENDERCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER TENDERCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTNUMBER TENDERCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$SENDERIDKEY TENDERCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY TENDERCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$PROTOCOLREASON TENDERCAPTION.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$PROGINDEX TENDERCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$DOCNUMBER TENDERCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SECURITYTSIZE TENDERCAPTION.SECURITYTSIZE%TYPE := :NEW.SECURITYTSIZE;
  new$SECURITYASIZE TENDERCAPTION.SECURITYASIZE%TYPE := :NEW.SECURITYASIZE;
  new$AVANSSIZE TENDERCAPTION.AVANSSIZE%TYPE := :NEW.AVANSSIZE;
  new$PREFERENCECRIPPLE TENDERCAPTION.PREFERENCECRIPPLE%TYPE := :NEW.PREFERENCECRIPPLE;
  new$PREFERENCERUSPRODUCT TENDERCAPTION.PREFERENCERUSPRODUCT%TYPE := :NEW.PREFERENCERUSPRODUCT;
  new$PREFERENCEPRISON TENDERCAPTION.PREFERENCEPRISON%TYPE := :NEW.PREFERENCEPRISON;
  new$AGREEMENTEXECUTIONDATE TENDERCAPTION.AGREEMENTEXECUTIONDATE%TYPE := :NEW.AGREEMENTEXECUTIONDATE;
  new$PURCHASECODE TENDERCAPTION.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$PURCHASESOCIALNKO TENDERCAPTION.PURCHASESOCIALNKO%TYPE := :NEW.PURCHASESOCIALNKO;
  new$AVERSION TENDERCAPTION.AVERSION%TYPE := :NEW.AVERSION;
  new$PARENTREF TENDERCAPTION.PARENTREF%TYPE := :NEW.PARENTREF;
  new$REJECTCAUSE TENDERCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  CurVal$ NUMBER(10);
  DetCount$ NUMBER(10);
  ParentProgIndex$ NUMBER(10);
  ParentInnerNumber$ NUMBER(10);
  AdjParentRef$ NUMBER(10);
  AdjParentInnerNumber$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_TENDERCAPTION_BU_0)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  /*         ( ) */
  if (new$ProgIndex = 230 and new$Multipurpose is null) then
    new$Multipurpose := 0;
  END IF;
  if (new$AcceptSumma is null) then
    new$AcceptSumma := 0;
  END IF;
  if (new$YearAcceptSumma is null) then
    new$YearAcceptSumma := 0;
  END IF;
  if (new$Allowance is null) then
    new$Allowance := 0;
  END IF;
  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if (not((new$BudgetRef is null) and (:old.BudgetRef is null))) then
      select count(ID)         into DetCount$ from TENDERSOURCEORG where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERCONTACTS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERSUPDOCUMENT where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERSUPPLEMENTS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERYARDSTICKS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TenderLot where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  if (new$SaleType is null) then
    new$SaleType := 0;
  END IF;
  if (new$TenderOption is null) then
    new$TenderOption := 0;
  END IF;
  if (new$InnerNumber is Null) then
    new$InnerNumber := GEN_ID('G_TenderInnerNumber',1);
  END IF;
  if (new$RefinementCause is Null) then
    new$RefinementCause := 0;
  END IF;
  if (new$Preference is Null) then
    new$Preference := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$SupportUndertaker is null) then
    new$SupportUndertaker := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_3 (TR_TENDERCAPTION_BU_3)
-- Create 03.12.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   /*             */
   new$AdjustmentRef := :OLD.AdjustmentRef;

-- - - - - - - - - - - - -
-- BU_5 (TR_TENDERCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_TENDERCAPTION_BU_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.0*/
  if ((new$InnerNumber <> :old.InnerNumber) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber)) then
    RaiseException('EX_AGR_CHANGEINNERNUMS');
  END IF;

  /*   !!!*/
  if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and
  ((new$Accepted = 1) or (new$AcceptDate is null))) then
    RaiseException('EX_RollbackCancel');
  END IF;

  /*  ,     LastAccepted*/
  if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) or
  ((:old.Accepted = 0) and (new$Accepted = 1) and (new$AcceptDate is not null))) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;

    else
      RaiseException('EX_Ten_ChangeStateAdjust');
    END IF;
  END IF;

  /*    ,     LastAccepted*/
  if (((:old.AcceptDate is not null) and (:old.Accepted = 1)) and
  ((new$Accepted = 0) or (new$AcceptDate is null))) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 0;

    else
      RaiseException('EX_Ten_ChangeStateAdjust');
    END IF;
  END IF;

  /*   ,     LastAdjustment*/
  if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 0)) or
  ((:old.Accepted = 1) and (new$Accepted = 0) and (new$AcceptDate is not null))) then
    if (new$LastAdjustment = 1) then
      new$LastAdjustment := 0;
      new$LastAccepted := 0;

    else
      RaiseException('EX_Ten_ChangeStateAdjust');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_TENDERCAPTION_BU_30)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  /* :  /    / */
  if (new$ParentRef is not null
  /*  ,   */
  and  (:old.ParentRef is null
  or (:old.ParentRef is not null and :old.ParentRef <> new$ParentRef)))
  then
    /* :     ParentRef  */
    if (new$LastAdjustment = 0) then
      RaiseException('EX_ChangeAdjTenderParentRef');
    END IF;
    BEGIN
      select ProgIndex, InnerNumber
      into ParentProgIndex$, ParentInnerNumber$     from TenderCaption
      where ID=new$ParentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /* :  /    / */
    if  ((new$ProgIndex=243 and ParentProgIndex$ <> 242)
    or (new$ProgIndex=241 and ParentProgIndex$ <> 240))
    then
      RaiseException('EX_IncorrectTenderParentRef');
    END IF;
    /* :       /     ( ,    ) */
    if (new$AdjustmentRef is not null) then
      BEGIN
        select ParentRef
        into AdjParentRef$       from TenderCaption
        where ID=new$AdjustmentRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (AdjParentRef$ is not null) then
        BEGIN
          select InnerNumber
          into AdjParentInnerNumber$         from TenderCaption
          where ID=AdjParentRef$

          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        if (AdjParentInnerNumber$ <> ParentInnerNumber$) then
          RaiseException('EX_IncorrectAdjTenderParentRef');
        END IF;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_50 (TR_TENDERCAPTION_BU_50)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  if (new$InnerNumber is not null) then
    CurVal$ := GEN_ID('G_TENDERINNERNUMBER',0);
    if (CurVal$ < new$InnerNumber) then
      CurVal$ := GEN_ID('G_TENDERINNERNUMBER',new$InnerNumber - CurVal$);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_TENDERCAPTION_BU_200)
-- Create 03.12.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   /*        */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
        VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef);
   END IF;

-- - - - - - - - - - - - -
-- BU_600 (tendercaption_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_TENDERCAPTION_BU_700)
-- Create 14.10.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_TENDERCAPTION SET
    ID = new$ID,
    BUDGETREF = new$BUDGETREF,
    FACIALACCCLS = new$FACIALACCCLS,
    MULTIPURPOSE = new$MULTIPURPOSE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    PERIOD = new$PERIOD,
    ACCEPTSUMMA = new$ACCEPTSUMMA,
    SALETYPE = new$SALETYPE,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DOCSTATEREF = new$DOCSTATEREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    ACCEPTED = new$ACCEPTED,
    EXPORTDATE = new$EXPORTDATE,
    YEARACCEPTSUMMA = new$YEARACCEPTSUMMA,
    TENDEROPTION = new$TENDEROPTION,
    TENDERTARGET = new$TENDERTARGET,
    RVERSION = new$RVERSION,
    ALLOWANCE = new$ALLOWANCE,
    REFINEMENTCAUSE = new$REFINEMENTCAUSE,
    PREFERENCE = new$PREFERENCE,
    PREFERENCESIZE = new$PREFERENCESIZE,
    SECURITY = new$SECURITY,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PERIODYEAR = new$PERIODYEAR,
    SUPPORTUNDERTAKER = new$SUPPORTUNDERTAKER,
    AYEAR = new$AYEAR,
    REWORKCAUSE = new$REWORKCAUSE,
    NOTE = new$NOTE,
    REALID = new$REALID,
    INNERNUMBER = new$INNERNUMBER,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    PROTOCOLREASON = new$PROTOCOLREASON,
    PROGINDEX = new$PROGINDEX,
    DOCNUMBER = new$DOCNUMBER,
    SECURITYTSIZE = new$SECURITYTSIZE,
    SECURITYASIZE = new$SECURITYASIZE,
    AVANSSIZE = new$AVANSSIZE,
    PREFERENCECRIPPLE = new$PREFERENCECRIPPLE,
    PREFERENCERUSPRODUCT = new$PREFERENCERUSPRODUCT,
    PREFERENCEPRISON = new$PREFERENCEPRISON,
    AGREEMENTEXECUTIONDATE = new$AGREEMENTEXECUTIONDATE,
    PURCHASECODE = new$PURCHASECODE,
    PURCHASESOCIALNKO = new$PURCHASESOCIALNKO,
    AVERSION = new$AVERSION,
    PARENTREF = new$PARENTREF,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_TENDERCAPTION_AU_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.1*/
  /*      */
  /*     ,       */
  if ((new$AdjustmentNumber > 0) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update TenderCaption set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

  /*       LastAdjustment    */
  if ((new$AdjustmentNumber > 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update TenderCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_TENDERCAPTION_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   2.0*/
  /*       ,      */
  if (:old.FacialAccCls <> new$FacialAccCls) then
    update TenderProduct set
    RVersion = -1,
    FacialAccCls = new$FacialAccCls
    where
    (RecordIndex = new$ID) and (ProgIndex = 230);
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (tr_TenderCaption_au_30)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) /*      */
  and ((new$ProgIndex = 240) /* */ or (new$ProgIndex = 242) /* */))
  then
    if ((new$Accepted <> :old.Accepted)
    or (new$AcceptDate is not null and :old.AcceptDate is null)
    or (new$AcceptDate is null and :old.AcceptDate is not null)
    or (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))
    then 
      update TenderCaption set
      RejectCls = new$RejectCls,
      AcceptDate = new$AcceptDate
      where ParentRef=new$ID;
      /*          */
      if (:old.Accepted=1 and new$Accepted=0) then
        update TenderCaption set
        RejectCause = '   : ' || new$RejectCause
        where ParentRef=new$ID;
      END IF;
      /*             */
      if (:old.Accepted=0 and new$Accepted=1) then
        update TenderCaption set
        RejectCls = null,
        RejectCause = null
        where ParentRef=new$ID;
          
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_TENDERCAPTION_AU_500)
-- Create 28.04.2005
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
           VALUES (139, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
            WHERE (TableID = 139) AND (RecordId = new$ID);
   END IF;

END;
/
-- CREATE TRIGGER tr_tendercaption_bu_10
CREATE OR REPLACE TRIGGER TR_TENDERCAPTION_IU
  INSTEAD OF UPDATE
  ON TENDERCAPTION
  FOR EACH ROW
DECLARE
  new$ID TENDERCAPTION.ID%TYPE := :NEW.ID;
  new$BUDGETREF TENDERCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FACIALACCCLS TENDERCAPTION.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$MULTIPURPOSE TENDERCAPTION.MULTIPURPOSE%TYPE := :NEW.MULTIPURPOSE;
  new$DOCUMENTDATE TENDERCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE TENDERCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PERIOD TENDERCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$ACCEPTSUMMA TENDERCAPTION.ACCEPTSUMMA%TYPE := :NEW.ACCEPTSUMMA;
  new$SALETYPE TENDERCAPTION.SALETYPE%TYPE := :NEW.SALETYPE;
  new$REJECTCLS TENDERCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS TENDERCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID TENDERCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID TENDERCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCSTATEREF TENDERCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CREATERUSER TENDERCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TENDERCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE TENDERCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER TENDERCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$LASTADJUSTMENT TENDERCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED TENDERCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$ADJUSTMENTREF TENDERCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ACCEPTED TENDERCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$EXPORTDATE TENDERCAPTION.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$YEARACCEPTSUMMA TENDERCAPTION.YEARACCEPTSUMMA%TYPE := :NEW.YEARACCEPTSUMMA;
  new$TENDEROPTION TENDERCAPTION.TENDEROPTION%TYPE := :NEW.TENDEROPTION;
  new$TENDERTARGET TENDERCAPTION.TENDERTARGET%TYPE := :NEW.TENDERTARGET;
  new$RVERSION TENDERCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$ALLOWANCE TENDERCAPTION.ALLOWANCE%TYPE := :NEW.ALLOWANCE;
  new$REFINEMENTCAUSE TENDERCAPTION.REFINEMENTCAUSE%TYPE := :NEW.REFINEMENTCAUSE;
  new$PREFERENCE TENDERCAPTION.PREFERENCE%TYPE := :NEW.PREFERENCE;
  new$PREFERENCESIZE TENDERCAPTION.PREFERENCESIZE%TYPE := :NEW.PREFERENCESIZE;
  new$SECURITY TENDERCAPTION.SECURITY%TYPE := :NEW.SECURITY;
  new$UNKNOWNAMOUNT TENDERCAPTION.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PERIODYEAR TENDERCAPTION.PERIODYEAR%TYPE := :NEW.PERIODYEAR;
  new$SUPPORTUNDERTAKER TENDERCAPTION.SUPPORTUNDERTAKER%TYPE := :NEW.SUPPORTUNDERTAKER;
  new$AYEAR TENDERCAPTION.AYEAR%TYPE := :NEW.AYEAR;
  new$REWORKCAUSE TENDERCAPTION.REWORKCAUSE%TYPE := :NEW.REWORKCAUSE;
  new$NOTE TENDERCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$REALID TENDERCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER TENDERCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTNUMBER TENDERCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$SENDERIDKEY TENDERCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY TENDERCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$PROTOCOLREASON TENDERCAPTION.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$PROGINDEX TENDERCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$DOCNUMBER TENDERCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SECURITYTSIZE TENDERCAPTION.SECURITYTSIZE%TYPE := :NEW.SECURITYTSIZE;
  new$SECURITYASIZE TENDERCAPTION.SECURITYASIZE%TYPE := :NEW.SECURITYASIZE;
  new$AVANSSIZE TENDERCAPTION.AVANSSIZE%TYPE := :NEW.AVANSSIZE;
  new$PREFERENCECRIPPLE TENDERCAPTION.PREFERENCECRIPPLE%TYPE := :NEW.PREFERENCECRIPPLE;
  new$PREFERENCERUSPRODUCT TENDERCAPTION.PREFERENCERUSPRODUCT%TYPE := :NEW.PREFERENCERUSPRODUCT;
  new$PREFERENCEPRISON TENDERCAPTION.PREFERENCEPRISON%TYPE := :NEW.PREFERENCEPRISON;
  new$AGREEMENTEXECUTIONDATE TENDERCAPTION.AGREEMENTEXECUTIONDATE%TYPE := :NEW.AGREEMENTEXECUTIONDATE;
  new$PURCHASECODE TENDERCAPTION.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$PURCHASESOCIALNKO TENDERCAPTION.PURCHASESOCIALNKO%TYPE := :NEW.PURCHASESOCIALNKO;
  new$AVERSION TENDERCAPTION.AVERSION%TYPE := :NEW.AVERSION;
  new$PARENTREF TENDERCAPTION.PARENTREF%TYPE := :NEW.PARENTREF;
  new$REJECTCAUSE TENDERCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
--
  CurVal$ NUMBER(10);
  DetCount$ NUMBER(10);
  ParentProgIndex$ NUMBER(10);
  ParentInnerNumber$ NUMBER(10);
  AdjParentRef$ NUMBER(10);
  AdjParentInnerNumber$ NUMBER(10);
  countLastAdj$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_TENDERCAPTION_BU_0)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  /*         ( ) */
  if (new$ProgIndex = 230 and new$Multipurpose is null) then
    new$Multipurpose := 0;
  END IF;
  if (new$AcceptSumma is null) then
    new$AcceptSumma := 0;
  END IF;
  if (new$YearAcceptSumma is null) then
    new$YearAcceptSumma := 0;
  END IF;
  if (new$Allowance is null) then
    new$Allowance := 0;
  END IF;
  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if (not((new$BudgetRef is null) and (:old.BudgetRef is null))) then
      select count(ID)         into DetCount$ from TENDERSOURCEORG where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERCONTACTS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERSUPDOCUMENT where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERSUPPLEMENTS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TENDERYARDSTICKS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount$ from TenderLot where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  if (new$SaleType is null) then
    new$SaleType := 0;
  END IF;
  if (new$TenderOption is null) then
    new$TenderOption := 0;
  END IF;
  if (new$InnerNumber is Null) then
    new$InnerNumber := GEN_ID('G_TenderInnerNumber',1);
  END IF;
  if (new$RefinementCause is Null) then
    new$RefinementCause := 0;
  END IF;
  if (new$Preference is Null) then
    new$Preference := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$SupportUndertaker is null) then
    new$SupportUndertaker := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_3 (TR_TENDERCAPTION_BU_3)
-- Create 03.12.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   /*             */
   new$AdjustmentRef := :OLD.AdjustmentRef;

-- - - - - - - - - - - - -
-- BU_5 (TR_TENDERCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_TENDERCAPTION_BU_10)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*   12.0*/
  if ((new$InnerNumber <> :old.InnerNumber) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber)) then
    RaiseException('EX_AGR_CHANGEINNERNUMS');
  END IF;
      
  /*   !!!*/
  if (:old.AcceptDate is not null
  and :old.Accepted = 0
  and (new$Accepted = 1 or new$AcceptDate is null))
  then 
    /* :  */
    if (new$AdjustmentNumber > 0) then
      RaiseException('EX_RollbackCancel');
    END IF;
    /*      ,
             , ,          */
    select count(ID)
    into countLastAdj$       from TenderCaption
    where InnerNumber=new$InnerNumber and LastAdjustment = 1
    ;
    if (countLastAdj$ = 0) then
      new$LastAdjustment := 1;
        
    END IF;
  END IF;
  /*  ,     LastAccepted*/
  if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) or 
  ((:old.Accepted = 0) and (new$Accepted = 1) and (new$AcceptDate is not null))) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;
              
    else
      RaiseException('EX_Ten_ChangeStateAdjust');    
    END IF;
  END IF;
      
  /*    ,     LastAccepted*/
  if (((:old.AcceptDate is not null) and (:old.Accepted = 1)) and
  ((new$Accepted = 0) or (new$AcceptDate is null))) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 0;
              
    else
      RaiseException('EX_Ten_ChangeStateAdjust');    
    END IF;
  END IF;
      
  /*   ,     LastAdjustment*/
  if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 0)) or 
  ((:old.Accepted = 1) and (new$Accepted = 0) and (new$AcceptDate is not null))) then
    if (new$LastAdjustment = 1) then
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
              
    else
      RaiseException('EX_Ten_ChangeStateAdjust');    
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_TENDERCAPTION_BU_30)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  /* :  /    / */
  if (new$ParentRef is not null
  /*  ,   */
  and  (:old.ParentRef is null
  or (:old.ParentRef is not null and :old.ParentRef <> new$ParentRef)))
  then
    /* :     ParentRef  */
    if (new$LastAdjustment = 0) then
      RaiseException('EX_ChangeAdjTenderParentRef');
    END IF;
    BEGIN
      select ProgIndex, InnerNumber
      into ParentProgIndex$, ParentInnerNumber$     from TenderCaption
      where ID=new$ParentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /* :  /    / */
    if  ((new$ProgIndex=243 and ParentProgIndex$ <> 242)
    or (new$ProgIndex=241 and ParentProgIndex$ <> 240))
    then
      RaiseException('EX_IncorrectTenderParentRef');
    END IF;
    /* :       /     ( ,    ) */
    if (new$AdjustmentRef is not null) then
      BEGIN
        select ParentRef
        into AdjParentRef$       from TenderCaption
        where ID=new$AdjustmentRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (AdjParentRef$ is not null) then
        BEGIN
          select InnerNumber
          into AdjParentInnerNumber$         from TenderCaption
          where ID=AdjParentRef$

          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        if (AdjParentInnerNumber$ <> ParentInnerNumber$) then
          RaiseException('EX_IncorrectAdjTenderParentRef');
        END IF;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_50 (TR_TENDERCAPTION_BU_50)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  if (new$InnerNumber is not null) then
    CurVal$ := GEN_ID('G_TENDERINNERNUMBER',0);
    if (CurVal$ < new$InnerNumber) then
      CurVal$ := GEN_ID('G_TENDERINNERNUMBER',new$InnerNumber - CurVal$);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_TENDERCAPTION_BU_200)
-- Create 03.12.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   /*        */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
        VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef);
   END IF;

-- - - - - - - - - - - - -
-- BU_600 (tendercaption_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_TENDERCAPTION_BU_700)
-- Create 14.10.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_TENDERCAPTION SET
    ID = new$ID,
    BUDGETREF = new$BUDGETREF,
    FACIALACCCLS = new$FACIALACCCLS,
    MULTIPURPOSE = new$MULTIPURPOSE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    PERIOD = new$PERIOD,
    ACCEPTSUMMA = new$ACCEPTSUMMA,
    SALETYPE = new$SALETYPE,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DOCSTATEREF = new$DOCSTATEREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    ACCEPTED = new$ACCEPTED,
    EXPORTDATE = new$EXPORTDATE,
    YEARACCEPTSUMMA = new$YEARACCEPTSUMMA,
    TENDEROPTION = new$TENDEROPTION,
    TENDERTARGET = new$TENDERTARGET,
    RVERSION = new$RVERSION,
    ALLOWANCE = new$ALLOWANCE,
    REFINEMENTCAUSE = new$REFINEMENTCAUSE,
    PREFERENCE = new$PREFERENCE,
    PREFERENCESIZE = new$PREFERENCESIZE,
    SECURITY = new$SECURITY,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PERIODYEAR = new$PERIODYEAR,
    SUPPORTUNDERTAKER = new$SUPPORTUNDERTAKER,
    AYEAR = new$AYEAR,
    REWORKCAUSE = new$REWORKCAUSE,
    NOTE = new$NOTE,
    REALID = new$REALID,
    INNERNUMBER = new$INNERNUMBER,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    PROTOCOLREASON = new$PROTOCOLREASON,
    PROGINDEX = new$PROGINDEX,
    DOCNUMBER = new$DOCNUMBER,
    SECURITYTSIZE = new$SECURITYTSIZE,
    SECURITYASIZE = new$SECURITYASIZE,
    AVANSSIZE = new$AVANSSIZE,
    PREFERENCECRIPPLE = new$PREFERENCECRIPPLE,
    PREFERENCERUSPRODUCT = new$PREFERENCERUSPRODUCT,
    PREFERENCEPRISON = new$PREFERENCEPRISON,
    AGREEMENTEXECUTIONDATE = new$AGREEMENTEXECUTIONDATE,
    PURCHASECODE = new$PURCHASECODE,
    PURCHASESOCIALNKO = new$PURCHASESOCIALNKO,
    AVERSION = new$AVERSION,
    PARENTREF = new$PARENTREF,
    REJECTCAUSE = new$REJECTCAUSE
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_TENDERCAPTION_AU_10)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*   5.1*/
  /*      */
  /*     ,       */
  if ((new$AdjustmentNumber > 0) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update TenderCaption set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

  /*       LastAdjustment    */
  if ((new$AdjustmentNumber > 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update TenderCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_TENDERCAPTION_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   2.0*/
  /*       ,      */
  if (:old.FacialAccCls <> new$FacialAccCls) then
    update TenderProduct set
    RVersion = -1,
    FacialAccCls = new$FacialAccCls
    where
    (RecordIndex = new$ID) and (ProgIndex = 230);
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (tr_TenderCaption_au_30)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) /*      */
  and ((new$ProgIndex = 240) /* */ or (new$ProgIndex = 242) /* */))
  then
    if ((new$Accepted <> :old.Accepted)
    or (new$AcceptDate is not null and :old.AcceptDate is null)
    or (new$AcceptDate is null and :old.AcceptDate is not null)
    or (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))
    then 
      update TenderCaption set
      RejectCls = new$RejectCls,
      AcceptDate = new$AcceptDate
      where ParentRef=new$ID;
      /*          */
      if (:old.Accepted=1 and new$Accepted=0) then
        update TenderCaption set
        RejectCause = '   : ' || new$RejectCause
        where ParentRef=new$ID;
      END IF;
      /*             */
      if (:old.Accepted=0 and new$Accepted=1) then
        update TenderCaption set
        RejectCls = null,
        RejectCause = null
        where ParentRef=new$ID;
          
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_TENDERCAPTION_AU_500)
-- Create 28.04.2005
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
           VALUES (139, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
            WHERE (TableID = 139) AND (RecordId = new$ID);
   END IF;

END;
/
commit work
/

-- #########################################################
-- #########################################################
-- Add_OrgReestrCode.sql
-- #########################################################
-- #########################################################

/*   OrgReestrCode (   )   */
ALTER TABLE TB_ORGANIZATIONS ADD (
  OrgReestrCode VARCHAR2(20)
)
/

CREATE OR REPLACE VIEW ORGANIZATIONS (
  ID,
  NAME,
  GOSNI,
  CITY,
  COUNTRY,
  PHONE,
  ADDRESS,
  ORG_CLS,
  INN20,
  SUBINN,
  FACIALACC,
  REGIONCLS,
  DIRNAME,
  BUGNAME,
  DIRPHONE,
  BUGPHONE,
  RCORG,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  INN,
  OKATO,
  EMAIL,
  WEBSITE,
  UFKCODE,
  ADDOKATO,
  SHORTNAME,
  RVERSION,
  SENDERID,
  KVSR,
  OKFS,
  OKOPF,
  OPENDATE,
  CLOSEDATE,
  CHANGEDATE,
  GENERALORG_REF,
  FEDERALREGIONCODE,
  ORG_TYPE,
  BUDGETREF,
  SUPPLIERSTATUS,
  COUNTRYCODE,
  DATECLOSE,
  ORGCODE,
  COSTAUTHORITY,
  INCOMEAUTHORITY,
  DEBTAUTHORITY,
  SVRAUTHORITY,
  CLIENTID,
  DATEOPEN,
  FUID,
  OKPO,
  OKTMO,
  DOCSTATEREF,
  CRYPTOSTATUS,
  OGRN,
  REJECT_CLS,
  EXTID,
  EXTOWNER,
  EXTSYNCDATE,
  REMOTEPBSCODE,
  REMOTENOTPBSCODE,
  USECHECK_CARD,
  EXTROOTID,
  EXTVERSION,
  EXTVERSIONDATE,
  RECORDOWNERORGREF,
  REJECTCAUSE,
  BLOCKEDDATE,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  ORGREESTRCODE)
AS
  SELECT
    ID,
    NAME,
    GOSNI,
    CITY,
    COUNTRY,
    PHONE,
    ADDRESS,
    ORG_CLS,
    INN20,
    SUBINN,
    FACIALACC,
    REGIONCLS,
    DIRNAME,
    BUGNAME,
    DIRPHONE,
    BUGPHONE,
    RCORG,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    INN,
    OKATO,
    EMAIL,
    WEBSITE,
    UFKCODE,
    ADDOKATO,
    SHORTNAME,
    RVERSION,
    SENDERID,
    KVSR,
    OKFS,
    OKOPF,
    OPENDATE,
    CLOSEDATE,
    CHANGEDATE,
    GENERALORG_REF,
    FEDERALREGIONCODE,
    ORG_TYPE,
    BUDGETREF,
    SUPPLIERSTATUS,
    COUNTRYCODE,
    DATECLOSE,
    ORGCODE,
    COSTAUTHORITY,
    INCOMEAUTHORITY,
    DEBTAUTHORITY,
    SVRAUTHORITY,
    CLIENTID,
    DATEOPEN,
    FUID,
    OKPO,
    OKTMO,
    DOCSTATEREF,
    CRYPTOSTATUS,
    OGRN,
    REJECT_CLS,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    REMOTEPBSCODE,
    REMOTENOTPBSCODE,
    USECHECK_CARD,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    RECORDOWNERORGREF,
    REJECTCAUSE,
    BLOCKEDDATE,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    ORGREESTRCODE
  FROM TB_ORGANIZATIONS
/

CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_ID
  INSTEAD OF DELETE
  ON ORGANIZATIONS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_ORGANIZATIONS_BD)
-- Last update 09.06.2008
-- - - - - - - - - - - - -

  if (:old.ID = 0) then
    RaiseException('ex_CantDelUnknownOrg');
  end if;

  delete from Org_Accounts where org_ref = :old.id;
  delete from Banks where id = :old.id;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_ORGANIZATIONS
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_200 (TR_ORGANIZATIONS_AD_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

update Organizations set
    GeneralOrg_Ref = id
  where
    GeneralOrg_Ref = :old.id;

-- - - - - - - - - - - - -
-- AD_210 (TR_ORGANIZATIONS_AD_210)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*       */
  delete 
  from 
  StateJumpHistory
  where 
  DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_ORGANIZATIONS_AD_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate) values(27, :old.ID ,SYSDATE);

END;
/

CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_II
  INSTEAD OF INSERT
  ON ORGANIZATIONS
  FOR EACH ROW
DECLARE
  new$ID ORGANIZATIONS.ID%TYPE := :NEW.ID;
  new$NAME ORGANIZATIONS.NAME%TYPE := :NEW.NAME;
  new$GOSNI ORGANIZATIONS.GOSNI%TYPE := :NEW.GOSNI;
  new$CITY ORGANIZATIONS.CITY%TYPE := :NEW.CITY;
  new$COUNTRY ORGANIZATIONS.COUNTRY%TYPE := :NEW.COUNTRY;
  new$PHONE ORGANIZATIONS.PHONE%TYPE := :NEW.PHONE;
  new$ADDRESS ORGANIZATIONS.ADDRESS%TYPE := :NEW.ADDRESS;
  new$ORG_CLS ORGANIZATIONS.ORG_CLS%TYPE := :NEW.ORG_CLS;
  new$INN20 ORGANIZATIONS.INN20%TYPE := :NEW.INN20;
  new$SUBINN ORGANIZATIONS.SUBINN%TYPE := :NEW.SUBINN;
  new$FACIALACC ORGANIZATIONS.FACIALACC%TYPE := :NEW.FACIALACC;
  new$REGIONCLS ORGANIZATIONS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$DIRNAME ORGANIZATIONS.DIRNAME%TYPE := :NEW.DIRNAME;
  new$BUGNAME ORGANIZATIONS.BUGNAME%TYPE := :NEW.BUGNAME;
  new$DIRPHONE ORGANIZATIONS.DIRPHONE%TYPE := :NEW.DIRPHONE;
  new$BUGPHONE ORGANIZATIONS.BUGPHONE%TYPE := :NEW.BUGPHONE;
  new$RCORG ORGANIZATIONS.RCORG%TYPE := :NEW.RCORG;
  new$CREATERUSER ORGANIZATIONS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ORGANIZATIONS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ORGANIZATIONS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ORGANIZATIONS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$INN ORGANIZATIONS.INN%TYPE := :NEW.INN;
  new$OKATO ORGANIZATIONS.OKATO%TYPE := :NEW.OKATO;
  new$EMAIL ORGANIZATIONS.EMAIL%TYPE := :NEW.EMAIL;
  new$WEBSITE ORGANIZATIONS.WEBSITE%TYPE := :NEW.WEBSITE;
  new$UFKCODE ORGANIZATIONS.UFKCODE%TYPE := :NEW.UFKCODE;
  new$ADDOKATO ORGANIZATIONS.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$SHORTNAME ORGANIZATIONS.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$RVERSION ORGANIZATIONS.RVERSION%TYPE := :NEW.RVERSION;
  new$SENDERID ORGANIZATIONS.SENDERID%TYPE := :NEW.SENDERID;
  new$KVSR ORGANIZATIONS.KVSR%TYPE := :NEW.KVSR;
  new$OKFS ORGANIZATIONS.OKFS%TYPE := :NEW.OKFS;
  new$OKOPF ORGANIZATIONS.OKOPF%TYPE := :NEW.OKOPF;
  new$OPENDATE ORGANIZATIONS.OPENDATE%TYPE := :NEW.OPENDATE;
  new$CLOSEDATE ORGANIZATIONS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$CHANGEDATE ORGANIZATIONS.CHANGEDATE%TYPE := :NEW.CHANGEDATE;
  new$GENERALORG_REF ORGANIZATIONS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$FEDERALREGIONCODE ORGANIZATIONS.FEDERALREGIONCODE%TYPE := :NEW.FEDERALREGIONCODE;
  new$ORG_TYPE ORGANIZATIONS.ORG_TYPE%TYPE := :NEW.ORG_TYPE;
  new$BUDGETREF ORGANIZATIONS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUPPLIERSTATUS ORGANIZATIONS.SUPPLIERSTATUS%TYPE := :NEW.SUPPLIERSTATUS;
  new$COUNTRYCODE ORGANIZATIONS.COUNTRYCODE%TYPE := :NEW.COUNTRYCODE;
  new$DATECLOSE ORGANIZATIONS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$ORGCODE ORGANIZATIONS.ORGCODE%TYPE := :NEW.ORGCODE;
  new$COSTAUTHORITY ORGANIZATIONS.COSTAUTHORITY%TYPE := :NEW.COSTAUTHORITY;
  new$INCOMEAUTHORITY ORGANIZATIONS.INCOMEAUTHORITY%TYPE := :NEW.INCOMEAUTHORITY;
  new$DEBTAUTHORITY ORGANIZATIONS.DEBTAUTHORITY%TYPE := :NEW.DEBTAUTHORITY;
  new$SVRAUTHORITY ORGANIZATIONS.SVRAUTHORITY%TYPE := :NEW.SVRAUTHORITY;
  new$CLIENTID ORGANIZATIONS.CLIENTID%TYPE := :NEW.CLIENTID;
  new$DATEOPEN ORGANIZATIONS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$FUID ORGANIZATIONS.FUID%TYPE := :NEW.FUID;
  new$OKPO ORGANIZATIONS.OKPO%TYPE := :NEW.OKPO;
  new$OKTMO ORGANIZATIONS.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCSTATEREF ORGANIZATIONS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ORGANIZATIONS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$OGRN ORGANIZATIONS.OGRN%TYPE := :NEW.OGRN;
  new$REJECT_CLS ORGANIZATIONS.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$EXTID ORGANIZATIONS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER ORGANIZATIONS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE ORGANIZATIONS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$REMOTEPBSCODE ORGANIZATIONS.REMOTEPBSCODE%TYPE := :NEW.REMOTEPBSCODE;
  new$REMOTENOTPBSCODE ORGANIZATIONS.REMOTENOTPBSCODE%TYPE := :NEW.REMOTENOTPBSCODE;
  new$USECHECK_CARD ORGANIZATIONS.USECHECK_CARD%TYPE := :NEW.USECHECK_CARD;
  new$EXTROOTID ORGANIZATIONS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION ORGANIZATIONS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE ORGANIZATIONS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$RECORDOWNERORGREF ORGANIZATIONS.RECORDOWNERORGREF%TYPE := :NEW.RECORDOWNERORGREF;
  new$REJECTCAUSE ORGANIZATIONS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$BLOCKEDDATE ORGANIZATIONS.BLOCKEDDATE%TYPE := :NEW.BLOCKEDDATE;
  new$BLOCKEDCAUSE ORGANIZATIONS.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE ORGANIZATIONS.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE ORGANIZATIONS.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$ORGREESTRCODE ORGANIZATIONS.ORGREESTRCODE%TYPE := :NEW.ORGREESTRCODE;
--
  CNT$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (tr_Organizations_bi)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$FUID is null) then
    new$FUID := new$id;
  END IF;
  if (new$GOSNI is null) then
    new$GOSNI := 0;
  END IF;
  if (new$Name is null) then
    new$Name := '  ';
  END IF;
  if (new$City is null) then
    GetVarcharConst(-1,7,new$City);
  END IF;
  if (new$COUNTRY is null) then
    new$COUNTRY := '';
  END IF;
  if (new$CountryCode is null) then
    new$CountryCode := 643;
  END IF;
  if (new$ORG_CLS is NULL) then
    new$ORG_CLS:= 0;
  END IF;
  if (new$SubINN is null) then
    new$SubINN:= 0;
  END IF;
  if (new$INN20 is null) then
    new$INN20:= '';
  END IF;
  if (new$RCOrg is null) then
    new$RCOrg := 0;
  END IF;
  if (new$RegionCls is null) then
    new$RegionCls := 0;
  END IF;
  if (new$OKATO is null) then
    new$OKATO := 0;
  END IF;
  if (new$KVSR is null) then
    new$KVSR := 0;
  END IF;
  if (new$OKFS is null) then
    new$OKFS := 0;
  END IF;
  if (new$OKOPF is null) then
    new$OKOPF := 0;
  END IF;
  if (new$FederalRegionCode is null) then
    GetIntConst(-1, 27,new$FederalRegionCode);
  END IF;
  if (new$FederalRegionCode is null) then
    new$FederalRegionCode := 0;
  END IF;
  if (new$BudgetRef is null) then
    new$BudgetRef := 0;
  END IF;
  /*    - */
  if (new$org_type is null) then
    new$org_type := 20000;
  END IF;
  /*        */
  if ((new$generalorg_ref is null) or (new$org_type < 10000) or (new$org_type >= 20000)) then
    new$generalorg_ref := new$id;
  END IF;
  /*    10 ,      */
  if ((new$INN > 9999999999.9) and (new$INN20 <> '') and (new$INN20 is not null)) then
    RaiseException('EX_WRONGKPP');
  END IF;
  check_unique_organization(new$inn,  new$inn20);
  if (new$CostAuthority is null) then
    new$CostAuthority:= 0;
  END IF;
  if (new$IncomeAuthority is null) then
    new$IncomeAuthority := 0;
  END IF;
  if (new$DebtAuthority is null) then
    new$DebtAuthority := 0;
  END IF;
  if (new$SVRAuthority is null) then
    new$SVRAuthority := 0;
  END IF;
  /*        */
  if (new$Org_Type is not null)
  then
    if (new$Org_Type between 10100 and 10299) then
      new$CostAuthority:= 1;
    END IF;
    if (new$Org_Type between 10300 and 10399) then
      new$CostAuthority:= 2;
    END IF;
    if (new$Org_Type between 10400 and 10499) then
      new$CostAuthority:= 4;
    END IF;
    if (((new$Org_Type between 10500 and 10599) and (new$CostAuthority<>16)) or
    (((new$Org_Type between 10000 and 10099) or (new$Org_Type between 10600 and 10799))
    and (new$CostAuthority=0))) then
      new$CostAuthority:= 8;

    END IF;
  END IF;
  if (new$UseCheck_Card is null) then
    new$UseCheck_Card := 0;
  END IF;
  if (new$RecordOwnerOrgRef is null) then
    new$RecordOwnerOrgRef := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_ORGANIZATIONS_BI_10)
-- Last update 19.10.2006
-- - - - - - - - - - - - -

  if (new$FacialAcc is not null) then
    select count(id) into cnt$ from Organizations where (FacialAcc = new$FacialAcc) AND (ROWNUM = 1);
    if (cnt$ <> 0) then RaiseException('ex_DublicateFacialAcc'); end if;
  end if;

-- - - - - - - - - - - - -
-- BI_200 (TR_ORGANIZATIONS_BI_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

  if (new$id <> new$GeneralOrg_Ref) then
    select count(*) into cnt$
    from Organizations o where (o.id = new$GeneralOrg_Ref) AND (ROWNUM = 1);

    if cnt$ = 0 then
      RaiseException('ex_GeneralOrgNotFound');
    end if;

    /*       ,     */
    if (new$KVSR = 0) then
      select o.KVSR into new$KVSR
      from Organizations o
      where o.id = new$GeneralOrg_Ref;
    end if;
  end if;

-- - - - - - - - - - - - -
-- BI_500 (TR_ORGANIZATIONS_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_ORGANIZATIONS (
    ID,
    NAME,
    GOSNI,
    CITY,
    COUNTRY,
    PHONE,
    ADDRESS,
    ORG_CLS,
    INN20,
    SUBINN,
    FACIALACC,
    REGIONCLS,
    DIRNAME,
    BUGNAME,
    DIRPHONE,
    BUGPHONE,
    RCORG,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    INN,
    OKATO,
    EMAIL,
    WEBSITE,
    UFKCODE,
    ADDOKATO,
    SHORTNAME,
    RVERSION,
    SENDERID,
    KVSR,
    OKFS,
    OKOPF,
    OPENDATE,
    CLOSEDATE,
    CHANGEDATE,
    GENERALORG_REF,
    FEDERALREGIONCODE,
    ORG_TYPE,
    BUDGETREF,
    SUPPLIERSTATUS,
    COUNTRYCODE,
    DATECLOSE,
    ORGCODE,
    COSTAUTHORITY,
    INCOMEAUTHORITY,
    DEBTAUTHORITY,
    SVRAUTHORITY,
    CLIENTID,
    DATEOPEN,
    FUID,
    OKPO,
    OKTMO,
    DOCSTATEREF,
    CRYPTOSTATUS,
    OGRN,
    REJECT_CLS,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    REMOTEPBSCODE,
    REMOTENOTPBSCODE,
    USECHECK_CARD,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    RECORDOWNERORGREF,
    REJECTCAUSE,
    BLOCKEDDATE,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    ORGREESTRCODE
  ) VALUES (
    new$ID,
    new$NAME,
    new$GOSNI,
    new$CITY,
    new$COUNTRY,
    new$PHONE,
    new$ADDRESS,
    new$ORG_CLS,
    new$INN20,
    new$SUBINN,
    new$FACIALACC,
    new$REGIONCLS,
    new$DIRNAME,
    new$BUGNAME,
    new$DIRPHONE,
    new$BUGPHONE,
    new$RCORG,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$INN,
    new$OKATO,
    new$EMAIL,
    new$WEBSITE,
    new$UFKCODE,
    new$ADDOKATO,
    new$SHORTNAME,
    new$RVERSION,
    new$SENDERID,
    new$KVSR,
    new$OKFS,
    new$OKOPF,
    new$OPENDATE,
    new$CLOSEDATE,
    new$CHANGEDATE,
    new$GENERALORG_REF,
    new$FEDERALREGIONCODE,
    new$ORG_TYPE,
    new$BUDGETREF,
    new$SUPPLIERSTATUS,
    new$COUNTRYCODE,
    new$DATECLOSE,
    new$ORGCODE,
    new$COSTAUTHORITY,
    new$INCOMEAUTHORITY,
    new$DEBTAUTHORITY,
    new$SVRAUTHORITY,
    new$CLIENTID,
    new$DATEOPEN,
    new$FUID,
    new$OKPO,
    new$OKTMO,
    new$DOCSTATEREF,
    new$CRYPTOSTATUS,
    new$OGRN,
    new$REJECT_CLS,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$REMOTEPBSCODE,
    new$REMOTENOTPBSCODE,
    new$USECHECK_CARD,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$RECORDOWNERORGREF,
    new$REJECTCAUSE,
    new$BLOCKEDDATE,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$ORGREESTRCODE);

-- - - - - - - - - - - - -
-- AI_500 (TR_ORGANIZATIONS_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 27) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_ORGANIZATIONS_IU
  INSTEAD OF UPDATE
  ON ORGANIZATIONS
  FOR EACH ROW
DECLARE
  new$ID ORGANIZATIONS.ID%TYPE := :NEW.ID;
  new$NAME ORGANIZATIONS.NAME%TYPE := :NEW.NAME;
  new$GOSNI ORGANIZATIONS.GOSNI%TYPE := :NEW.GOSNI;
  new$CITY ORGANIZATIONS.CITY%TYPE := :NEW.CITY;
  new$COUNTRY ORGANIZATIONS.COUNTRY%TYPE := :NEW.COUNTRY;
  new$PHONE ORGANIZATIONS.PHONE%TYPE := :NEW.PHONE;
  new$ADDRESS ORGANIZATIONS.ADDRESS%TYPE := :NEW.ADDRESS;
  new$ORG_CLS ORGANIZATIONS.ORG_CLS%TYPE := :NEW.ORG_CLS;
  new$INN20 ORGANIZATIONS.INN20%TYPE := :NEW.INN20;
  new$SUBINN ORGANIZATIONS.SUBINN%TYPE := :NEW.SUBINN;
  new$FACIALACC ORGANIZATIONS.FACIALACC%TYPE := :NEW.FACIALACC;
  new$REGIONCLS ORGANIZATIONS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$DIRNAME ORGANIZATIONS.DIRNAME%TYPE := :NEW.DIRNAME;
  new$BUGNAME ORGANIZATIONS.BUGNAME%TYPE := :NEW.BUGNAME;
  new$DIRPHONE ORGANIZATIONS.DIRPHONE%TYPE := :NEW.DIRPHONE;
  new$BUGPHONE ORGANIZATIONS.BUGPHONE%TYPE := :NEW.BUGPHONE;
  new$RCORG ORGANIZATIONS.RCORG%TYPE := :NEW.RCORG;
  new$CREATERUSER ORGANIZATIONS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ORGANIZATIONS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ORGANIZATIONS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ORGANIZATIONS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$INN ORGANIZATIONS.INN%TYPE := :NEW.INN;
  new$OKATO ORGANIZATIONS.OKATO%TYPE := :NEW.OKATO;
  new$EMAIL ORGANIZATIONS.EMAIL%TYPE := :NEW.EMAIL;
  new$WEBSITE ORGANIZATIONS.WEBSITE%TYPE := :NEW.WEBSITE;
  new$UFKCODE ORGANIZATIONS.UFKCODE%TYPE := :NEW.UFKCODE;
  new$ADDOKATO ORGANIZATIONS.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$SHORTNAME ORGANIZATIONS.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$RVERSION ORGANIZATIONS.RVERSION%TYPE := :NEW.RVERSION;
  new$SENDERID ORGANIZATIONS.SENDERID%TYPE := :NEW.SENDERID;
  new$KVSR ORGANIZATIONS.KVSR%TYPE := :NEW.KVSR;
  new$OKFS ORGANIZATIONS.OKFS%TYPE := :NEW.OKFS;
  new$OKOPF ORGANIZATIONS.OKOPF%TYPE := :NEW.OKOPF;
  new$OPENDATE ORGANIZATIONS.OPENDATE%TYPE := :NEW.OPENDATE;
  new$CLOSEDATE ORGANIZATIONS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$CHANGEDATE ORGANIZATIONS.CHANGEDATE%TYPE := :NEW.CHANGEDATE;
  new$GENERALORG_REF ORGANIZATIONS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$FEDERALREGIONCODE ORGANIZATIONS.FEDERALREGIONCODE%TYPE := :NEW.FEDERALREGIONCODE;
  new$ORG_TYPE ORGANIZATIONS.ORG_TYPE%TYPE := :NEW.ORG_TYPE;
  new$BUDGETREF ORGANIZATIONS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUPPLIERSTATUS ORGANIZATIONS.SUPPLIERSTATUS%TYPE := :NEW.SUPPLIERSTATUS;
  new$COUNTRYCODE ORGANIZATIONS.COUNTRYCODE%TYPE := :NEW.COUNTRYCODE;
  new$DATECLOSE ORGANIZATIONS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$ORGCODE ORGANIZATIONS.ORGCODE%TYPE := :NEW.ORGCODE;
  new$COSTAUTHORITY ORGANIZATIONS.COSTAUTHORITY%TYPE := :NEW.COSTAUTHORITY;
  new$INCOMEAUTHORITY ORGANIZATIONS.INCOMEAUTHORITY%TYPE := :NEW.INCOMEAUTHORITY;
  new$DEBTAUTHORITY ORGANIZATIONS.DEBTAUTHORITY%TYPE := :NEW.DEBTAUTHORITY;
  new$SVRAUTHORITY ORGANIZATIONS.SVRAUTHORITY%TYPE := :NEW.SVRAUTHORITY;
  new$CLIENTID ORGANIZATIONS.CLIENTID%TYPE := :NEW.CLIENTID;
  new$DATEOPEN ORGANIZATIONS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$FUID ORGANIZATIONS.FUID%TYPE := :NEW.FUID;
  new$OKPO ORGANIZATIONS.OKPO%TYPE := :NEW.OKPO;
  new$OKTMO ORGANIZATIONS.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCSTATEREF ORGANIZATIONS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CRYPTOSTATUS ORGANIZATIONS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$OGRN ORGANIZATIONS.OGRN%TYPE := :NEW.OGRN;
  new$REJECT_CLS ORGANIZATIONS.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$EXTID ORGANIZATIONS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER ORGANIZATIONS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE ORGANIZATIONS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$REMOTEPBSCODE ORGANIZATIONS.REMOTEPBSCODE%TYPE := :NEW.REMOTEPBSCODE;
  new$REMOTENOTPBSCODE ORGANIZATIONS.REMOTENOTPBSCODE%TYPE := :NEW.REMOTENOTPBSCODE;
  new$USECHECK_CARD ORGANIZATIONS.USECHECK_CARD%TYPE := :NEW.USECHECK_CARD;
  new$EXTROOTID ORGANIZATIONS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION ORGANIZATIONS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE ORGANIZATIONS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$RECORDOWNERORGREF ORGANIZATIONS.RECORDOWNERORGREF%TYPE := :NEW.RECORDOWNERORGREF;
  new$REJECTCAUSE ORGANIZATIONS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$BLOCKEDDATE ORGANIZATIONS.BLOCKEDDATE%TYPE := :NEW.BLOCKEDDATE;
  new$BLOCKEDCAUSE ORGANIZATIONS.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE ORGANIZATIONS.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE ORGANIZATIONS.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$ORGREESTRCODE ORGANIZATIONS.ORGREESTRCODE%TYPE := :NEW.ORGREESTRCODE;
--
  CNT$ NUMBER(10);
  c1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (tr_organizations_bu)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (new$gosni is null) then
    new$gosni := 0;
  END IF;
  if (new$city is null) then
    getvarcharconst(-1,7,new$city);
  END IF;
  if (new$country is null) then
    new$country := '';
  END IF;
  if (new$countrycode is null) then
    new$countrycode := 643;
  END IF;
  if (new$org_cls is null) then
    new$org_cls:= 0;
  END IF;
  if (new$inn20 is null) then
    new$inn20:= '';
  END IF;
  if (new$rcorg is null) then
    new$rcorg := 0;
  END IF;
  if (new$regioncls is null) then
    new$regioncls := 0;
  END IF;
  if (new$okato is null) then
    new$okato := 0;
  END IF;
  if (new$kvsr is null) then
    new$kvsr := 0;
  END IF;
  if (new$okfs is null) then
    new$okfs := 0;
  END IF;
  if (new$okopf is null) then
    new$okopf := 0;
  END IF;
  if (new$federalregioncode is null) then
    getintconst(-1, 27,new$federalregioncode);
  END IF;
  if (new$federalregioncode is null) then
    new$federalregioncode := 0;
  END IF;
  if (new$budgetref is null) then
    new$budgetref := 0;
  END IF;
  /*    - */
  if (new$org_type is null) then
    new$org_type := 20000;
  END IF;
  /*        */
  if ((new$generalorg_ref is null) or (new$org_type < 10000) or (new$org_type >= 20000)) then
    new$generalorg_ref := new$id;
  END IF;

  /*    10 ,      */
  if ((new$inn <> :old.inn) or ((:old.inn is null) and (new$inn is not null))) then
    if ((new$inn > 9999999999.9) and (new$inn20 <> '')) then
      RaiseException('ex_wrongkpp');
    END IF;
  END IF;
  if ( ((new$inn <> :old.inn) or ((:old.inn is null) and (new$inn is not null)))
  or ( (new$inn20 <> :old.inn20) or ((:old.inn20 is null) and (new$inn20 is not null))) )
  then
    check_unique_organization(new$inn,  new$inn20);
  END IF;

  if (new$regioncls <> :old.regioncls) then
    update dfaccountsbuhtable set
    regioncls = new$regioncls
    where id = any (select id from org_accounts where org_ref = new$id);
  END IF;
  /*      */
  if (:old.id = 0) then
    RaiseException('ex_cantmodifyunknownorg');
  END IF;
  /*        */
  if ((new$org_type<>:old.org_type) or (new$costauthority<>:old.costauthority))
  then
    c1$ := new$costauthority;
    if (new$org_type between 10100 and 10299) then
      new$costauthority:= 1;
    END IF;
    if (new$org_type between 10300 and 10399) then
      new$costauthority:= 2;
    END IF;
    if (new$org_type between 10400 and 10499) then
      new$costauthority:= 4;
    END IF;
    if (((new$org_type between 10500 and 10599) and (new$costauthority<>16)) or
    (((new$org_type between 10000 and 10099) or (new$org_type between 10600 and 10799))
    and (new$costauthority=0))) then
      new$costauthority:= 8;
    END IF;
    if ((new$org_type=:old.org_type) and (c1$<>new$costauthority)) then
      RaiseException('ex_wrongcostauthority');
    END IF;
  END IF;
  /*    RegionCls  ,  
         */
  if (new$regioncls <> :old.regioncls) then
    update facialacc_cls fac set
    fac.regioncls = new$regioncls
    where
    new$id = fac.org_ref;

  END IF;
  if (new$UseCheck_Card is null) then
    new$UseCheck_Card := 0;
  END IF;
  if (new$RecordOwnerOrgRef is null) then
    new$RecordOwnerOrgRef := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_ORGANIZATIONS_BU_10)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$FacialAcc <> :old.FacialAcc) then
    select count(id) into CNT$ from Organizations
      where (FacialAcc = new$FacialAcc) and (id <> new$id) AND (ROWNUM = 1);
    if (CNT$ <> 0) then
      RaiseException('ex_DublicateFacialAcc');
    end if;
  end if;

-- - - - - - - - - - - - -
-- BU_100 (TR_ORGANIZATIONS_BU_100)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*   */
  if ((new$DateClose is not null) and (:old.DateClose is null)) then
    /*        */
    update Org_Accounts set
    DateClose = new$DateClose,
    CloseCode = CloseCode + 10
    where Org_Ref = new$Id;

  END IF;
  /*  /      */
  if (((new$DateClose is not null) and (:old.DateClose is null)) or (new$DateClose <> :old.DateClose)) then
    /*     / */
    update FacialAcc_Cls set
    DateClose = new$DateClose,
    CloseCode = CloseCode + 10
    where Org_ref = new$Id;
  END IF;
  /*   */
  if ((new$DateClose is null) and (:old.DateClose is not null)) then
    update Org_Accounts set
    CloseCode = CloseCode - 10
    where Org_Ref = new$Id;

    /*     / */
    update FacialAcc_Cls set
    DateClose = new$DateClose,
    CloseCode = CloseCode - 10
    where Org_ref = new$Id;

  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_ORGANIZATIONS_BU_200)
-- Create 25.05.2007
-- - - - - - - - - - - - -

  if (new$id <> new$GeneralOrg_Ref) then
    select count(*) into cnt$
    from Organizations o where (o.id = new$GeneralOrg_Ref) AND (ROWNUM = 1);

    if cnt$ = 0 then
      RaiseException('ex_GeneralOrgNotFound');
    end if;
  end if;

  if (new$GeneralOrg_Ref <> :old.GeneralOrg_Ref) then
    update FacialAcc_CLS set
      GeneralOrg_Ref = new$GeneralOrg_Ref
    where
      Org_Ref = new$id;
  end if;

-- - - - - - - - - - - - -
-- BU_210 (TR_ORGANIZATIONS_BU_210)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$DOCSTATEREF <> :old.DOCSTATEREF) then
    insert into StateJumpHistory(DocID, BeginStateRef, EndStateRef)
    values(new$id, :old.DOCSTATEREF, new$DOCSTATEREF);
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_ORGANIZATIONS_BU_700)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  IF (new$RVersion IS NULL) THEN
    new$RVersion := 1;
  ELSIF ( (new$RVersion = -1) AND (:OLD.RVersion <> -1) ) THEN
    new$RVersion := :OLD.RVersion;
  ELSE
    new$RVersion := :OLD.RVersion + 1;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_ORGANIZATIONS SET
    ID = new$ID,
    NAME = new$NAME,
    GOSNI = new$GOSNI,
    CITY = new$CITY,
    COUNTRY = new$COUNTRY,
    PHONE = new$PHONE,
    ADDRESS = new$ADDRESS,
    ORG_CLS = new$ORG_CLS,
    INN20 = new$INN20,
    SUBINN = new$SUBINN,
    FACIALACC = new$FACIALACC,
    REGIONCLS = new$REGIONCLS,
    DIRNAME = new$DIRNAME,
    BUGNAME = new$BUGNAME,
    DIRPHONE = new$DIRPHONE,
    BUGPHONE = new$BUGPHONE,
    RCORG = new$RCORG,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    INN = new$INN,
    OKATO = new$OKATO,
    EMAIL = new$EMAIL,
    WEBSITE = new$WEBSITE,
    UFKCODE = new$UFKCODE,
    ADDOKATO = new$ADDOKATO,
    SHORTNAME = new$SHORTNAME,
    RVERSION = new$RVERSION,
    SENDERID = new$SENDERID,
    KVSR = new$KVSR,
    OKFS = new$OKFS,
    OKOPF = new$OKOPF,
    OPENDATE = new$OPENDATE,
    CLOSEDATE = new$CLOSEDATE,
    CHANGEDATE = new$CHANGEDATE,
    GENERALORG_REF = new$GENERALORG_REF,
    FEDERALREGIONCODE = new$FEDERALREGIONCODE,
    ORG_TYPE = new$ORG_TYPE,
    BUDGETREF = new$BUDGETREF,
    SUPPLIERSTATUS = new$SUPPLIERSTATUS,
    COUNTRYCODE = new$COUNTRYCODE,
    DATECLOSE = new$DATECLOSE,
    ORGCODE = new$ORGCODE,
    COSTAUTHORITY = new$COSTAUTHORITY,
    INCOMEAUTHORITY = new$INCOMEAUTHORITY,
    DEBTAUTHORITY = new$DEBTAUTHORITY,
    SVRAUTHORITY = new$SVRAUTHORITY,
    CLIENTID = new$CLIENTID,
    DATEOPEN = new$DATEOPEN,
    FUID = new$FUID,
    OKPO = new$OKPO,
    OKTMO = new$OKTMO,
    DOCSTATEREF = new$DOCSTATEREF,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    OGRN = new$OGRN,
    REJECT_CLS = new$REJECT_CLS,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    REMOTEPBSCODE = new$REMOTEPBSCODE,
    REMOTENOTPBSCODE = new$REMOTENOTPBSCODE,
    USECHECK_CARD = new$USECHECK_CARD,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    RECORDOWNERORGREF = new$RECORDOWNERORGREF,
    REJECTCAUSE = new$REJECTCAUSE,
    BLOCKEDDATE = new$BLOCKEDDATE,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    ORGREESTRCODE = new$ORGREESTRCODE
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AU_100 (TR_ORGANIZATIONS_AU_100)
-- Create 27.07.2007
-- - - - - - - - - - - - -

-- Comment   / 


  /*    */
  if ((new$DateClose is not null) and (:old.DateClose is null)) then
    update Banks set DateClose = new$DateClose where (id = new$ID) and (DateClose is null);
  end if;

  /*    */
  if ((new$DateClose is null) and (:old.DateClose is not null)) then
    update Banks set DateClose = null where (id = new$ID) and (DateClose is not null);
  end if;

-- - - - - - - - - - - - -
-- AU_200 (TR_ORGANIZATIONS_AU_200)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$BudgetRef <> :old.BudgetRef) then
    update FacialAcc_CLS set
    BudgetRef = new$BudgetRef
    where
    (ORG_REF = new$id)and((BudgetRef = :old.BudgetRef)or(BudgetRef<>0));
  END IF;
  /*     ,    */
  if ((new$KVSR <> :old.KVSR)and(new$Org_Type >= 10100)and(new$Org_Type <= 10299)) then
    update KVSR set
    Org_Ref = new$id
    where
    id = new$KVSR;
  END IF;
  if (new$KVSR <> :old.KVSR) then
    update FacialAcc_CLS set
    KVSR = new$KVSR
    where
    (ORG_REF = new$id) and (KVSR = :old.KVSR);
  END IF;
  if (new$BudgetRef <> :old.BudgetRef) then
    update organizations set
    BudgetRef = new$BudgetRef
    where
    (generalorg_ref = new$id) and (id <> new$id);
  END IF;
  if (new$KVSR <> :old.KVSR) then
    update organizations set
    KVSR = new$KVSR
    where
    (generalorg_ref = new$id) and (id <> new$id);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_ORGANIZATIONS_AU_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (27, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=27) and (RecordId=new$ID);
  end if;

END;
/
commit work 
/

-- #########################################################
-- #########################################################
-- Alter_Trigger_KD_IFS.sql
-- #########################################################
-- #########################################################

/* 
          Extid       
           Extid
*/
-- CREATE TRIGGER tr_kd_ai_100
CREATE OR REPLACE TRIGGER TR_KD_II
  INSTEAD OF INSERT
  ON KD
  FOR EACH ROW
DECLARE
  new$ID KD.ID%TYPE := :NEW.ID;
  new$REPCODE KD.REPCODE%TYPE := :NEW.REPCODE;
  new$CREATEDATE KD.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE KD.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$KVSR KD.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE KD.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE KD.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE KD.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE KD.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR KD.KESR%TYPE := :NEW.KESR;
  new$KDVALUE KD.KDVALUE%TYPE := :NEW.KDVALUE;
  new$REMOTEFLAG KD.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$UNIONFLAG KD.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$BUDGETREF KD.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE KD.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME KD.NAME%TYPE := :NEW.NAME;
  new$KD_LEVEL KD.KD_LEVEL%TYPE := :NEW.KD_LEVEL;
  new$STARTDATE KD.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME KD.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CREATERUSER KD.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER KD.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$EXTID KD.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER KD.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE KD.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID KD.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION KD.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE KD.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPKD KD.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
--
  tmp$ NUMBER(15,0);
  tmp_Double$ NUMBER;
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(5);
  sDescrCode2$ VARCHAR2(5);
  sProgCode$ VARCHAR2(4);
  sAnalyticalGroupKD$ VARCHAR2(3);
  CNT$1 NUMBER(10);
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sKDLevel$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_KD_BI_0)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupKD is null) then 
    new$AnalyticalGroupKD := 0;
  END IF;
  if (new$ProgramCode is null) then 
    new$ProgramCode := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  if (new$KVSR <> 0) then
    select max(kd_level) into sKDLevel$ from KD where ((AnalyticalGroupKD = new$AnalyticalGroupKD) and (ProgramCode=new$ProgramCode)and (BudgetRef=new$BudgetRef)
    and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0))  ;
  END IF;
  if (sKDLevel$ is not null) then
    new$kd_Level := sKDLevel$;
  END IF;
  /*          */
    
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100;
  new$MainDescriptionCode := tmp_Double$;
  if (new$MainDescriptionCode > tmp_Double$) then 
    new$MainDescriptionCode := new$MainDescriptionCode - 1;
  END IF;
  tmp_Double$ := new$MainDescriptionCode;
  tmp_Double$ := tmp_Double$ * 100;
  new$ItemCode := tmp$ - tmp_Double$; 
  BEGIN

    /*      */ 
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-   */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode1$ < 10) then
      sKVSR$ := '00' || KVSRCode1$;
          
    else
      if (KVSRCode1$ < 100) then
        sKVSR$ := '0' || KVSRCode1$;
            
      else
        sKVSR$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*       */    
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 100000;
  DescrCode2$ := tmp_Double$;
      
  if (DescrCode1$ = 0) then
    sDescrCode1$ := '00000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '0000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '00' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '0' || DescrCode1$;
                
          else
            sDescrCode1$ := DescrCode1$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '00000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '0000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '00' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '0' || DescrCode2$;
                
          else
            sDescrCode2$ := DescrCode2$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  /*      */
  if (new$programcode = 0) then
    sProgCode$ := '0000';
        
  else
    if (new$programcode < 10) then
      sProgCode$ := '000' || new$programcode;
          
    else
      if (new$programcode < 100) then
        sProgCode$ := '00' || new$programcode;
            
      else
        if (new$programcode < 1000) then
          sProgCode$ := '0' || new$programcode;
              
        else
          sProgCode$ := new$programcode;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */ 
    select Code into sAnalyticalGroupKD$ from AnalyticalGroupKD where (ID = new$AnalyticalGroupKD) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    new$KESR := sAnalyticalGroupKD$;
  END IF;
  /*      */    
      
  new$kdvalue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sProgCode$ || sAnalyticalGroupKD$;
      
  if ((new$ID = 0) and (new$kdvalue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroKD');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_KD_BI_500)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_KD (
    ID,
    REPCODE,
    CREATEDATE,
    UPDATEDATE,
    KVSR,
    DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE,
    ITEMCODE,
    PROGRAMCODE,
    KESR,
    KDVALUE,
    REMOTEFLAG,
    UNIONFLAG,
    BUDGETREF,
    DELETEDATE,
    NAME,
    KD_LEVEL,
    STARTDATE,
    SHORTNAME,
    CREATERUSER,
    UPDATERUSER,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    ANALYTICALGROUPKD
  ) VALUES (
    new$ID,
    new$REPCODE,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$KVSR,
    new$DESCRIPTIONCODE,
    new$MAINDESCRIPTIONCODE,
    new$ITEMCODE,
    new$PROGRAMCODE,
    new$KESR,
    new$KDVALUE,
    new$REMOTEFLAG,
    new$UNIONFLAG,
    new$BUDGETREF,
    new$DELETEDATE,
    new$NAME,
    new$KD_LEVEL,
    new$STARTDATE,
    new$SHORTNAME,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$ANALYTICALGROUPKD);

-- - - - - - - - - - - - -
-- AI_100 (TR_KD_AI_100)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from kd kd1
    where ((kd1.kvsr = 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and (kd1.BudgetRef = new$BudgetRef)
    ) AND (ROWNUM = 1)                   ;
    if (not (CNT$1<> 0))
    then  
      insert into KD (KVSR, DescriptionCode, ProgramCode, AnalyticalGroupKD, Name, ShortName, RemoteFlag, kd_level, budgetref, extid)
      values (0, new$DescriptionCode, new$ProgramCode, new$AnalyticalGroupKD, new$Name, new$ShortName, new$RemoteFlag, new$kd_level, new$budgetref, new$extid);
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_KD_AI_500)
-- Last update 14.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 80)  and (RecordID = new$ID);

END;
/
-- CREATE TRIGGER tr_kd_au_100
CREATE OR REPLACE TRIGGER TR_KD_IU
  INSTEAD OF UPDATE
  ON KD
  FOR EACH ROW
DECLARE
  new$ID KD.ID%TYPE := :NEW.ID;
  new$REPCODE KD.REPCODE%TYPE := :NEW.REPCODE;
  new$CREATEDATE KD.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE KD.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$KVSR KD.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE KD.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE KD.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE KD.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE KD.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR KD.KESR%TYPE := :NEW.KESR;
  new$KDVALUE KD.KDVALUE%TYPE := :NEW.KDVALUE;
  new$REMOTEFLAG KD.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$UNIONFLAG KD.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$BUDGETREF KD.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE KD.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME KD.NAME%TYPE := :NEW.NAME;
  new$KD_LEVEL KD.KD_LEVEL%TYPE := :NEW.KD_LEVEL;
  new$STARTDATE KD.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME KD.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CREATERUSER KD.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER KD.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$EXTID KD.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER KD.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE KD.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID KD.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION KD.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE KD.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPKD KD.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
--
  tmp$ NUMBER(15,0);
  CNT$1 NUMBER(10);
  tmp_Double$ NUMBER;
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(5);
  sDescrCode2$ VARCHAR2(5);
  sProgCode$ VARCHAR2(4);
  sAnalyticalGroupKD$ VARCHAR2(3);
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sKDLevel$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_KD_BU_0)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*     */
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupKD is null) then 
    new$AnalyticalGroupKD := 0;
  END IF;
  if (new$ProgramCode is null) then 
    new$ProgramCode := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  if (new$KVSR <> 0) then
    select max(kd_level) into sKDLevel$ from KD where ((AnalyticalGroupKD = new$AnalyticalGroupKD) and (ProgramCode=new$ProgramCode)and (BudgetRef=new$BudgetRef)
    and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0))  ;
  END IF;
  if (sKDLevel$ is not null) then
    new$kd_Level := sKDLevel$;
  END IF;
  /*          */
    
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100;
  new$MainDescriptionCode := tmp_Double$;
  if (new$MainDescriptionCode > tmp_Double$) then 
    new$MainDescriptionCode := new$MainDescriptionCode - 1;
  END IF;
  tmp_Double$ := new$MainDescriptionCode;
  tmp_Double$ := tmp_Double$ * 100;
  new$ItemCode := tmp$ - tmp_Double$; 
  BEGIN

    /*      */ 
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-   */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode1$ < 10) then
      sKVSR$ := '00' || KVSRCode1$;
          
    else
      if (KVSRCode1$ < 100) then
        sKVSR$ := '0' || KVSRCode1$;
            
      else
        sKVSR$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*       */    
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 100000;
  DescrCode2$ := tmp_Double$;
      
  if (DescrCode1$ = 0) then
    sDescrCode1$ := '00000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '0000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '00' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '0' || DescrCode1$;
                
          else
            sDescrCode1$ := DescrCode1$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '00000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '0000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '00' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '0' || DescrCode2$;
                
          else
            sDescrCode2$ := DescrCode2$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  /*      */
  if (new$programcode = 0) then
    sProgCode$ := '0000';
        
  else
    if (new$programcode < 10) then
      sProgCode$ := '000' || new$programcode;
          
    else
      if (new$programcode < 100) then
        sProgCode$ := '00' || new$programcode;
            
      else
        if (new$programcode < 1000) then
          sProgCode$ := '0' || new$programcode;
              
        else
          sProgCode$ := new$programcode;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */ 
    select Code into sAnalyticalGroupKD$ from AnalyticalGroupKD where (ID = new$AnalyticalGroupKD) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    new$KESR := sAnalyticalGroupKD$;
  END IF;
  /*      */    
      
  new$kdvalue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sProgCode$ || sAnalyticalGroupKD$;
      
  if ((new$ID = 0) and (new$kdvalue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroKD');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_KD SET
    ID = new$ID,
    REPCODE = new$REPCODE,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    KDVALUE = new$KDVALUE,
    REMOTEFLAG = new$REMOTEFLAG,
    UNIONFLAG = new$UNIONFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    KD_LEVEL = new$KD_LEVEL,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPKD = new$ANALYTICALGROUPKD
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AU_100 (TR_KD_AU_100)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from kd kd1
    where ((kd1.kvsr = 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and
    (kd1.BudgetRef = new$BudgetRef)
    ) AND (ROWNUM = 1)                     ;
    /*    0,        =0 */
    if (not (CNT$1<> 0))
    then
      insert into KD (KVSR, DescriptionCode, ProgramCode, AnalyticalGroupKD, Name, ShortName, RemoteFlag, kd_level, budgetref, extid)
      values (0, new$DescriptionCode, new$ProgramCode, new$AnalyticalGroupKD, new$Name, new$ShortName, new$RemoteFlag, new$kd_level, new$budgetref, new$extid);
        
    END IF;
  else
    /*   = 0,         ,     */
    update kd kd1 set
    name = new$name,
    ShortName = new$ShortName, 
    kd_level = new$kd_level
    where
    (kd1.kvsr <> 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and
    (kd1.BudgetRef = new$BudgetRef);
    /*        */
    if (new$deletedate is not null) then
      update kd kd1 set
      deletedate = new$deletedate
      where
      (kd1.kvsr <> 0) and
      ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
      (kd1.programcode = new$programcode) and
      (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and
      (kd1.DeleteDate is null) and
      (kd1.BudgetRef = new$BudgetRef);
        
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_KD_AU_500)
-- Create 28.04.2005
-- Last update 14.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (80, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=80) and (RecordId=new$ID);
  end if;

END;
/
-- CREATE TRIGGER tr_kd_bd_0
CREATE OR REPLACE TRIGGER TR_KD_ID
  INSTEAD OF DELETE
  ON KD
  FOR EACH ROW
DECLARE
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_KD_BD_0)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*    ,      */
  if (:old.kvsr = 0) then
    SELECT COUNT(*) INTO CNT$1
    from kd kd1
    where ((kd1.kvsr <> 0) and
    ((kd1.descriptioncode-:old.descriptioncode>-1) and (kd1.descriptioncode-:old.descriptioncode<1)) and
    (kd1.programcode = :old.programcode) and
    (kd1.AnalyticalGroupKD = :old.AnalyticalGroupKD) and
    (kd1.BudgetRef = :old.BudgetRef)
    ) AND (ROWNUM = 1)       ;
    if ((CNT$1<> 0)) 
    then
      RaiseException('EX_CANTDELBASECODE');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_KD
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_KD_AD_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate) values(80, :old.ID, sysdate);

END;
/
-- CREATE TRIGGER tr_innerfinsource_ai_100
CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_II
  INSTEAD OF INSERT
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  new$ID INNERFINSOURCE.ID%TYPE := :NEW.ID;
  new$CREATEDATE INNERFINSOURCE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INNERFINSOURCE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$DIRECTION INNERFINSOURCE.DIRECTION%TYPE := :NEW.DIRECTION;
  new$KVSR INNERFINSOURCE.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE INNERFINSOURCE.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE INNERFINSOURCE.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE INNERFINSOURCE.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE INNERFINSOURCE.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR INNERFINSOURCE.KESR%TYPE := :NEW.KESR;
  new$FINSOURCEVALUE INNERFINSOURCE.FINSOURCEVALUE%TYPE := :NEW.FINSOURCEVALUE;
  new$UNIONFLAG INNERFINSOURCE.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$REMOTEFLAG INNERFINSOURCE.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$BUDGETREF INNERFINSOURCE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE INNERFINSOURCE.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME INNERFINSOURCE.NAME%TYPE := :NEW.NAME;
  new$STARTDATE INNERFINSOURCE.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME INNERFINSOURCE.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CLSASPECT INNERFINSOURCE.CLSASPECT%TYPE := :NEW.CLSASPECT;
  new$CREATERUSER INNERFINSOURCE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER INNERFINSOURCE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$IFS_LEVEL INNERFINSOURCE.IFS_LEVEL%TYPE := :NEW.IFS_LEVEL;
  new$EXTID INNERFINSOURCE.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER INNERFINSOURCE.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE INNERFINSOURCE.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID INNERFINSOURCE.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION INNERFINSOURCE.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE INNERFINSOURCE.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPIFS INNERFINSOURCE.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
--
  tmp$ NUMBER(15,0);
  tmp_Double$ NUMBER;
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(7);
  sDescrCode2$ VARCHAR2(7);
  sAnalyticalGroupIFS$ VARCHAR2(3);
  CNT$1 NUMBER(10);
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sIFSLevel1$ NUMBER(10);
  sDirection1$ NUMBER(10);
  AGIFS$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_INNERFINSOURCE_BI_0)
-- Version 11.20.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupIFS is null) then 
    new$AnalyticalGroupIFS := 0;
  END IF;
  if (new$ClsAspect is null) then 
    new$ClsAspect := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  /*     */
  if (new$KVSR <> 0) then
    select max(IFS_Level), max(Direction)
    into sIFSLevel1$, sDirection1$     from innerfinsource 
    where ((AnalyticalGroupIFS = new$AnalyticalGroupIFS) and (BudgetRef=new$BudgetRef) and 
    (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0)) 
    ;
  END IF;
  if (sIFSLevel1$ is not null) then
    new$IFS_Level := sIFSLevel1$;
  END IF;
  if (sDirection1$ is not null) then
    new$Direction := sDirection1$;
  END IF;
  /*         
            =3,5,8 */
  if (new$Direction is null) then
    if ((new$AnalyticalGroupIFS between 300 and 399) or 
    (new$AnalyticalGroupIFS between 500 and 599) or 
    (new$AnalyticalGroupIFS between 800 and 899)) then
      new$Direction := -1;
          
    else
      new$Direction := 1;
    END IF;
    GetIntConst(60, 9,AGIFS$);
    if (new$AnalyticalGroupIFS = AGIFS$) then
      new$Direction := 1;
    END IF;
    GetIntConst(60, 10,AGIFS$);
    if (new$AnalyticalGroupIFS = AGIFS$) then
      new$Direction := -1;  
      
    END IF;
  END IF;
  BEGIN
      

    /*      */ 
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-    */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode1$ < 10) then
      sKVSR$ := '00' || KVSRCode1$;
          
    else
      if (KVSRCode1$ < 100) then
        sKVSR$ := '0' || KVSRCode1$;
            
      else
        sKVSR$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*    , ,  */
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 1000000;
  DescrCode1$ := tmp_Double$;
  /*      ,
          ,    1 */
  if (DescrCode1$  > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$MainDescriptionCode := DescrCode1$; /*    */
  /*       */    
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 1000000;
  DescrCode2$ := tmp_Double$;
  tmp_Double$ := DescrCode2$ / 10000;
  DescrCode1$ := tmp_Double$;
  /*      */
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$ItemCode := DescrCode1$; /* */
  tmp_Double$ := DescrCode2$ - DescrCode1$ * 10000;
  new$ProgramCode := tmp_Double$; /* */
  /*       */
      
  tmp_Double$ := tmp$ / 10000000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 10000000;
  DescrCode2$ := tmp_Double$;
  if (DescrCode1$ = 0) then
    sDescrCode1$ := '0000000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '000000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '00000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '0000' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '000' || DescrCode1$;
                
          else
            if (DescrCode1$ < 100000) then
              sDescrCode1$ := '00' || DescrCode1$;
                  
            else
              if (DescrCode1$ < 1000000) then
                sDescrCode1$ := '0' || DescrCode1$;
                    
              else
                sDescrCode1$ := DescrCode1$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '0000000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '000000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '00000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '0000' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '000' || DescrCode2$;
                
          else
            if (DescrCode2$ < 100000) then
              sDescrCode2$ := '00' || DescrCode2$;
                  
            else
              if (DescrCode2$ < 1000000) then
                sDescrCode2$ := '0' || DescrCode2$;
                    
              else
                sDescrCode2$ := DescrCode2$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */ 
    select Code into sAnalyticalGroupIFS$ from AnalyticalGroupIFS where (ID = new$AnalyticalGroupIFS) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    new$KESR := sAnalyticalGroupIFS$;
  END IF;
  /*      */
      
  new$FinSourceValue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sAnalyticalGroupIFS$;
      
  if ((new$ID = 0) and (new$FinSourceValue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroIFS');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_INNERFINSOURCE_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_INNERFINSOURCE (
    ID,
    CREATEDATE,
    UPDATEDATE,
    DIRECTION,
    KVSR,
    DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE,
    ITEMCODE,
    PROGRAMCODE,
    KESR,
    FINSOURCEVALUE,
    UNIONFLAG,
    REMOTEFLAG,
    BUDGETREF,
    DELETEDATE,
    NAME,
    STARTDATE,
    SHORTNAME,
    CLSASPECT,
    CREATERUSER,
    UPDATERUSER,
    IFS_LEVEL,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    ANALYTICALGROUPIFS
  ) VALUES (
    new$ID,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$DIRECTION,
    new$KVSR,
    new$DESCRIPTIONCODE,
    new$MAINDESCRIPTIONCODE,
    new$ITEMCODE,
    new$PROGRAMCODE,
    new$KESR,
    new$FINSOURCEVALUE,
    new$UNIONFLAG,
    new$REMOTEFLAG,
    new$BUDGETREF,
    new$DELETEDATE,
    new$NAME,
    new$STARTDATE,
    new$SHORTNAME,
    new$CLSASPECT,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$IFS_LEVEL,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$ANALYTICALGROUPIFS);

-- - - - - - - - - - - - -
-- AI_100 (TR_INNERFINSOURCE_AI_100)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from InnerFinSource ifs1
    where ((ifs1.kvsr = 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
    (ifs1.BudgetRef = new$BudgetRef)
    ) AND (ROWNUM = 1)                   ;
    if (not (CNT$1<> 0))
    then  
      insert into InnerFinSource (KVSR, DescriptionCode, AnalyticalGroupIFS, Name, ShortName, CLSAspect, RemoteFlag, Direction, IFS_Level, BudgetRef, ExtID)
      values (0, new$DescriptionCode, new$AnalyticalGroupIFS, new$Name, new$ShortName, new$CLSAspect, new$RemoteFlag, new$direction, new$IFS_Level, new$BudgetRef, new$ExtID);
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_INNERFINSOURCE_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 145) and (RecordId = new$ID);

END;
/
-- CREATE TRIGGER tr_innerfinsource_au_100
CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_IU
  INSTEAD OF UPDATE
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  new$ID INNERFINSOURCE.ID%TYPE := :NEW.ID;
  new$CREATEDATE INNERFINSOURCE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INNERFINSOURCE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$DIRECTION INNERFINSOURCE.DIRECTION%TYPE := :NEW.DIRECTION;
  new$KVSR INNERFINSOURCE.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE INNERFINSOURCE.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE INNERFINSOURCE.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE INNERFINSOURCE.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE INNERFINSOURCE.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR INNERFINSOURCE.KESR%TYPE := :NEW.KESR;
  new$FINSOURCEVALUE INNERFINSOURCE.FINSOURCEVALUE%TYPE := :NEW.FINSOURCEVALUE;
  new$UNIONFLAG INNERFINSOURCE.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$REMOTEFLAG INNERFINSOURCE.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$BUDGETREF INNERFINSOURCE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE INNERFINSOURCE.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME INNERFINSOURCE.NAME%TYPE := :NEW.NAME;
  new$STARTDATE INNERFINSOURCE.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME INNERFINSOURCE.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CLSASPECT INNERFINSOURCE.CLSASPECT%TYPE := :NEW.CLSASPECT;
  new$CREATERUSER INNERFINSOURCE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER INNERFINSOURCE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$IFS_LEVEL INNERFINSOURCE.IFS_LEVEL%TYPE := :NEW.IFS_LEVEL;
  new$EXTID INNERFINSOURCE.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER INNERFINSOURCE.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE INNERFINSOURCE.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID INNERFINSOURCE.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION INNERFINSOURCE.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE INNERFINSOURCE.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPIFS INNERFINSOURCE.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
--
  tmp$ NUMBER(15,0);
  tmp_Double$ NUMBER;
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(7);
  sDescrCode2$ VARCHAR2(7);
  CNT$1 NUMBER(10);
  sAnalyticalGroupIFS$ VARCHAR2(3);
  KVSRCode$ NUMBER(10);
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  sIFSLevel$ NUMBER(10);
  sDirection$ NUMBER(10);
  AGIFS$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INNERFINSOURCE_BU_0)
-- Version 11.20.00.2
-- - - - - - - - - - - - -

  /*  Id,     */
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupIFS is null) then 
    new$AnalyticalGroupIFS := 0;
  END IF;
  if (new$ClsAspect is null) then 
    new$ClsAspect := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  /*     */
  if (new$KVSR <> 0) then
    select max(IFS_Level), max(Direction) 
    into sIFSLevel$, sDirection$     from innerfinsource 
    where ((AnalyticalGroupIFS = new$AnalyticalGroupIFS) and (BudgetRef=new$BudgetRef) and 
    (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0)) 
    ;
  END IF;
  if (sIFSLevel$ is not null) then
    new$IFS_Level := sIFSLevel$;
  END IF;
  if (sDirection$ is not null) then
    new$Direction := sDirection$;
  END IF;
  /*         
            =3,5,8 */
  if (new$Direction is null) then
    if ((new$AnalyticalGroupIFS between 300 and 399) or 
    (new$AnalyticalGroupIFS between 500 and 599) or 
    (new$AnalyticalGroupIFS between 800 and 899)) then
      new$Direction := -1;
          
    else
      new$Direction := 1;
    END IF;
    GetIntConst(60, 9,AGIFS$);
    if (new$AnalyticalGroupIFS = AGIFS$) then
      new$Direction := 1;
    END IF;
    GetIntConst(60, 10,AGIFS$);
    if (new$AnalyticalGroupIFS = AGIFS$) then
      new$Direction := -1;  
      
    END IF;
  END IF;
  BEGIN
      

    /*      */ 
    select Code into KVSRCode$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-    */
  /*      */
  if (KVSRCode$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode$ < 10) then
      sKVSR$ := '00' || KVSRCode$;
          
    else
      if (KVSRCode$ < 100) then
        sKVSR$ := '0' || KVSRCode$;
            
      else
        sKVSR$ := KVSRCode$;
      END IF;
    END IF;
  END IF;
  /*    , ,  */
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 1000000;
  DescrCode1$ := tmp_Double$;
  /*      ,
          ,    1 */
  if (DescrCode1$  > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$MainDescriptionCode := DescrCode1$; /*    */
  /*       */    
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 1000000;
  DescrCode2$ := tmp_Double$;
  tmp_Double$ := DescrCode2$ / 10000;
  DescrCode1$ := tmp_Double$;
  /*      */
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$ItemCode := DescrCode1$; /* */
  tmp_Double$ := DescrCode2$ - DescrCode1$ * 10000;
  new$ProgramCode := tmp_Double$; /* */
  /*       */
      
  tmp_Double$ := tmp$ / 10000000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 10000000;
  DescrCode2$ := tmp_Double$;
  if (DescrCode1$ = 0) then
    sDescrCode1$ := '0000000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '000000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '00000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '0000' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '000' || DescrCode1$;
                
          else
            if (DescrCode1$ < 100000) then
              sDescrCode1$ := '00' || DescrCode1$;
                  
            else
              if (DescrCode1$ < 1000000) then
                sDescrCode1$ := '0' || DescrCode1$;
                    
              else
                sDescrCode1$ := DescrCode1$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '0000000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '000000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '00000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '0000' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '000' || DescrCode2$;
                
          else
            if (DescrCode2$ < 100000) then
              sDescrCode2$ := '00' || DescrCode2$;
                  
            else
              if (DescrCode2$ < 1000000) then
                sDescrCode2$ := '0' || DescrCode2$;
                    
              else
                sDescrCode2$ := DescrCode2$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */ 
    select Code into sAnalyticalGroupIFS$ from AnalyticalGroupIFS where (ID = new$AnalyticalGroupIFS) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    new$KESR := sAnalyticalGroupIFS$;
  END IF;
  /*      */
      
  new$FinSourceValue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sAnalyticalGroupIFS$;
      
  if ((new$ID = 0) and (new$FinSourceValue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroIFS');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INNERFINSOURCE SET
    ID = new$ID,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    DIRECTION = new$DIRECTION,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    FINSOURCEVALUE = new$FINSOURCEVALUE,
    UNIONFLAG = new$UNIONFLAG,
    REMOTEFLAG = new$REMOTEFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CLSASPECT = new$CLSASPECT,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    IFS_LEVEL = new$IFS_LEVEL,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPIFS = new$ANALYTICALGROUPIFS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_INNERFINSOURCE_AU_100)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from InnerFinSource ifs1
    where ((ifs1.kvsr = 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
    (ifs1.BudgetRef = new$BudgetRef)
    ) AND (ROWNUM = 1)
    ;
    if (not (CNT$1<> 0))
    then  
      insert into InnerFinSource (KVSR, DescriptionCode, AnalyticalGroupIFS, Name, ShortName, CLSAspect, RemoteFlag, IFS_Level, BudgetRef, ExtID)
      values (0, new$DescriptionCode, new$AnalyticalGroupIFS, new$Name, new$ShortName, new$CLSAspect, new$RemoteFlag, new$IFS_Level, new$BudgetRef, new$ExtID);
      
    END IF;
  else
    /*   = 0,         ,     */
    update InnerFinSource ifs1 set
    name = new$name,
    ShortName = new$ShortName,
    ifs_level = new$ifs_level,
    Direction = new$Direction
    where
    (ifs1.kvsr <> 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
    (ifs1.BudgetRef = new$BudgetRef) and
    ((ifs1.ExtID = new$ExtID)or((ifs1.ExtID is null)and(new$ExtID is null)));
    /*        */
    if (new$deletedate is not null) then
      update InnerFinSource ifs1 set
      deletedate = new$deletedate
      where
      (ifs1.kvsr <> 0) and
      ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
      (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
      (ifs1.DeleteDate is null) and
      (ifs1.BudgetRef = new$BudgetRef) and
      ((ifs1.ExtID = new$ExtID)or((ifs1.ExtID is null)and(new$ExtID is null)));
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INNERFINSOURCE_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (145, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=145) and (RecordId=new$ID);
  end if;

END;
/
-- CREATE TRIGGER tr_innerfinsource_bd_0
CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_ID
  INSTEAD OF DELETE
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_INNERFINSOURCE_BD_0)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  /*    ,      */
  if (:old.kvsr = 0) then
    SELECT COUNT(*) INTO CNT$1
    from InnerFinSource ifs1
    where ((ifs1.kvsr <> 0) and
    ((ifs1.descriptioncode-:old.descriptioncode>-1) and (ifs1.descriptioncode-:old.descriptioncode<1)) and
    (ifs1.AnalyticalGroupIFS = :old.AnalyticalGroupIFS) and
    (ifs1.BudgetRef = :old.BudgetRef)
    ) AND (ROWNUM = 1)       ;
    if ((CNT$1<> 0)) 
    then
      RaiseException('EX_CANTDELBASECODE');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_INNERFINSOURCE
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_INNERFINSOURCE_AD_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate) values(145,:old.ID,SYSDATE);

END;
/
-- CREATE TRIGGER tr_transfertcls_bi_200
CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_II
  INSTEAD OF INSERT
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKESR TRANSFERTCLS.RECEIVEKESR%TYPE := :NEW.RECEIVEKESR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
  new$EXTROOTID TRANSFERTCLS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION TRANSFERTCLS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE TRANSFERTCLS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
--
  CurrentDate$ NUMBER;
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_TRANSFERTCLS_BI)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  select g_shared.nextval into new$ID from dual;
   
  if (new$BUDGETREF is null) then 
    new$BUDGETREF := 0;
  END IF;
  if (new$RECEIVEKVSR is null) then 
    new$RECEIVEKVSR := 0;
  END IF;
  if (new$RECEIVEKCSR is null) then 
    new$RECEIVEKCSR := 0;
  END IF;
  if (new$RECEIVEKFSR is null) then 
    new$RECEIVEKFSR := 0;
  END IF;
  if (new$RECEIVEKESR is null) then 
    new$RECEIVEKESR := 0;
  END IF;
  if (new$RECEIVEKD is null) then 
    new$RECEIVEKD := 0;
  END IF;
  if ((new$RECEIVEKVR is null) or (new$RECEIVEKVR  is null)) then 
    new$RECEIVEKVR := '000';
  END IF;
  if (new$TRANSFERKVSR is null) then 
    new$TRANSFERKVSR := 0;
  END IF;
  if (new$TRANSFERKCSR is null) then 
    new$TRANSFERKCSR := 0;
  END IF;
  if (new$TRANSFERKFSR is null) then 
    new$TRANSFERKFSR := 0;
  END IF;
  if (new$TRANSFERKVR is null) then 
    new$TRANSFERKVR := 0;
  END IF;
  if (new$TRANSFERKESR is null) then 
    new$TRANSFERKESR := 0;
  END IF;
  if ((new$TRANSFERKDVALUE is null) or (new$TRANSFERKDVALUE  is null)) then 
    new$TRANSFERKDVALUE := '00000000000000000000';
  END IF;
  if (new$TARGETMEANSSIGN is null) then 
    new$TARGETMEANSSIGN := 1;
  END IF;
  if (new$REGIONCLS is null) then 
    new$REGIONCLS := 0;
  END IF;
  if (new$FACT is null) then 
    new$FACT := 0;
  END IF;
  if (new$SourceLevel is null) then 
    new$SourceLevel := 0;
  END IF;
  if (new$GrantKind is null) then 
    new$GrantKind := 0;
  END IF;
  if (new$GrantKind = 2) then /*   "" */
    new$DestLevel := 1; /*    */
     
  else
    /*   ""  " "   */
    if ((new$GrantKind = 1) or (new$DestLevel is null)) then
      new$DestLevel := 0; /*   */
    END IF;
  END IF;
  if (new$TransfertKind is null) then 
    new$TransfertKind  := 0; 
  END IF;
  if (new$TransfertYear is null) then
    CurDateToDouble(CurrentDate$);
    new$TransfertYear := CurrentDate$ / 10000;
     
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_TRANSFERTCLS_BI_200)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(*) INTO CNT$1
  from TransfertCls t where
  (        (t.ID <> new$ID) and
  (t.CODE=new$CODE) and
  (t.RECEIVEKVSR=new$RECEIVEKVSR) and
  (t.RECEIVEKFSR=new$RECEIVEKFSR) and
  (t.RECEIVEKCSR=new$RECEIVEKCSR) and
  (t.RECEIVEKVR=new$RECEIVEKVR) and
  (t.RECEIVEKESR=new$RECEIVEKESR) and
  (t.RECEIVEKD=new$RECEIVEKD) and
  (t.TRANSFERKVSR=new$TRANSFERKVSR) and
  (t.TRANSFERKFSR=new$TRANSFERKFSR) and
  (t.TRANSFERKCSR=new$TRANSFERKCSR) and
  (t.TRANSFERKVR=new$TRANSFERKVR) and
  (t.TRANSFERKESR=new$TRANSFERKESR) and
  (t.TRANSFERKDVALUE=new$TRANSFERKDVALUE) and
  (t.TARGETMEANSSIGN=new$TARGETMEANSSIGN) and
  (t.REGIONCLS=new$REGIONCLS) and
  (t.DESTLEVEL=new$DESTLEVEL) and
  (t.BUDGETREF=new$BUDGETREF) and
  (t.EXTID=new$EXTID) and
  (t.FACT=new$FACT)) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    RaiseException('EX_DUPLICATE_TRANSFERT');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_TRANSFERTCLS_BI_500)
-- Create 24.09.2007
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_TRANSFERTCLS (
    ID,
    REGIONCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    CODE,
    RECEIVEKVSR,
    RECEIVEKFSR,
    RECEIVEKVR,
    RECEIVEKESR,
    RECEIVEKD,
    TRANSFERKVSR,
    TRANSFERKFSR,
    TRANSFERKCSR,
    TRANSFERKVR,
    TRANSFERKESR,
    TRANSFERKDVALUE,
    TARGETMEANSSIGN,
    TARGETCLS,
    STARTDATE,
    DELETEDATE,
    NOTE,
    NAME,
    BUDGETREF,
    RECEIVEKCSR,
    SOURCELEVEL,
    DESTLEVEL,
    TRANSFERTKIND,
    GRANTKIND,
    TRANSFERTYEAR,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    FACT,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE
  ) VALUES (
    new$ID,
    new$REGIONCLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$CODE,
    new$RECEIVEKVSR,
    new$RECEIVEKFSR,
    new$RECEIVEKVR,
    new$RECEIVEKESR,
    new$RECEIVEKD,
    new$TRANSFERKVSR,
    new$TRANSFERKFSR,
    new$TRANSFERKCSR,
    new$TRANSFERKVR,
    new$TRANSFERKESR,
    new$TRANSFERKDVALUE,
    new$TARGETMEANSSIGN,
    new$TARGETCLS,
    new$STARTDATE,
    new$DELETEDATE,
    new$NOTE,
    new$NAME,
    new$BUDGETREF,
    new$RECEIVEKCSR,
    new$SOURCELEVEL,
    new$DESTLEVEL,
    new$TRANSFERTKIND,
    new$GRANTKIND,
    new$TRANSFERTYEAR,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$FACT,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE);

-- - - - - - - - - - - - -
-- AI_500 (TR_TRANSFERTCLS_AI_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);

END;
/
-- CREATE TRIGGER tr_transfertcls_bu_200
CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_IU
  INSTEAD OF UPDATE
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKESR TRANSFERTCLS.RECEIVEKESR%TYPE := :NEW.RECEIVEKESR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
  new$EXTROOTID TRANSFERTCLS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION TRANSFERTCLS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE TRANSFERTCLS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
--
  CurrentDate$ NUMBER;
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_TRANSFERTCLS_BU)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$BUDGETREF is null) then 
    new$BUDGETREF := 0;
  END IF;
  if (new$RECEIVEKVSR is null) then 
    new$RECEIVEKVSR := 0;
  END IF;
  if (new$RECEIVEKCSR is null) then 
    new$RECEIVEKCSR := 0;
  END IF;
  if (new$RECEIVEKFSR is null) then 
    new$RECEIVEKFSR := 0;
  END IF;
  if (new$RECEIVEKESR is null) then 
    new$RECEIVEKESR := 0;
  END IF;
  if (new$RECEIVEKD is null) then 
    new$RECEIVEKD := 0;
  END IF;
  if ((new$RECEIVEKVR is null) or (new$RECEIVEKVR  is null)) then 
    new$RECEIVEKVR := '000';
  END IF;
  if (new$TRANSFERKVSR is null) then 
    new$TRANSFERKVSR := 0;
  END IF;
  if (new$TRANSFERKCSR is null) then 
    new$TRANSFERKCSR := 0;
  END IF;
  if (new$TRANSFERKFSR is null) then 
    new$TRANSFERKFSR := 0;
  END IF;
  if (new$TRANSFERKVR is null) then 
    new$TRANSFERKVR := 0;
  END IF;
  if (new$TRANSFERKESR is null) then 
    new$TRANSFERKESR := 0;
  END IF;
  if ((new$TRANSFERKDVALUE is null) or (new$TRANSFERKDVALUE  is null)) then 
    new$TRANSFERKDVALUE := '00000000000000000000';
  END IF;
  if (new$TARGETMEANSSIGN is null) then 
    new$TARGETMEANSSIGN := 1;
  END IF;
  if (new$REGIONCLS is null) then 
    new$REGIONCLS := 0;
  END IF;
  if (new$FACT is null) then 
    new$FACT := 0;
  END IF;
  if (new$SourceLevel is null) then 
    new$SourceLevel := 0;
  END IF;
  if (new$GrantKind is null) then 
    new$GrantKind := 0;
  END IF;
  if (new$GrantKind = 2) then /*   "" */
    new$DestLevel := 1; /*    */
     
  else
    /*   ""  " "   */
    if ((new$GrantKind = 1) or (new$DestLevel is null)) then
      new$DestLevel := 0; /*   */
    END IF;
  END IF;
  if (new$TransfertKind is null) then 
    new$TransfertKind  := 0;
  END IF;
  if (new$TransfertYear is null) then
    CurDateToDouble(CurrentDate$);
    new$TransfertYear := CurrentDate$ / 10000;
     
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_TRANSFERTCLS_BU_100)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if ((new$id = 0) and (new$Code <> :old.Code)) then
    RaiseException('EX_CANTMODIFY_ZEROTRANFERTSCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_TRANSFERTCLS_BU_200)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(*) INTO CNT$1
  from TransfertCls t where
  (        (t.ID <> new$ID) and
  (t.CODE=new$CODE) and
  (t.RECEIVEKVSR=new$RECEIVEKVSR) and
  (t.RECEIVEKFSR=new$RECEIVEKFSR) and
  (t.RECEIVEKCSR=new$RECEIVEKCSR) and
  (t.RECEIVEKVR=new$RECEIVEKVR) and
  (t.RECEIVEKESR=new$RECEIVEKESR) and
  (t.RECEIVEKD=new$RECEIVEKD) and
  (t.TRANSFERKVSR=new$TRANSFERKVSR) and
  (t.TRANSFERKFSR=new$TRANSFERKFSR) and
  (t.TRANSFERKCSR=new$TRANSFERKCSR) and
  (t.TRANSFERKVR=new$TRANSFERKVR) and
  (t.TRANSFERKESR=new$TRANSFERKESR) and
  (t.TRANSFERKDVALUE=new$TRANSFERKDVALUE) and
  (t.TARGETMEANSSIGN=new$TARGETMEANSSIGN) and
  (t.REGIONCLS=new$REGIONCLS) and
  (t.DESTLEVEL=new$DESTLEVEL) and
  (t.BUDGETREF=new$BUDGETREF) and
  (t.EXTID=new$EXTID) and
  (t.FACT=new$FACT)) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    RaiseException('EX_DUPLICATE_TRANSFERT');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_TRANSFERTCLS SET
    ID = new$ID,
    REGIONCLS = new$REGIONCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    CODE = new$CODE,
    RECEIVEKVSR = new$RECEIVEKVSR,
    RECEIVEKFSR = new$RECEIVEKFSR,
    RECEIVEKVR = new$RECEIVEKVR,
    RECEIVEKESR = new$RECEIVEKESR,
    RECEIVEKD = new$RECEIVEKD,
    TRANSFERKVSR = new$TRANSFERKVSR,
    TRANSFERKFSR = new$TRANSFERKFSR,
    TRANSFERKCSR = new$TRANSFERKCSR,
    TRANSFERKVR = new$TRANSFERKVR,
    TRANSFERKESR = new$TRANSFERKESR,
    TRANSFERKDVALUE = new$TRANSFERKDVALUE,
    TARGETMEANSSIGN = new$TARGETMEANSSIGN,
    TARGETCLS = new$TARGETCLS,
    STARTDATE = new$STARTDATE,
    DELETEDATE = new$DELETEDATE,
    NOTE = new$NOTE,
    NAME = new$NAME,
    BUDGETREF = new$BUDGETREF,
    RECEIVEKCSR = new$RECEIVEKCSR,
    SOURCELEVEL = new$SOURCELEVEL,
    DESTLEVEL = new$DESTLEVEL,
    TRANSFERTKIND = new$TRANSFERTKIND,
    GRANTKIND = new$GRANTKIND,
    TRANSFERTYEAR = new$TRANSFERTYEAR,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    FACT = new$FACT,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_TRANSFERTCLS_AU_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  if (new$Id <> :old.Id) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (203, :Old.Id, SYSDATE);
    delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);
  end if;

END;
/

commit work
/





-- #########################################################
-- #########################################################
-- Alter_DOFields.sql
-- #########################################################
-- #########################################################

/*         " "*/
ALTER TABLE TB_ExecutionDocumentsCaption ADD (
  InfoNumber VARCHAR2(50),/*  */
  NotifyDate NUMBER,/*  */
  NumberMoneyRespons VARCHAR2(50),/*   */
  PurportDoc VARCHAR2(255)/*  */
)
/

CREATE OR REPLACE VIEW ExecutionDocumentsCaption (
  ID,
  DOCTYPE,
  DOCUMENTDATE,
  ACCEPTDATE,
  SUMMA,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  BUDGETREF,
  STEPNUMBER,
  FACIALACC_CLS,
  RECIPIENT_REF,
  REGISTRATIONTYPE,
  REESTRNUMBER,
  AGREEMENTINNERNUMBER,
  REJECTCLS,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  REVIEWNOTE,
  DOCSTATEREF,
  RVERSION,
  EXECDOCFINSUMMA,
  FACT,
  DOCNUMBER,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  REALID,
  INNERNUMBER,
  ADJUSTMENTREF,
  ADJUSTMENTNUMBER,
  ACCEPTED,
  LASTACCEPTED,
  LASTADJUSTMENT,
  AGREEMENTREF,
  NOTE,
  SUPPLIERSTOREDPROPS,
  SUPPLIER_REF,
  SUPPLIERACC_REF,
  REJECTCAUSE,
  INFONUMBER,
  NOTIFYDATE,
  NUMBERMONEYRESPONS,
  PURPORTDOC)
AS
  SELECT
    ID,
    DOCTYPE,
    DOCUMENTDATE,
    ACCEPTDATE,
    SUMMA,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    STEPNUMBER,
    FACIALACC_CLS,
    RECIPIENT_REF,
    REGISTRATIONTYPE,
    REESTRNUMBER,
    AGREEMENTINNERNUMBER,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXECDOCFINSUMMA,
    FACT,
    DOCNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REALID,
    INNERNUMBER,
    ADJUSTMENTREF,
    ADJUSTMENTNUMBER,
    ACCEPTED,
    LASTACCEPTED,
    LASTADJUSTMENT,
    AGREEMENTREF,
    NOTE,
    SUPPLIERSTOREDPROPS,
    SUPPLIER_REF,
    SUPPLIERACC_REF,
    REJECTCAUSE,
    INFONUMBER,
    NOTIFYDATE,
    NUMBERMONEYRESPONS,
    PURPORTDOC
  FROM TB_ExecutionDocumentsCaption
/

CREATE OR REPLACE TRIGGER TR_EXECUTIONDOCUMENTSCAPTIO_ID
  INSTEAD OF DELETE
  ON EXECUTIONDOCUMENTSCAPTION
  FOR EACH ROW
DECLARE
  quant$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_DOCEXECCAPTION_BD)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  select count(ID)   into quant$ from executiondocumentscaption 
  where AdjustmentRef = :old.ID
  ;
  if (quant$  = 0) then
    delete from ExecutionDocumentsDetail where (RecordIndex = :old.ID);
    delete from paymentschedule where (ExecutionRef = :old.ID)and(ProgIndex=308);
      
  else
    RaiseException('ex_agr_cantdeladjustmented');
  END IF;

-- - - - - - - - - - - - -
-- BD_10 (TR_DocExecCaption_BD_10)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*   LastAdjustment     */
  if ((:old.AdjustmentRef is not null) and (:old.LastAdjustment = 1)) then
    update ExecutionDocumentsCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;
  /*   LastAccepted     */    
  if ((:old.AdjustmentRef is not null) and (:old.LastAccepted = 1)) then
    update ExecutionDocumentsCaption set
    LastAccepted = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_EXECUTIONDOCUMENTSCAPTION
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_10 (TR_ExecDocCaption_AD_10)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*   LastAdjustment     */
  if ((:old.AdjustmentRef is not null) and (:old.LastAdjustment = 1)) then
    update ExecutionDocumentsCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;
  /*   LastAccepted     */    
  if ((:old.AdjustmentRef is not null) and (:old.LastAccepted = 1)) then
    update ExecutionDocumentsCaption set
    LastAccepted = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AD_200 (TR_EXECDOCCAPTION_AD_200)
-- Create 04.10.2004
-- - - - - - - - - - - - -

  /*        */
  delete from StateJumpHistory where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_EXECDOCCAPTION_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordId, DeleteDate, SUMMA) values (114, :old.ID, SYSDATE, :old.SUMMA);

END;
/

CREATE OR REPLACE TRIGGER TR_EXECUTIONDOCUMENTSCAPTIO_II
  INSTEAD OF INSERT
  ON EXECUTIONDOCUMENTSCAPTION
  FOR EACH ROW
DECLARE
  new$ID EXECUTIONDOCUMENTSCAPTION.ID%TYPE := :NEW.ID;
  new$DOCTYPE EXECUTIONDOCUMENTSCAPTION.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$DOCUMENTDATE EXECUTIONDOCUMENTSCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE EXECUTIONDOCUMENTSCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SUMMA EXECUTIONDOCUMENTSCAPTION.SUMMA%TYPE := :NEW.SUMMA;
  new$CREATERUSER EXECUTIONDOCUMENTSCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE EXECUTIONDOCUMENTSCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE EXECUTIONDOCUMENTSCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER EXECUTIONDOCUMENTSCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF EXECUTIONDOCUMENTSCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$STEPNUMBER EXECUTIONDOCUMENTSCAPTION.STEPNUMBER%TYPE := :NEW.STEPNUMBER;
  new$FACIALACC_CLS EXECUTIONDOCUMENTSCAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$RECIPIENT_REF EXECUTIONDOCUMENTSCAPTION.RECIPIENT_REF%TYPE := :NEW.RECIPIENT_REF;
  new$REGISTRATIONTYPE EXECUTIONDOCUMENTSCAPTION.REGISTRATIONTYPE%TYPE := :NEW.REGISTRATIONTYPE;
  new$REESTRNUMBER EXECUTIONDOCUMENTSCAPTION.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$AGREEMENTINNERNUMBER EXECUTIONDOCUMENTSCAPTION.AGREEMENTINNERNUMBER%TYPE := :NEW.AGREEMENTINNERNUMBER;
  new$REJECTCLS EXECUTIONDOCUMENTSCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS EXECUTIONDOCUMENTSCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID EXECUTIONDOCUMENTSCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID EXECUTIONDOCUMENTSCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REVIEWNOTE EXECUTIONDOCUMENTSCAPTION.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF EXECUTIONDOCUMENTSCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION EXECUTIONDOCUMENTSCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$EXECDOCFINSUMMA EXECUTIONDOCUMENTSCAPTION.EXECDOCFINSUMMA%TYPE := :NEW.EXECDOCFINSUMMA;
  new$FACT EXECUTIONDOCUMENTSCAPTION.FACT%TYPE := :NEW.FACT;
  new$DOCNUMBER EXECUTIONDOCUMENTSCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SENDERIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REALID EXECUTIONDOCUMENTSCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER EXECUTIONDOCUMENTSCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTREF EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ADJUSTMENTNUMBER EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$ACCEPTED EXECUTIONDOCUMENTSCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED EXECUTIONDOCUMENTSCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$LASTADJUSTMENT EXECUTIONDOCUMENTSCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$AGREEMENTREF EXECUTIONDOCUMENTSCAPTION.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$NOTE EXECUTIONDOCUMENTSCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$SUPPLIERSTOREDPROPS EXECUTIONDOCUMENTSCAPTION.SUPPLIERSTOREDPROPS%TYPE := :NEW.SUPPLIERSTOREDPROPS;
  new$SUPPLIER_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIER_REF%TYPE := :NEW.SUPPLIER_REF;
  new$SUPPLIERACC_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIERACC_REF%TYPE := :NEW.SUPPLIERACC_REF;
  new$REJECTCAUSE EXECUTIONDOCUMENTSCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$INFONUMBER EXECUTIONDOCUMENTSCAPTION.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$NOTIFYDATE EXECUTIONDOCUMENTSCAPTION.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$NUMBERMONEYRESPONS EXECUTIONDOCUMENTSCAPTION.NUMBERMONEYRESPONS%TYPE := :NEW.NUMBERMONEYRESPONS;
  new$PURPORTDOC EXECUTIONDOCUMENTSCAPTION.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
--
  Tmp$ NUMBER(10);
  AdjID$ NUMBER(10);
  AdjDocNum$ VARCHAR2(50);
  agr_accepted$ NUMBER(10);
  agr_acceptdate$ NUMBER(10);
  PreviousInner$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ExecDoccaption_BI)
-- Version 11.20.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$DocType is null) then 
    new$DocType := 0;
  END IF;
  if (new$Summa is null) then 
    new$Summa := 0;
  END IF;
  if (new$ExecDocFinSumma is null) then 
    new$ExecDocFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$RegistrationType is null) then 
    new$RegistrationType := 0;
  END IF;
  if (new$Fact is null) then 
    new$Fact := 0;
  END IF;
  if (new$Accepted is null) then 
    new$Accepted := 1;
  END IF;
  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    BEGIN
      select fa.BudgetRef
      into new$BudgetRef     from FacialAcc_Cls fa
      where fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then 
    GetIntConst(-1,3,new$BudgetRef);
  END IF;
  if (new$Supplier_Ref is null and new$SupplierAcc_Ref is not null) then
    BEGIN
      select oa.Org_Ref
      into new$Supplier_Ref   from Org_Accounts oa
      where oa.id = new$SupplierAcc_Ref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,     ,      */
  if (new$AdjustmentRef is null) then
    new$InnerNumber := GEN_ID('g_ExecDocNumber',1);
      
  else
    BEGIN
      /*          */
      select
      InnerNumber 
      into PreviousInner$     from ExecutionDocumentsCaption
      where ID = new$AdjustmentRef and LastAccepted = 1 and LastAdjustment = 1
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (PreviousInner$ is null) then
      RaiseException('EX_ExecDoc_NotFindInner');
    END IF;
    new$InnerNumber := PreviousInner$;
      
  END IF;
  /*      id */  
  new$agreementinnernumber := null;
  if (new$agreementref is not null) then
    BEGIN
      select
      innernumber
      into new$agreementinnernumber     from agreements
      where
      id = new$agreementref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_EXECDOCCAPTION_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;
          
    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_EXECDOCCAPTION_BI_10)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*    .*/
  if (new$InnerNumber is null) then
    RaiseException('EX_AGR_InnerNumsIsNull');
  END IF;

  /*    */
  select max(AdjustmentNumber)
  into Tmp$     from ExecutionDocumentsCaption
  where (InnerNumber = new$InnerNumber)
  ;
  /*      ,   0*/
  if (Tmp$ is null) then
    new$AdjustmentNumber := 0;
        
  else
    new$AdjustmentNumber := Tmp$ + 1;
  END IF;
  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;
        
  else
    new$LastAdjustment := 1;
  END IF;
  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then
    new$LastAccepted := 1;
        
  else
    new$LastAccepted := 0;
  END IF;
  /*    */
  if (new$AdjustmentRef is not null) then
    /*      -    */
    select count(ID), max(ID), max(DocNumber)
    into Tmp$, AdjID$, AdjDocNum$       from ExecutionDocumentsCaption
    where (InnerNumber = new$InnerNumber) and (LastAccepted = 1)
    ;
    /*   ,  */
    if (Tmp$ <> 1) then
      RaiseException('EX_ExecDoc_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID)
    into Tmp$       from ExecutionDocumentsCaption
    where (InnerNumber = new$InnerNumber) and (AcceptDate is null)
    ;
    if (Tmp$ > 0) then
      RaiseException('EX_ExecDoc_AdjustDuplicate');
    END IF;
    /* ,    ,    */      
    new$AdjustmentRef := AdjID$;
        
  else /*     */
    /*       (    )*/      
    new$AdjustmentRef := null;
  END IF;

-- - - - - - - - - - - - -
-- BI_40 (tr_execdoccaption_bi_40)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*       */
  if (new$senderId is null) then 
    new$senderIdKey := -1;
      
  else 
    new$senderIdKey := new$senderId;
  END IF;
  if (new$SenderRecordID is null)then
    new$SenderRecordIDKey := new$ID;
      
  else 
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_60 (tr_execdoccaption_bi_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$agreementinnernumber is not null) then
    BEGIN
      /*        , .. 
             ,    ,   
            ,     */
      select accepted, acceptdate     into
      agr_accepted$, agr_acceptdate$ from agreements
      where
      innernumber = new$agreementinnernumber and adjustmentnumber = 0
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*        */
    if (new$acceptdate is null and agr_accepted$ = 0 and agr_acceptdate$ is not null) then
      RaiseException('EX_Agr_Rejected');
    END IF;
    /*        */
    if (new$accepted = 1 and new$acceptdate is not null and
    (agr_accepted$ = 0 or agr_acceptdate$ is null)) then
      RaiseException('EX_Agr_NotAccepted');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_EXECDOCCAPTION_BI_500)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_EXECUTIONDOCUMENTSCAPTION (
    ID,
    DOCTYPE,
    DOCUMENTDATE,
    ACCEPTDATE,
    SUMMA,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    STEPNUMBER,
    FACIALACC_CLS,
    RECIPIENT_REF,
    REGISTRATIONTYPE,
    REESTRNUMBER,
    AGREEMENTINNERNUMBER,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXECDOCFINSUMMA,
    FACT,
    DOCNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REALID,
    INNERNUMBER,
    ADJUSTMENTREF,
    ADJUSTMENTNUMBER,
    ACCEPTED,
    LASTACCEPTED,
    LASTADJUSTMENT,
    AGREEMENTREF,
    NOTE,
    SUPPLIERSTOREDPROPS,
    SUPPLIER_REF,
    SUPPLIERACC_REF,
    REJECTCAUSE,
    INFONUMBER,
    NOTIFYDATE,
    NUMBERMONEYRESPONS,
    PURPORTDOC
  ) VALUES (
    new$ID,
    new$DOCTYPE,
    new$DOCUMENTDATE,
    new$ACCEPTDATE,
    new$SUMMA,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$STEPNUMBER,
    new$FACIALACC_CLS,
    new$RECIPIENT_REF,
    new$REGISTRATIONTYPE,
    new$REESTRNUMBER,
    new$AGREEMENTINNERNUMBER,
    new$REJECTCLS,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$REVIEWNOTE,
    new$DOCSTATEREF,
    new$RVERSION,
    new$EXECDOCFINSUMMA,
    new$FACT,
    new$DOCNUMBER,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$REALID,
    new$INNERNUMBER,
    new$ADJUSTMENTREF,
    new$ADJUSTMENTNUMBER,
    new$ACCEPTED,
    new$LASTACCEPTED,
    new$LASTADJUSTMENT,
    new$AGREEMENTREF,
    new$NOTE,
    new$SUPPLIERSTOREDPROPS,
    new$SUPPLIER_REF,
    new$SUPPLIERACC_REF,
    new$REJECTCAUSE,
    new$INFONUMBER,
    new$NOTIFYDATE,
    new$NUMBERMONEYRESPONS,
    new$PURPORTDOC);

-- - - - - - - - - - - - -
-- AI_0 (TR_ExecDocCaption_AI)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*       */
  /*     ,       */
  if ((new$AdjustmentRef is not null) and (new$LastAdjustment = 1)) then
    update ExecutionDocuMENTSCaption set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);        
    if (new$LastAccepted = 1) then
      update ExecutionDocuMENTSCaption set
      LastAccepted = 0,
      RVersion = -1
      where (ID = new$AdjustmentRef);
        
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_EXECDOCCAPTION_AI_500)
-- - - - - - - - - - - - -

-- 25.08.2004
  delete from DelRecIndexes where (TableID = 114) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_EXECUTIONDOCUMENTSCAPTIO_IU
  INSTEAD OF UPDATE
  ON EXECUTIONDOCUMENTSCAPTION
  FOR EACH ROW
DECLARE
  new$ID EXECUTIONDOCUMENTSCAPTION.ID%TYPE := :NEW.ID;
  new$DOCTYPE EXECUTIONDOCUMENTSCAPTION.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$DOCUMENTDATE EXECUTIONDOCUMENTSCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE EXECUTIONDOCUMENTSCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SUMMA EXECUTIONDOCUMENTSCAPTION.SUMMA%TYPE := :NEW.SUMMA;
  new$CREATERUSER EXECUTIONDOCUMENTSCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE EXECUTIONDOCUMENTSCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE EXECUTIONDOCUMENTSCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER EXECUTIONDOCUMENTSCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF EXECUTIONDOCUMENTSCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$STEPNUMBER EXECUTIONDOCUMENTSCAPTION.STEPNUMBER%TYPE := :NEW.STEPNUMBER;
  new$FACIALACC_CLS EXECUTIONDOCUMENTSCAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$RECIPIENT_REF EXECUTIONDOCUMENTSCAPTION.RECIPIENT_REF%TYPE := :NEW.RECIPIENT_REF;
  new$REGISTRATIONTYPE EXECUTIONDOCUMENTSCAPTION.REGISTRATIONTYPE%TYPE := :NEW.REGISTRATIONTYPE;
  new$REESTRNUMBER EXECUTIONDOCUMENTSCAPTION.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$AGREEMENTINNERNUMBER EXECUTIONDOCUMENTSCAPTION.AGREEMENTINNERNUMBER%TYPE := :NEW.AGREEMENTINNERNUMBER;
  new$REJECTCLS EXECUTIONDOCUMENTSCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS EXECUTIONDOCUMENTSCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID EXECUTIONDOCUMENTSCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID EXECUTIONDOCUMENTSCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REVIEWNOTE EXECUTIONDOCUMENTSCAPTION.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF EXECUTIONDOCUMENTSCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION EXECUTIONDOCUMENTSCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$EXECDOCFINSUMMA EXECUTIONDOCUMENTSCAPTION.EXECDOCFINSUMMA%TYPE := :NEW.EXECDOCFINSUMMA;
  new$FACT EXECUTIONDOCUMENTSCAPTION.FACT%TYPE := :NEW.FACT;
  new$DOCNUMBER EXECUTIONDOCUMENTSCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SENDERIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REALID EXECUTIONDOCUMENTSCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER EXECUTIONDOCUMENTSCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTREF EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ADJUSTMENTNUMBER EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$ACCEPTED EXECUTIONDOCUMENTSCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED EXECUTIONDOCUMENTSCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$LASTADJUSTMENT EXECUTIONDOCUMENTSCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$AGREEMENTREF EXECUTIONDOCUMENTSCAPTION.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$NOTE EXECUTIONDOCUMENTSCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$SUPPLIERSTOREDPROPS EXECUTIONDOCUMENTSCAPTION.SUPPLIERSTOREDPROPS%TYPE := :NEW.SUPPLIERSTOREDPROPS;
  new$SUPPLIER_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIER_REF%TYPE := :NEW.SUPPLIER_REF;
  new$SUPPLIERACC_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIERACC_REF%TYPE := :NEW.SUPPLIERACC_REF;
  new$REJECTCAUSE EXECUTIONDOCUMENTSCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$INFONUMBER EXECUTIONDOCUMENTSCAPTION.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$NOTIFYDATE EXECUTIONDOCUMENTSCAPTION.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$NUMBERMONEYRESPONS EXECUTIONDOCUMENTSCAPTION.NUMBERMONEYRESPONS%TYPE := :NEW.NUMBERMONEYRESPONS;
  new$PURPORTDOC EXECUTIONDOCUMENTSCAPTION.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  CntAgr$ NUMBER(10);
  CntStep$ NUMBER(10);
  agr_accepted$ NUMBER(10);
  agr_acceptdate$ NUMBER(10);
  CountExecDoc$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_EXECDOCCAPTION_BU)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$DocType is null) then 
    new$DocType := 0;
  END IF;
  if (new$Summa is null) then 
    new$Summa := 0;
  END IF;
  if (new$ExecDocFinSumma is null) then 
    new$ExecDocFinSumma := 0;  
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$RegistrationType is null) then 
    new$RegistrationType := 0;
  END IF;
  if (new$Fact is null) then 
    new$Fact := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      SELECT COUNT(                   Id
      ) INTO CNT$1
      from ExecutionDocumentsDetail
      where 
      (                   RecordIndex = :old.Id
      ) AND (ROWNUM = 1)                ;
      if ((CNT$1<> 0)         ) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      SELECT COUNT(                   Id
      ) INTO CNT$2
      from PaymentSchedule
      where
      (                   ExecutionRef = :old.Id
      ) AND (ROWNUM = 1)                ;
      if ((CNT$2<> 0)         ) then
        RaiseException('Ex_CantModufyBudget');    
      END IF;
    END IF;
  END IF;
  /*     ,        */
  if (new$InnerNumber is null) then
    new$InnerNumber := :old.InnerNumber;
  END IF;
  /* c,           */
  /* ,    */
  if (new$InnerNumber <> :old.InnerNumber or
  new$AdjustmentRef <> :old.AdjustmentRef or
  new$AdjustmentNumber <> :old.AdjustmentNumber) then
    RaiseException('EX_Agr_ChangeInnerNums');
  END IF;
  /*      id */  
  new$agreementinnernumber := null;
  if (new$agreementref is not null) then
    BEGIN
      select
      innernumber
      into new$agreementinnernumber     from agreements
      where
      id = new$agreementref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_EXECDOCCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;
          
    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_EXECDOCCAPTION_BU_10)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*     */
  if (:old.AcceptDate is not null and :old.Accepted = 0 and (new$Accepted = 1 or new$AcceptDate is null)) then
    RaiseException('EX_RollbackCancel');
  END IF;
      
  /*   ,     LastAccepted*/
  if (:old.AcceptDate is null and new$AcceptDate is not null and new$Accepted = 1) then 
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 1;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    END IF;
  END IF;
      
  /*    ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 1 and new$AcceptDate is null) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 0;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');  
    END IF;
  END IF;
      
  /*   ,     LastAdjustment  LastAccepted */
  if (new$AcceptDate is not null and new$Accepted = 0 and (:old.AcceptDate is null or :old.Accepted = 1)) then
    if (:old.LastAdjustment = 1) then
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    END IF;
    SELECT COUNT(                 Id
    ) INTO CNT$1
    from ExecutionDocumentsCaption
    where
    (                 InnerNumber = new$InnerNumber and AdjustmentNumber > 0
    ) AND (ROWNUM = 1)              ;
    /*          */
    if (new$AdjustmentNumber = 0 and 
    (CNT$1<> 0)       ) then
      RaiseException('EX_ExecDoc_PrimaryAgrHasNotify');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_40 (tr_execdoccaption_bu_40)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  if ((:old.AcceptDate is not null) and (new$AcceptDate is null)) then
    select count(ID) into CntAgr$ from Agreements where (CloseDoc = :old.ID) ;
    select count(ID) into CntStep$ from AgreementSteps where (CloseDoc = :old.ID) ;
    if ((CntAgr$ > 0) or (CntStep$ > 0)) then
      RaiseException('ex_CannotUpdateCloseDoc');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_60 (tr_execdoccaption_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$agreementinnernumber is not null) then
    BEGIN
      /*        , .. 
             ,    ,   
            ,     */
      select accepted, acceptdate     into
      agr_accepted$, agr_acceptdate$ from agreements
      where
      innernumber = new$agreementinnernumber and adjustmentnumber = 0
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*        */
    if (new$acceptdate is null and agr_accepted$ = 0 and agr_acceptdate$ is not null) then
      RaiseException('EX_Agr_Rejected');
    END IF;
    /*        */
    if (new$accepted = 1 and new$acceptdate is not null and
    (agr_accepted$ = 0 or agr_acceptdate$ is null)) then
      RaiseException('EX_Agr_NotAccepted');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_EXECDOCCAPTION_BU_200)
-- Create 04.10.2004
-- - - - - - - - - - - - -

  /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_EXECDOCCAPTION_BU_210)
-- Version 11.20.00.1
-- - - - - - - - - - - - -

  /*   */
  if (new$rejectcls is not null and new$accepted = 0) then
    /*         */
    select
    count(ffd.id)
    into CountExecDoc$     from
    facialfindetail ffd
    left join facialfincaption ffc on ffc.id = ffd.recordindex
    where
    (ffc.acceptdate is not null and (ffd.sourceexecdoc = new$id or ffd.destexecdoc = new$id))
    ;
    /*       */
    if (CountExecDoc$ <> 0) then
      RaiseException('ex_exedoc_useinfacialfindetail');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_EDCAPTION_BU_700)
-- Create 14.10.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_EXECUTIONDOCUMENTSCAPTION SET
    ID = new$ID,
    DOCTYPE = new$DOCTYPE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    SUMMA = new$SUMMA,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    STEPNUMBER = new$STEPNUMBER,
    FACIALACC_CLS = new$FACIALACC_CLS,
    RECIPIENT_REF = new$RECIPIENT_REF,
    REGISTRATIONTYPE = new$REGISTRATIONTYPE,
    REESTRNUMBER = new$REESTRNUMBER,
    AGREEMENTINNERNUMBER = new$AGREEMENTINNERNUMBER,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXECDOCFINSUMMA = new$EXECDOCFINSUMMA,
    FACT = new$FACT,
    DOCNUMBER = new$DOCNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REALID = new$REALID,
    INNERNUMBER = new$INNERNUMBER,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    ACCEPTED = new$ACCEPTED,
    LASTACCEPTED = new$LASTACCEPTED,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    AGREEMENTREF = new$AGREEMENTREF,
    NOTE = new$NOTE,
    SUPPLIERSTOREDPROPS = new$SUPPLIERSTOREDPROPS,
    SUPPLIER_REF = new$SUPPLIER_REF,
    SUPPLIERACC_REF = new$SUPPLIERACC_REF,
    REJECTCAUSE = new$REJECTCAUSE,
    INFONUMBER = new$INFONUMBER,
    NOTIFYDATE = new$NOTIFYDATE,
    NUMBERMONEYRESPONS = new$NUMBERMONEYRESPONS,
    PURPORTDOC = new$PURPORTDOC
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_0 (TR_ExecDocCaption_AU)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*       */
  /*     ,       */
  if ((new$AdjustmentRef is not null) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update ExecutionDocuMENTSCaption set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentRef is not null) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update ExecutionDocuMENTSCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_EXECDOCCAPTION_AU_30)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$Accepted <> :old.Accepted) or 
  (new$AcceptDate is not null and :old.AcceptDate is null) or 
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where ExecutionRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_EXECDOCCAPTION_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (114, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=114) and (RecordId=new$ID);
  end if;

END;
/
commit work 
/

-- #########################################################
-- #########################################################
-- Add_StoredContent_BudgetData.sql
-- #########################################################
-- #########################################################

/*   STOREDCONTENT (  )   */
ALTER TABLE BUDGETDATA ADD (
  STOREDCONTENT VARCHAR2(4000)
)
/
COMMIT WORK
/


-- #########################################################
-- #########################################################
-- Add_StoredContent_BudNotify.sql
-- #########################################################
-- #########################################################

/*   STOREDCONTENT (  )   */
ALTER TABLE TB_BUDNOTIFY ADD (
  STOREDCONTENT VARCHAR2(4000)
)
/

CREATE OR REPLACE VIEW BUDNOTIFY (
  ID,
  DAT,
  DOCDAT,
  NOTIFYTYPE,
  BUDGETREF,
  DOCBASE,
  VARIANT,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  SENDERID,
  SENDERRECORDID,
  ANUMBER,
  ATYPE,
  DOCUMENTSTATE,
  USERSVISA,
  DATEINPUT,
  ORGREF,
  REJECTCLS,
  PLANDOCTYPE,
  RECORDINDEX,
  STIMATEID,
  CRYPTOSTATUS,
  RVERSION,
  DOCSTATEREF,
  DOCNUMBER,
  FACIALACCCLS,
  LASTEXTRCHANGE,
  BIDNUMBER,
  FAXDOCCOUNT,
  PLANKIND,
  ASSIGNMENTSOURCE,
  BA_LBO_FLAG,
  KPPERIOD,
  CLSTYPE,
  DATE_UTV_PP,
  PROGINDEX,
  NOTE,
  NOTE2,
  DOCCHANGEDATE,
  SIGNERS,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  EXTID,
  EXTROOTID,
  NOTE1,
  REJECTNOTE,
  STOREDCONTENT)
AS
  SELECT
    ID,
    DAT,
    DOCDAT,
    NOTIFYTYPE,
    BUDGETREF,
    DOCBASE,
    VARIANT,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SENDERID,
    SENDERRECORDID,
    ANUMBER,
    ATYPE,
    DOCUMENTSTATE,
    USERSVISA,
    DATEINPUT,
    ORGREF,
    REJECTCLS,
    PLANDOCTYPE,
    RECORDINDEX,
    STIMATEID,
    CRYPTOSTATUS,
    RVERSION,
    DOCSTATEREF,
    DOCNUMBER,
    FACIALACCCLS,
    LASTEXTRCHANGE,
    BIDNUMBER,
    FAXDOCCOUNT,
    PLANKIND,
    ASSIGNMENTSOURCE,
    BA_LBO_FLAG,
    KPPERIOD,
    CLSTYPE,
    DATE_UTV_PP,
    PROGINDEX,
    NOTE,
    NOTE2,
    DOCCHANGEDATE,
    SIGNERS,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    EXTID,
    EXTROOTID,
    NOTE1,
    REJECTNOTE,
    STOREDCONTENT
  FROM TB_BUDNOTIFY
/

CREATE OR REPLACE TRIGGER TR_BUDNOTIFY_ID
  INSTEAD OF DELETE
  ON BUDNOTIFY
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_BUDNOTIFY_BD)
-- - - - - - - - - - - - -

  delete from BudgetData where (RecordIndex = :old.id);

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_BUDNOTIFY
  WHERE id=:old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_BUDNOTIFY_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(tableid, recordid, deletedate, createruser, progindex) values(28, :old.id, SYSDATE, user, :old.progindex);

END;
/

CREATE OR REPLACE TRIGGER TR_BUDNOTIFY_II
  INSTEAD OF INSERT
  ON BUDNOTIFY
  FOR EACH ROW
DECLARE
  new$ID BUDNOTIFY.ID%TYPE := :NEW.ID;
  new$DAT BUDNOTIFY.DAT%TYPE := :NEW.DAT;
  new$DOCDAT BUDNOTIFY.DOCDAT%TYPE := :NEW.DOCDAT;
  new$NOTIFYTYPE BUDNOTIFY.NOTIFYTYPE%TYPE := :NEW.NOTIFYTYPE;
  new$BUDGETREF BUDNOTIFY.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DOCBASE BUDNOTIFY.DOCBASE%TYPE := :NEW.DOCBASE;
  new$VARIANT BUDNOTIFY.VARIANT%TYPE := :NEW.VARIANT;
  new$CREATERUSER BUDNOTIFY.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE BUDNOTIFY.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE BUDNOTIFY.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER BUDNOTIFY.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SENDERID BUDNOTIFY.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID BUDNOTIFY.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$ANUMBER BUDNOTIFY.ANUMBER%TYPE := :NEW.ANUMBER;
  new$ATYPE BUDNOTIFY.ATYPE%TYPE := :NEW.ATYPE;
  new$DOCUMENTSTATE BUDNOTIFY.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA BUDNOTIFY.USERSVISA%TYPE := :NEW.USERSVISA;
  new$DATEINPUT BUDNOTIFY.DATEINPUT%TYPE := :NEW.DATEINPUT;
  new$ORGREF BUDNOTIFY.ORGREF%TYPE := :NEW.ORGREF;
  new$REJECTCLS BUDNOTIFY.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$PLANDOCTYPE BUDNOTIFY.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$RECORDINDEX BUDNOTIFY.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$STIMATEID BUDNOTIFY.STIMATEID%TYPE := :NEW.STIMATEID;
  new$CRYPTOSTATUS BUDNOTIFY.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$RVERSION BUDNOTIFY.RVERSION%TYPE := :NEW.RVERSION;
  new$DOCSTATEREF BUDNOTIFY.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$DOCNUMBER BUDNOTIFY.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$FACIALACCCLS BUDNOTIFY.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$LASTEXTRCHANGE BUDNOTIFY.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$BIDNUMBER BUDNOTIFY.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT BUDNOTIFY.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$PLANKIND BUDNOTIFY.PLANKIND%TYPE := :NEW.PLANKIND;
  new$ASSIGNMENTSOURCE BUDNOTIFY.ASSIGNMENTSOURCE%TYPE := :NEW.ASSIGNMENTSOURCE;
  new$BA_LBO_FLAG BUDNOTIFY.BA_LBO_FLAG%TYPE := :NEW.BA_LBO_FLAG;
  new$KPPERIOD BUDNOTIFY.KPPERIOD%TYPE := :NEW.KPPERIOD;
  new$CLSTYPE BUDNOTIFY.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$DATE_UTV_PP BUDNOTIFY.DATE_UTV_PP%TYPE := :NEW.DATE_UTV_PP;
  new$PROGINDEX BUDNOTIFY.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE BUDNOTIFY.NOTE%TYPE := :NEW.NOTE;
  new$NOTE2 BUDNOTIFY.NOTE2%TYPE := :NEW.NOTE2;
  new$DOCCHANGEDATE BUDNOTIFY.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$SIGNERS BUDNOTIFY.SIGNERS%TYPE := :NEW.SIGNERS;
  new$SENDERIDKEY BUDNOTIFY.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY BUDNOTIFY.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXTID BUDNOTIFY.EXTID%TYPE := :NEW.EXTID;
  new$EXTROOTID BUDNOTIFY.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$NOTE1 BUDNOTIFY.NOTE1%TYPE := :NEW.NOTE1;
  new$REJECTNOTE BUDNOTIFY.REJECTNOTE%TYPE := :NEW.REJECTNOTE;
  new$STOREDCONTENT BUDNOTIFY.STOREDCONTENT%TYPE := :NEW.STOREDCONTENT;
--
  UseFax$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_BUDNOTIFY_BI)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$NotifyType is null) then
    new$NotifyType := 0;
  END IF;
  if (new$DocBase is null) then
    new$DocBase := 0;
  END IF;
  if (new$PlanKind is null) then
    new$PlanKind := 0;
  END IF;
  if (new$AssignmentSource is null) then
    new$AssignmentSource := 0;
  END IF;
  if ((new$PlanDocType is null) or (new$PlanDocType < 100)) then
    new$PlanDocType := 200;
  END IF;
  if ((new$PlanDocType > 99)and(new$PlanDocType < 200)) then
    new$AType := 0;

  else
    new$AType := 1;
  END IF;
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  if (new$BA_LBO_Flag is null) then
    new$BA_LBO_Flag := 0;
  END IF;
  if (new$KPPeriod is null) then
    new$KPPeriod := 0;
  END IF;
  if (new$ClsType is null) then
    new$ClsType := 3;
  END IF;
  if ((new$ProgIndex = 262)and(new$FacialAccCLS <> 0)and(new$OrgRef is null)) then
    BEGIN
      /*         
             - \  */
      select
      fac.ORG_REF
      into new$OrgRef     from
      FacialACC_CLS fac
      where
      (fac.ID = new$FacialAccCLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*         */
  if ((new$Dat is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_BUDNOTIFY_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;

  else
    new$SenderIDKey := new$SenderID;
  END IF;

  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;

  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_430 (TR_BUDNOTIFY_BI_430)
-- Create 18.09.2006
-- - - - - - - - - - - - -

  IF (NEW$SenderID IS NOT NULL) THEN
    /*        */
    GetIntConst(30, 19, UseFax$);
    IF ((NEW$BidNumber IS NULL) AND (UseFax$ = 1)) THEN
      NEW$BidNumber := NEW$ANumber;
    end if;
    NEW$FaxDocCount := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_BUDNOTIFY_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$DocChangeDate := new$UpdateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_BUDNOTIFY (
    ID,
    DAT,
    DOCDAT,
    NOTIFYTYPE,
    BUDGETREF,
    DOCBASE,
    VARIANT,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SENDERID,
    SENDERRECORDID,
    ANUMBER,
    ATYPE,
    DOCUMENTSTATE,
    USERSVISA,
    DATEINPUT,
    ORGREF,
    REJECTCLS,
    PLANDOCTYPE,
    RECORDINDEX,
    STIMATEID,
    CRYPTOSTATUS,
    RVERSION,
    DOCSTATEREF,
    DOCNUMBER,
    FACIALACCCLS,
    LASTEXTRCHANGE,
    BIDNUMBER,
    FAXDOCCOUNT,
    PLANKIND,
    ASSIGNMENTSOURCE,
    BA_LBO_FLAG,
    KPPERIOD,
    CLSTYPE,
    DATE_UTV_PP,
    PROGINDEX,
    NOTE,
    NOTE2,
    DOCCHANGEDATE,
    SIGNERS,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    EXTID,
    EXTROOTID,
    NOTE1,
    REJECTNOTE,
    STOREDCONTENT
  ) VALUES (
    new$ID,
    new$DAT,
    new$DOCDAT,
    new$NOTIFYTYPE,
    new$BUDGETREF,
    new$DOCBASE,
    new$VARIANT,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$SENDERID,
    new$SENDERRECORDID,
    new$ANUMBER,
    new$ATYPE,
    new$DOCUMENTSTATE,
    new$USERSVISA,
    new$DATEINPUT,
    new$ORGREF,
    new$REJECTCLS,
    new$PLANDOCTYPE,
    new$RECORDINDEX,
    new$STIMATEID,
    new$CRYPTOSTATUS,
    new$RVERSION,
    new$DOCSTATEREF,
    new$DOCNUMBER,
    new$FACIALACCCLS,
    new$LASTEXTRCHANGE,
    new$BIDNUMBER,
    new$FAXDOCCOUNT,
    new$PLANKIND,
    new$ASSIGNMENTSOURCE,
    new$BA_LBO_FLAG,
    new$KPPERIOD,
    new$CLSTYPE,
    new$DATE_UTV_PP,
    new$PROGINDEX,
    new$NOTE,
    new$NOTE2,
    new$DOCCHANGEDATE,
    new$SIGNERS,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$EXTID,
    new$EXTROOTID,
    new$NOTE1,
    new$REJECTNOTE,
    new$STOREDCONTENT);

-- - - - - - - - - - - - -
-- AI_500 (TR_BUDNOTIFY_AI_500)
-- - - - - - - - - - - - -

        delete from DelRecIndexes where (TableID = 28) and (RecordID = NEW$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_BUDNOTIFY_IU
  INSTEAD OF UPDATE
  ON BUDNOTIFY
  FOR EACH ROW
DECLARE
  new$ID BUDNOTIFY.ID%TYPE := :NEW.ID;
  new$DAT BUDNOTIFY.DAT%TYPE := :NEW.DAT;
  new$DOCDAT BUDNOTIFY.DOCDAT%TYPE := :NEW.DOCDAT;
  new$NOTIFYTYPE BUDNOTIFY.NOTIFYTYPE%TYPE := :NEW.NOTIFYTYPE;
  new$BUDGETREF BUDNOTIFY.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DOCBASE BUDNOTIFY.DOCBASE%TYPE := :NEW.DOCBASE;
  new$VARIANT BUDNOTIFY.VARIANT%TYPE := :NEW.VARIANT;
  new$CREATERUSER BUDNOTIFY.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE BUDNOTIFY.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE BUDNOTIFY.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER BUDNOTIFY.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SENDERID BUDNOTIFY.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID BUDNOTIFY.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$ANUMBER BUDNOTIFY.ANUMBER%TYPE := :NEW.ANUMBER;
  new$ATYPE BUDNOTIFY.ATYPE%TYPE := :NEW.ATYPE;
  new$DOCUMENTSTATE BUDNOTIFY.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA BUDNOTIFY.USERSVISA%TYPE := :NEW.USERSVISA;
  new$DATEINPUT BUDNOTIFY.DATEINPUT%TYPE := :NEW.DATEINPUT;
  new$ORGREF BUDNOTIFY.ORGREF%TYPE := :NEW.ORGREF;
  new$REJECTCLS BUDNOTIFY.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$PLANDOCTYPE BUDNOTIFY.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$RECORDINDEX BUDNOTIFY.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$STIMATEID BUDNOTIFY.STIMATEID%TYPE := :NEW.STIMATEID;
  new$CRYPTOSTATUS BUDNOTIFY.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$RVERSION BUDNOTIFY.RVERSION%TYPE := :NEW.RVERSION;
  new$DOCSTATEREF BUDNOTIFY.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$DOCNUMBER BUDNOTIFY.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$FACIALACCCLS BUDNOTIFY.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$LASTEXTRCHANGE BUDNOTIFY.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$BIDNUMBER BUDNOTIFY.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$FAXDOCCOUNT BUDNOTIFY.FAXDOCCOUNT%TYPE := :NEW.FAXDOCCOUNT;
  new$PLANKIND BUDNOTIFY.PLANKIND%TYPE := :NEW.PLANKIND;
  new$ASSIGNMENTSOURCE BUDNOTIFY.ASSIGNMENTSOURCE%TYPE := :NEW.ASSIGNMENTSOURCE;
  new$BA_LBO_FLAG BUDNOTIFY.BA_LBO_FLAG%TYPE := :NEW.BA_LBO_FLAG;
  new$KPPERIOD BUDNOTIFY.KPPERIOD%TYPE := :NEW.KPPERIOD;
  new$CLSTYPE BUDNOTIFY.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$DATE_UTV_PP BUDNOTIFY.DATE_UTV_PP%TYPE := :NEW.DATE_UTV_PP;
  new$PROGINDEX BUDNOTIFY.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE BUDNOTIFY.NOTE%TYPE := :NEW.NOTE;
  new$NOTE2 BUDNOTIFY.NOTE2%TYPE := :NEW.NOTE2;
  new$DOCCHANGEDATE BUDNOTIFY.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$SIGNERS BUDNOTIFY.SIGNERS%TYPE := :NEW.SIGNERS;
  new$SENDERIDKEY BUDNOTIFY.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY BUDNOTIFY.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXTID BUDNOTIFY.EXTID%TYPE := :NEW.EXTID;
  new$EXTROOTID BUDNOTIFY.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$NOTE1 BUDNOTIFY.NOTE1%TYPE := :NEW.NOTE1;
  new$REJECTNOTE BUDNOTIFY.REJECTNOTE%TYPE := :NEW.REJECTNOTE;
  new$STOREDCONTENT BUDNOTIFY.STOREDCONTENT%TYPE := :NEW.STOREDCONTENT;
--
  IsReject$ NUMBER(10);
  DetCount$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_BUDNOTIFY_BU)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$NotifyType is null) then
    new$NotifyType := 0;
  END IF;
  if (new$DocBase is null) then
    new$DocBase := 0;
  END IF;
  if (new$PlanKind is null) then
    new$PlanKind := 0;
  END IF;
  if (new$AssignmentSource is null) then
    new$AssignmentSource := 0;
  END IF;
  if ((new$PlanDocType > 99)and(new$PlanDocType < 200)) then
    new$AType := 0;

  else
    if (new$PlanDocType > 199) then
      new$AType := 1;
    END IF;
  END IF;
  if (new$PlanDocType is null) then
    if (new$AType = 1) then
      new$PlanDocType := 200;

    else
      new$PlanDocType := 100;

    END IF;
  END IF;
  /*    */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)              into DetCount$ from BudgetData where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  if (new$BA_LBO_Flag is null) then
    new$BA_LBO_Flag := 0;
  END IF;
  if (new$KPPeriod is null) then
    new$KPPeriod := 0;
  END IF;
  if (new$ClsType is null) then
    new$ClsType := 3;
  END IF;
  if ((new$ProgIndex = 262)and(new$FacialAccCLS <> :old.FacialAccCLS)
  and(new$FacialAccCLS <> 0)) then
    BEGIN
      /*     -    \   
             - \  ,
           ,   \  */
      select
      fac.ORG_REF
      into new$OrgRef     from
      FacialACC_CLS fac
      where
      (fac.ID = new$FacialAccCLS)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*        */
  if ((new$Dat is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_BUDNOTIFY_BU_200)
-- Create 08.02.2005
-- - - - - - - - - - - - -

   --     
  IF (:OLD.DOCSTATEREF <> NEW$DOCSTATEREF) THEN
    INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
      VALUES (NEW$ID, :OLD.DOCSTATEREF, NEW$DOCSTATEREF);
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_BUDNOTIFY_BU_300)
-- Create 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from BudgetData d where d.RecordIndex = :new.id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_BUDNOTIFY_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

  IF (NEW$RVersion IS NULL) THEN
    NEW$RVersion := 1;
  ELSIF ((NEW$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
    NEW$RVersion := :OLD.RVersion;
  ELSE
    NEW$RVersion := :OLD.RVersion + 1;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_BUDNOTIFY SET
    ID = new$ID,
    DAT = new$DAT,
    DOCDAT = new$DOCDAT,
    NOTIFYTYPE = new$NOTIFYTYPE,
    BUDGETREF = new$BUDGETREF,
    DOCBASE = new$DOCBASE,
    VARIANT = new$VARIANT,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    ANUMBER = new$ANUMBER,
    ATYPE = new$ATYPE,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    DATEINPUT = new$DATEINPUT,
    ORGREF = new$ORGREF,
    REJECTCLS = new$REJECTCLS,
    PLANDOCTYPE = new$PLANDOCTYPE,
    RECORDINDEX = new$RECORDINDEX,
    STIMATEID = new$STIMATEID,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    RVERSION = new$RVERSION,
    DOCSTATEREF = new$DOCSTATEREF,
    DOCNUMBER = new$DOCNUMBER,
    FACIALACCCLS = new$FACIALACCCLS,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    BIDNUMBER = new$BIDNUMBER,
    FAXDOCCOUNT = new$FAXDOCCOUNT,
    PLANKIND = new$PLANKIND,
    ASSIGNMENTSOURCE = new$ASSIGNMENTSOURCE,
    BA_LBO_FLAG = new$BA_LBO_FLAG,
    KPPERIOD = new$KPPERIOD,
    CLSTYPE = new$CLSTYPE,
    DATE_UTV_PP = new$DATE_UTV_PP,
    PROGINDEX = new$PROGINDEX,
    NOTE = new$NOTE,
    NOTE2 = new$NOTE2,
    DOCCHANGEDATE = new$DOCCHANGEDATE,
    SIGNERS = new$SIGNERS,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    EXTID = new$EXTID,
    EXTROOTID = new$EXTROOTID,
    NOTE1 = new$NOTE1,
    REJECTNOTE = new$REJECTNOTE,
    STOREDCONTENT = new$STOREDCONTENT
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_300 (TR_BudNotify_AU_300)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((new$ClsType <> :old.ClsType)and(new$ClsType <> 3)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$ClsType = 0) then
      update BudgetData set
      KD = 0,
      IFS = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 1) then
      update BudgetData set
      KD = 0,
      KVSR = 0,
      KFSR = 0,
      KCSR = 0,
      KVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 2) then
      update BudgetData set
      IFS = 0,
      KVSR = 0,
      KFSR = 0,
      KCSR = 0,
      KVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);

    END IF;
  END IF;
  if ((new$ProgIndex in (252, 253))and(new$FacialAccCLS <> :old.FacialAccCLS)) then
    update BudgetData set
    facialacc_cls = new$FacialAccCLS
    where
    RecordIndex = new$id;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_BUDNOTIFY_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (NEW$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (28, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=28) and (RecordId=NEW$ID);
  end if;

END;
/
COMMIT WORK
/



-- #########################################################
-- #########################################################
-- Add_Dual_Rights.sql
-- #########################################################
-- #########################################################

/*          +     +  */
CREATE OR REPLACE procedure AddObjKind(New_ID$ NUMBER,New_Name$ VARCHAR2)
AS
  CNT$1 NUMBER(10);
BEGIN
  SELECT COUNT(id ) INTO CNT$1
  from objectkind where (Id=New_ID$  and Name=New_Name$) AND (ROWNUM = 1);
  if (not (CNT$1<> 0))
  then
    insert into objectkind (Id, Name)
    values (New_ID$, New_Name$);
  END IF;
END;
/
commit work
/
CREATE OR REPLACE procedure AddDBRight(New_RightKindRef$ NUMBER,New_ObjectKindRef$ NUMBER)
AS
  CNT$1 NUMBER(10);
BEGIN
  SELECT COUNT(id ) INTO CNT$1
  from DBRights where (RightKindRef=New_RightKindRef$  and ObjectKindRef=New_ObjectKindRef$) AND (ROWNUM = 1);
  if (not (CNT$1<> 0))
  then
    insert into DBRights (RightKindRef, ObjectKindRef)
    values (New_RightKindRef$, New_ObjectKindRef$);
  END IF;
END;
/
commit work
/
CALL AddObjKind(29000000, ' +  ')
/
CALL AddObjKind(30000000, ' +  ')
/
commit work 
/
/*      +  */
CALL AddDBRight(2, 29000000)
/
/*      +  */
CALL AddDBRight(2, 30000000)
/
commit work 
/
drop procedure AddObjKind
/
drop procedure AddDBRight
/
commit work 
/
commit work
/

-- #########################################################
-- #########################################################
-- AddAccInBuhAccPlan.sql
-- #########################################################
-- #########################################################

/*   501.9  503.9   " "        */
CREATE OR REPLACE PROCEDURE AddAccInBuhAccPlan(NewBuhAcc$$ NUMBER,NewName$ VARCHAR2)
AS
  NewBuhAcc$ NUMBER(10) := NewBuhAcc$$;
  CNT$1 NUMBER(10);
BEGIN
  NewBuhAcc$ := NewBuhAcc$  * 100;
  SELECT COUNT(ID ) INTO CNT$1
  FROM BuhAccPlan WHERE ((BuhAcc = NewBuhAcc$) AND (ECCLS = '000') AND (CLSTYPE = 5)) AND (ROWNUM = 1);
  IF (NOT (CNT$1<> 0)) THEN
    INSERT INTO BuhAccPlan (BuhAcc, Name, ECCLS, CLSTYPE)
    VALUES (NewBuhAcc$, NewName$, '000', 5);
  END IF;
END;
/
COMMIT WORK 
/
CALL AddAccInBuhAccPlan(50190, '       (   )') 
/
CALL AddAccInBuhAccPlan(50191, '        (   )') 
/
CALL AddAccInBuhAccPlan(50192, '       (   ),  ') 
/
CALL AddAccInBuhAccPlan(50193, '          (   )') 
/
CALL AddAccInBuhAccPlan(50194, '        (   )') 
/
CALL AddAccInBuhAccPlan(50195, '        (   )') 
/
CALL AddAccInBuhAccPlan(50196, '         (   )') 
/
CALL AddAccInBuhAccPlan(50199, '        (   )') 
/
CALL AddAccInBuhAccPlan(50390, '      (   )') 
/
CALL AddAccInBuhAccPlan(50391, '       (   )') 
/
CALL AddAccInBuhAccPlan(50392, '      (   ),  ') 
/
CALL AddAccInBuhAccPlan(50393, '              (   )') 
/
CALL AddAccInBuhAccPlan(50394, '       (   )') 
/
CALL AddAccInBuhAccPlan(50395, '       (   )') 
/
CALL AddAccInBuhAccPlan(50396, '        (   )') 
/
CALL AddAccInBuhAccPlan(50399, '       (   )') 
/
DROP PROCEDURE AddAccInBuhAccPlan 
/
COMMIT WORK 
/

-- #########################################################
-- #########################################################
-- Add_StoredContent_UnionNotifyCpt.sql
-- #########################################################
-- #########################################################

/*   STOREDCONTENT (  )   */
ALTER TABLE UNIONNOTIFYCAPTION ADD (
  STOREDCONTENT VARCHAR2(4000)
)
/
COMMIT WORK
/



-- #########################################################
-- #########################################################
-- Add_StoredContent_UnionNotifyDet.sql
-- #########################################################
-- #########################################################

/*   STOREDCONTENT (  )   */
ALTER TABLE UNIONNOTIFYDETAIL ADD (
  STOREDCONTENT VARCHAR2(4000)
)
/
COMMIT WORK
/


-- #########################################################
-- #########################################################
-- AddUseNRIConst.sql
-- #########################################################
-- #########################################################

/*     " ",       */
CREATE OR REPLACE procedure AddUseNRIConst
AS
  vUseNRI$ NUMBER(10);
BEGIN
  select
  count(id)
  into vUseNRI$   from intconst
  where (progindex = 53) and (constindex = 1)
  ;
  if (vUseNRI$  = 0) then
    insert into intconst
    (progindex, constindex, constvalue, note)
    values
    (53,1,0,' ');
  END IF;
END;
/
CALL AddUseNRIConst()
/
drop procedure AddUseNRIConst
/
commit work
/

-- #########################################################
-- #########################################################
-- UpdDocFields_12.00.00_Ora.sql
-- #########################################################
-- #########################################################


--  : 110000 - 120000.     14.11.2016 19:20:28.
CREATE OR REPLACE PROCEDURE ImportDocType (
   ID_               NUMBER,
   PROGINDEX_        NUMBER,
   NAME_             VARCHAR2,
   USESTATE_         NUMBER,
   DBTABLE_          VARCHAR2,
   NEEDEDS_          NUMBER,
   LOCKMASK_         NUMBER,
   DEFAULTACTIONMACROSNAME_ VARCHAR2,
   DOCUMENTKIND_     NUMBER,
   SHORTNAME_         VARCHAR2
) IS
   IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
     INTO IDExists$
     FROM DocumentTypes
    WHERE (ID = ID_);

  IF (IDExists$ = 0) THEN
     INSERT INTO DocumentTypes
                 (ID, PROGINDEX, NAME, USESTATE, DBTABLE, NEEDEDS, LOCKMASK, DEFAULTACTIONMACROSNAME, DOCUMENTKIND, SHORTNAME)
          VALUES (ID_, PROGINDEX_, NAME_, USESTATE_, DBTABLE_, NEEDEDS_, LOCKMASK_, DEFAULTACTIONMACROSNAME_, DOCUMENTKIND_, SHORTNAME_);
  else
      Update documenttypes set
        Name=Name_,
		    DBTABLE=DBTABLE_,
        LockMask=LockMask_,
        DEFAULTACTIONMACROSNAME=DEFAULTACTIONMACROSNAME_,
        DOCUMENTKIND=DOCUMENTKIND_,
        SHORTNAME=SHORTNAME_,
	      PROGINDEX=PROGINDEX_
      where (id=ID_)
        and (
          (Name<>Name_) or
          ((LockMask is null) and (LockMask_ is not null)) or
          ((LockMask is not null) and (LockMask_ is null)) or
          ((LockMask is not null) and (LockMask_ is not null) and (LockMask <> LockMask_)) or
          (DEFAULTACTIONMACROSNAME is null) or
          (DOCUMENTKIND<>DOCUMENTKIND_) or 
          (SHORTNAME is null) or 
          (SHORTNAME<>SHORTNAME_) or
          (PROGINDEX <> PROGINDEX_) or 
          ((DBTABLE is null) and (DBTABLE_ is not null)) or
          ((DBTABLE is not null) and (DBTABLE_ is null)) or
          ((DBTABLE is not null) and (DBTABLE_ is not null) and (DBTABLE <> DBTABLE_))
        );
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE UPDATEINTERFACES (
  CLS_   NUMBER,
  NOTE_  VARCHAR2,
  GUID_  VARCHAR2,
  PARAM_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT (ID)
   INTO IDEXISTS$
   FROM INTERFACES
  WHERE (GUID=GUID_);
  
  IF (IDExists$ = 0)  THEN
    INSERT INTO INTERFACES
      (CLS,NOTE,GUID,PARAM)
    VALUES
      (CLS_,NOTE_,GUID_,PARAM_);
  ELSE
    IF ((PARAM_ ='')OR(PARAM_ IS NULL)) THEN 
      UPDATE INTERFACES SET
        CLS = CLS_
      WHERE (GUID=GUID_) AND ((CLS<> CLS_)OR(CLS IS NULL));
    ELSE 
      UPDATE INTERFACES SET
        CLS = CLS_
      WHERE (GUID=GUID_) AND (PARAM=PARAM_) AND ((CLS<> CLS_)OR(CLS IS NULL));
    END IF;
  END IF;
END;
/

--   
CALL ImportDocType(0, 0, ' ', 0, '', 0,0,'',30000,'') ;

CALL ImportDocType(101, 223, '   ', 0, ' ', 0,-1,'',10200,'') ;

CALL ImportDocType(200, 0, '  ()', 0, '', 0,0,'',30000,'') ;

CALL ImportDocType(201, 32, '   ()', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL ImportDocType(202, 260, ' ()', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL ImportDocType(203, 261, '  ()', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL ImportDocType(204, 262, ' , ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL ImportDocType(209, 274, ' ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL UpdateInterfaces(209, ' ', '{DA309359-EF6B-4D29-AC0D-309040B5CDB6}', '') ;

CALL ImportDocType(210, 252, ' ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'') ;

CALL UpdateInterfaces(210, ' ', '{2EF0F811-E21F-4ADB-BC7E-A3A9B16059A4}', '') ;

CALL ImportDocType(211, 275, ' ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL UpdateInterfaces(211, ' ', '{AE8281A0-BE7F-4F3A-90BD-A7831E8D842F}', '') ;

CALL ImportDocType(212, 276, '  , ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL UpdateInterfaces(212, '  , ', '{B743C24B-6E28-4C9C-B3CA-16AC6E529D07}', '') ;

CALL ImportDocType(300, 0, '  ', 0, '', 0,0,'',30000,'') ;

CALL ImportDocType(302, 63, '  \', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(304, 64, '  ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(308, 67, ' ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL UpdateInterfaces(308, ' ', '{B50F2C63-9CF4-42C3-8062-E355EABD53E4}', '') ;

CALL ImportDocType(311, 68, '   ', 0, 'FacialFinCaption', 0,-1,'_',10100,'_') ;

CALL ImportDocType(312, 69, '    ', 0, 'FacialFinCaption', 0,-1,'_',10100,'_') ;

CALL ImportDocType(314, 70, '   ', 0, 'FacialFinCaption', 0,-1,'_',10100,'_') ;

CALL ImportDocType(315, 71, '     ', 0, 'FacialFinCaption', 0,-1,'_',10200,'_') ;

CALL ImportDocType(322, 73, '  ', 0, 'FacialFinCaption', 0,-1,'_',10200,'') ;

CALL ImportDocType(323, 75, ' ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(324, 76, ' ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(802, 0, '  ()', 0, ' ', 0,-1,'',10200,'_') ;

CALL ImportDocType(803, 0, '    ', 0, ' ', 0,-1,'',10200,'_') ;

CALL ImportDocType(804, 0, '  ', 0, ' ', 0,-1,'',10200,'_') ;

CALL ImportDocType(900, 0, '', 0, '', 0,0,'',30000,'') ;

CALL ImportDocType(902, 0, '  ()', 0, ' ', 0,-1,'',10200,'_') ;

CALL ImportDocType(903, 45, '  ', 0, ' ', 0,-1,'',10100,'_') ;

CALL ImportDocType(905, 0, '  ', 0, ' ', 0,-1,'',10200,'_') ;

CALL ImportDocType(906, 41, '  ()', 0, ' ', 0,-1,'',10200,'_') ;

CALL ImportDocType(907, 0, '  ()', 0, ' ', 0,-1,'',10200,'_') ;

CALL ImportDocType(1201, 0, ' ', 0, ' ', 0,-1,'',10200,'') ;

CALL ImportDocType(1601, 224, ' ', 0, 'Promise_Caption', 0,-1,'_',10100,'') ;

CALL ImportDocType(1809, 0, '     ', 0, 'BANKEXCH_SUBSTITUTION', 0,0,'',10200,'') ;

CALL UpdateInterfaces(1809, '     ', '{84AB1481-04A6-4885-9524-B0689D95F35A}', '') ;

CALL ImportDocType(1816, 0, '  ', 0, '', 0,-1,'',10200,'') ;

CALL UpdateInterfaces(1816, '  ', '{584B1826-AD94-47DC-A420-B5E42F2CA7D7}', '') ;

CALL ImportDocType(2201, 46, '  ()', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL ImportDocType(2502, 304, '', 0, 'Agreements', 0,-65537,'',10100,'') ;

CALL ImportDocType(2504, 314, ' ', 0, 'Agreements', 0,-65537,'',10100,'') ;

CALL ImportDocType(3001, 230, '   ', 0, 'TenderCaption', 0,-65537,'',10100,'') ;

CALL ImportDocType(3002, 0, '', 0, 'TenderResultCaption', 0,0,'',3,'') ;

CALL ImportDocType(3004, 0, ' ', 0, 'TenderProposal', 0,0,'',3,' ') ;

CALL ImportDocType(3005, 240, '-', 0, 'TenderCaption', 0,127,'',10100,'') ;

CALL ImportDocType(3006, 241, ' -', 0, 'TenderCaption', 0,-65537,'',10100,'') ;

CALL ImportDocType(3010, 242, ' ', 0, 'TenderCaption', 0,-1,'',10100,'') ;

CALL ImportDocType(3011, 243, '  ', 0, 'TenderCaption', 0,-1,'',10100,'') ;

CALL ImportDocType(4403, 254, ' ,', 0, 'UnionNotifyCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(4903, 527, ' ', 0, 'DataPacket', 0,-1,'_',10100,'') ;

CALL ImportDocType(5101, 0, '  ', 0, 'StoredAttributesCaption', 0,-1,'',10200,'') ;

CALL ImportDocType(5201, 555, ' / ', 0, 'WritExecutionCaption', 0,-1,'',10100,'') ;

CALL UpdateInterfaces(5201, ' / ', '{623EE404-09D9-4069-9115-27974DB69AD1}', '') ;

CALL ImportDocType(5501, 312, '   ', 0, 'CorrectionCaption', 0,-1,'',10100,'_') ;

CALL ImportDocType(5502, 313, '   ', 0, 'CorrectionCaption', 0,-1,'',10100,'_') ;

CALL ImportDocType(5503, 0, '   ', 0, 'ReplacementClsCaption', 0,-1,'',10100,'') ;

CALL UpdateInterfaces(5503, '   ', '{6110B8B7-DFE8-46EF-BD9F-39CCF092BB79}', '') ;

CALL ImportDocType(9701, 0, '   ', 0, 'AnalyticalGroupKD', 0,0,'',20100,'') ;

CALL ImportDocType(9702, 0, '   ', 0, 'AnalyticalGroupIFS', 0,0,'',20100,'') ;

CALL ImportDocType(9870, 0, '  ', 0, 'ProgramCode', 0,0,'',20200,'') ;

CALL ImportDocType(9894, 0, '    ', 0, 'COMMDIRECTIONEXPENCECLS', 0,0,'',20100,'') ;

CALL ImportDocType(9897, 0, '', 0, 'ontractostsCls', 0,0,'',20100,'') ;

CALL ImportDocType(9903, 0, ' ', 0, 'ORGANIZATIONS', 0,-1,'',10100,'_') ;

CALL ImportDocType(9904, 560, '  ', 0, 'CONTACTPERSONS', 0,0,'',10200,' ') ;

CALL ImportDocType(9916, 0, ' ', 0, '', 0,0,'',10300,'') ;

CALL ImportDocType(9928, 0, '   ', 0, 'ClsCorrespondents', 0,0,'',20100,'') ;

CALL UpdateInterfaces(9928, '   ', '{C1FAE5FE-7817-4D46-858B-ACFA478BA485}', '') ;

CALL ImportDocType(9930, 0, '   ', 0, 'AutoSanctionData', 0,0,'',10200,'') ;

CALL UpdateInterfaces(9930, '   ', '{23B8DC44-93C1-48C2-B2EB-DCAF31C23929}', '') ;

CALL ImportDocType(9931, 0, '   ', 0, 'ClsCorrespondents', 0,0,'',20100,'') ;

CALL UpdateInterfaces(9931, '   ', '{DCD828A5-5C9F-4446-ACA2-85F6B3BE0FD6}', '') ;

DROP PROCEDURE ImportDocType
/

DROP PROCEDURE UPDATEINTERFACES
/



CREATE OR REPLACE PROCEDURE SELECTIONS_IMPORT(
  ID_ NUMBER,
  KIND_ NUMBER,
  NAME_ VARCHAR2,
  NOTE_ VARCHAR2,
  READONLY_ NUMBER,
  USEINDOC_ NUMBER,
  TABLENAME_ VARCHAR2,
  ALIAS_ VARCHAR2,
  TABLECODE_ NUMBER,
  NEEDGROUPONDB_ NUMBER,
  NEEDDISTINCT_ NUMBER,
  MASTER_ NUMBER,
  DISCRIMVALUE_ VARCHAR2,
  AVAILABLEINDEREF_ NUMBER,
  CACHETYPE_ NUMBER,
  FULLORMODINSREFRTIME_ NUMBER,
  DELETEREFRTIME_ NUMBER,
  FINDTIMEREFRESH_ NUMBER,
  ANNOTATION_ VARCHAR2,
  DEREFNAME_ VARCHAR2,
  GroupID_ NUMBER,
  IsLogged_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONS SET
      KIND = KIND_,
      NAME = NAME_,
      NOTE = NOTE_,
      READONLY = READONLY_,
      USEINDOC = USEINDOC_,
      TABLENAME = TABLENAME_,
      ALIAS = ALIAS_,
      TABLECODE = TABLECODE_,    
      NEEDGROUPONDB = NEEDGROUPONDB_,
      NEEDDISTINCT = NEEDDISTINCT_,
      MASTER = MASTER_,
      DISCRIMVALUE = DISCRIMVALUE_,
      AVAILABLEINDEREF = AVAILABLEINDEREF_,         
      CACHETYPE = CACHETYPE_,   
      FULLORMODINSREFRTIME = FULLORMODINSREFRTIME_,   
      DELETEREFRTIME = DELETEREFRTIME_,   
      FINDTIMEREFRESH = FINDTIMEREFRESH_,   
      ANNOTATION = ANNOTATION_,   
      DEREFNAME = DEREFNAME_,     
      GroupID = GroupID_, 
      IsLogged = IsLogged_  
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONS
      (ID, KIND, NAME, NOTE, READONLY, USEINDOC, TABLENAME, ALIAS, TABLECODE, NEEDGROUPONDB, NEEDDISTINCT, MASTER, DISCRIMVALUE,
      AVAILABLEINDEREF, CACHETYPE, FULLORMODINSREFRTIME, DELETEREFRTIME, FINDTIMEREFRESH, ANNOTATION, DEREFNAME, GroupID, IsLogged)
    VALUES
      (ID_, KIND_, NAME_, NOTE_, READONLY_, USEINDOC_, TABLENAME_, ALIAS_, TABLECODE_, NEEDGROUPONDB_, NEEDDISTINCT_, MASTER_, DISCRIMVALUE_,
      AVAILABLEINDEREF_, CACHETYPE_, FULLORMODINSREFRTIME_, DELETEREFRTIME_, FINDTIMEREFRESH_, ANNOTATION_, DEREFNAME_, GroupID_, IsLogged_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONSDETAIL_IMPORT(
  ID_ NUMBER,
  SELECTIONREF_ NUMBER,
  TABLEREF_ NUMBER,
  ALIAS_ VARCHAR2,
  JOINORDER_ NUMBER,
  JOINTYPE_ NUMBER,
  RELATIONTYPE_ NUMBER,
  JOINCONDITION_ VARCHAR2,
  DONTUSETABLELIMITS_ NUMBER,
  LIMITNAMESLIST_ VARCHAR2,
  QueryGroup_ NUMBER  
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONSDETAIL
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONSDETAIL SET
      SELECTIONREF = SELECTIONREF_,
      TABLEREF = TABLEREF_,
      ALIAS = ALIAS_,
      JOINORDER = JOINORDER_,
      JOINTYPE = JOINTYPE_,
      RELATIONTYPE = RELATIONTYPE_,
      JOINCONDITION = JOINCONDITION_,
      DONTUSETABLELIMITS = DONTUSETABLELIMITS_,
      LIMITNAMESLIST = LIMITNAMESLIST_,
      QueryGroup = QueryGroup_
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONSDETAIL
      (ID, SELECTIONREF, TABLEREF, ALIAS, JOINORDER, JOINTYPE, RELATIONTYPE, JOINCONDITION, DONTUSETABLELIMITS, LIMITNAMESLIST, QueryGroup)
    VALUES
      (ID_, SELECTIONREF_, TABLEREF_, ALIAS_, JOINORDER_, JOINTYPE_, RELATIONTYPE_, JOINCONDITION_, DONTUSETABLELIMITS_, LIMITNAMESLIST_, QueryGroup_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FIELDSINFO_IMPORT(
  ID_ NUMBER,
  FIELDKIND_ NUMBER,
  DESCRIPTIONLEVEL_ NUMBER,
  ANCESTORREF_ NUMBER,
  SELECTIONREF_ NUMBER,
  TABLEREF_ NUMBER,
  FIELDNAME_ VARCHAR2,
  DATATYPE_ NUMBER,
  SUBDATATYPE_ NUMBER,
  FIELDSIZE_ NUMBER,
  DISPLAYLABEL_ VARCHAR2,
  NOTE_ VARCHAR2,
  DEFAULTWIDTH_ NUMBER,
  EDITMASK_ VARCHAR2,
  DISPLAYFORMAT_ VARCHAR2,
  EDITFORMAT_ VARCHAR2,
  CANTEDIT_ NUMBER,
  NOVISUALIZE_ NUMBER,
  ENUMSREF_ NUMBER,
  REQUIRED_ NUMBER,
  FOREIGNKEY_ NUMBER,
  ONDELACTION_ NUMBER,
  PRIMARYKEY_ NUMBER,
  ISRVERSION_ NUMBER,
  LIMITPARAMNAMES_ VARCHAR2,
  FOLLOWORDER_ NUMBER,
  SORTDIRECTION_ NUMBER,
  SORTORDER_ NUMBER,
  AGRFUNCTION_ NUMBER,
  FLAGFIELDNAME_ NUMBER,
  FLAGDISPLAYLABEL_ NUMBER,
  FLAGNOTE_ NUMBER,
  FLAGDEFAULTWIDTH_ NUMBER,
  FLAGCANTEDIT_ NUMBER,
  FLAGNOVISUALIZE_ NUMBER,
  FLAGREQUIRED_ NUMBER,
  FLAGLIMITPARAMNAMES_ NUMBER,
  FLAGAGRFUNCTION_ NUMBER,
  ISTIMESTAMPFIELD_ NUMBER,
  ISBUDGET_ NUMBER,
  AVAILABLEINDEREF_ NUMBER,
  ANNOTATION_ VARCHAR2,
  ALIAS_ VARCHAR2,
  DEREFNAME_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM FIELDSINFO
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE FIELDSINFO SET
      FIELDKIND = FIELDKIND_,
      DESCRIPTIONLEVEL = DESCRIPTIONLEVEL_,
      ANCESTORREF = ANCESTORREF_,
      SELECTIONREF = SELECTIONREF_,
      TABLEREF = TABLEREF_,
      FIELDNAME = FIELDNAME_,
      DATATYPE = DATATYPE_,
      SUBDATATYPE = SUBDATATYPE_,
      FIELDSIZE = FIELDSIZE_,
      DISPLAYLABEL = DISPLAYLABEL_,
      NOTE = NOTE_,
      DEFAULTWIDTH = DEFAULTWIDTH_,
      EDITMASK = EDITMASK_,
      DISPLAYFORMAT = DISPLAYFORMAT_,
      EDITFORMAT = EDITFORMAT_,
      CANTEDIT = CANTEDIT_,
      NOVISUALIZE = NOVISUALIZE_,
      ENUMSREF = ENUMSREF_,
      REQUIRED = REQUIRED_,
      FOREIGNKEY = FOREIGNKEY_,
      ONDELACTION = ONDELACTION_,
      PRIMARYKEY = PRIMARYKEY_,
      ISRVERSION = ISRVERSION_,
      LIMITPARAMNAMES = LIMITPARAMNAMES_,
      FOLLOWORDER = FOLLOWORDER_,
      SORTDIRECTION = SORTDIRECTION_,
      SORTORDER = SORTORDER_,
      AGRFUNCTION = AGRFUNCTION_,
      FLAGFIELDNAME = FLAGFIELDNAME_,
      FLAGDISPLAYLABEL = FLAGDISPLAYLABEL_,
      FLAGNOTE = FLAGNOTE_,
      FLAGDEFAULTWIDTH = FLAGDEFAULTWIDTH_,
      FLAGCANTEDIT = FLAGCANTEDIT_,
      FLAGNOVISUALIZE = FLAGNOVISUALIZE_,
      FLAGREQUIRED = FLAGREQUIRED_,
      FLAGLIMITPARAMNAMES = FLAGLIMITPARAMNAMES_,
      FLAGAGRFUNCTION = FLAGAGRFUNCTION_,
      ISTIMESTAMPFIELD = ISTIMESTAMPFIELD_,
      ISBUDGET = ISBUDGET_,
      AVAILABLEINDEREF = AVAILABLEINDEREF_,
      ANNOTATION = ANNOTATION_,
      ALIAS = ALIAS_,
      DEREFNAME = DEREFNAME_
    WHERE ID = ID_;
  ELSE
    INSERT INTO FIELDSINFO
      (ID, FIELDKIND, DESCRIPTIONLEVEL, ANCESTORREF, SELECTIONREF, TABLEREF, FIELDNAME, DATATYPE, SUBDATATYPE,
       FIELDSIZE, DISPLAYLABEL, NOTE, DEFAULTWIDTH, EDITMASK, DISPLAYFORMAT, EDITFORMAT, CANTEDIT, NOVISUALIZE,
       ENUMSREF, REQUIRED, FOREIGNKEY, ONDELACTION, PRIMARYKEY, ISRVERSION, LIMITPARAMNAMES,
       FOLLOWORDER, SORTDIRECTION, SORTORDER, AGRFUNCTION, FLAGFIELDNAME, FLAGDISPLAYLABEL, FLAGNOTE,
       FLAGDEFAULTWIDTH, FLAGCANTEDIT, FLAGNOVISUALIZE, FLAGREQUIRED, FLAGLIMITPARAMNAMES, FLAGAGRFUNCTION,
       ISTIMESTAMPFIELD, ISBUDGET, AVAILABLEINDEREF, ANNOTATION, ALIAS, DEREFNAME)
    VALUES
      (ID_, FIELDKIND_, DESCRIPTIONLEVEL_, ANCESTORREF_, SELECTIONREF_, TABLEREF_, FIELDNAME_, DATATYPE_, SUBDATATYPE_,
       FIELDSIZE_, DISPLAYLABEL_, NOTE_, DEFAULTWIDTH_, EDITMASK_, DISPLAYFORMAT_, EDITFORMAT_, CANTEDIT_, NOVISUALIZE_,
       ENUMSREF_, REQUIRED_, FOREIGNKEY_, ONDELACTION_, PRIMARYKEY_, ISRVERSION_, LIMITPARAMNAMES_,
       FOLLOWORDER_, SORTDIRECTION_, SORTORDER_, AGRFUNCTION_, FLAGFIELDNAME_, FLAGDISPLAYLABEL_, FLAGNOTE_,
       FLAGDEFAULTWIDTH_, FLAGCANTEDIT_, FLAGNOVISUALIZE_, FLAGREQUIRED_, FLAGLIMITPARAMNAMES_, FLAGAGRFUNCTION_,
       ISTIMESTAMPFIELD_, ISBUDGET_, AVAILABLEINDEREF_, ANNOTATION_, ALIAS_, DEREFNAME_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONEVENTS_IMPORT(
  ID_ NUMBER,
  SELECTIONREF_ NUMBER,
  EVENTCODE_ NUMBER,
  SCRIPTNAME_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONEVENTS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONEVENTS SET
      SELECTIONREF = SELECTIONREF_,
      EVENTCODE = EVENTCODE_,
      SCRIPTNAME = SCRIPTNAME_
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONEVENTS
      (ID, SELECTIONREF, EVENTCODE, SCRIPTNAME)
    VALUES
      (ID_, SELECTIONREF_, EVENTCODE_, SCRIPTNAME_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FIELDSINFO_DELETE(
  ID_ NUMBER
) IS
BEGIN
  UPDATE DOCUMENTFIELDS SET
    FIELDINFOREF = NULL
  WHERE FIELDINFOREF = ID_;
  DELETE FROM FIELDSINFO FI
  WHERE FI.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONSDETAIL_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONSDETAIL SLD
  WHERE SLD.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONS SL
  WHERE SL.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONEVENTS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONEVENTS SE
  WHERE SE.ID = ID_;
END;
/

-- 
CALL FIELDSINFO_DELETE(38641) ;

CALL FIELDSINFO_DELETE(38642) ;

CALL FIELDSINFO_DELETE(38645) ;

CALL FIELDSINFO_DELETE(38646) ;

CALL FIELDSINFO_DELETE(38749) ;

CALL FIELDSINFO_DELETE(38752) ;

CALL FIELDSINFO_DELETE(38755) ;

CALL FIELDSINFO_DELETE(38756) ;

CALL FIELDSINFO_DELETE(38757) ;

CALL FIELDSINFO_DELETE(38761) ;

CALL FIELDSINFO_DELETE(38774) ;

CALL FIELDSINFO_DELETE(38957) ;

CALL SELECTIONS_IMPORT(23058, 1, 'UNLOCKDATES', '       ', 0, 0, 'UNLOCKDATES', 'UNLOCKDATES', 0, 0, 0, 1, '', 1, 0, 600, null, null, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(38766, 2, 'CLS_324', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, 'PERSISTENT=STOREDAYCOUNT=7,Composite=', '', null, 0) ;

CALL SELECTIONS_IMPORT(38791, 2, 'CLS_209', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(38818, 2, 'CLS_212', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(38846, 2, 'CLS_211', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(38906, 1, 'ANALYTICALGROUPKD', '   ', 0, 0, 'ANALYTICALGROUPKD', 'ANALYTICALGROUPKD', 0, 0, 0, 2, '', 1, 0, -1, null, null, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(39170, 1, 'AUTOSANCTIONDATA', '   ', 0, 0, 'AUTOSANCTIONDATA', 'asd', 0, 0, 0, 2, '', 1, 1, 3600, null, 5, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(38917, 1, 'ANALYTICALGROUPIFS', '    ', 0, 0, 'ANALYTICALGROUPIFS', 'ANALYTICALGROUPIFS', 0, 0, 0, 2, '', 1, 0, -1, null, null, '', '', null, 0) ;

CALL SELECTIONSDETAIL_IMPORT(38710, 38701, 18947, 'FFC', 0, 0, 1, 'FFC.Progindex=67', 0, '', 0) ;

CALL SELECTIONSDETAIL_IMPORT(38767, 38766, 18947, 'FFC', 0, 0, 1, 'FFC.Progindex=76', 0, '', 0) ;

CALL SELECTIONSDETAIL_IMPORT(38768, 38766, 18864, 'FFD', 1, 1, 1, 'FFD.RECORDINDEX=FFC.ID', 0, '', 0) ;

CALL SELECTIONSDETAIL_IMPORT(38792, 38791, 17463, 'BN', 0, 0, 1, 'BN.Progindex=274', 0, '', 0) ;

CALL SELECTIONSDETAIL_IMPORT(38794, 38791, 17408, 'BDAT', 1, 2, 1, 'BDAT.RECORDINDEX=BN.ID', 0, '', 0) ;

CALL SELECTIONSDETAIL_IMPORT(38821, 38818, 17463, 'BN', 0, 0, 1, 'BN.Progindex=276', 0, '', 0) ;

CALL SELECTIONSDETAIL_IMPORT(38822, 38818, 17408, 'BDAT', 1, 2, 1, 'BDAT.RECORDINDEX=BN.ID', 0, '', 0) ;

CALL SELECTIONSDETAIL_IMPORT(38847, 38846, 17463, 'BN', 0, 0, 1, 'BN.Progindex=275', 0, '', 0) ;

CALL SELECTIONSDETAIL_IMPORT(38848, 38846, 17408, 'BDAT', 1, 2, 1, 'BDAT.RECORDINDEX=BN.ID', 0, '', 0) ;

-- ORGANIZATIONS
CALL FIELDSINFO_IMPORT(39263, 0, 1, null, 16642, null, 'RECORDOWNERORGREF', 3, 0, 0, '   (  )', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 64, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- KD
CALL FIELDSINFO_IMPORT(16830, 0, 1, null, 16824, null, 'KVSR', 3, 0, 0, ' ()', '', 4, '', '', '', 0, 0, null, 1, 16851, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(16834, 0, 1, null, 16824, null, 'PROGRAMCODE', 3, 0, 0, '', '', 5, '9999', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(16835, 0, 1, null, 16824, null, 'KESR', 3, 0, 0, '', '', 6, '9.9.9', '', '', 0, 0, null, 1, 16871, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(16836, 0, 1, null, 16824, null, 'KDVALUE', 1, 0, 20, ' ', '  ', 31, '999.9.99.99.999.99.9999.999;0;_', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(24895, 0, 1, null, 16824, null, 'KD_LEVEL', 3, 0, 0, ' ', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 20, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39102, 0, 1, null, 16824, null, 'ANALYTICALGROUPKD', 3, 0, 0, ' ()', '', 6, '', '', '', 0, 0, null, 1, 38906, 0, 0, 0, '', 25, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- INNERFINSOURCE
CALL FIELDSINFO_IMPORT(17049, 0, 1, null, 17043, null, 'KVSR', 3, 0, 0, ' ()', '', 4, '999', '999', '', 0, 0, null, 1, 16851, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(17054, 0, 1, null, 17043, null, 'KESR', 3, 0, 0, '', '', 6, '9.9.9', '', '', 0, 0, null, 1, 16871, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39103, 0, 1, null, 17043, null, 'ANALYTICALGROUPIFS', 3, 0, 0, ' ()', '', 6, '', '', '', 0, 0, null, 0, 38917, 0, 0, 0, '', 23, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- BUDGETDATA
CALL FIELDSINFO_IMPORT(17461, 0, 1, null, 17408, null, 'KVRCORR', 3, 0, 0, ' ', ' ', 6, '9.9.9', '', '', 0, 0, null, 1, 16864, 0, 0, 0, '', 53, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39879, 0, 1, null, 17408, null, 'SUMMAYEAR4', 6, 0, 0, '   ', '      ', 13, '', ',0.00####', '0.00', 0, 0, null, 1, null, 0, 0, 0, '', 66, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39880, 0, 1, null, 17408, null, 'SUMMAOTHERYEARS', 6, 0, 0, '   ', '     ', 13, '', ',0.00####', '0.00', 0, 0, null, 1, null, 0, 0, 0, '', 67, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- FACIALFINCAPTION
CALL FIELDSINFO_IMPORT(39225, 0, 1, null, 18947, null, 'AUTOSANCTION', 3, 0, 0, '   ', '', 0, '', '', '', 0, 0, null, 0, 39170, 0, 0, 0, '', 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- AGREEMENTS
CALL FIELDSINFO_IMPORT(39226, 0, 1, null, 19795, null, 'AUTOSANCTION', 3, 0, 0, '  ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 103, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- BUHACCPLAN
CALL FIELDSINFO_IMPORT(21630, 0, 1, null, 21627, null, 'ECCLS', 1, 0, 20, ' ', '', 4, '>aaa', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39104, 0, 1, null, 21627, null, 'CLSTYPE', 3, 0, 0, '', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- UNLOCKDATES
CALL FIELDSINFO_IMPORT(38954, 0, 1, null, 23058, null, 'DAYKIND', 3, 0, 0, '  ', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 15, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, '', '', '') ;

-- WRITEXECUTIONDETAIL
CALL FIELDSINFO_IMPORT(38765, 0, 1, null, 23401, null, 'NOTE', 1, 0, 1024, ' ', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 61, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- CLSCORRESPONDENTS
CALL FIELDSINFO_IMPORT(39250, 0, 1, null, 35357, null, 'KFSR', 3, 0, 0, '', '', 0, '', '', '', 0, 0, null, 1, 16844, 0, 0, 0, '', 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39251, 0, 1, null, 35357, null, 'CORRTYPE', 3, 0, 0, ' ', '', 0, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39252, 0, 1, null, 35357, null, 'CORRBEL', 3, 0, 0, ' ', '', 0, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- ANALYTICALGROUPKD
CALL FIELDSINFO_IMPORT(38907, 0, 1, null, 38906, null, 'ID', 3, 0, 0, ' ', '', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38908, 0, 1, null, 38906, null, 'CODE', 1, 0, 20, '', '', 0, '999', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38909, 0, 1, null, 38906, null, 'CREATEDATE', 11, 0, 0, ' ', '', 20, '99/99/9999', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38910, 0, 1, null, 38906, null, 'UPDATEDATE', 11, 0, 0, ' ', '', 20, '99/99/9999', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38911, 0, 1, null, 38906, null, 'CREATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38912, 0, 1, null, 38906, null, 'UPDATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38913, 0, 1, null, 38906, null, 'NAME', 1, 0, 1024, '', '', 60, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38914, 0, 1, null, 38906, null, 'BUDGETREF', 3, 0, 0, ' ', '', 11, '', '', '', 0, 0, null, 1, 16803, 0, 0, 0, '', 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38915, 0, 1, null, 38906, null, 'DELETEDATE', 11, 0, 0, ' ', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38916, 0, 1, null, 38906, null, 'STARTDATE', 11, 0, 0, '   ', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38931, 0, 1, null, 38906, null, 'EXTID', 1, 0, 50, 'UID     ', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38932, 0, 1, null, 38906, null, 'EXTOWNER', 1, 0, 50, '  ', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38933, 0, 1, null, 38906, null, 'EXTSYNCDATE', 11, 0, 0, '     ', '', 20, '99/99/9999', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- ANALYTICALGROUPIFS
CALL FIELDSINFO_IMPORT(38918, 0, 1, null, 38917, null, 'ID', 3, 0, 0, ' ', '', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38919, 0, 1, null, 38917, null, 'CODE', 1, 0, 20, '', '', 0, '999', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38920, 0, 1, null, 38917, null, 'CREATEDATE', 11, 0, 0, ' ', '', 20, '99/99/9999', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38921, 0, 1, null, 38917, null, 'UPDATEDATE', 11, 0, 0, ' ', '', 20, '99/99/9999', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38922, 0, 1, null, 38917, null, 'CREATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38923, 0, 1, null, 38917, null, 'UPDATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38924, 0, 1, null, 38917, null, 'NAME', 1, 0, 1024, '', '', 60, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38925, 0, 1, null, 38917, null, 'BUDGETREF', 3, 0, 0, ' ', '', 11, '', '', '', 0, 0, null, 1, 16803, 0, 0, 0, '', 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38926, 0, 1, null, 38917, null, 'DELETEDATE', 11, 0, 0, ' ', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38927, 0, 1, null, 38917, null, 'STARTDATE', 11, 0, 0, '   ', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38928, 0, 1, null, 38917, null, 'EXTID', 1, 0, 50, 'UID     ', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38929, 0, 1, null, 38917, null, 'EXTOWNER', 1, 0, 50, '  ', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(38930, 0, 1, null, 38917, null, 'EXTSYNCDATE', 11, 0, 0, '     ', '', 20, '99/99/9999', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- AUTOSANCTIONDATA
CALL FIELDSINFO_IMPORT(39171, 0, 1, null, 39170, null, 'ID', 3, 0, 0, ' ', '', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39172, 0, 1, null, 39170, null, 'CODE', 1, 0, 20, '', '', 20, '>9999.aa.aaa.aaaa', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39173, 0, 1, null, 39170, null, 'CREATEDATE', 11, 0, 0, ' ', '', 20, '99/99/9999', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39174, 0, 1, null, 39170, null, 'UPDATEDATE', 11, 0, 0, ' ', '', 20, '99/99/9999', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39175, 0, 1, null, 39170, null, 'CREATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39176, 0, 1, null, 39170, null, 'UPDATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39177, 0, 1, null, 39170, null, 'NAME', 1, 0, 255, '', '', 60, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39178, 0, 1, null, 39170, null, 'BUDGETREF', 3, 0, 0, ' ', '', 11, '', '', '', 0, 0, null, 1, 16803, 0, 0, 0, '', 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39179, 0, 1, null, 39170, null, 'DELETEDATE', 11, 0, 0, ' ', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39180, 0, 1, null, 39170, null, 'STARTDATE', 11, 0, 0, '   ', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39181, 0, 1, null, 39170, null, 'KFSR', 3, 0, 0, '', '', 20, '', '', '', 0, 0, null, 0, 16844, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39182, 0, 1, null, 39170, null, 'KCSR', 3, 0, 0, '', '', 20, '', '', '', 0, 0, null, 0, 16857, 0, 0, 0, '', 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39183, 0, 1, null, 39170, null, 'KVSR', 3, 0, 0, '', '', 0, '', '', '', 0, 0, null, 0, 16851, 0, 0, 0, '', 13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39184, 0, 1, null, 39170, null, 'KVR', 3, 0, 0, '', '', 0, '', '', '', 0, 0, null, 0, 16864, 0, 0, 0, '', 14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39185, 0, 1, null, 39170, null, 'KESR', 3, 0, 0, '', '', 0, '', '', '', 0, 0, null, 0, 16871, 0, 0, 0, '', 15, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39186, 0, 1, null, 39170, null, 'KD', 3, 0, 0, ' ', '', 0, '', '', '', 0, 0, null, 0, 16824, 0, 0, 0, '', 16, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39187, 0, 1, null, 39170, null, 'IFS', 3, 0, 0, '', '', 0, '', '', '', 0, 0, null, 0, 17043, 0, 0, 0, '', 17, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39188, 0, 1, null, 39170, null, 'TAXNOTE', 1, 0, 150, '  ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 18, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39189, 0, 1, null, 39170, null, 'AUTOSANCTION', 3, 0, 0, ' ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 19, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39190, 0, 1, null, 39170, null, 'ACC', 1, 0, 255, ' ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 20, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39191, 0, 1, null, 39170, null, 'NOTE', 1, 0, 255, '', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 21, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39192, 0, 1, null, 39170, null, 'CLSTYPE', 3, 0, 0, ' ', '', 0, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 22, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39193, 0, 1, null, 39170, null, 'DOCTYPE', 3, 0, 0, ' ', '', 0, '', '', '', 0, 0, null, 0, 16814, 0, 0, 0, '', 23, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39228, 0, 1, null, 39170, null, 'PROMISE', 1, 0, 1024, '  ', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 24, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- CLS_303
CALL FIELDSINFO_IMPORT(38654, 0, 2, 18926, 34448, 34451, 'DESTKD', 3, 0, 0, ' ', '    ', 11, '', '', '', 0, 0, null, 0, 16824, 0, 0, 0, '', 26, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KD', '') ;

-- CLS_311
CALL FIELDSINFO_IMPORT(34928, 0, 2, 18927, 34517, 34520, 'SOURCEREGIONCLS', 3, 0, 0, ' .', '', 9, '99.99.99', '', '', 0, 0, null, 1, 16688, 0, 1, 0, '', 21, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, '', 'REGIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38753, 0, 2, 18956, 34517, 34519, 'SOURCEACCOUNT', 3, 0, 0, '\ ', '   ()', 11, '', '', '', 0, 0, null, 0, 17108, 0, 0, 0, '', 26, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'ACCOUNT', '') ;

-- CLS_314
CALL FIELDSINFO_IMPORT(34545, 0, 2, 18958, 34539, 34541, 'DESTACCOUNT', 3, 0, 0, '\ ', '   ()', 11, '', '', '', 0, 0, null, 0, 17108, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'DESTACCOUNT', '') ;

-- CLS_322
CALL FIELDSINFO_IMPORT(34603, 0, 2, 18868, 34588, 34591, 'SOURCEKESR', 3, 0, 0, '', ' ', 6, '9.9.9', '', '', 0, 0, null, 0, 16871, 0, 0, 0, '', 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, '', 'KESR', '') ;

-- CLS_323
CALL FIELDSINFO_IMPORT(34619, 0, 2, 19007, 34610, 34612, 'BUHOPERATIONCLS', 3, 0, 0, '  ', '   70  ', 11, '', '', '', 0, 0, null, 1, 21634, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'BUHOPERATIONCLS', '') ;

-- CLS_903
CALL FIELDSINFO_IMPORT(38956, 0, 2, 17712, 35019, 35024, 'KESR', 3, 0, 0, '', ' ', 6, '9.9.9', '', '', 0, 0, null, 1, 16871, 0, 0, 0, '', 21, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KESR', '') ;

-- CLS_210
CALL FIELDSINFO_IMPORT(38762, 0, 2, 25270, 37748, 34633, 'KD', 3, 0, 0, '', '   ', 11, '', '', '', 0, 0, null, 1, 16824, 0, 0, 0, '', 26, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KD', '') ;

-- CLS_308
CALL FIELDSINFO_IMPORT(38714, 0, 2, 18983, 38701, 38710, 'BUDGETREF', 3, 0, 0, '', '  ,    ', 11, '999', '', '', 0, 0, null, 1, 16803, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'BUDGETREF', '') ;

CALL FIELDSINFO_IMPORT(38715, 0, 2, 18958, 38701, 38710, 'DESTACCOUNT', 3, 0, 0, '\ ', '   ()', 11, '', '', '', 0, 0, null, 0, 17108, 0, 0, 0, '', 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'DESTACCOUNT', '') ;

-- CLS_324
CALL FIELDSINFO_IMPORT(38769, 0, 2, 18983, 38766, 38767, 'BUDGETREF', 3, 0, 0, '', '  ,    ', 11, '999', '', '', 0, 0, null, 1, 16803, 0, 0, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'BUDGETREF', '') ;

CALL FIELDSINFO_IMPORT(38770, 0, 2, 19007, 38766, 38767, 'BUHOPERATIONCLS', 3, 0, 0, '  ', '   70  ', 11, '', '', '', 0, 0, null, 1, 21634, 0, 0, 0, '', 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'BUHOPERATIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38771, 0, 2, 18979, 38766, 38767, 'CREATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, '', 'CREATERUSER', '') ;

CALL FIELDSINFO_IMPORT(38772, 0, 2, 34968, 38766, 38767, 'DOCCHANGEDATE', 11, 0, 0, '   ', ' ,  ', 20, '99/99/9999', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 4, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, '', 'DOCCHANGEDATE', '') ;

CALL FIELDSINFO_IMPORT(38773, 0, 2, 18948, 38766, 38767, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 5, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 1, '', 'CAPTIONID', '') ;

CALL FIELDSINFO_IMPORT(38775, 0, 2, 18972, 38766, 38767, 'REJECT_CLS', 3, 0, 0, ' ', '  ', 9, '99.99.99', '', '', 0, 0, null, 0, 17026, 0, 0, 0, '', 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'REJECT_CLS', '') ;

CALL FIELDSINFO_IMPORT(38776, 0, 2, 18958, 38766, 38767, 'DESTACCOUNT', 3, 0, 0, '\ ', '   ()', 11, '', '', '', 0, 0, null, 0, 17108, 0, 0, 0, '', 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'ACCOUNT', '') ;

CALL FIELDSINFO_IMPORT(38777, 0, 2, 18914, 38766, 38768, 'DESTDIRECTIONCLS', 3, 0, 0, '', '   ', 4, '999', '', '', 0, 0, null, 1, 21555, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'DIRECTIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38778, 0, 2, 18869, 38766, 38768, 'DESTFACIALACC_CLS', 3, 0, 0, '\ ', '   ', 13, '999.99.999.9', '', '', 0, 0, null, 1, 17129, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'FACIALACC_CLS', '') ;

CALL FIELDSINFO_IMPORT(38779, 0, 2, 18899, 38766, 38768, 'DESTFACT', 3, 0, 0, '', ' ', 9, '99.99.99', '', '', 0, 0, null, 1, 16964, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'FACT', '') ;

CALL FIELDSINFO_IMPORT(38780, 0, 2, 18896, 38766, 38768, 'DESTKCSR', 3, 0, 0, ' ()', '  ', 11, '999.99.99', '', '', 0, 0, null, 1, 16857, 0, 0, 0, '', 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KCSR', '') ;

CALL FIELDSINFO_IMPORT(38781, 0, 2, 18871, 38766, 38768, 'DESTKESR', 3, 0, 0, '', ' ', 6, '9.9.9', '', '', 0, 0, null, 1, 16871, 0, 0, 0, '', 13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KESR', '') ;

CALL FIELDSINFO_IMPORT(38782, 0, 2, 18897, 38766, 38768, 'DESTKFSR', 3, 0, 0, '', ' ', 6, '99.99', '', '', 0, 0, null, 1, 16844, 0, 0, 0, '', 14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KFSR', '') ;

CALL FIELDSINFO_IMPORT(38783, 0, 2, 18870, 38766, 38768, 'DESTKVR', 3, 0, 0, ' ()', '  ', 7, '>AAA', '', '', 0, 0, null, 1, 16864, 0, 0, 0, '', 15, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KVR', '') ;

CALL FIELDSINFO_IMPORT(38784, 0, 2, 18895, 38766, 38768, 'DESTKVSR', 3, 0, 0, ' ()', '  ', 4, '999', '', '', 0, 0, null, 1, 16851, 0, 0, 0, '', 16, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KVSR', '') ;

CALL FIELDSINFO_IMPORT(38785, 0, 2, 18900, 38766, 38768, 'DESTMEANSTYPE', 3, 0, 0, ' ', '  ', 9, '99.99.99', '', '', 0, 0, null, 1, 17311, 0, 0, 0, '', 17, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'MEANSTYPE', '') ;

CALL FIELDSINFO_IMPORT(38786, 0, 2, 18928, 38766, 38768, 'DESTREGIONCLS', 3, 0, 0, ' -', '', 9, '99.99.99', '', '', 0, 0, null, 1, 16688, 0, 0, 0, '', 18, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'REGIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38787, 0, 2, 18898, 38766, 38768, 'DESTSUBKESR', 3, 0, 0, '', '   ', 10, '999.99.99', '', '', 0, 0, null, 1, 16915, 0, 0, 0, '', 19, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SUBKESR', '') ;

CALL FIELDSINFO_IMPORT(38788, 0, 2, 26624, 38766, 38768, 'DESTSUBSIDYCLS', 3, 0, 0, '', '', 12, '', '', '', 0, 0, null, 0, 26536, 0, 0, 0, '', 20, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SUBSIDYCLS', '') ;

CALL FIELDSINFO_IMPORT(38789, 0, 2, 18936, 38766, 38768, 'DESTTRANSFERTCLS', 3, 0, 0, '    ()', '    ', 12, '9.99.999.999', '', '', 0, 0, null, 0, 22773, 0, 0, 0, '', 21, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'TRANSFERTCLS', '') ;

CALL FIELDSINFO_IMPORT(38790, 0, 2, 18865, 38766, 38768, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 22, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 1, '', 'RECORDCOUNT', '') ;

-- CLS_209
CALL FIELDSINFO_IMPORT(38795, 0, 2, 17472, 38791, 38792, 'BUDGETREF', 3, 0, 0, '', '  ,    ', 11, '999', '', '', 0, 0, null, 1, 16803, 0, 0, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'BUDGETREF', '') ;

CALL FIELDSINFO_IMPORT(38796, 0, 2, 17451, 38791, 38794, 'BUHOPERATIONCLS', 3, 0, 0, ' ', '    70', 11, '999.99', '', '', 0, 0, null, 1, 21634, 0, 0, 0, '', 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'BUHOPERATIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38797, 0, 2, 17477, 38791, 38792, 'CREATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, '', 'CREATERUSER', '') ;

CALL FIELDSINFO_IMPORT(38798, 0, 2, 17450, 38791, 38794, 'DIRECTIONCLS', 3, 0, 0, '', '   ', 4, '999', '000', '000', 0, 0, null, 1, 21555, 0, 0, 0, '', 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'DIRECTIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38799, 0, 2, 36043, 38791, 38792, 'DOCCHANGEDATE', 11, 0, 0, '', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, '', 'DOCCHANGEDATE', '') ;

CALL FIELDSINFO_IMPORT(38800, 0, 2, 17419, 38791, 38794, 'FACIALACC_CLS', 3, 0, 0, ' ', ' ', 13, '999.99.999.9', '', '', 0, 0, null, 1, 17129, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'FACIALACC_CLS', '') ;

CALL FIELDSINFO_IMPORT(38801, 0, 2, 17418, 38791, 38794, 'FACT', 3, 0, 0, '', ' ', 9, '99.99.99', '', '', 0, 0, null, 1, 16964, 0, 0, 0, '', 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'FACT', '') ;

CALL FIELDSINFO_IMPORT(38802, 0, 2, 17409, 38791, 38794, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 1, null, 0, 0, 0, '', 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(38803, 0, 2, 17464, 38791, 38792, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'CAPTIONID', '') ;

CALL FIELDSINFO_IMPORT(38804, 0, 2, 17452, 38791, 38794, 'IFS', 3, 0, 0, '  ()', '   ', 11, '', '', '', 0, 0, null, 1, 17043, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'IFS', '') ;

CALL FIELDSINFO_IMPORT(38805, 0, 2, 17413, 38791, 38794, 'KCSR', 3, 0, 0, '', '', 11, '999.99.99', '000', '000', 0, 0, null, 1, 16857, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KCSR', '') ;

CALL FIELDSINFO_IMPORT(38806, 0, 2, 17415, 38791, 38794, 'KESR', 3, 0, 0, '', ' ', 6, '9.9.9', '', '', 0, 0, null, 1, 16871, 0, 0, 0, '', 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KESR', '') ;

CALL FIELDSINFO_IMPORT(38807, 0, 2, 17411, 38791, 38794, 'KFSR', 3, 0, 0, '', ' ', 6, '99.99', '', '', 0, 0, null, 1, 16844, 0, 0, 0, '', 13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KFSR', '') ;

CALL FIELDSINFO_IMPORT(38808, 0, 2, 17414, 38791, 38794, 'KVR', 3, 0, 0, '', '', 7, '>AAA', '000', '000', 0, 0, null, 1, 16864, 0, 0, 0, '', 14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KVR', '') ;

CALL FIELDSINFO_IMPORT(38809, 0, 2, 17412, 38791, 38794, 'KVSR', 3, 0, 0, '', '', 4, '999', '000', '000', 0, 0, null, 1, 16851, 0, 0, 0, '', 15, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KVSR', '') ;

CALL FIELDSINFO_IMPORT(38810, 0, 2, 17426, 38791, 38794, 'MEANSTYPE', 3, 0, 0, ' ', '  ', 9, '99.99.99', '', '', 0, 0, null, 1, 17311, 0, 0, 0, '', 16, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'MEANSTYPE', '') ;

CALL FIELDSINFO_IMPORT(38811, 0, 2, 17417, 38791, 38794, 'REGIONCLS', 3, 0, 0, '', ' ', 9, '99.99.99', '', '', 0, 0, null, 1, 16688, 0, 0, 0, '', 17, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'REGIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38812, 0, 2, 17485, 38791, 38792, 'REJECTCLS', 3, 0, 0, ' ', '  ', 9, '99.99.99', '', '', 0, 0, null, 0, 17026, 0, 0, 0, '', 18, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'REJECTCLS', '') ;

CALL FIELDSINFO_IMPORT(38813, 0, 2, 17416, 38791, 38794, 'SUBKESR', 3, 0, 0, '', '   ', 10, '9.9.9', '', '', 0, 0, null, 1, 16915, 0, 0, 0, '', 19, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SUBKESR', '') ;

CALL FIELDSINFO_IMPORT(38814, 0, 2, 26542, 38791, 38794, 'SUBSIDYCLS', 3, 0, 0, '', '', 12, '', '', '', 0, 0, null, 0, 26536, 0, 0, 0, '', 20, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SUBSIDYCLS', '') ;

CALL FIELDSINFO_IMPORT(38815, 0, 2, 17460, 38791, 38794, 'TRANSFERTCLS', 3, 0, 0, '   ()', '    ', 12, '', '', '', 0, 0, null, 0, 22773, 0, 0, 0, '', 21, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'TRANSFERTCLS', '') ;

CALL FIELDSINFO_IMPORT(38816, 0, 2, 17474, 38791, 38792, 'VARIANT', 3, 0, 0, ' ', ' ', 4, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 22, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'VARIANT', '') ;

-- CLS_212
CALL FIELDSINFO_IMPORT(38837, 0, 2, 17414, 38818, 34633, 'KVR', 3, 0, 0, '', '', 7, '>AAA', '000', '000', 0, 0, null, 1, 16864, 0, 0, 0, '', 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KVR', '') ;

CALL FIELDSINFO_IMPORT(38838, 0, 2, 17412, 38818, 34633, 'KVSR', 3, 0, 0, '', '', 4, '999', '000', '000', 0, 0, null, 1, 16851, 0, 0, 0, '', 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KVSR', '') ;

CALL FIELDSINFO_IMPORT(38839, 0, 2, 17426, 38818, 34633, 'MEANSTYPE', 3, 0, 0, ' ', '  ', 9, '99.99.99', '', '', 0, 0, null, 1, 17311, 0, 0, 0, '', 18, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'MEANSTYPE', '') ;

CALL FIELDSINFO_IMPORT(38840, 0, 2, 17417, 38818, 34633, 'REGIONCLS', 3, 0, 0, '', ' ', 9, '99.99.99', '', '', 0, 0, null, 1, 16688, 0, 0, 0, '', 19, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'REGIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38841, 0, 2, 17485, 38818, 38821, 'REJECTCLS', 3, 0, 0, ' ', '  ', 9, '99.99.99', '', '', 0, 0, null, 0, 17026, 0, 0, 0, '', 27, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'REJECTCLS', '') ;

CALL FIELDSINFO_IMPORT(38842, 0, 2, 17416, 38818, 38822, 'SUBKESR', 3, 0, 0, '', '   ', 10, '9.9.9', '', '', 0, 0, null, 1, 16915, 0, 0, 0, '', 28, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SUBKESR', '') ;

CALL FIELDSINFO_IMPORT(38843, 0, 2, 26542, 38818, 38822, 'SUBSIDYCLS', 3, 0, 0, '', '', 12, '', '', '', 0, 0, null, 0, 26536, 0, 0, 0, '', 29, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SUBSIDYCLS', '') ;

CALL FIELDSINFO_IMPORT(38844, 0, 2, 17460, 38818, 38822, 'TRANSFERTCLS', 3, 0, 0, '   ()', '    ', 12, '', '', '', 0, 0, null, 0, 22773, 0, 0, 0, '', 30, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'TRANSFERTCLS', '') ;

CALL FIELDSINFO_IMPORT(38845, 0, 2, 17474, 38818, 38821, 'VARIANT', 3, 0, 0, ' ', ' ', 4, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 31, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'VARIANT', '') ;

CALL FIELDSINFO_IMPORT(38823, 0, 2, 17472, 38818, 34632, 'BUDGETREF', 3, 0, 0, '', '  ,    ', 11, '999', '', '', 0, 0, null, 1, 16803, 0, 0, 0, '', 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'BUDGETREF', '') ;

CALL FIELDSINFO_IMPORT(38824, 0, 2, 17451, 38818, 34633, 'BUHOPERATIONCLS', 3, 0, 0, ' ', '    70', 11, '999.99', '', '', 0, 0, null, 1, 21634, 0, 0, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'BUHOPERATIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38825, 0, 2, 17477, 38818, 34632, 'CREATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, '', 'CREATERUSER', '') ;

CALL FIELDSINFO_IMPORT(38826, 0, 2, 17450, 38818, 34633, 'DIRECTIONCLS', 3, 0, 0, '', '   ', 4, '999', '000', '000', 0, 0, null, 1, 21555, 0, 0, 0, '', 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'DIRECTIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38827, 0, 2, 36043, 38818, 34632, 'DOCCHANGEDATE', 11, 0, 0, '', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 24, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, '', 'DOCCHANGEDATE', '') ;

CALL FIELDSINFO_IMPORT(38828, 0, 2, 17419, 38818, 34633, 'FACIALACC_CLS', 3, 0, 0, ' ', ' ', 13, '999.99.999.9', '', '', 0, 0, null, 1, 17129, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'FACIALACC_CLS', '') ;

CALL FIELDSINFO_IMPORT(38829, 0, 2, 17418, 38818, 34633, 'FACT', 3, 0, 0, '', ' ', 9, '99.99.99', '', '', 0, 0, null, 1, 16964, 0, 0, 0, '', 16, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'FACT', '') ;

CALL FIELDSINFO_IMPORT(38830, 0, 2, 17464, 38818, 34632, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 23, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 1, '', 'CAPTIONID', '') ;

CALL FIELDSINFO_IMPORT(38831, 0, 2, 17409, 38818, 34633, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 22, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 1, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(38832, 0, 2, 17452, 38818, 34633, 'IFS', 3, 0, 0, '  ()', '   ', 11, '', '', '', 0, 0, null, 1, 17043, 0, 0, 0, '', 25, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'IFS', '') ;

CALL FIELDSINFO_IMPORT(38833, 0, 2, 17413, 38818, 34633, 'KCSR', 3, 0, 0, '', '', 11, '999.99.99', '000', '000', 0, 0, null, 1, 16857, 0, 0, 0, '', 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KCSR', '') ;

CALL FIELDSINFO_IMPORT(38834, 0, 2, 25270, 38818, 34633, 'KD', 3, 0, 0, '', '   ', 11, '', '', '', 0, 0, null, 1, 16824, 0, 0, 0, '', 26, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KD', '') ;

CALL FIELDSINFO_IMPORT(38835, 0, 2, 17415, 38818, 34633, 'KESR', 3, 0, 0, '', ' ', 6, '9.9.9', '', '', 0, 0, null, 1, 16871, 0, 0, 0, '', 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KESR', '') ;

CALL FIELDSINFO_IMPORT(38836, 0, 2, 17411, 38818, 34633, 'KFSR', 3, 0, 0, '', ' ', 6, '99.99', '', '', 0, 0, null, 1, 16844, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KFSR', '') ;

-- CLS_211
CALL FIELDSINFO_IMPORT(38849, 0, 2, 17472, 38846, 34632, 'BUDGETREF', 3, 0, 0, '', '  ,    ', 11, '999', '', '', 0, 0, null, 1, 16803, 0, 0, 0, '', 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'BUDGETREF', '') ;

CALL FIELDSINFO_IMPORT(38850, 0, 2, 17451, 38846, 34633, 'BUHOPERATIONCLS', 3, 0, 0, ' ', '    70', 11, '999.99', '', '', 0, 0, null, 1, 21634, 0, 0, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'BUHOPERATIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38851, 0, 2, 17477, 38846, 34632, 'CREATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, '', 'CREATERUSER', '') ;

CALL FIELDSINFO_IMPORT(38852, 0, 2, 17450, 38846, 34633, 'DIRECTIONCLS', 3, 0, 0, '', '   ', 4, '999', '000', '000', 0, 0, null, 1, 21555, 0, 0, 0, '', 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'DIRECTIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38853, 0, 2, 36043, 38846, 34632, 'DOCCHANGEDATE', 11, 0, 0, '', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 24, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, '', 'DOCCHANGEDATE', '') ;

CALL FIELDSINFO_IMPORT(38854, 0, 2, 17419, 38846, 34633, 'FACIALACC_CLS', 3, 0, 0, ' ', ' ', 13, '999.99.999.9', '', '', 0, 0, null, 1, 17129, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'FACIALACC_CLS', '') ;

CALL FIELDSINFO_IMPORT(38855, 0, 2, 17418, 38846, 34633, 'FACT', 3, 0, 0, '', ' ', 9, '99.99.99', '', '', 0, 0, null, 1, 16964, 0, 0, 0, '', 16, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'FACT', '') ;

CALL FIELDSINFO_IMPORT(38856, 0, 2, 17464, 38846, 34632, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 23, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 1, '', 'CAPTIONID', '') ;

CALL FIELDSINFO_IMPORT(38857, 0, 2, 17409, 38846, 34633, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 22, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 1, '', 'RECORDCOUNT', '') ;

CALL FIELDSINFO_IMPORT(38858, 0, 2, 17452, 38846, 34633, 'IFS', 3, 0, 0, '  ()', '   ', 11, '', '', '', 0, 0, null, 1, 17043, 0, 0, 0, '', 25, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'IFS', '') ;

CALL FIELDSINFO_IMPORT(38859, 0, 2, 17413, 38846, 34633, 'KCSR', 3, 0, 0, '', '', 11, '999.99.99', '000', '000', 0, 0, null, 1, 16857, 0, 0, 0, '', 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KCSR', '') ;

CALL FIELDSINFO_IMPORT(38860, 0, 2, 25270, 38846, 34633, 'KD', 3, 0, 0, '', '   ', 11, '', '', '', 0, 0, null, 1, 16824, 0, 0, 0, '', 26, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KD', '') ;

CALL FIELDSINFO_IMPORT(38861, 0, 2, 17415, 38846, 34633, 'KESR', 3, 0, 0, '', ' ', 6, '9.9.9', '', '', 0, 0, null, 1, 16871, 0, 0, 0, '', 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KESR', '') ;

CALL FIELDSINFO_IMPORT(38862, 0, 2, 17411, 38846, 34633, 'KFSR', 3, 0, 0, '', ' ', 6, '99.99', '', '', 0, 0, null, 1, 16844, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KFSR', '') ;

CALL FIELDSINFO_IMPORT(38863, 0, 2, 17414, 38846, 34633, 'KVR', 3, 0, 0, '', '', 7, '>AAA', '000', '000', 0, 0, null, 1, 16864, 0, 0, 0, '', 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KVR', '') ;

CALL FIELDSINFO_IMPORT(38864, 0, 2, 17412, 38846, 34633, 'KVSR', 3, 0, 0, '', '', 4, '999', '000', '000', 0, 0, null, 1, 16851, 0, 0, 0, '', 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KVSR', '') ;

CALL FIELDSINFO_IMPORT(38865, 0, 2, 17426, 38846, 34633, 'MEANSTYPE', 3, 0, 0, ' ', '  ', 9, '99.99.99', '', '', 0, 0, null, 1, 17311, 0, 0, 0, '', 18, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'MEANSTYPE', '') ;

CALL FIELDSINFO_IMPORT(38866, 0, 2, 17417, 38846, 34633, 'REGIONCLS', 3, 0, 0, '', ' ', 9, '99.99.99', '', '', 0, 0, null, 1, 16688, 0, 0, 0, '', 19, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'REGIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38867, 0, 2, 17485, 38846, 38847, 'REJECTCLS', 3, 0, 0, ' ', '  ', 9, '99.99.99', '', '', 0, 0, null, 0, 17026, 0, 0, 0, '', 27, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'REJECTCLS', '') ;

CALL FIELDSINFO_IMPORT(38868, 0, 2, 17416, 38846, 38848, 'SUBKESR', 3, 0, 0, '', '   ', 10, '9.9.9', '', '', 0, 0, null, 1, 16915, 0, 0, 0, '', 28, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SUBKESR', '') ;

CALL FIELDSINFO_IMPORT(38869, 0, 2, 26542, 38846, 38848, 'SUBSIDYCLS', 3, 0, 0, '', '', 12, '', '', '', 0, 0, null, 0, 26536, 0, 0, 0, '', 29, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'SUBSIDYCLS', '') ;

CALL FIELDSINFO_IMPORT(38870, 0, 2, 17460, 38846, 38848, 'TRANSFERTCLS', 3, 0, 0, '   ()', '    ', 12, '', '', '', 0, 0, null, 0, 22773, 0, 0, 0, '', 30, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'TRANSFERTCLS', '') ;

CALL FIELDSINFO_IMPORT(38871, 0, 2, 17474, 38846, 38847, 'VARIANT', 3, 0, 0, ' ', ' ', 4, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 31, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'VARIANT', '') ;

--  
DROP PROCEDURE SELECTIONS_IMPORT
/

DROP PROCEDURE SELECTIONSDETAIL_IMPORT
/

DROP PROCEDURE FIELDSINFO_IMPORT
/

DROP PROCEDURE SELECTIONEVENTS_IMPORT
/

DROP PROCEDURE FIELDSINFO_DELETE
/

DROP PROCEDURE SELECTIONSDETAIL_DELETE
/

DROP PROCEDURE SELECTIONS_DELETE
/

DROP PROCEDURE SELECTIONEVENTS_DELETE
/

CREATE OR REPLACE PROCEDURE ImportDocCLS (
   ID_                 NUMBER,
   DOCTYPE_            NUMBER,
   DOCTYPENOTE_        VARCHAR2,
   TABLENAME_          VARCHAR2,
   TABLENAMEURM_       VARCHAR2,
   PRIMARYKEYNAME_     VARCHAR2,
   PRIMARYKEYNAMEURM_  VARCHAR2,
   LINKFIELDNAME_      VARCHAR2,
   LINKFIELDNAMEURM_   VARCHAR2,
   CLSTYPE_            NUMBER,
   SELECTIONREFBUDGET_ NUMBER,
   SELECTIONREFURM_    NUMBER,
   PROGINDEX_          NUMBER
) IS IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
   INTO IDExists$
   FROM DOCUMENTCLS
   WHERE (ID = ID_);

   IF (IDExists$ = 0) THEN
   INSERT INTO DOCUMENTCLS
   (ID, DOCTYPE, DOCTYPENOTE, TABLENAME, TABLENAMEURM, PRIMARYKEYNAME, PRIMARYKEYNAMEURM, LINKFIELDNAME, LINKFIELDNAMEURM, CLSTYPE, 
     SELECTIONREFBUDGET, SELECTIONREFURM, PROGINDEX)
   VALUES (ID_, DOCTYPE_, DOCTYPENOTE_, TABLENAME_, TABLENAMEURM_, PRIMARYKEYNAME_, PRIMARYKEYNAMEURM_, LINKFIELDNAME_, LINKFIELDNAMEURM_, CLSTYPE_, 
     SELECTIONREFBUDGET_, SELECTIONREFURM_, PROGINDEX_);
   ELSE
   UPDATE DOCUMENTCLS 
   SET
     DOCTYPENOTE = DOCTYPENOTE_,
     TABLENAME = TABLENAME_,
     TABLENAMEURM = TABLENAMEURM_,
     PRIMARYKEYNAME = PRIMARYKEYNAME_,
     PRIMARYKEYNAMEURM = PRIMARYKEYNAMEURM_,
     LINKFIELDNAME = LINKFIELDNAME_,
     LINKFIELDNAMEURM = LINKFIELDNAMEURM_,
     CLSTYPE = CLSTYPE_,
     SELECTIONREFBUDGET = SELECTIONREFBUDGET_,
     SELECTIONREFURM = SELECTIONREFURM_,
     PROGINDEX = PROGINDEX_
   WHERE  
    (ID = ID_)
    AND NOT (
            (
                    ((DOCTYPENOTE IS NOT NULL AND DOCTYPENOTE_ IS NOT NULL) AND
                       (UPPER (DOCTYPENOTE) = UPPER (DOCTYPENOTE_))
                    )
                    OR (DOCTYPENOTE IS NULL AND DOCTYPENOTE_ IS NULL)
                )    
        AND (UPPER (TABLENAME) = UPPER (TABLENAME_))    
        AND (
                    ((TABLENAMEURM IS NOT NULL AND TABLENAMEURM_ IS NOT NULL) AND
                       (UPPER (TABLENAMEURM) = UPPER (TABLENAMEURM_))
                    )
                    OR (TABLENAMEURM IS NULL AND TABLENAMEURM_ IS NULL)
                )    
        AND (UPPER (PRIMARYKEYNAME) = UPPER (PRIMARYKEYNAME_))
        AND (
                    ((PRIMARYKEYNAMEURM IS NOT NULL AND PRIMARYKEYNAMEURM_ IS NOT NULL) AND
                       (UPPER (PRIMARYKEYNAMEURM) = UPPER (PRIMARYKEYNAMEURM_))
                    )
                    OR (PRIMARYKEYNAMEURM IS NULL AND PRIMARYKEYNAMEURM_ IS NULL)
                )    
        AND (
                    ((LINKFIELDNAME IS NOT NULL AND LINKFIELDNAME_ IS NOT NULL) AND
                       (UPPER (LINKFIELDNAME) = UPPER (LINKFIELDNAME_))
                    )
                    OR (LINKFIELDNAME IS NULL AND LINKFIELDNAME_ IS NULL)
                )    
        AND (
                    ((LINKFIELDNAMEURM IS NOT NULL AND LINKFIELDNAMEURM_ IS NOT NULL) AND
                       (UPPER (LINKFIELDNAMEURM) = UPPER (LINKFIELDNAMEURM_))
                    )
                    OR (LINKFIELDNAMEURM IS NULL AND LINKFIELDNAMEURM_ IS NULL)
                )    
        AND (
                    ((CLSTYPE IS NOT NULL AND CLSTYPE_ IS NOT NULL) AND
                       (UPPER (CLSTYPE) = UPPER (CLSTYPE_))
                    )
                    OR (CLSTYPE IS NULL AND CLSTYPE_ IS NULL)
                ) 
        AND (
                    ((PROGINDEX IS NOT NULL AND PROGINDEX_ IS NOT NULL) AND
                       (PROGINDEX = PROGINDEX_)
                    )
                    OR (PROGINDEX IS NULL AND PROGINDEX_ IS NULL)
                )   
            );
   
   END IF;
END;
/

--   
CALL ImportDocCLS(10100, 101, '', 'FINDOCCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 223) ;

CALL ImportDocCLS(10101, 101, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, 223) ;

CALL ImportDocCLS(10102, 101, ' ', 'FINDOCDETAIL', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(10103, 101, ' ', 'DEBT', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(10104, 101, ' %  ', 'FINDOCDETAIL', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(10105, 101, ' ', 'INCOMES32', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(20100, 201, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 32) ;

CALL ImportDocCLS(20101, 201, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 32) ;

CALL ImportDocCLS(30100, 301, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 66) ;

CALL ImportDocCLS(30101, 301, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 66) ;

CALL ImportDocCLS(30200, 302, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 63) ;

CALL ImportDocCLS(30201, 302, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 63) ;

CALL ImportDocCLS(30300, 303, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 65) ;

CALL ImportDocCLS(30301, 303, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 65) ;

CALL ImportDocCLS(30400, 304, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 64) ;

CALL ImportDocCLS(30401, 304, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 64) ;

CALL ImportDocCLS(30500, 305, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 61) ;

CALL ImportDocCLS(30501, 305, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 61) ;

CALL ImportDocCLS(30600, 306, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 62) ;

CALL ImportDocCLS(30601, 306, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 62) ;

CALL ImportDocCLS(30700, 307, '', 'FACIALFINREESTR', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(31100, 311, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 68) ;

CALL ImportDocCLS(31101, 311, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 68) ;

CALL ImportDocCLS(31200, 312, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 69) ;

CALL ImportDocCLS(31201, 312, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 69) ;

CALL ImportDocCLS(31400, 314, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 70) ;

CALL ImportDocCLS(31401, 314, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 70) ;

CALL ImportDocCLS(31500, 315, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 71) ;

CALL ImportDocCLS(31501, 315, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 71) ;

CALL ImportDocCLS(992500, 9925, '', 'Cards', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992501, 9925, ' ', 'CARDSDETAIL_FACC', ' ', 'ID', ' ', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(490300, 4903, '', 'DATAPACKET', ' ', 'ID', ' ', '', ' ', 0, null, null, 527) ;

CALL ImportDocCLS(32200, 322, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 73) ;

CALL ImportDocCLS(32201, 322, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 73) ;

CALL ImportDocCLS(32300, 323, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 75) ;

CALL ImportDocCLS(32301, 323, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 75) ;

CALL ImportDocCLS(32400, 324, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 76) ;

CALL ImportDocCLS(32401, 324, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 76) ;

CALL ImportDocCLS(40100, 401, '', 'LOANCREDIT', ' ', 'ID', ' ', '', ' ', 0, null, null, 130) ;

CALL ImportDocCLS(40101, 401, '', 'DEBT', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 131) ;

CALL ImportDocCLS(40102, 401, ' ', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 137) ;

CALL ImportDocCLS(40103, 401, '', 'DEBT', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 132) ;

CALL ImportDocCLS(40104, 401, ' %', 'LOANCREDITPERCENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 134) ;

CALL ImportDocCLS(40105, 401, '  %', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 138) ;

CALL ImportDocCLS(40106, 401, ' %', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 133) ;

CALL ImportDocCLS(40107, 401, ' %', 'PERCENTJOURNAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(40108, 401, '. ', 'DEBT', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(40109, 401, '', 'COLLATERAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 340) ;

CALL ImportDocCLS(40110, 401, '.', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 341) ;

CALL ImportDocCLS(40111, 401, '', 'LOANCREDITCONTRACTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 342) ;

CALL ImportDocCLS(50100, 501, '', 'LOANCREDIT', ' ', 'ID', ' ', '', ' ', 0, null, null, 120) ;

CALL ImportDocCLS(50101, 501, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 121) ;

CALL ImportDocCLS(50102, 501, ' ', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 127) ;

CALL ImportDocCLS(50103, 501, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 122) ;

CALL ImportDocCLS(50104, 501, ' %', 'LOANCREDITPERCENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 124) ;

CALL ImportDocCLS(50105, 501, '  %', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 128) ;

CALL ImportDocCLS(50106, 501, ' %', 'INCOMES32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 123) ;

CALL ImportDocCLS(50107, 501, ' %', 'PERCENTJOURNAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(50108, 501, '', 'COLLATERAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 321) ;

CALL ImportDocCLS(70100, 701, '', 'FINDOCCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 23) ;

CALL ImportDocCLS(70101, 701, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 23) ;

CALL ImportDocCLS(70200, 702, '', 'PAYDOC32', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(70201, 702, '', 'PAYDOC32', ' ', 'ID', ' ', 'PARENTINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(70300, 703, '', 'FINDOCDETAIL', ' ', 'ID', ' ', '', ' ', 0, null, null, 36) ;

CALL ImportDocCLS(80100, 801, '', 'LIMITNOTIFYCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80101, 801, '', 'LIMITFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 57) ;

CALL ImportDocCLS(80200, 802, '', 'LIMITFINDETAIL', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80300, 803, '', 'REQUESTFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80301, 803, '', 'LIMITFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80400, 804, '', 'LIMITFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(90100, 901, '', 'QUOTESTITLE', ' ', 'ID', ' ', '', ' ', 0, null, null, 145) ;

CALL ImportDocCLS(90101, 901, '', 'INCOMES32', ' ', 'ID', ' ', 'RecordIndex', ' ', 0, null, null, 0) ;

CALL ImportDocCLS(90300, 903, '', 'QUOTESTITLE', ' ', 'ID', ' ', '', ' ', 0, null, null, 45) ;

CALL ImportDocCLS(90301, 903, '', 'INCOMES32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 45) ;

CALL ImportDocCLS(90500, 905, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, 44) ;

CALL ImportDocCLS(90600, 906, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, 41) ;

CALL ImportDocCLS(90601, 906, '', 'INCOMES32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 42) ;

CALL ImportDocCLS(120100, 1201, '', 'BUH_JOURNAL', ' ', 'ID', ' ', '', ' ', 0, null, null, 309) ;

CALL ImportDocCLS(150100, 1501, '', 'ORGOPERAT', ' ', 'ID', ' ', '', ' ', 0, null, null, 35) ;

CALL ImportDocCLS(160100, 1601, '', 'PROMISE_CAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(160101, 1601, '', 'PROMISE_DETAIL', ' ', 'ID', ' ', 'TITLE_REF', ' ', 0, null, null, 345) ;

CALL ImportDocCLS(160200, 1602, '', 'PROMISE_DETAIL', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(170100, 1701, '', 'REQUESTS', ' ', 'ID', ' ', '', ' ', 0, null, null, 222) ;

CALL ImportDocCLS(170200, 1702, '', 'REQUESTS', ' ', 'ID', ' ', '', ' ', 0, null, null, 221) ;

CALL ImportDocCLS(170201, 1702, '', 'REQUESTSPAYMENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(190100, 1901, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 264) ;

CALL ImportDocCLS(190101, 1901, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 264) ;

CALL ImportDocCLS(220100, 2201, '', 'BUDNOTIFY', 'BUDNOTIFY', 'ID', ' ', '', ' ', 0, null, null, 46) ;

CALL ImportDocCLS(220101, 2201, '', 'BUDGETDATA', 'BUDGETDATA', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 46) ;

CALL ImportDocCLS(280100, 2801, '', 'ACCSOPERTITLE', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(280101, 2801, '', 'PAYDOC32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 16) ;

CALL ImportDocCLS(280200, 2802, '', 'DFACCOUNTOPERATION', ' ', 'ID', ' ', '', ' ', 0, null, null, 50) ;

CALL ImportDocCLS(440100, 4401, '', 'UNIONNOTIFYCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 251) ;

CALL ImportDocCLS(440101, 4401, '', 'UNIONNOTIFYDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 251) ;

CALL ImportDocCLS(0, 0, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991304, 9913, ' ', 'STATICLINKS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(440300, 4403, '', 'UNIONNOTIFYCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 254) ;

CALL ImportDocCLS(440301, 4403, '', 'UNIONNOTIFYDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 254) ;

CALL ImportDocCLS(989500, 9895, ' ', 'OKTMO', 'OKTMO', 'id', 'id', '', '', 95, null, null, null) ;

CALL ImportDocCLS(990300, 9903, '', 'ORGANIZATIONS', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(990301, 9903, ' ', 'ORG_ACCOUNTS', ' ', 'ID', ' ', 'ORG_REF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(990302, 9903, ' ', 'FACIALACC_CLS', ' ', 'ID', ' ', 'ORG_REF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(990500, 9905, '', 'ORGANIZATIONS', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(90200, 902, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, 38) ;

CALL ImportDocCLS(20701, 207, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 272) ;

CALL ImportDocCLS(90700, 907, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(181200, 1812, '', 'ED_CorrectionCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181000, 1810, '', 'ED_OUTPAYDOC', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(20700, 207, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 272) ;

CALL ImportDocCLS(181001, 1810, '', 'ED_DETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(992700, 9927, '', 'REMOTECLIENT', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(550100, 5501, '', 'CORRECTIONCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 312) ;

CALL ImportDocCLS(20801, 208, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 273) ;

CALL ImportDocCLS(30701, 307, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', 'REESTR_REF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(21100, 211, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 275) ;

CALL ImportDocCLS(490100, 4901, '', 'DATAPACKET', ' ', 'ID', ' ', '', ' ', 0, null, null, 525) ;

CALL ImportDocCLS(992701, 9927, '  ', 'REMOTEREADRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(550101, 5501, '', 'CORRECTIONDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 312) ;

CALL ImportDocCLS(490301, 4903, '', 'ARCHIVEOPLOG', ' ', 'ID', ' ', 'DATAPACKETREF', '', 0, null, null, null) ;

CALL ImportDocCLS(390100, 3901, '', 'DELOIN', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(21101, 211, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 275) ;

CALL ImportDocCLS(992300, 9923, '', 'SIGNSCHEMECAPTION', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181201, 1812, '', 'ED_CorrectionDetail', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(550200, 5502, '', 'CORRECTIONCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 313) ;

CALL ImportDocCLS(20800, 208, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 273) ;

CALL ImportDocCLS(550201, 5502, '', 'CORRECTIONDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 313) ;

CALL ImportDocCLS(90000, 900, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992301, 9923, '', 'SIGNSCHEMEDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(991600, 9916, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992200, 9922, '', 'ARCHIVEDOCTYPE', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(90001, 900, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(390101, 3901, '', 'DELOEXEC', ' ', 'ID', ' ', 'DOCID', ' ', 0, null, null, null) ;

CALL ImportDocCLS(180700, 1807, '', 'PayDocExchange', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(21102, 211, '2', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 275) ;

CALL ImportDocCLS(991700, 9917, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991200, 9912, '', 'DFACCOUNTSBUHTABLE', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(181600, 1816, '', 'FacialFinCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(30800, 308, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 67) ;

CALL ImportDocCLS(250100, 2501, '', 'AGREEMENTS', 'AGREEMENTS', 'ID', 'ID', '', ' ', 0, null, null, 305) ;

CALL ImportDocCLS(21200, 212, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 276) ;

CALL ImportDocCLS(250101, 2501, '  ', 'ESTIMATE', 'ESTIMATE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, 305) ;

CALL ImportDocCLS(30801, 308, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 67) ;

CALL ImportDocCLS(250200, 2502, '', 'AGREEMENTS', 'AGREEMENTS', 'ID', 'ID', '', ' ', 0, null, null, 304) ;

CALL ImportDocCLS(250201, 2502, ' ', 'AGREEMENTSTEPS', 'AGREEMENTSTEPS', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(988900, 9889, ' ', 'SubsidyCls', ' ', 'id', ' ', '', '', 89, null, null, null) ;

CALL ImportDocCLS(250202, 2502, '  ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'AGREEMENTREF', 'AGREEMENTREF', 0, null, null, 304) ;

CALL ImportDocCLS(988700, 9887, ' ', 'VariantCls', ' ', 'ID', ' ', '', '', 87, null, null, null) ;

CALL ImportDocCLS(520100, 5201, '', 'WritExecutionCaption', 'WritExecutionCaption', 'id', 'id', '', '', 0, null, null, 555) ;

CALL ImportDocCLS(990800, 9908, '', 'DocumentTypes', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(250300, 2503, '', 'EXECUTIONDOCUMENTSCAPTION', 'EXECUTIONDOCUMENTSCAPTION', 'ID', 'ID', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(21201, 212, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 276) ;

CALL ImportDocCLS(250301, 2503, '', 'EXECUTIONDOCUMENTSDETAIL', 'EXECUTIONDOCUMENTSDETAIL', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(180500, 1805, '', 'BANKEXCH_MERDOC', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(20201, 202, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 260) ;

CALL ImportDocCLS(20301, 203, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 261) ;

CALL ImportDocCLS(20401, 204, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 262) ;

CALL ImportDocCLS(20501, 205, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 263) ;

CALL ImportDocCLS(20601, 206, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 268) ;

CALL ImportDocCLS(190201, 1902, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 215) ;

CALL ImportDocCLS(190301, 1903, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 265) ;

CALL ImportDocCLS(20000, 200, '', 'BUDNOTIFY', ' ', 'id', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(190601, 1906, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 271) ;

CALL ImportDocCLS(20200, 202, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 260) ;

CALL ImportDocCLS(20300, 203, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 261) ;

CALL ImportDocCLS(20400, 204, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 262) ;

CALL ImportDocCLS(20500, 205, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 263) ;

CALL ImportDocCLS(20600, 206, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 268) ;

CALL ImportDocCLS(190200, 1902, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 215) ;

CALL ImportDocCLS(190300, 1903, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 265) ;

CALL ImportDocCLS(180501, 1805, '', 'ED_DETAIL', ' ', 'ID', ' ', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(190600, 1906, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 271) ;

CALL ImportDocCLS(988400, 9884, ' ', 'TransfertCLS', ' ', 'ID', ' ', '', '', 84, null, null, null) ;

CALL ImportDocCLS(988800, 9888, ' ', 'OKP', ' ', 'ID', ' ', '', '', 88, null, null, null) ;

CALL ImportDocCLS(989900, 9899, ' ', 'DBUsers', ' ', 'ID', ' ', '', '', 201, null, null, null) ;

CALL ImportDocCLS(990801, 9908, ' ', 'DOCUMENTFIELDS', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(361000, 3610, '', 'UTYPEDFORMSCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 550) ;

CALL ImportDocCLS(987200, 9872, ' ', 'BalanceCls', ' ', 'ID', ' ', '', '', 72, null, null, null) ;

CALL ImportDocCLS(984600, 9846, ' ', 'BUHPAYMENTCLS', ' ', 'ID', ' ', '', '', 46, null, null, null) ;

CALL ImportDocCLS(981800, 9818, ' ', 'CURRENCYCLS', ' ', 'ID', ' ', '', '', 18, null, null, null) ;

CALL ImportDocCLS(988500, 9885, ' ', 'AssignmentKind', ' ', 'ID', ' ', '', '', 85, null, null, null) ;

CALL ImportDocCLS(983500, 9835, ' ', 'BUDGETTYPE', ' ', 'ID', ' ', '', '', 35, null, null, null) ;

CALL ImportDocCLS(985800, 9858, ' ', 'DEBTTYPE', ' ', 'ID', ' ', '', '', 58, null, null, null) ;

CALL ImportDocCLS(988600, 9886, ' ', 'AssignmentSource', ' ', 'ID', ' ', ' ', ' ', 86, null, null, null) ;

CALL ImportDocCLS(988300, 9883, ' ', 'Org_Type', ' ', 'ID', ' ', '', '', 83, null, null, null) ;

CALL ImportDocCLS(986400, 9864, ' ', 'PlanDocType', ' ', 'ID', ' ', '', '', 64, null, null, null) ;

CALL ImportDocCLS(985700, 9857, ' ', 'LOANTYPE', ' ', 'ID', ' ', '', '', 57, null, null, null) ;

CALL ImportDocCLS(984300, 9843, ' ', 'PAYTYPECLS', ' ', 'ID', ' ', '', '', 43, null, null, null) ;

CALL ImportDocCLS(982300, 9823, ' ', 'GOSNI', ' ', 'ID', ' ', '', '', 23, null, null, null) ;

CALL ImportDocCLS(982200, 9822, ' ', 'GroupInf_CLS', ' ', 'ID', ' ', '', '', 22, null, null, null) ;

CALL ImportDocCLS(982900, 9829, ' ', 'DocBase', ' ', 'ID', ' ', '', '', 29, null, null, null) ;

CALL ImportDocCLS(981100, 9811, ' ', 'DocTypes', ' ', 'ID', ' ', '', '', 11, null, null, null) ;

CALL ImportDocCLS(986000, 9860, ' ', 'MEASUREMENTCLS', ' ', 'ID', ' ', '', '', 60, null, null, null) ;

CALL ImportDocCLS(988000, 9880, ' ', 'FundsSource', ' ', 'ID', ' ', '', '', 80, null, null, null) ;

CALL ImportDocCLS(985200, 9852, ' ', 'InnerFinSource', ' ', 'ID', ' ', '', '', 52, null, null, null) ;

CALL ImportDocCLS(981300, 9813, ' ', 'NOTIFYTYPES', ' ', 'ID', ' ', '', '', 13, null, null, null) ;

CALL ImportDocCLS(984500, 9845, ' ', 'PAYSYMBOLCLS', ' ', 'ID', ' ', '', '', 45, null, null, null) ;

CALL ImportDocCLS(980400, 9804, ' ', 'KVR', ' ', 'ID', ' ', '', '', 4, null, null, null) ;

CALL ImportDocCLS(980300, 9803, ' ', 'KVSR', ' ', 'ID', ' ', '', '', 3, null, null, null) ;

CALL ImportDocCLS(980900, 9809, ' ', 'KD', ' ', 'ID', ' ', '', '', 9, null, null, null) ;

CALL ImportDocCLS(984700, 9847, ' ', 'TYPEOPERATIONCLS', ' ', 'ID', ' ', '', '', 47, null, null, null) ;

CALL ImportDocCLS(986800, 9868, ' ', 'KESR', ' ', 'ID', ' ', '', '', 68, null, null, null) ;

CALL ImportDocCLS(987900, 9879, ' ', 'TargetCls', ' ', 'ID', ' ', '', '', 79, null, null, null) ;

CALL ImportDocCLS(985100, 9851, ' ', 'Error', ' ', 'ID', ' ', '', '', 51, null, null, null) ;

CALL ImportDocCLS(982100, 9821, ' ', 'ACC_CLS', ' ', 'ID', ' ', '', '', 21, null, null, null) ;

CALL ImportDocCLS(981400, 9814, ' ', 'KSHK', ' ', 'ID', ' ', '', '', 14, null, null, null) ;

CALL ImportDocCLS(980200, 9802, ' ', 'kfsr', ' ', 'ID', ' ', '', '', 2, null, null, null) ;

CALL ImportDocCLS(980500, 9805, ' ', 'KCSR', ' ', 'ID', ' ', '', '', 5, null, null, null) ;

CALL ImportDocCLS(984100, 9841, ' ', 'FACIALACC_CLS', ' ', 'ID', ' ', '', '', 41, null, null, null) ;

CALL ImportDocCLS(981500, 9815, ' ', 'VALUECLS', ' ', 'ID', ' ', '', '', 15, null, null, null) ;

CALL ImportDocCLS(982800, 9828, ' ', 'FACT', ' ', 'ID', ' ', '', '', 28, null, null, null) ;

CALL ImportDocCLS(984800, 9848, ' ', 'PAYDESTINATIONCLS', ' ', 'ID', ' ', '', '', 48, null, null, null) ;

CALL ImportDocCLS(986900, 9869, ' ', 'DirectionCLS', ' ', 'ID', ' ', '', '', 69, null, null, null) ;

CALL ImportDocCLS(986200, 9862, ' ', 'OKATO', ' ', 'ID', ' ', '', '', 62, null, null, null) ;

CALL ImportDocCLS(988200, 9882, ' ', 'OKOPF', ' ', 'ID', ' ', '', '', 82, null, null, null) ;

CALL ImportDocCLS(988100, 9881, ' ', 'OKFS', ' ', 'ID', ' ', '', '', 81, null, null, null) ;

CALL ImportDocCLS(981600, 9816, ' ', 'MeansCLS', ' ', 'ID', ' ', '', '', 16, null, null, null) ;

CALL ImportDocCLS(985900, 9859, ' ', 'DepartmentCLS', ' ', 'ID', ' ', '', '', 59, null, null, null) ;

CALL ImportDocCLS(986500, 9865, ' ', 'BuhAccPlan', ' ', 'ID', ' ', '', '', 65, null, null, null) ;

CALL ImportDocCLS(986100, 9861, ' ', 'TenderObjects', ' ', 'ID', ' ', '', '', 61, null, null, null) ;

CALL ImportDocCLS(985000, 9850, ' ', 'RejectCLS', ' ', 'ID', ' ', '', '', 50, null, null, null) ;

CALL ImportDocCLS(987000, 9870, ' ', 'ProgramCode', ' ', 'ID', ' ', '', '', 70, null, null, null) ;

CALL ImportDocCLS(981200, 9812, ' ', 'RegionCLS', ' ', 'ID', ' ', '', '', 12, null, null, null) ;

CALL ImportDocCLS(982600, 9826, ' ', 'BUDGETACCOUNTS', ' ', 'ID', ' ', '', '', 26, null, null, null) ;

CALL ImportDocCLS(981700, 9817, ' ', 'REFCLS', ' ', 'ID', ' ', '', '', 17, null, null, null) ;

CALL ImportDocCLS(981000, 9810, ' ', 'SubKD', ' ', 'ID', ' ', '', '', 10, null, null, null) ;

CALL ImportDocCLS(980600, 9806, ' ', 'SUBKCSR', ' ', 'ID', ' ', '', '', 6, null, null, null) ;

CALL ImportDocCLS(980800, 9808, ' ', 'KESRSubCode', ' ', 'ID', ' ', '', '', 8, null, null, null) ;

CALL ImportDocCLS(986300, 9863, ' ', 'COLLATERALTYPE', ' ', 'ID', ' ', '', '', 63, null, null, null) ;

CALL ImportDocCLS(982000, 9820, ' ', 'ORG_CLS', ' ', 'ID', ' ', '', '', 20, null, null, null) ;

CALL ImportDocCLS(983400, 9834, ' ', 'ReportType', ' ', 'ID', ' ', '', '', 34, null, null, null) ;

CALL ImportDocCLS(985300, 9853, ' ', 'REESTRTYPE', ' ', 'ID', ' ', '', '', 53, null, null, null) ;

CALL ImportDocCLS(984900, 9849, ' ', 'MEANSTYPE', ' ', 'ID', ' ', '', '', 49, null, null, null) ;

CALL ImportDocCLS(982700, 9827, ' ', 'FinType', ' ', 'ID', ' ', '', '', 27, null, null, null) ;

CALL ImportDocCLS(984400, 9844, ' ', 'Org_AccDefaults', ' ', 'ID', ' ', '', '', 44, null, null, null) ;

CALL ImportDocCLS(960100, 9601, ' ', 'ORGANIZATIONS', ' ', 'ID', ' ', '', '', 1000, null, null, null) ;

CALL ImportDocCLS(960200, 9602, ' ', 'ORG_ACCOUNTS', ' ', 'ID', ' ', '', '', 1001, null, null, null) ;

CALL ImportDocCLS(960400, 9604, ' ', 'DFACCOUNTSBUHTABLE', ' ', 'ID', ' ', '', '', 1003, null, null, null) ;

CALL ImportDocCLS(960300, 9603, ' ', 'BANKS', ' ', 'ID', ' ', '', '', 1002, null, null, null) ;

CALL ImportDocCLS(987100, 9871, ' ', 'BuhOperationCls', ' ', 'Id', ' ', '', '', 71, null, null, null) ;

CALL ImportDocCLS(987800, 9878, ' ', 'budgets_s', ' ', 'id', ' ', '', '', 78, null, null, null) ;

CALL ImportDocCLS(991400, 9914, '', 'DATAPACKETTYPES', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991401, 9914, '', 'DATAPACKETCONTENT', ' ', 'ID', ' ', 'DATAPACKETTYPE', '', 0, null, null, null) ;

CALL ImportDocCLS(991500, 9915, '', 'UNLOCKDATES', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991501, 9915, '', 'UNLOCKDATES', ' ', 'ID', ' ', 'ID', '', 0, null, null, null) ;

CALL ImportDocCLS(20001, 200, '', 'BUDGETDATA', ' ', 'id', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(30000, 300, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(30001, 300, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(190000, 1900, '', 'BUDNOTIFY', ' ', 'id', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(190001, 1900, '', 'BUDGETDATA', ' ', 'id', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(220000, 2200, '', 'BUDNOTIFY', ' ', 'id', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(220001, 2200, '', 'BUDGETDATA', ' ', 'id', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(991300, 9913, '', 'INTERFACES', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991301, 9913, '', 'Permissions', ' ', 'ID', ' ', 'INTERFACEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(991302, 9913, '', 'LinkType', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991303, 9913, ' ', ' ', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(490200, 4902, '', 'DATAPACKET', ' ', 'ID', ' ', '', ' ', 0, null, null, 526) ;

CALL ImportDocCLS(250400, 2504, '', 'AGREEMENTS', 'AGREEMENTS', 'ID', 'ID', '', '', 0, null, null, 314) ;

CALL ImportDocCLS(300100, 3001, '', 'TenderCaption', ' ', 'ID', ' ', '', '', 0, null, null, 230) ;

CALL ImportDocCLS(250401, 2504, '  ', 'AGREEMENTSTEPS', 'AGREEMENTSTEPS', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(250402, 2504, '   ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'AGREEMENTREF', 'AGREEMENTREF', 0, null, null, 314) ;

CALL ImportDocCLS(250403, 2504, '  ', 'ESTIMATE', 'ESTIMATE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(300600, 3006, '', 'TENDERCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 241) ;

CALL ImportDocCLS(250102, 2501, '  . ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, 305) ;

CALL ImportDocCLS(70202, 702, '', 'PAYDOCEXCHANGE', ' ', 'ID', ' ', 'PAYDOCREF', '', 0, null, null, null) ;

CALL ImportDocCLS(170101, 1701, '', 'REQUESTSPAYMENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(20900, 209, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 274) ;

CALL ImportDocCLS(300601, 3006, '  ', 'TENDERPRODUCT', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 241) ;

CALL ImportDocCLS(300602, 3006, '   ', 'TENDERCONTACTS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300300, 3003, '', 'TenderResultCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(300101, 3001, ' ', 'TenderProduct', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 230) ;

CALL ImportDocCLS(300102, 3001, ' ', 'TenderLot', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300103, 3001, '   ', 'TENDERSOURCEORG', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300104, 3001, '   ', 'TENDERYARDSTICKS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300105, 3001, '   ', 'TENDERYARDSTICKS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300106, 3001, ' ', 'TENDERCONTACTS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300107, 3001, '   ', 'TENDERSUPPLEMENTS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300108, 3001, ',  ', 'TENDERSUPDOCUMENT', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(370100, 3701, '', 'TenderObjects', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(520101, 5201, '', 'WritExecutionDetail', 'WritExecutionDetail', 'id', 'id', 'RecordIndex', '', 0, null, null, 556) ;

CALL ImportDocCLS(20901, 209, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 274) ;

CALL ImportDocCLS(21000, 210, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 252) ;

CALL ImportDocCLS(21001, 210, ', ', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 252) ;

CALL ImportDocCLS(21002, 210, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 253) ;

CALL ImportDocCLS(991800, 9918, '', 'USERGENERATOR', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991801, 9918, '', 'USERGENERATORFIELDS', ' ', 'ID', ' ', 'GENREF', '', 0, null, null, null) ;

CALL ImportDocCLS(992702, 9927, '   ', 'REMOTEINPUTRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(21202, 212, '2', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 276) ;

CALL ImportDocCLS(990802, 9908, ' ', 'STATE_DOCSTATES', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(990803, 9908, '', 'STATE_JUMPS', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(990804, 9908, '', 'STATE_ACTIONS', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(992703, 9927, '   ', 'REMOTECLIENTACCOUNT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(992000, 9920, '', 'BUHOPERATIONCLS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992001, 9920, '', 'BUHACCCORR', ' ', 'ID', ' ', 'BUHOPERATIONCLS', '', 0, null, null, null) ;

CALL ImportDocCLS(992100, 9921, '', 'BUDGETS_S', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992101, 9921, ' ', 'FACIALACC_CLS', ' ', 'ID', ' ', 'BUDGETREF', '', 0, null, null, null) ;

CALL ImportDocCLS(992102, 9921, ' ', 'DFACCOUNTSBUHTABLE', ' ', 'ID', ' ', 'BUDGETREF', '', 0, null, null, null) ;

CALL ImportDocCLS(989000, 9890, ' ', 'BudAllocationCls', ' ', 'id', ' ', '', '', 90, null, null, null) ;

CALL ImportDocCLS(989100, 9891, ' ', 'PayPromiseCls', ' ', 'id', ' ', '', '', 91, null, null, null) ;

CALL ImportDocCLS(550300, 5503, '', 'ReplacementClsCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(550301, 5503, '   ', 'ReplacementClsDetail', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(550302, 5503, ' ', 'ReplacementClsDetailInfo', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(250302, 2503, ' ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'EXECUTIONREF', '', 0, null, null, 308) ;

CALL ImportDocCLS(181400, 1814, '', 'BANKEXCH_LS_KB', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(180900, 1809, '', 'BANKEXCH_SUBSTITUTION', 'BANKEXCH_SUBSTITUTION', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181500, 1815, '', 'BANKEXCH_KO_SALDO', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992900, 9929, '', 'BudStruct', 'BudStruct', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992201, 9922, '', 'ARCHIVEDOCPARAMS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(992400, 9924, '', 'SIGNS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(480101, 4801, '', 'GeneralDocsDetail', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992502, 9925, '', 'CARDSDETAIL_KESR', ' ', 'ID', ' ', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(250203, 2502, ' ', 'ESTIMATE', 'ESTIMATE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, 304) ;

CALL ImportDocCLS(250404, 2504, ' ', 'EXECUTIONDOCUMENTSCAPTION', 'EXECUTIONDOCUMENTSCAPTION', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(520102, 5201, '2', 'WritExecutionNotify', 'WritExecutionNotify', 'id', 'id', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(989200, 9892, ' ', 'ArchiveDocType', ' ', 'id', ' ', '', '', 92, null, null, null) ;

CALL ImportDocCLS(480100, 4801, '', 'GeneralDocuments', ' ', 'ID', ' ', '', '', 0, null, null, 528) ;

CALL ImportDocCLS(992600, 9926, '', 'WritNotifyCls', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992601, 9926, '', 'WRITNOTIFYCLSDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(992602, 9926, ' ', 'WritNotifyClsPart', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(31600, 316, '', 'ManagerBid', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(20902, 209, '2', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 274) ;

CALL ImportDocCLS(992704, 9927, '  + /', 'DUALRIGHTS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992705, 9927, ' ', 'REMOTEEDSRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(992706, 9927, ' ', 'REMOTEEDSRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(990400, 9904, '', 'CONTACTPERSONS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181601, 1816, '', 'FacialFinCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992707, 9927, '', 'SIGNCERTIFICATE', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992708, 9927, '  ', 'SIGNDOCUMENTSGROUP', ' ', 'ID', ' ', 'CLIENTREF', '', 0, null, null, null) ;

CALL ImportDocCLS(510100, 5101, '', 'StoredAttributesCaption', 'StoredAttributesCaption', 'id', 'id', '', '', 0, null, null, null) ;

CALL ImportDocCLS(510101, 5101, '', 'StoredAttributesDetail', 'StoredAttributesDetail', 'id', 'id', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(250405, 2504, ' ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(993000, 9930, '', 'AUTOSANCTIONDATA', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(301000, 3010, '', 'TENDERCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 242) ;

CALL ImportDocCLS(970200, 9702, ' ', 'AnalyticalGroupIFS', 'AnalyticalGroupIFS', 'ID', 'ID', '', '', 102, null, null, null) ;

CALL ImportDocCLS(970100, 9701, ' ', 'AnalyticalGroupKD', 'AnalyticalGroupKD', 'ID', 'ID', '', '', 101, null, null, null) ;

CALL ImportDocCLS(301100, 3011, '', 'TENDERCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 243) ;

CALL ImportDocCLS(301101, 3011, ' ', 'TENDERPRODUCT', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 243) ;

CALL ImportDocCLS(300500, 3005, '', 'TENDERCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 240) ;

DROP PROCEDURE ImportDocCLS
/

COMMIT WORK
/


CREATE OR REPLACE PROCEDURE ImportField (
   ID_                NUMBER,
   NAME_              VARCHAR2,
   ITFFIELDNAME_      VARCHAR2,
   NOTE_              VARCHAR2,
   TEMPLATEFIELD_     VARCHAR2,
   ISBUDGET_          NUMBER,
   DOCTYPEREF_        NUMBER,
   DETAILNUMBER_      NUMBER,
   ONLYREAD_          NUMBER,
   ReportFieldName_   VARCHAR2,
   KIND_	      NUMBER,
   FIELDINFOREF_      NUMBER,
   CONTAINERREF_      NUMBER, 
   ATTRFIELDKIND_     NUMBER,
   ATTRIBUTENAME_     VARCHAR2
) IS
   IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
     INTO IDExists$
     FROM DocumentFields
    WHERE (ID = ID_);

   IF (IDExists$ <> 0) THEN
      UPDATE DocumentFields
         SET NAME = NAME_,
             ITFFIELDNAME = ITFFIELDNAME_,
             NOTE = NOTE_,
             TEMPLATEFIELD = TEMPLATEFIELD_,
             ISBUDGET = ISBUDGET_,
             DOCTYPEREF = DOCTYPEREF_,
             DETAILNUMBER = DETAILNUMBER_,
             ONLYREAD = ONLYREAD_,
             ReportFieldName = ReportFieldName_,
			       FIELDINFOREF = FIELDINFOREF_, 
             CONTAINERREF = CONTAINERREF_, 
             ATTRFIELDKIND = ATTRFIELDKIND_,
             ATTRIBUTENAME = ATTRIBUTENAME_
       WHERE (ID = ID_)
         AND NOT (
                      (
                          (
                           (NAME IS NOT NULL AND NAME_ IS NOT NULL) AND
                           (UPPER (NAME) = UPPER (NAME_))
                          )
                       OR (NAME IS NULL AND NAME_ IS NULL)
                      )

                  AND (
                          (
                           (ITFFIELDNAME_ IS NOT NULL AND ITFFIELDNAME IS NOT NULL) AND
                           (UPPER (ITFFIELDNAME_) = UPPER (ITFFIELDNAME))
                          )
                       OR (ITFFIELDNAME_ IS NULL AND ITFFIELDNAME IS NULL)
                      )
                      
                  AND (
                          (
                           (NOTE IS NOT NULL AND NOTE_ IS NOT NULL) AND
                           (UPPER (NOTE) = UPPER (NOTE_))
                          )
                       OR (NOTE IS NULL AND NOTE_ IS NULL)
                      )
                  AND (UPPER (TEMPLATEFIELD) = UPPER (TEMPLATEFIELD_))
                  AND (
                          (
                           (ISBUDGET IS NOT NULL AND ISBUDGET_ IS NOT NULL) AND
                           (ISBUDGET = ISBUDGET_)
                          )
                       OR (ISBUDGET IS NULL AND ISBUDGET_ IS NULL)
                      )
                  AND (
                          (
                           (FIELDINFOREF IS NOT NULL AND FIELDINFOREF_ IS NOT NULL) AND
                           (FIELDINFOREF = FIELDINFOREF_)
                          )
                       OR (FIELDINFOREF IS NULL AND FIELDINFOREF_ IS NULL)
                      )
                  AND (
                          (
                           (CONTAINERREF IS NOT NULL AND CONTAINERREF_ IS NOT NULL) AND
                           (CONTAINERREF = CONTAINERREF_)
                          )
                       OR (CONTAINERREF IS NULL AND CONTAINERREF_ IS NULL)
                      )   
                  AND (
                          (
                           (ATTRFIELDKIND IS NOT NULL AND ATTRFIELDKIND_ IS NOT NULL) AND
                           (ATTRFIELDKIND = ATTRFIELDKIND_)
                          )
                       OR (ATTRFIELDKIND IS NULL AND ATTRFIELDKIND_ IS NULL)
                      )
                  AND (
                          (
                           (ATTRIBUTENAME_ IS NOT NULL AND ATTRIBUTENAME IS NOT NULL) AND
                           (UPPER (ATTRIBUTENAME_) = UPPER (ATTRIBUTENAME))
                          )
                       OR (ATTRIBUTENAME_ IS NULL AND ATTRIBUTENAME IS NULL)
                      )
                  AND (DOCTYPEREF = DOCTYPEREF_)
                  AND (DETAILNUMBER = DETAILNUMBER_)
                  AND (ONLYREAD = ONLYREAD_)
                  AND (
                          (
                           (ReportFieldName IS NOT NULL AND ReportFieldName_ IS NOT NULL) AND
                           (UPPER (ReportFieldName) = UPPER (ReportFieldName_))
                          )
                       OR (ReportFieldName IS NULL AND ReportFieldName_ IS NULL)
                      )
                 );
   ELSE
      INSERT INTO DocumentFields
                  (ID, NAME, ITFFIELDNAME, NOTE, TEMPLATEFIELD,
                   ISBUDGET, DOCTYPEREF, DETAILNUMBER, ONLYREAD, ReportFieldName, FIELDINFOREF, CONTAINERREF, ATTRFIELDKIND, ATTRIBUTENAME
                  )
           VALUES (ID_, NAME_, ITFFIELDNAME_, NOTE_, TEMPLATEFIELD_,
                   ISBUDGET_, DOCTYPEREF_, DETAILNUMBER_, ONLYREAD_, ReportFieldName_, FIELDINFOREF_, CONTAINERREF_, ATTRFIELDKIND_, ATTRIBUTENAME_
                  );
   END IF;

   FOR tab_rec IN (
                   SELECT ID
                     FROM DocumentFields
                    WHERE (ID <> ID_)
                      AND (DOCTYPEREF = DOCTYPEREF_)
                      AND (
                              (
                               (ISBUDGET IS NOT NULL AND ISBUDGET_ IS NOT NULL) AND
                               (ISBUDGET = ISBUDGET_)
                              )
                           OR (ISBUDGET IS NULL AND ISBUDGET_ IS NULL)
                          )
                      AND (DETAILNUMBER = DETAILNUMBER_)
              AND ( /*      ,       ,       */
                            (
                             ((ITFFIELDNAME_ IS NULL)or(ITFFIELDNAME_=' '))
                 and not((TEMPLATEFIELD_ IS NULL)or(TEMPLATEFIELD_=' '))
                 and(TEMPLATEFIELD is NOT null) and (UPPER(TEMPLATEFIELD)=UPPER(TEMPLATEFIELD_))
                            )
                    or (
                        not ((ITFFIELDNAME_ IS NULL) or (ITFFIELDNAME_=' '))
                                and (ITFFIELDNAME IS NOT NULL) and (UPPER(ITFFIELDNAME)=UPPER(ITFFIELDNAME_)))
                            )
                       )
   LOOP
      UPDATE State_OpenFields
         SET DOCFIELDREF = ID_
       WHERE (DOCFIELDREF = tab_rec.ID);

      UPDATE DOCLOCKFIELDS
         SET FIELDREF = ID_
       WHERE (FIELDREF = tab_rec.ID);

      UPDATE staticlinks
         SET PARENTFIELDREF = ID_
      WHERE (PARENTFIELDREF = tab_rec.ID);

      UPDATE staticlinks
         SET CHILDFIELDREF = ID_
      WHERE (CHILDFIELDREF = tab_rec.ID);

      DELETE FROM DocumentFields
            WHERE (ID = tab_rec.ID);
   END LOOP;
END;
/

CREATE OR REPLACE PROCEDURE DeleteFields (ID$ NUMBER) IS
BEGIN
  DELETE FROM State_OpenFields
  WHERE (docfieldref = ID$);
  DELETE FROM DOCLOCKFIELDS
  WHERE (fieldref = ID$);

  DELETE FROM STATE_JUMPCONTROL
  WHERE STATICLINKREF IN(SELECT ID FROM staticlinks
                           WHERE (PARENTFIELDREF=ID$)OR(CHILDFIELDREF=ID$));
  DELETE FROM staticlinks
  WHERE (PARENTFIELDREF=ID$)OR(CHILDFIELDREF=ID$);
  
  DELETE FROM DOCUMENTTEMPLATEFIELDS
  WHERE (FIELDS=ID$);

  DELETE FROM DocumentFields
  WHERE (id = ID$);
END;
/

CREATE OR REPLACE PROCEDURE INSERTCONST (
  PROGINDEX_     NUMBER,
  CONSTINDEX_    NUMBER,
  CONSTTYPE_     NUMBER,
  NOTE_          VARCHAR2,
  VARCHARVALUE_  VARCHAR2,
  DOUBLEVALUE_   NUMBER,
  INTVALUE_      INTEGER,
  EDITDOCCODE_   INTEGER
) IS
  IDEXISTS$ NUMBER;
BEGIN
  IF (CONSTTYPE_ = 3) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM IntConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO INTCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,INTVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE INTCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;    
  END IF;

  IF (CONSTTYPE_ = 8) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM VarcharConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO VARCHARCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,VARCHARVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE VARCHARCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;    
  END IF;

  IF (CONSTTYPE_ = 5) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM RealConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO REALCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,DOUBLEVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE REALCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;   
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DELETECONST (
  PROGINDEX_     NUMBER,
  CONSTINDEX_    NUMBER,
  CONSTTYPE_     NUMBER
) IS
BEGIN
  IF (CONSTTYPE_ = 3) THEN
    UPDATE IntConst
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);
  END IF;
  IF (CONSTTYPE_ = 8) THEN
    UPDATE VARCHARCONST
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_); 
  END IF;
  IF (CONSTTYPE_ = 5) THEN
    UPDATE REALCONST
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);
  END IF;
END;
/

--       
ALTER TRIGGER TR_INTCONST_BU_500 DISABLE
/

ALTER TRIGGER TR_VARCHARCONST_BU_500 DISABLE
/

ALTER TRIGGER TR_REALCONST_BU_500 DISABLE
/

--     
CALL DeleteFields(20211028) ;

CALL DeleteFields(20411028) ;

CALL DeleteFields(20511029) ;

CALL DeleteFields(20901138) ;

CALL DeleteFields(21011018) ;

CALL DeleteFields(30200018) ;

CALL DeleteFields(30201069) ;

CALL DeleteFields(30210056) ;

CALL DeleteFields(30210001) ;

CALL DeleteFields(90111011) ;

CALL DeleteFields(550301001) ;

CALL DeleteFields(550301002) ;

CALL DeleteFields(990410012) ;

CALL DeleteFields(990410013) ;

CALL DeleteFields(990410014) ;

CALL DeleteFields(990410015) ;

CALL DeleteFields(990410016) ;

CALL DeleteFields(990410017) ;

CALL DeleteFields(990410018) ;

CALL DeleteFields(990410019) ;

CALL DeleteFields(990410020) ;

CALL DeleteFields(990410021) ;

CALL DeleteFields(990410022) ;

CALL DeleteFields(990410023) ;

CALL DeleteFields(993110003) ;

--    , (1)
CALL ImportField(10111012, '', 'KESR', '', ' ', 1, 101, 1, 0, '', 0, 17827, 0, 0, '') ;

CALL ImportField(10111019, ' ', 'SUBKESR', ' ', ' ', 1, 101, 1, 0, '', 0, 17828, 0, 0, '') ;

CALL ImportField(10111022, ' . ', 'FINTYPECode', ' . ', ' ', 1, 101, 1, 0, '', 0, 36853, 0, 0, '') ;

CALL ImportField(10111188, ' .  ()', 'FINTYPE', ' . ', ' ', 1, 101, 1, 0, '', 0, 17833, 0, 0, '') ;

CALL ImportField(10112049, '', 'KESR', '', ' ', 1, 101, 2, 0, '', 0, 17827, 0, 0, '') ;

CALL ImportField(10112054, '', 'SUBKESR', '', ' ', 1, 101, 2, 0, '', 0, 17828, 0, 0, '') ;

CALL ImportField(10112059, ' . ', 'FINTYPECode', ' . ', ' ', 1, 101, 2, 0, '', 0, 36853, 0, 0, '') ;

CALL ImportField(10112219, ' .  ()', 'FINTYPE', ' . ', ' ', 1, 101, 2, 0, '', 0, 17833, 0, 0, '') ;

CALL ImportField(10114111, '', 'KESR', '', ' ', 1, 101, 4, 0, '', 0, 17827, 0, 0, '') ;

CALL ImportField(10114116, '', 'SUBKESR', '', ' ', 1, 101, 4, 0, '', 0, 17828, 0, 0, '') ;

CALL ImportField(10114121, ' . ', 'FINTYPECode', ' . ', ' ', 1, 101, 4, 0, '', 0, 36853, 0, 0, '') ;

CALL ImportField(10114221, ' .  ()', 'FINTYPE', ' . ', ' ', 1, 101, 4, 0, '', 0, 17833, 0, 0, '') ;

CALL ImportField(10115141, '( )', 'KDKESR', '', ' ', 1, 101, 5, 0, '', 0, 38908, 0, 0, '') ;

--   (), (1)
CALL ImportField(20011020, '', '{("")}', '', ' ', 1, 200, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20011021, '', '{("")}', '', ' ', 1, 200, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20011037, '  ', '{("")}', '  ', ' ', 1, 200, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20011038, ' ', '{("")}', '  ', ' ', 1, 200, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20011039, ' ', '{("")}', ' ', ' ', 1, 200, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20011040, '  ', '{("")}', '  ', ' ', 1, 200, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20011041, '  ', '{("")}', '  ', ' ', 1, 200, 1, 0, '', 0, null, 0, 0, '') ;

--    (), (1)
CALL ImportField(20110083, ' ( )', 'StoredContent', ' ( )', 'StoredContent', 1, 201, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(20111007, '', 'Kesr', '', 'DestKesr', 1, 201, 1, 0, '', 0, 17415, 0, 0, '') ;

CALL ImportField(20111009, ' ', 'SubKesr', '', 'DestSubKesr', 1, 201, 1, 0, '', 0, 17416, 0, 0, '') ;

CALL ImportField(20111064, ' () ', 'KVRCORR', ' () ', 'KVRCORRKey', 1, 201, 1, 1, '', 0, 17461, 0, 0, '') ;

CALL ImportField(20111095, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 201, 1, 1, '', 0, 27835, 0, 0, '') ;

CALL ImportField(20111193, ' ()', 'KVRCORRCode', ' ()', 'KVRCORR', 1, 201, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20111194, '', 'ContractCostsClsCode', '', ' ', 1, 201, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20111195, '', 'ContractCostsCls', '', ' ', 1, 201, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(20111196, ' ', 'SUMMAOTHERYEARS', ' ', 'SUMMAOTHERYEARS', 1, 201, 1, 0, '', 0, 39880, 0, 0, '') ;

CALL ImportField(20111197, '  ', 'SUMMAYEAR4', '  ', 'SUMMAYEAR4', 1, 201, 1, 0, '', 0, 39879, 0, 0, '') ;

CALL ImportField(20111198, '   ( )', 'StoredContent', '   ( )', 'StoredContentDet', 1, 201, 1, 0, '', 0, null, 0, 2, '') ;

--  (), (1)
CALL ImportField(20211032, '', 'KESR', '', 'DestKesr', 1, 202, 1, 0, '', 0, 17415, 0, 0, '') ;

CALL ImportField(20211063, '  ', 'SUMMAYEAR2', '  ', 'SUMMAYEAR2', 1, 202, 1, 0, ',', 0, 17458, 0, 0, '') ;

CALL ImportField(20211064, ' ', 'SUMMAYEAR1', ' ', 'SUMMAYEAR1', 1, 202, 1, 0, ',', 0, 17457, 0, 0, '') ;

CALL ImportField(20211065, '  ', 'SUMMAYEAR3', '  ', 'SUMMAYEAR3', 1, 202, 1, 0, ',', 0, 17459, 0, 0, '') ;

CALL ImportField(20211067, ' ', 'SUBKESR', ' ', 'DestSubKesr', 1, 202, 1, 0, '', 0, 17416, 0, 0, '') ;

CALL ImportField(20211103, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 202, 1, 1, '', 0, 27835, 0, 0, '') ;

CALL ImportField(20211110, '/ ', 'FCAccountName', '/ ', ' ', 1, 202, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20211111, '', 'ContractCostsClsCode', '', ' ', 1, 202, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20211112, '', 'ContractCostsCls', '', ' ', 1, 202, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(20211113, ' ', 'SUMMAOTHERYEARS', ' ', 'SUMMAOTHERYEARS', 1, 202, 1, 0, ',', 0, 39880, 0, 0, '') ;

CALL ImportField(20211114, '  ', 'SUMMAYEAR4', '  ', 'SUMMAYEAR4', 1, 202, 1, 0, ',', 0, 39879, 0, 0, '') ;

--   (), (1)
CALL ImportField(20311032, '', 'KESR', '', 'DestKesr', 1, 203, 1, 0, '', 0, 17415, 0, 0, '') ;

CALL ImportField(20311067, ' ', 'SUBKESR', ' ', 'DestSubKesr', 1, 203, 1, 0, '', 0, 17416, 0, 0, '') ;

CALL ImportField(20311094, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 203, 1, 1, '', 0, 27835, 0, 0, '') ;

CALL ImportField(20311100, '/ ', 'FCAccountName', '/ ', ' ', 1, 203, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20311101, '', 'ContractCostsClsCode', '', ' ', 1, 203, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20311102, '', 'ContractCostsCls', '', ' ', 1, 203, 1, 1, '', 0, null, 0, 0, '') ;

--  , , (1)
CALL ImportField(20411032, '', 'KESR', '', 'DestKesr', 1, 204, 1, 0, '', 0, 17415, 0, 0, '') ;

CALL ImportField(20411067, ' ', 'SUBKESR', ' ', 'DestSubKesr', 1, 204, 1, 0, '', 0, 17416, 0, 0, '') ;

CALL ImportField(20411093, '()', 'IFSAGCode', '()', 'IFSAGCode', 1, 204, 1, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(20411097, '()', 'KDAGCode', '()', 'KDAGCode', 1, 204, 1, 0, '', 0, 38908, 0, 0, '') ;

CALL ImportField(20411112, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 204, 1, 1, '', 0, 27835, 0, 0, '') ;

CALL ImportField(20411120, '', 'ContractCostsCls', '', ' ', 1, 204, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(20411121, '', 'ContractCostsClsCode', '', ' ', 1, 204, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20411122, ' ', 'SUMMAOTHERYEARS', ' ', 'SUMMAOTHERYEARS', 1, 204, 1, 0, '', 0, 39880, 0, 0, '') ;

CALL ImportField(20411123, '  ', 'SUMMAYEAR4', '  ', 'SUMMAYEAR4', 1, 204, 1, 0, '', 0, 39879, 0, 0, '') ;

-- , (1)
CALL ImportField(20511008, '  ', 'SUMMAYEAR2', '  ', 'SUMMAYEAR2', 1, 205, 1, 0, ',', 0, 17458, 0, 0, '') ;

CALL ImportField(20511009, ' ', 'SUMMAYEAR1', ' ', 'SUMMAYEAR1', 1, 205, 1, 0, ',', 0, 17457, 0, 0, '') ;

CALL ImportField(20511010, '  ', 'SUMMAYEAR3', '  ', 'SUMMAYEAR3', 1, 205, 1, 0, ',', 0, 17459, 0, 0, '') ;

CALL ImportField(20511033, '', 'KESR', '', 'DestKesr', 1, 205, 1, 0, '', 0, 17415, 0, 0, '') ;

CALL ImportField(20511065, ' ', 'SUBKESR', ' ', 'DestSubKesr', 1, 205, 1, 0, '', 0, 17416, 0, 0, '') ;

CALL ImportField(20511076, '()', 'IFSAGCode', '()', ' ', 1, 205, 1, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(20511079, '()', 'KDAGCode', '()', ' ', 1, 205, 1, 0, '', 0, 38908, 0, 0, '') ;

CALL ImportField(20511099, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 205, 1, 1, '', 0, 27835, 0, 0, '') ;

CALL ImportField(20511107, '', 'ContractCostsCls', '', ' ', 1, 205, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(20511108, '', 'ContractCostsClsCode', '', ' ', 1, 205, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20511109, ' ', 'SUMMAOTHERYEARS', ' ', 'SUMMAOTHERYEARS', 1, 205, 1, 0, ',', 0, 39880, 0, 0, '') ;

CALL ImportField(20511110, '  ', 'SUMMAYEAR4', '  ', 'SUMMAYEAR4', 1, 205, 1, 0, ',', 0, 39879, 0, 0, '') ;

--    (), (1)
CALL ImportField(20611033, '', 'KESR', '', 'DestKesr', 1, 206, 1, 0, '', 0, 17415, 0, 0, '') ;

CALL ImportField(20611068, ' ', 'SUBKESR', ' ', 'DestSubKesr', 1, 206, 1, 0, '', 0, 17416, 0, 0, '') ;

CALL ImportField(20611102, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 206, 1, 1, '', 0, 27835, 0, 0, '') ;

CALL ImportField(20611188, '', 'ContractCostsCls', '', ' ', 1, 206, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(20611189, '', 'ContractCostsClsCode', '', ' ', 1, 206, 1, 0, '', 0, null, 0, 0, '') ;

--   , (1)
CALL ImportField(20711033, '', 'KESR', '', 'DestKesr', 1, 207, 1, 0, '', 0, 17415, 0, 0, '') ;

CALL ImportField(20711068, ' ', 'SUBKESR', ' ', 'DestSubKesr', 1, 207, 1, 0, '', 0, 17416, 0, 0, '') ;

CALL ImportField(20711080, '()', 'IFSAGCode', '()', 'IFS_KESRCode', 1, 207, 1, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(20711168, '()', 'KDAGCode', '()', 'KDKESRCode', 1, 207, 1, 0, '', 0, 38908, 0, 0, '') ;

CALL ImportField(20711181, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 207, 1, 1, '', 0, 27835, 0, 0, '') ;

CALL ImportField(20711188, '', 'ContractCostsCls', '', ' ', 1, 207, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(20711189, '', 'ContractCostsClsCode', '', ' ', 1, 207, 1, 0, '', 0, null, 0, 0, '') ;

--    , (1)
CALL ImportField(20811033, '', 'KESR', '', 'DestKesr', 1, 208, 1, 0, '', 0, 17415, 0, 0, '') ;

CALL ImportField(20811068, ' ', 'SUBKESR', ' ', 'DestSubKesr', 1, 208, 1, 0, '', 0, 17416, 0, 0, '') ;

CALL ImportField(20811080, '()', 'IFSAGCode', '()', 'IFSAGCode', 1, 208, 1, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(20811081, '()', 'IFS_KVSRCode', '()', 'IFS_KVSRCode', 1, 208, 1, 0, '', 0, 25472, 0, 0, '') ;

CALL ImportField(20811177, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 208, 1, 1, '', 0, 27835, 0, 0, '') ;

CALL ImportField(20811189, '', 'ContractCostsCls', '', ' ', 1, 208, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(20811190, '', 'ContractCostsClsCode', '', ' ', 1, 208, 1, 0, '', 0, null, 0, 0, '') ;

--  , (1)
CALL ImportField(20911012, '()', 'IFSAGCode', '()', 'IFSAGCode', 1, 209, 1, 1, '', 0, 38919, 0, 0, '') ;

CALL ImportField(20911013, '()', 'IFS_KVSRCode', '()', 'IFS_KVSRCode', 1, 209, 1, 1, '', 0, 25472, 0, 0, '') ;

CALL ImportField(20911017, '()', 'KESR', '', 'DestKesr', 1, 209, 1, 1, '', 0, 17415, 0, 0, '') ;

CALL ImportField(20911027, ' ', 'SUBKESR', ' ', 'DestSubkesr', 1, 209, 1, 1, '', 0, 17416, 0, 0, '') ;

CALL ImportField(20911141, '   ', 'PayPromiseCls', '   ()', 'PayPromiseCls', 1, 209, 1, 1, '', 0, 27835, 0, 0, '') ;

CALL ImportField(20912012, '()', 'IFSAGCode', '()', ' ', 1, 209, 2, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(20912013, '()', 'IFS_KVSRCode', '()', ' ', 1, 209, 2, 0, '', 0, 25472, 0, 0, '') ;

CALL ImportField(20912017, '()', 'KESR', '', ' ', 1, 209, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20912027, ' ', 'SUBKESR', ' ', ' ', 1, 209, 2, 0, '', 0, null, 0, 0, '') ;

--  , (1)
CALL ImportField(21011013, '()', 'IFSAGCode', '()', ' ', 1, 210, 1, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(21011017, '()', 'KESR', '', 'DestKesr', 1, 210, 1, 0, '', 0, 17415, 0, 0, '') ;

CALL ImportField(21011029, ' ', 'SUBKESR', ' ', 'DestSubkesr', 1, 210, 1, 0, '', 0, 17416, 0, 0, '') ;

CALL ImportField(21011042, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 210, 1, 1, '', 0, 27835, 0, 0, '') ;

CALL ImportField(21011043, '  ', 'PayPromiseClsCode', '', 'PayPromiseClsCode', 1, 210, 1, 0, '', 0, 27849, 0, 0, '') ;

CALL ImportField(21011047, ' ', 'SUMMAOTHERYEARS', ' ', 'SUMMAOTHERYEARS', 1, 210, 1, 0, '', 0, 39880, 0, 0, '') ;

CALL ImportField(21011048, '  ', 'SUMMAYEAR4', '  ', 'SUMMAYEAR4', 1, 210, 1, 0, '', 0, 39879, 0, 0, '') ;

CALL ImportField(21012015, '()', 'KESR', '', 'DestKesr', 1, 210, 2, 0, '', 0, 17415, 0, 0, '') ;

CALL ImportField(21012016, ' ()', 'KESRCORR', ' ()', 'KESRCORR', 1, 210, 2, 1, '', 0, 17461, 0, 0, '') ;

CALL ImportField(21012043, ' ', 'SUBKESR', ' ', 'DestSubkesr', 1, 210, 2, 0, '', 0, 17416, 0, 0, '') ;

CALL ImportField(21012049, '()', 'IFSAGCode', '', ' ', 1, 210, 2, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(21012056, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 210, 2, 1, '', 0, 27835, 0, 0, '') ;

CALL ImportField(21012057, '  ', 'PayPromiseClsCode', '', 'PayPromiseClsCode', 1, 210, 2, 0, '', 0, 27849, 0, 0, '') ;

--  , (1)
CALL ImportField(21111014, '()', 'IFSAGCode', '()', 'IFSAGCode', 1, 211, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21111019, '()', 'KESR', '', 'DestKesr', 1, 211, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21111029, ' ', 'SUBKESR', ' ', 'DestSubkesr', 1, 211, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21111036, '()', 'KDAGCode', '()', 'KDAGCode', 1, 211, 1, 0, '', 0, 38908, 0, 0, '') ;

CALL ImportField(21111045, '   ', 'PayPromiseCls', '   ()', 'PayPromiseCls', 1, 211, 1, 1, '', 0, 27835, 0, 0, '') ;

CALL ImportField(21111049, '', 'ContractCostsClsCode', '', ' ', 1, 211, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21112011, '()', 'IFSAGCode', '()', ' ', 1, 211, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21112016, '()', 'KESR', '', ' ', 1, 211, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21112026, ' ', 'SUBKESR', ' ', ' ', 1, 211, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21112048, '', 'ContractCostsCls', '', ' ', 1, 211, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21112049, '', 'ContractCostsClsCode', '', ' ', 1, 211, 2, 0, '', 0, null, 0, 0, '') ;

--   , , (1)
CALL ImportField(21211014, '()', 'IFSAGCode', '()', 'IFSAGCode', 1, 212, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21211019, '()', 'KESR', '', 'DestKesr', 1, 212, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21211029, ' ', 'SUBKESR', ' ', 'DestSubkesr', 1, 212, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21211036, '()', 'KDAGCode', '()', 'KDAGCode', 1, 212, 1, 0, '', 0, 38908, 0, 0, '') ;

CALL ImportField(21211046, '   ', 'PayPromiseCls', '   ()', 'PayPromiseCls', 1, 212, 1, 1, '', 0, 27835, 0, 0, '') ;

CALL ImportField(21211050, '', 'ContractCostsClsCode', '', ' ', 1, 212, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21212011, '()', 'IFSAGCode', '()', ' ', 1, 212, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21212016, '()', 'KESR', '', ' ', 1, 212, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21212026, ' ', 'SUBKESR', ' ', ' ', 1, 212, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21212049, '', 'ContractCostsCls', '', ' ', 1, 212, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21212050, '', 'ContractCostsClsCode', '', ' ', 1, 212, 2, 0, '', 0, null, 0, 0, '') ;

--   , (1)
CALL ImportField(30011030, '', '{("")}', ' ()', ' ', 1, 300, 1, 0, '', 0, null, 0, 0, '') ;

--  , (1)
CALL ImportField(30111005, ' .( .)', 'SourceKESR', ' ', 'SourceKESR', 1, 301, 1, 0, ',', 0, 18868, 0, 0, '') ;

CALL ImportField(30111009, '  .', 'SourceSubKESR', ' ', 'SourceSubKESR', 1, 301, 1, 0, ',', 0, 18889, 0, 0, '') ;

CALL ImportField(30111012, ' .  .', 'SourceFinTypeCode', '   ', 'SourceFINTYPECLS', 1, 301, 1, 0, ',,,', 0, 36853, 0, 0, '') ;

CALL ImportField(30111017, ' -( -)', 'DestKESR', ' ', 'DestKESR', 1, 301, 1, 0, 'DestKESR,', 0, 18871, 0, 0, '') ;

CALL ImportField(30111021, '  -', 'DestSubKESR', ' ', 'DestSubKESR', 1, 301, 1, 0, 'DestSubKESR,', 0, 18898, 0, 0, '') ;

CALL ImportField(30111050, '', 'BuhOperationCLS', ' ', 'BuhOperationCLS', 1, 301, 1, 0, '', 0, 18919, 0, 0, '') ;

CALL ImportField(30111079, '( .)', 'SourceIFSAGCode', ' ()', ' ', 1, 301, 1, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(30111082, '( -)', 'DestIFSAGCode', ' ()', ' ', 1, 301, 1, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(30111114, '( .)', 'SourceKDAGCode', '', ' ', 1, 301, 1, 0, '', 0, 38908, 0, 0, '') ;

CALL ImportField(30111118, ' -( -)', 'DestKDAGCode', '1', ' ', 1, 301, 1, 0, '', 0, 38908, 0, 0, '') ;

CALL ImportField(30111161, '   .', 'SourcePayPromiseCls', '', 'SourcePayPromiseCls', 1, 301, 1, 1, '', 0, 27845, 0, 0, '') ;

CALL ImportField(30111166, ' .  . ()', 'SourceFinType', '   ', 'SourceFINTYPECLSKey', 1, 301, 1, 1, ',,,', 0, 18893, 0, 0, '') ;

--   \, (1)
CALL ImportField(30210002, '.  () ', 'DESTFACIALACC_CLS', '/  ()', 'DestFacialAccCls', 1, 302, 0, 0, '', 0, 18959, 0, 0, '') ;

CALL ImportField(30210003, ' / ', 'ACC', ' / ', 'DestAccountName', 1, 302, 0, 0, '', 0, 17112, 30210153, 1, '') ;

CALL ImportField(30210004, '  ()', 'REJECTCAUSE', '  ()', 'RejectCause', 1, 302, 0, 0, '', 0, 18973, 0, 0, '') ;

CALL ImportField(30210005, ' ', 'PAYPRIORITY', ' ', 'PayPriority', 1, 302, 0, 0, '', 0, 18966, 0, 0, '') ;

CALL ImportField(30210006, ' ', 'ACCEPTDATE', ' ', 'AcceptDate', 1, 302, 0, 0, '', 0, 18952, 0, 0, '') ;

CALL ImportField(30210007, '  ()', 'BUHPAYMENTCLS', '. ', 'BUHPAYMENTCLS', 1, 302, 0, 0, '', 0, 18968, 0, 0, '') ;

CALL ImportField(30210008, '', 'ARHIVEDOC', ' ', 'ARHIVEDOC', 1, 302, 0, 0, '', 0, 18961, 0, 0, '') ;

CALL ImportField(30210009, ' ', 'TYPEOPERATIONCLS', ' ', 'OperationTypeCls', 1, 302, 0, 0, '', 0, 18967, 0, 0, '') ;

CALL ImportField(30210010, '   (  )', 'TAXNOTE', ' ', 'TaxNote', 1, 302, 0, 0, '', 0, 18991, 0, 0, '') ;

CALL ImportField(30210011, ' ', 'PAYDATE', ' ', 'PayDate', 1, 302, 0, 0, '', 0, 18951, 0, 0, '') ;

CALL ImportField(30210012, ' /', 'DOCUMENTDATE', ' ', 'DocumentDate', 1, 302, 0, 0, '', 0, 18953, 0, 0, '') ;

CALL ImportField(30210013, '/ ', 'DESTACCOUNT', '/ ', 'DESTACCOUNT', 1, 302, 0, 1, '', 0, 18958, 0, 0, '') ;

CALL ImportField(30210014, ' (  )', 'NOTE', ' ', 'NOTE', 1, 302, 0, 0, '', 0, 18964, 0, 0, '') ;

CALL ImportField(30210016, '(  )', 'NDS', '', 'NDS', 1, 302, 0, 0, '', 0, 18990, 0, 0, '') ;

CALL ImportField(30210017, ' ', 'BIDNUMBER', '  ', 'BidNumber', 1, 302, 0, 0, '', 0, 18993, 0, 0, '') ;

CALL ImportField(30210023, ' ', 'REJECT_CLS', ' ', 'REJECTCLS', 1, 302, 0, 0, '', 0, 18972, 0, 0, '') ;

CALL ImportField(30210024, '()', 'SUMMA', '', 'SUMMA', 1, 302, 0, 0, '', 0, 18955, 0, 0, '') ;

CALL ImportField(30210025, ' ', 'REESTRNUMBER', ' ', 'ReestrNumber', 1, 302, 0, 0, '', 0, 19090, 0, 0, '') ;

CALL ImportField(30210026, ' ', 'REESTRDATE', ' ', 'REESTRDATE', 1, 302, 0, 0, '', 0, 19091, 0, 0, '') ;

CALL ImportField(30210027, '()', 'NAME', ' ()', 'DestOrgName', 1, 302, 0, 0, '', 0, 16646, 0, 0, '') ;

CALL ImportField(30210028, '()', 'INN', ' ()', 'DestOrgINN', 1, 302, 0, 0, '', 0, 16645, 0, 0, '') ;

CALL ImportField(30210029, ' ', 'PAYTYPECLS', ' ', 'PAYTYPECLS', 1, 302, 0, 0, '', 0, 18963, 0, 0, '') ;

CALL ImportField(30210030, '/  ()', 'SOURCEACCOUNTNAME', '/  ()', 'SourceAccountName', 1, 302, 0, 0, '', 0, 17112, 30210154, 1, '') ;

CALL ImportField(30210031, ' ', 'CardNumber', '  ', 'CARDNUMBER', 1, 302, 0, 0, '', 0, 18985, 0, 0, '') ;

CALL ImportField(30210032, '/ ', 'SOURCEFACIALACC_CLS', '/ ', 'SourceFacialAccCls', 1, 302, 0, 0, ',', 0, 18957, 0, 0, '') ;

CALL ImportField(30210033, '', 'DEPARTMENTCLS', '', 'DEPARTMENTCLS', 1, 302, 0, 1, '', 0, 18989, 0, 0, '') ;

CALL ImportField(30210034, ' /', 'DOCNUMBER', ' ', 'DocumentNumber', 1, 302, 0, 0, '', 0, 18949, 0, 0, '') ;

CALL ImportField(30210035, '()', 'INN20', ' ()', 'DestOrgKPP', 1, 302, 0, 0, '', 0, 16653, 0, 0, '') ;

CALL ImportField(30210039, '/   ', 'SourceFacialCode', '   ', 'SourceFacialAccClsFacialCode', 1, 302, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30210043, '   ', 'SOURCEACCOUNT', '  ', 'SOURCEACCOUNT', 1, 302, 0, 1, ',', 0, 18956, 0, 0, '') ;

CALL ImportField(30210044, '', 'DocStateRef', ' ', 'DocStateRef', 1, 302, 0, 1, '', 0, 18996, 0, 0, '') ;

CALL ImportField(30210045, '  ', ' ', '  ', 'IsInBudget', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210046, ' ', ' ', ' ', 'DocSuspended', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210047, '', ' ', '', 'IsVised', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210048, '   ', 'ManagerBid', ' ', 'ManagerBid', 1, 302, 0, 1, '', 0, 18992, 0, 0, '') ;

CALL ImportField(30210049, '  ', ' ', '  ', 'LASTEXTRCHANGE', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210053, '  ', ' ', '  ', 'ManBidFuid', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210054, ' ', 'Reestr_Ref', ' ', 'Reestr_Ref', 1, 302, 0, 1, '', 0, 18971, 0, 0, '') ;

CALL ImportField(30210055, ' ', 'CRYPTOSTATUS', ' ', 'CRYPTOSTATUS', 1, 302, 0, 1, '', 0, 18975, 0, 0, '') ;

CALL ImportField(30210057, '   ', ' ', '   ', 'SoftRejectCause', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210058, ' c', 'FEDERALFUNDSREF', ' c', 'FEDERALFUNDSREF', 1, 302, 0, 1, '', 0, 19004, 0, 0, '') ;

CALL ImportField(30210059, '   c', ' ', '   c', 'FEDERALFUNDSREESTR', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210061, '  ', ' ', '  ', 'RequestNumber', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210062, '  ', ' ', '  ', 'RequestDate', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210063, ' ', ' ', ' ', 'SourceBankDepartmentNumber', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210064, ' ', ' ', ' ', 'SourceFKFacialCode', 1, 302, 0, 1, '', 1, null, 30210154, 1, '') ;

CALL ImportField(30210065, '   ', ' ', '   ', 'SourceOrgId', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210066, '   ( )', ' ', '   ( )', 'SourceOrgFUID', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210067, ' ', ' ', ' -', 'SourceOrgINN', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210068, ' ', ' ', ' -', 'SourceOrgKPP', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210069, ' ', ' ', ' -', 'SourceOrgName', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210070, ' -', ' ', ' -', 'SourceOrgCity', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210071, ' ', ' ', ' ', 'SourceBankFUID', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210072, '  ', ' ', '  ', 'SourceBankName', 1, 302, 0, 1, '', 1, null, 30210154, 1, '') ;

CALL ImportField(30210073, '  ', ' ', '  ', 'SourceBankBIK', 1, 302, 0, 1, '', 1, null, 30210154, 1, '') ;

CALL ImportField(30210074, '.  ', ' ', '.  ', 'SourceBankCor', 1, 302, 0, 1, '', 1, null, 30210154, 1, '') ;

CALL ImportField(30210075, '   ', ' ', '   ', 'SourceBankCity', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210076, '\ ', ' ', ' \ ', 'SourceFacialAccClsName', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210077, ' \ ', ' ', ' \ ', 'SourceFacialAccClsFacialCode', 1, 302, 0, 0, '', 1, null, 0, 0, '') ;

CALL ImportField(30210078, ' - \ ', 'SourceFacialAccClsOrgINN', ' - \ ', 'SourceFacialAccClsOrgINN', 1, 302, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(30210079, '  \ ', ' ', ' - \ ', 'SourceFacialAccClsOrgKPP', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210080, '   \ ', ' ', '   \ ', 'SourceFacialAccClsOrgName', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210081, '   ', ' ', '   ', 'SourceFKOrgINN', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210082, '   ', ' ', '   ', 'SourceFKOrgKPP', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210083, '  ', ' ', '  ', 'SourceFKOrgName', 1, 302, 0, 1, '', 1, null, 30210154, 1, '') ;

CALL ImportField(30210084, '   ', ' ', '   ', 'SourceFKOrgCity', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210085, '   ', ' ', '   ', 'DestBankDepartmentNumber', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210086, ' ', ' ', ' ', 'DestFKFacialCode', 1, 302, 0, 1, '', 1, null, 30210153, 1, '') ;

CALL ImportField(30210087, '   ', ' ', '   ', 'DestOrgId', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210088, '   ( )', ' ', '   ( )', 'DestOrgFUID', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210089, ' -', ' ', ' -', 'DestOrgCity', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210090, ' ', ' ', ' ', 'DestBankFUID', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210091, '  ', ' ', '  ', 'DestBankName', 1, 302, 0, 1, '', 1, null, 30210153, 1, '') ;

CALL ImportField(30210092, '  ', ' ', '  ', 'DestBankBIK', 1, 302, 0, 1, '', 1, null, 30210153, 1, '') ;

CALL ImportField(30210093, '.  ', ' ', '.  ', 'DestBankCor', 1, 302, 0, 1, '', 1, null, 30210153, 1, '') ;

CALL ImportField(30210094, '   ', ' ', '   ', 'DestBankCity', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210095, '\  ()', ' ', '\ ', 'DestFacialAccClsName', 1, 302, 0, 0, '', 1, null, 0, 0, '') ;

CALL ImportField(30210096, ' \ ', ' ', ' \ ', 'DestFacialAccClsFacialCode', 1, 302, 0, 0, '', 1, null, 0, 0, '') ;

CALL ImportField(30210097, '  \ ', ' ', ' - \ ', 'DestFacialAccClsOrgINN', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210098, '  \ ', ' ', ' - \ ', 'DestFacialAccClsOrgKPP', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210099, '  \ ', ' ', ' - \ ', 'DestFacialAccClsOrgName', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210100, '   ', ' ', '   ', 'DestFKOrgINN', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210101, '   ', ' ', '   ', 'DestFKOrgKPP', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210102, '  ', ' ', '  ', 'DestFKOrgName', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210103, '   ', ' ', '   ', 'DestFKOrgCity', 1, 302, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30210104, ' ', 'OperationDirection', ' ', 'OperationDirection', 1, 302, 0, 0, '', 0, 19009, 0, 0, '') ;

CALL ImportField(30210105, '', 'BUDGETREF', '', 'BudgetRef', 1, 302, 0, 0, '', 0, 18983, 0, 0, '') ;

CALL ImportField(30210113, ' ', 'ClsType', ' (, , )', 'CLSTYPE', 1, 302, 0, 0, '', 0, 19008, 0, 0, '') ;

CALL ImportField(30210114, ' ', 'ID', ' ', 'Id', 1, 302, 0, 1, '', 0, 18948, 0, 0, '') ;

CALL ImportField(30210122, '  ', 'SENDERID', '  ', 'SenderID', 1, 302, 0, 1, '', 0, 18969, 0, 0, '') ;

CALL ImportField(30210123, '  ', 'SENDERRECORDID', '  ', 'SenderRecordID', 1, 302, 0, 1, '', 0, 18970, 0, 0, '') ;

CALL ImportField(30210128, '( )', 'ManagerBIDNUMBER', '( )', ' ', 1, 302, 0, 1, '', 0, 20507, 0, 0, '') ;

CALL ImportField(30210134, '(  )', 'Status', '', 'Status', 1, 302, 0, 1, '', 0, 17233, 0, 0, '') ;

CALL ImportField(30210136, ' ', 'Progindex', '  ()', 'ProgIndex', 1, 302, 0, 1, '', 0, 18960, 0, 0, '') ;

CALL ImportField(30210137, ' ', 'BidDate', ' ', 'BidDate', 1, 302, 0, 0, '', 0, 24730, 0, 0, '') ;

CALL ImportField(30210141, '  ', 'RegionBudgetEst', '  ', 'RegionBudgetEst', 1, 302, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(30210151, ' ()', 'CardRef', '  ', 'CardRef', 1, 302, 0, 1, '', 0, 31656, 0, 0, '') ;

CALL ImportField(30210152, ' ', 'CardRefName', '  ', 'CardRefName', 1, 302, 0, 0, '', 0, 18939, 0, 0, '') ;

CALL ImportField(30210153, '(  )', 'DestStoredPaymentProps', '', 'DestStoredPaymentProps', 1, 302, 0, 0, '', 0, 31657, 0, 2, '') ;

CALL ImportField(30210154, '(  )', 'SourceStoredPaymentProps', '', 'SourceStoredPaymentProps', 1, 302, 0, 0, '', 0, 31658, 0, 2, '') ;

CALL ImportField(30210155, ' (  )', 'StoredPaymentNote', '', 'StoredPaymentNote', 1, 302, 0, 0, '', 0, 31659, 0, 2, '') ;

CALL ImportField(30210157, '(  )', 'UINCode', '  ', 'UINCode', 1, 302, 0, 0, '', 0, 35367, 0, 0, '') ;

CALL ImportField(30210158, ' ', 'DocOsn', ' ', 'DocOsn', 1, 302, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30210159, ' ', 'CashierPersonalInfo', ' ', 'CashierPersonalInfo', 1, 302, 0, 0, '', 0, 24731, 0, 0, '') ;

CALL ImportField(30210160, '', 'Signers', '', 'Signers', 1, 302, 0, 0, '', 0, 38174, 0, 2, '') ;

CALL ImportField(30210163, ' (  )', 'StoredPaymentContent', '  ( )', 'StoredPaymentContent', 1, 302, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(30210164, '   ', '', '   ', 'SourceFKCode', 1, 302, 0, 0, '', 0, null, 30210154, 1, '') ;

CALL ImportField(30210165, '  ( )', '', '  ( )', 'UBPOrgName', 1, 302, 0, 0, '', 0, null, 30210163, 1, '') ;

CALL ImportField(30210166, ' ', '', ' ', 'SourceINN', 1, 302, 0, 0, '', 0, null, 30210154, 1, '') ;

CALL ImportField(30210167, ' ', '', ' ', 'SourceKPP', 1, 302, 0, 0, '', 0, null, 30210154, 1, '') ;

CALL ImportField(30210168, ' ', '', ' ', 'SourceName', 1, 302, 0, 0, '', 0, null, 30210154, 1, '') ;

CALL ImportField(30210169, '  ', '', '  ', 'GeneralOrgKVSR', 1, 302, 0, 0, '', 0, null, 30210163, 1, '') ;

CALL ImportField(30210170, ' ', '', ' ', 'GeneralOrgName', 1, 302, 0, 0, '', 0, null, 30210163, 1, '') ;

CALL ImportField(30210171, '   ', '', '   ', 'UBPCode', 1, 302, 0, 0, '', 0, null, 30210163, 1, '') ;

CALL ImportField(30210172, ' ', '', ' ', 'BudgetName', 1, 302, 0, 0, '', 0, null, 30210163, 1, '') ;

CALL ImportField(30210173, ' ', '', ' ', 'FOName', 1, 302, 0, 0, '', 0, null, 30210163, 1, '') ;

CALL ImportField(30210174, '  ', '', '  ', 'OKPO', 1, 302, 0, 0, '', 0, null, 30210163, 1, '') ;

CALL ImportField(30210175, ' ', '', ' ', 'DestName', 1, 302, 0, 0, '', 0, null, 30210153, 1, '') ;

CALL ImportField(30210176, '  ', '', '  ', 'DestINN', 1, 302, 0, 0, '', 0, null, 30210153, 1, '') ;

CALL ImportField(30210177, ' ', '', ' ', 'DetKPP', 1, 302, 0, 0, '', 0, null, 30210153, 1, '') ;

CALL ImportField(30210178, '  ', '', '  ', 'ExportDate', 1, 302, 0, 0, '', 0, null, 30210163, 1, '') ;

CALL ImportField(30210179, '  ', '', '  ', 'ExecutionDate', 1, 302, 0, 0, '', 0, null, 30210163, 1, '') ;

CALL ImportField(30210180, '   ', '', '   ', 'urrencyName', 1, 302, 0, 0, '', 0, null, 30210163, 1, '') ;

CALL ImportField(30210182, '  ', '', '  ', 'DestCLSType', 1, 302, 0, 0, '', 0, null, 30210153, 1, '') ;

CALL ImportField(30210183, '   ', '', '   ', 'DestKBK', 1, 302, 0, 0, '', 0, null, 30210153, 1, '') ;

CALL ImportField(30210185, '   ', '', '   ', 'DestTargetCLS', 1, 302, 0, 0, '', 0, null, 30210153, 1, '') ;

CALL ImportField(30210186, ' ', '', ' ', 'PaymentPurpose', 1, 302, 0, 0, '', 0, null, 30210163, 1, '') ;

CALL ImportField(30210187, '  ', '', '  ', 'NameRukUBP', 1, 302, 0, 0, '', 0, null, 30210160, 1, '') ;

CALL ImportField(30210188, ' ', '', ' ', 'PostRukUBP', 1, 302, 0, 0, '', 0, null, 30210160, 1, '') ;

CALL ImportField(30210189, '  ', '', '  ', 'NameBuhUBP', 1, 302, 0, 0, '', 0, null, 30210160, 1, '') ;

CALL ImportField(30210190, '  ', '', '  ', 'PostBuhUBP', 1, 302, 0, 0, '', 0, null, 30210160, 1, '') ;

CALL ImportField(30210191, '   ', '', '   ', 'ActivityKind', 1, 302, 0, 0, '', 0, null, 30210163, 1, '') ;

CALL ImportField(30210192, '   ', '', '   ', 'ZRNote', 1, 302, 0, 0, '', 0, null, 30210163, 1, '') ;

CALL ImportField(30211001, ' ', 'SOURCESUBKESR', '', 'SOURCESUBKESR', 1, 302, 1, 0, '', 0, 18889, 0, 0, '') ;

CALL ImportField(30211002, '', 'SourceDirectionClsCode', '', 'SourceDirectionCLS', 1, 302, 1, 0, '', 0, 36861, 0, 0, '') ;

CALL ImportField(30211003, '', 'SOURCEKVR', '', 'SourceKVRKey', 1, 302, 1, 1, '', 0, 18867, 0, 0, '') ;

CALL ImportField(30211004, '', 'SOURCEKESR', '', 'SourceKESR', 1, 302, 1, 0, '', 0, 18868, 0, 0, '') ;

CALL ImportField(30211005, '()', 'SOURCEKFSR', '', 'SourceKFSR', 1, 302, 1, 0, '', 0, 18888, 0, 0, '') ;

CALL ImportField(30211006, '', 'SOURCEKCSR', '', 'SourceKCSRKey', 1, 302, 1, 1, '', 0, 18887, 0, 0, '') ;

CALL ImportField(30211007, '', 'SOURCEKVSR', '', 'SourceKVSRKey', 1, 302, 1, 1, '', 0, 18886, 0, 0, '') ;

CALL ImportField(30211008, '', 'SOURCEFACTCODE', '', 'SOURCEFACTCLS', 1, 302, 1, 0, '', 0, 36863, 0, 0, '') ;

CALL ImportField(30211009, ' ', 'SOURCEMEANSTYPE', ' ', 'SOURCEMEANSTYPECLS', 1, 302, 1, 0, '', 0, 18891, 0, 0, '') ;

CALL ImportField(30211010, ' ', 'SOURCEFINSOURCE', ' ', 'SOURCEFINSOURCECLS', 1, 302, 1, 0, '', 0, 18892, 0, 0, '') ;

CALL ImportField(30211011, ' . ', 'SOURCEFINTYPECODE', '  ', 'SOURCEFINTYPECLS', 1, 302, 1, 0, ',', 0, 36853, 0, 0, '') ;

CALL ImportField(30211012, ' ', 'SOURCEDOCTYPE', ' ', 'SOURCEDOCTYPECLS', 1, 302, 1, 0, '', 0, 18894, 0, 0, '') ;

CALL ImportField(30211013, ' ()', 'SUMMA', '', 'SUMMA', 1, 302, 1, 0, '', 0, 18873, 0, 0, '') ;

CALL ImportField(30211014, '  ()', 'SOURCEBUDGETPROMISENUM', '  ()', 'SourceBudgetPROMISENum', 1, 302, 1, 0, ',', 0, 20223, 0, 0, '') ;

CALL ImportField(30211015, '  ', 'SOURCEPROMISE', '  ', 'SOURCEPROMISE', 1, 302, 1, 0, '', 0, 18905, 0, 0, '') ;

CALL ImportField(30211016, '', 'SourceDocBaseCode', '', 'SourceDocBase', 1, 302, 1, 0, ',', 0, 36865, 0, 0, '') ;

CALL ImportField(30211018, '.   ', 'SourceBudgetPromise', '     ', 'SOURCEBUDGETPROMISE', 1, 302, 1, 1, ',', 0, 18908, 0, 0, '') ;

CALL ImportField(30211019, '.  ', 'SourceExecDocCollaps', '  ', ' ', 1, 302, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30211020, ' ..  ', 'SourceExecDoc', '    ', 'SourceExecDoc', 1, 302, 1, 1, '', 0, 18917, 0, 0, '') ;

CALL ImportField(30211021, '(.  )', 'SourceExecDocNum', '   ', 'SourceExecDocNum', 1, 302, 1, 0, ',', 0, 19739, 0, 0, '') ;

CALL ImportField(30211022, ' (.  )', 'SourceExecDocReestr', '   ', 'SourceExecDocReestr', 1, 302, 1, 1, '', 0, 19756, 0, 0, '') ;

CALL ImportField(30211023, '(.  )', 'SourceExecDocDate', '  ', 'SourceExecDocDate', 1, 302, 1, 1, ',', 0, 19740, 0, 0, '') ;

CALL ImportField(30211024, '(.  )', 'SourceExecDocType', '  ', 'SourceExecDocType', 1, 302, 1, 1, '', 0, 19738, 0, 0, '') ;

CALL ImportField(30211025, '(.  )', 'SourceExecDocSumma', '   ', 'SourceExecDocSumma', 1, 302, 1, 1, '', 0, 19744, 0, 0, '') ;

CALL ImportField(30211026, '(.  )', 'SourceExecDocNote', '  ', 'SourceExecDocNote', 1, 302, 1, 1, '', 0, 19762, 0, 0, '') ;

CALL ImportField(30211037, '', 'NOTE', ' ()', 'NOTE', 1, 302, 1, 0, '', 0, 18876, 0, 0, '') ;

CALL ImportField(30211040, '\ ', ' ', '\ ', 'SourceFacialAccCls', 1, 302, 1, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30211041, ' ', 'SourceRegionCLS', ' ', 'SourceRegionCls', 1, 302, 1, 0, ',', 0, 18927, 0, 0, '') ;

CALL ImportField(30211043, '', 'BuhOperationCLS', ' ', 'BuhOperationCLS', 1, 302, 1, 0, '', 0, 18919, 0, 0, '') ;

CALL ImportField(30211044, ' ', 'ClsType', ' (, , )', 'ClsType', 1, 302, 1, 1, '', 0, 18922, 0, 0, '') ;

CALL ImportField(30211047, ' . - ', 'SourceBudgetPromiseCollaps', '  ', 'SourceBudgetPromiseCollaps', 1, 302, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30211048, ' ', 'SourceBudgetPromiseSumma', ' ', 'SourceBudgetPromiseSumma', 1, 302, 1, 1, ',', 0, 20242, 0, 0, '') ;

CALL ImportField(30211049, ' ', 'SourceBudgetPromiseAgrNum', ' ', 'SourceBudgetPromiseAgrNum', 1, 302, 1, 1, ',', 0, null, 0, 0, '') ;

CALL ImportField(30211050, ' ', 'SourceBudgetPromiseAgrDate', ' ', 'SourceBudgetPromiseAgrDate', 1, 302, 1, 1, ',', 0, null, 0, 0, '') ;

CALL ImportField(30211051, ' ', 'SourceBudgetPromiseAgrSumma', ' ', 'SourceBudgetPromiseAgrSumma', 1, 302, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(30211052, '  .', 'SourceBudgetPromiseAgrRNum', '  .', 'SourceBudgetPromiseAgrReestrNum', 1, 302, 1, 1, ',', 0, null, 0, 0, '') ;

CALL ImportField(30211053, '. ', 'SourceBudgetPromiseAgrNote', '. ', 'SourceBudgetPromiseAgrNote', 1, 302, 1, 1, ',', 0, null, 0, 0, '') ;

CALL ImportField(30211054, ' . ', 'SourceBudgetPromiseSONum', ' . ', 'SourceBudgetPromiseAgrNum', 1, 302, 1, 1, '', 0, 19798, 0, 0, '') ;

CALL ImportField(30211055, ' . ', 'SourceBudgetPromiseSODate', ' . ', 'SourceBudgetPromiseAgrDate', 1, 302, 1, 1, '', 0, 19799, 0, 0, '') ;

CALL ImportField(30211057, '  . ', 'SourceBudgetPromiseSORNum', '  . ', 'SourceBudgetPromiseAgrReestrNum', 1, 302, 1, 1, '', 0, 19830, 0, 0, '') ;

CALL ImportField(30211058, '. . ', 'SourceBudgetPromiseSONote', '. . ', 'SourceBudgetPromiseAgrNote', 1, 302, 1, 1, '', 0, 19821, 0, 0, '') ;

CALL ImportField(30211076, '()', 'SourceIFSAGCode', ' ( )', ' ', 1, 302, 1, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(30211077, ' ()', 'SourceIFS_DescriptionCode', '  ( )', 'SourceIFS_DescriptionCode', 1, 302, 1, 0, '', 0, 17050, 0, 0, '') ;

CALL ImportField(30211110, '()', 'SourceKDAGCode', '()', ' ', 1, 302, 1, 0, '', 0, 38908, 0, 0, '') ;

CALL ImportField(30211112, ' ', 'SourceFundsSource', ' ', 'SourceFundsSource', 1, 302, 1, 0, '', 0, 18930, 0, 0, '') ;

CALL ImportField(30211117, ' ', 'SourceIFS', ' ', 'SourceIFS', 1, 302, 1, 1, ',', 0, 18920, 0, 0, '') ;

CALL ImportField(30211118, ' ', 'SourceKD', ' ', 'SourceKD', 1, 302, 1, 1, '', 0, 18925, 0, 0, '') ;

CALL ImportField(30211120, ' ', 'RECORDINDEX', ' ', 'RecordIndex', 1, 302, 1, 1, '', 0, 18878, 0, 0, '') ;

CALL ImportField(30211121, ' ', 'ID', ' ', 'Id', 1, 302, 1, 1, '', 0, 18865, 0, 0, '') ;

CALL ImportField(30211130, ' ', 'SourceKD_Value', ' ', 'SourceKDValue', 1, 302, 1, 1, '', 0, 16836, 0, 0, '') ;

CALL ImportField(30211131, ' ', 'Progindex', '  ()', 'ProgIndex', 1, 302, 1, 1, '', 0, 18877, 0, 0, '') ;

CALL ImportField(30211137, '  ', 'SourceTransfertCls', '   ()', 'SourceTransfertCls', 1, 302, 1, 1, '', 0, 18935, 0, 0, '') ;

CALL ImportField(30211138, '  ', 'SourceTransfertClsCode', '  ', 'SourceTransfertClsValue', 1, 302, 1, 0, '', 0, 25326, 0, 0, '') ;

CALL ImportField(30211140, '()', 'SourceKCSRCode', '()', 'SourceKCSR', 1, 302, 1, 0, '', 0, 25462, 0, 0, '') ;

CALL ImportField(30211142, '()', 'SOURCEKVRCode', '()', 'SourceKVR', 1, 302, 1, 0, '', 0, 25467, 0, 0, '') ;

CALL ImportField(30211143, '()', 'SourceKVSRCode', '()', 'SourceKVSR', 1, 302, 1, 0, '', 0, 25472, 0, 0, '') ;

CALL ImportField(30211144, ' ', 'SourceSubsidyCls', '  ()', 'SourceSubsidyCls', 1, 302, 1, 1, '', 0, 26626, 0, 0, '') ;

CALL ImportField(30211145, ' ', 'SourceSubsidyClsCode', ' ', 'SourceSubsidyClsCode', 1, 302, 1, 0, '', 0, 26641, 0, 0, '') ;

CALL ImportField(30211147, '  ', 'SourceBudAllocationClsCode', '', 'SourceBudAllocationClsCode', 1, 302, 1, 0, '', 0, 27825, 0, 0, '') ;

CALL ImportField(30211148, '  ', 'SourcePayPromiseClsCode', '', 'SourcePayPromiseClsCode', 1, 302, 1, 0, '', 0, 27849, 0, 0, '') ;

CALL ImportField(30211149, '  ', 'SourceBudAllocationCls', '', 'SourceBudAllocationCls', 1, 302, 1, 1, '', 0, 27844, 0, 0, '') ;

CALL ImportField(30211150, '  ', 'SourcePayPromiseCls', '', 'SourcePayPromiseCls', 1, 302, 1, 1, '', 0, 27845, 0, 0, '') ;

CALL ImportField(30211151, '()', 'SourceFact', '', 'SourceFACTCLSKey', 1, 302, 1, 1, '', 0, 18890, 0, 0, '') ;

CALL ImportField(30211153, ' .  ()', 'SOURCEFINTYPE', '  ', 'SourceFINTYPECLSKey', 1, 302, 1, 1, ',', 0, 18893, 0, 0, '') ;

CALL ImportField(30211158, '   ( )', 'StoredPaymentContent', '   ( )', 'StoredPaymentContentDet', 1, 302, 1, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(30211181, '  ', '', '  ', 'SourceCLSType', 1, 302, 1, 0, '', 0, null, 30211158, 1, '') ;

CALL ImportField(30211184, '  ', '', '  ', 'SourceTargetCLS', 1, 302, 1, 0, '', 0, null, 30211158, 1, '') ;

CALL ImportField(30211185, '  ', '', '  ', 'SourceKBK', 1, 302, 1, 1, '', 0, null, 30211158, 1, '') ;

CALL ImportField(30211193, '   ', '', '   ', 'NoteKBK', 1, 302, 1, 1, '', 0, null, 30211158, 1, '') ;

CALL ImportField(30211194, '', 'SourceContractCostsClsCode', '', ' ', 1, 302, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30211195, '', 'SourceContractCostsCls', '', ' ', 1, 302, 1, 1, '', 0, null, 0, 0, '') ;

--   \, +(2)
CALL ImportField(30210161, ' ()', 'AutoSanction', '  ', 'AutoSanction', 2, 302, 0, 0, '', 0, 39225, 0, 0, '') ;

CALL ImportField(30210162, ' ', 'AutoSanctionCode', '', ' ', 2, 302, 0, 0, '', 0, null, 0, 0, '') ;

--  (), (1)
CALL ImportField(30311017, '', 'DESTKESR', '', 'DESTKESR', 1, 303, 1, 0, '', 0, 18871, 0, 0, '') ;

CALL ImportField(30311021, '()', 'DestIFSAGCode', '', ' ', 1, 303, 1, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(30311022, ' ', 'DestSubKESR', ' ', 'DestSubKESR', 1, 303, 1, 0, '', 0, 18898, 0, 0, '') ;

--   , (1)
CALL ImportField(30410040, ' ', 'StimateID', ' ', 'StimateID', 1, 304, 0, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(30411014, '', 'SOURCEKESR', '', 'SourceKESR', 1, 304, 1, 0, '', 0, 18868, 0, 0, '') ;

CALL ImportField(30411016, ' ', 'SOURCESUBKESR', '', 'SOURCESUBKESR', 1, 304, 1, 0, '', 0, 18889, 0, 0, '') ;

CALL ImportField(30411045, '', 'BuhOperationCLS', ' ', 'BuhOperationCLS', 1, 304, 1, 0, '', 0, 18919, 0, 0, '') ;

CALL ImportField(30411077, '()', 'SourceIFSAGCode', ' ( )', ' ', 1, 304, 1, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(30411100, '()', 'SourceKDAGCode', '()', ' ', 1, 304, 1, 0, '', 0, 38908, 0, 0, '') ;

CALL ImportField(30411147, '', 'SourceContractCostsClsCode', '', ' ', 1, 304, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30411148, '', 'SourceContractCostsCls', '', ' ', 1, 304, 1, 1, '', 0, null, 0, 0, '') ;

--   \, (1)
CALL ImportField(30511014, '', 'DESTKESR', ' ', 'DestKESR', 1, 305, 1, 0, '', 0, 18871, 0, 0, '') ;

CALL ImportField(30511018, ' ', 'DestSubKESR', ' ', 'DestSUBKESR', 1, 305, 1, 0, '', 0, 18898, 0, 0, '') ;

CALL ImportField(30511035, '', 'BuhOperationCLS', ' ', 'BuhOperationCLS', 1, 305, 1, 0, '', 0, 18919, 0, 0, '') ;

CALL ImportField(30511050, '()', 'DestIFSAGCode', '( )', ' ', 1, 305, 1, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(30511112, '()', 'DestKDAGCode', '', ' ', 1, 305, 1, 0, '', 0, 38908, 0, 0, '') ;

CALL ImportField(30511148, '', 'DestContractCostsClsCode', '', ' ', 1, 305, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30511149, '', 'DestContractCostsCls', '', ' ', 1, 305, 1, 1, '', 0, null, 0, 0, '') ;

--   , (1)
CALL ImportField(30611022, '', 'DESTKESR', '', 'DestKESR', 1, 306, 1, 0, '', 0, 18871, 0, 0, '') ;

CALL ImportField(30611027, '()', 'DestIFSAGCode', '', ' ', 1, 306, 1, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(30611031, '()', 'DestKDAGCode', '', ' ', 1, 306, 1, 0, '', 0, 38908, 0, 0, '') ;

CALL ImportField(30611039, ' ', 'DestSubKESR', ' ', 'DestSUBKESR', 1, 306, 1, 0, '', 0, 18898, 0, 0, '') ;

CALL ImportField(30611150, '', 'DestContractCostsClsCode', '', ' ', 1, 306, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30611151, '', 'DestContractCostsCls', '', ' ', 1, 306, 1, 1, '', 0, null, 0, 0, '') ;

--  , (1)
CALL ImportField(30811001, '', 'BUDGETREF', '', 'BudgetRef', 1, 308, 1, 1, '', 0, 18872, 0, 0, '') ;

CALL ImportField(30811021, ' ( )', 'DestKDAGCode', ' -( -)', ' ', 1, 308, 1, 0, '', 0, 38908, 0, 0, '') ;

CALL ImportField(30811027, '  ', 'DestSubKESR', '  -', 'DestSUBKESR', 1, 308, 1, 0, '', 0, 18898, 0, 0, '') ;

CALL ImportField(30811045, ' ( )', 'SOURCEKESR', ' .( .)', 'SourceKESR', 1, 308, 1, 0, ',', 0, 18868, 0, 0, '') ;

CALL ImportField(30811052, '  ', 'SourceSubKESR', '  .', 'SourceSUBKESR', 1, 308, 1, 0, ',', 0, 18889, 0, 0, '') ;

CALL ImportField(30811069, ' ( )', 'DESTKESR', '', 'DestKESR', 1, 308, 1, 0, '', 0, 18871, 0, 0, '') ;

CALL ImportField(30811077, '( )', 'SourceKDAGCode', '', ' ', 1, 308, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30811096, '( )', 'DestIFSAGCode', '', ' ', 1, 308, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30811100, '( )', 'SourceIFSAGCode', '', ' ', 1, 308, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30811115, ' ', 'DestContractCostsClsCode', '', ' ', 1, 308, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30811116, ' ', 'DestContractCostsCls', '', ' ', 1, 308, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(30811117, ' ', 'SourceContractCostsCls', '', ' ', 1, 308, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(30811118, ' ', 'SourceContractCostsClsCode', '', ' ', 1, 308, 1, 0, '', 0, null, 0, 0, '') ;

--    , (1)
CALL ImportField(31111005, '', 'SOURCEKESR', '', 'SOURCEKESR', 1, 311, 1, 0, '', 0, 18868, 0, 0, '') ;

CALL ImportField(31111009, ' ', 'SourceSubKESR', ' ', 'SourceSubKESR', 1, 311, 1, 0, '', 0, 18889, 0, 0, '') ;

CALL ImportField(31111018, ' ', 'DESTKESR', ' ', 'DESTKESR', 1, 311, 1, 1, '', 0, 18871, 0, 0, '') ;

CALL ImportField(31111022, '  ', 'DestSubKESR', '  ', 'DestSubKESR', 1, 311, 1, 1, '', 0, 18898, 0, 0, '') ;

CALL ImportField(31111053, '()', 'SourceIFSAGCode', '', ' ', 1, 311, 1, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(31111057, '()', 'SourceKDAGCode', '', ' ', 1, 311, 1, 0, '', 0, 38908, 0, 0, '') ;

CALL ImportField(31111109, '', 'SourceContractCostsCls', '', ' ', 1, 311, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(31111110, '', 'SourceContractCostsClsCode', '', ' ', 1, 311, 1, 0, '', 0, null, 0, 0, '') ;

--     , (1)
CALL ImportField(31211017, '', 'DestKESR', ' ', 'DestKESR', 1, 312, 1, 0, '', 0, 18871, 0, 0, '') ;

CALL ImportField(31211021, ' ', 'DestSUBKESR', ' ', 'DestSUBKESR', 1, 312, 1, 0, '', 0, 18898, 0, 0, '') ;

CALL ImportField(31211035, ' ', 'SourceKESR', ' ', 'SourceKESR', 1, 312, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(31211039, ' ', 'SourceSUBKESR', ' ', 'SourceSUBKESR', 1, 312, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(31211043, ' .  ', ' ', ' .  ', 'SourceFINTYPECLS', 1, 312, 1, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(31211074, '()', 'DestIFSAGCode', ' ( )', ' ', 1, 312, 1, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(31211099, '()', 'DestKDAGCode', '', ' ', 1, 312, 1, 0, '', 0, 38908, 0, 0, '') ;

CALL ImportField(31211144, '', 'DestContractCostsCls', '', ' ', 1, 312, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(31211145, '', 'DestContractCostsClsCode', '', ' ', 1, 312, 1, 0, '', 0, null, 0, 0, '') ;

--    , (1)
CALL ImportField(31411017, ' ', 'DestKESR', ' ', 'DestKESR', 1, 314, 1, 1, '', 0, 18871, 0, 0, '') ;

CALL ImportField(31411021, ' ', 'DestSUBKESR', ' ', 'DestSUBKESR', 1, 314, 1, 1, '', 0, 18898, 0, 0, '') ;

CALL ImportField(31411025, ' .  ', ' ', ' .  ', 'DestFINTYPECLS', 1, 314, 1, 1, '', 1, null, 0, 0, '') ;

CALL ImportField(31411035, '', 'SourceKESR', ' ', 'SourceKESR', 1, 314, 1, 0, '', 0, 18868, 0, 0, '') ;

CALL ImportField(31411039, ' ', 'SourceSUBKESR', ' ', 'SourceSUBKESR', 1, 314, 1, 0, '', 0, 18889, 0, 0, '') ;

CALL ImportField(31411074, '()', 'SourceIFSAGCode', '()', ' ', 1, 314, 1, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(31411099, '()', 'SourceKDAGCode', '()', ' ', 1, 314, 1, 0, '', 0, 38908, 0, 0, '') ;

CALL ImportField(31411144, '', 'SourceContractCostsClsCode', '', ' ', 1, 314, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(31411145, '', 'SourceContractCostsCls', '', ' ', 1, 314, 1, 1, '', 0, null, 0, 0, '') ;

--      , (1)
CALL ImportField(31511020, '', 'DESTKESR', '', 'DestKESR', 1, 315, 1, 0, '', 0, 18871, 0, 0, '') ;

CALL ImportField(31511025, '()', 'DestIFSAGCode', '', ' ', 1, 315, 1, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(31511029, '()', 'DestKDAGCode', '', ' ', 1, 315, 1, 0, '', 0, 38908, 0, 0, '') ;

CALL ImportField(31511031, ' ', 'DestSubKESR', ' ', 'DestSUBKESR', 1, 315, 1, 0, '', 0, 18898, 0, 0, '') ;

CALL ImportField(31511100, '', 'DestContractCostsClsCode', '', ' ', 1, 315, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(31511101, '', 'DestContractCostsCls', '', ' ', 1, 315, 1, 1, '', 0, null, 0, 0, '') ;

--   , (1)
CALL ImportField(32211027, '', 'SOURCEKESR', '', ' ', 1, 322, 1, 0, '', 0, 18868, 0, 0, '') ;

CALL ImportField(32211032, '()', 'SourceIFSAGCode', '', ' ', 1, 322, 1, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(32211039, ' ', 'SourceSubKESR', ' ', ' ', 1, 322, 1, 0, '', 0, 18889, 0, 0, '') ;

CALL ImportField(32211092, '', 'SourceContractCostsCls', '', ' ', 1, 322, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(32211093, '', 'SourceContractCostsClsCode', '', ' ', 1, 322, 1, 0, '', 0, null, 0, 0, '') ;

--  , (1)
CALL ImportField(32311018, '', 'DESTKESR', '', 'DestKESR', 1, 323, 1, 0, '', 0, 18871, 0, 0, '') ;

CALL ImportField(32311023, '()', 'DestIFSAGCode', '', ' ', 1, 323, 1, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(32311031, ' ', 'DestSubKESR', ' ', 'DestSUBKESR', 1, 323, 1, 0, '', 0, 18898, 0, 0, '') ;

CALL ImportField(32311164, '    ', 'DestBudgetPromiseNumLine', '    ', 'DestBudgetPromiseNumLine', 1, 323, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(32311165, '', 'DestContractCostsClsCode', '', ' ', 1, 323, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(32311166, '', 'DestContractCostsCls', '', ' ', 1, 323, 1, 1, '', 0, null, 0, 0, '') ;

--  , (1)
CALL ImportField(32411076, '', 'DESTKESR', ' -', 'DestKESR', 1, 324, 1, 0, ',', 0, 18871, 0, 0, '') ;

CALL ImportField(32411081, ' ', 'DestSubKESR', '  -', 'DestSUBKESR', 1, 324, 1, 0, ',', 0, 18898, 0, 0, '') ;

CALL ImportField(32411090, '()', 'DestIFSAGCode', '()', ' ', 1, 324, 1, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(32411205, '', 'DestContractCostsCls', '', ' ', 1, 324, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(32411206, '', 'DestContractCostsClsCode', '', ' ', 1, 324, 1, 0, '', 0, null, 0, 0, '') ;

--    , (1)
CALL ImportField(40114104, '', 'KESR', '', ' ', 1, 401, 4, 0, '', 0, 18151, 0, 0, '') ;

CALL ImportField(40116125, '', 'KESR', '', ' ', 1, 401, 6, 0, '', 0, 17827, 0, 0, '') ;

CALL ImportField(40116128, ' . ', 'FINTYPECode', ' . ', ' ', 1, 401, 6, 0, '', 0, 36853, 0, 0, '') ;

CALL ImportField(40116139, '', 'SUBKESR', '', ' ', 1, 401, 6, 0, '', 0, 17828, 0, 0, '') ;

CALL ImportField(40116250, ' .  ()', 'FINTYPE', ' .  ()', ' ', 1, 401, 6, 1, ',', 0, 17833, 0, 0, '') ;

CALL ImportField(40110190, ' . ', 'FINTYPECode', ' . ', ' ', 1, 401, 10, 0, '', 0, 36853, 0, 0, '') ;

CALL ImportField(40110196, '', 'KESR', '', ' ', 1, 401, 10, 0, '', 0, 17827, 0, 0, '') ;

CALL ImportField(40110202, '', 'SUBKESR', '', ' ', 1, 401, 10, 0, '', 0, 17828, 0, 0, '') ;

CALL ImportField(40110255, ' .  ()', 'FINTYPE', ' .  ()', ' ', 1, 401, 10, 1, ',', 0, 17833, 0, 0, '') ;

--   , (1)
CALL ImportField(50111042, '', 'KESR', '', ' ', 1, 501, 1, 0, '', 0, 17827, 0, 0, '') ;

CALL ImportField(50111045, '', 'SUBKESR', '', ' ', 1, 501, 1, 0, '', 0, 17828, 0, 0, '') ;

CALL ImportField(50111048, ' . ', 'FINTYPECODE', ' . ', ' ', 1, 501, 1, 0, '', 0, 36853, 0, 0, '') ;

CALL ImportField(50111178, '()', 'IFSAGCode', '()', ' ', 1, 501, 1, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(50111186, ' .  ()', 'FINTYPE', ' .  ()', ' ', 1, 501, 1, 1, '', 0, 17833, 0, 0, '') ;

CALL ImportField(50113078, '', 'KESR', '', ' ', 1, 501, 3, 0, '', 0, 17827, 0, 0, '') ;

CALL ImportField(50113081, '', 'SUBKESR', '', ' ', 1, 501, 3, 0, '', 0, 17828, 0, 0, '') ;

CALL ImportField(50113084, ' . ', 'FINTYPECODE', ' . ', ' ', 1, 501, 3, 0, '', 0, 36853, 0, 0, '') ;

CALL ImportField(50113182, '()', 'IFSAGCode', '()', ' ', 1, 501, 3, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(50113190, ' .  ()', 'FINTYPE', ' .  ()', ' ', 1, 501, 3, 1, '', 0, 17833, 0, 0, '') ;

--   , (1)
CALL ImportField(70111011, '', 'KESR', '', ' ', 1, 701, 1, 0, '', 0, 17827, 0, 0, '') ;

CALL ImportField(70111018, ' ', 'SUBKESR', ' ', ' ', 1, 701, 1, 0, '', 0, 17828, 0, 0, '') ;

CALL ImportField(70111021, ' . ', 'FINTYPECODE', ' . ', ' ', 1, 701, 1, 0, '', 0, 36853, 0, 0, '') ;

CALL ImportField(70111072, ' . ', 'FINTYPE', ' . ', ' ', 1, 701, 1, 1, '', 0, 17833, 0, 0, '') ;

--  , (1)
CALL ImportField(70310008, '', 'KESR', '', ' ', 1, 703, 0, 0, '', 0, 17827, 0, 0, '') ;

CALL ImportField(70310015, ' ', 'SUBKESR', ' ', ' ', 1, 703, 0, 0, '', 0, 17828, 0, 0, '') ;

CALL ImportField(70310020, ' . ', 'FINTYPECode', ' . ', ' ', 1, 703, 0, 0, '', 0, 36853, 0, 0, '') ;

CALL ImportField(70310054, ' . ', 'FINTYPE', ' . ', ' ', 1, 703, 0, 1, '', 0, 17833, 0, 0, '') ;

--  , (1)
CALL ImportField(80111023, '', 'KESR', '', 'KESR', 1, 801, 1, 0, '', 0, 18630, 0, 0, '') ;

CALL ImportField(80111040, '', 'SUBKESR', '', 'SUBKESR', 1, 801, 1, 0, '', 0, 18635, 0, 0, '') ;

CALL ImportField(80111047, '()', 'IFSAGCode', '()', ' ', 1, 801, 1, 0, '', 0, 38919, 0, 0, '') ;

--   (), (1)
CALL ImportField(80210010, '', 'KESR', '', ' ', 1, 802, 0, 0, '', 0, 18630, 0, 0, '') ;

CALL ImportField(80210015, '()', 'IFSAGCode', '', ' ', 1, 802, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(80210017, '', 'SUBKESR', '', ' ', 1, 802, 0, 0, '', 0, 18635, 0, 0, '') ;

CALL ImportField(80210026, ' . ', 'FinTypeCode', ' . ', ' ', 1, 802, 0, 0, '', 0, 36853, 0, 0, '') ;

CALL ImportField(80210041, ' .  ()', 'FinType', ' .  ()', ' ', 1, 802, 0, 1, '', 0, 18634, 0, 0, '') ;

--     , (1)
CALL ImportField(80311015, '', 'KESR', '', ' ', 1, 803, 1, 0, '', 0, 18630, 0, 0, '') ;

CALL ImportField(80311019, '()', 'SourceIFSAGCode', '', ' ', 1, 803, 1, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(80311028, ' . ', 'FinTypeCode', ' . ', ' ', 1, 803, 1, 0, '', 0, 36853, 0, 0, '') ;

CALL ImportField(80311029, '', 'SUBKESR', '', ' ', 1, 803, 1, 0, '', 0, 18635, 0, 0, '') ;

CALL ImportField(80311054, ' .  ()', 'FinType', ' .  ()', ' ', 1, 803, 1, 1, '', 0, 18634, 0, 0, '') ;

--    , (1)
CALL ImportField(90111056, '()', 'KDAGCode', '()', ' ', 1, 901, 1, 0, '', 0, 38908, 0, 0, '') ;

--   , (1)
CALL ImportField(90311015, '()', 'KDAGCode', '', ' ', 1, 903, 1, 0, '', 0, 38908, 0, 0, '') ;

CALL ImportField(90311018, '()', 'IFSAGCode', '', ' ', 1, 903, 1, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(90311030, '', 'KESR', '', 'KESR', 1, 903, 1, 0, '', 0, 17712, 0, 0, '') ;

CALL ImportField(90311035, ' ', 'CLSType', ' ', 'ClsType', 1, 903, 1, 0, '', 0, 17723, 0, 0, '') ;

--   , (1)
CALL ImportField(90510008, '()', 'KDAGCode', '', ' ', 1, 905, 0, 0, '', 0, 38908, 0, 0, '') ;

CALL ImportField(90510038, '()', 'IFSAGCode', '', ' ', 1, 905, 0, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(90510046, '', 'KESR', '', 'KESR', 1, 905, 0, 0, '', 0, 17712, 0, 0, '') ;

--   (), (1)
CALL ImportField(90610082, '', 'KESR', '', 'KESR', 1, 906, 0, 0, '', 0, 17712, 0, 0, '') ;

CALL ImportField(90611088, '', 'KESR', '', 'KESR', 1, 906, 1, 0, '', 0, 17712, 0, 0, '') ;

--   (), (1)
CALL ImportField(90710007, '()', 'KDAGCode', '', ' ', 1, 907, 0, 0, '', 0, 38908, 0, 0, '') ;

CALL ImportField(90710040, '()', 'IFSAGCode', '()', ' ', 1, 907, 0, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(90710058, '', 'KESR', '', 'KESR', 1, 907, 0, 0, '', 0, null, 0, 0, '') ;

--  , (1)
CALL ImportField(120110009, '( )', 'KESR', '( )', ' ', 1, 1201, 0, 0, '', 0, 17343, 0, 0, '') ;

CALL ImportField(120110012, '( )', 'IFSAGCode', '', ' ', 1, 1201, 0, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(120110016, '( )', 'KDAGCode', '', ' ', 1, 1201, 0, 0, '', 0, 38908, 0, 0, '') ;

CALL ImportField(120110023, '( )', 'KESR_corr', '( )', ' ', 1, 1201, 0, 0, '', 0, 17349, 0, 0, '') ;

CALL ImportField(120110030, '( )', 'KDAG_corrCode', '', ' ', 1, 1201, 0, 0, '', 0, 38908, 0, 0, '') ;

CALL ImportField(120110061, ' . ', 'FinTypeCode', ' . ', ' ', 1, 1201, 0, 1, ',', 0, 36853, 0, 0, '') ;

CALL ImportField(120110062, ' . ', 'FinType_corrCode', ' . ', ' ', 1, 1201, 0, 1, '', 0, 36853, 0, 0, '') ;

CALL ImportField(120110064, '( )', 'IFSAG_corrCode', '( )', ' ', 1, 1201, 0, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(120110068, '', 'SubKESR', '', ' ', 1, 1201, 0, 1, '', 0, 17387, 0, 0, '') ;

CALL ImportField(120110069, '', 'SubKESR_corr', '', ' ', 1, 1201, 0, 1, '', 0, 17388, 0, 0, '') ;

CALL ImportField(120110077, ' .  ()', 'FinType', ' . ', ' ', 1, 1201, 0, 1, ',', 0, 17381, 0, 0, '') ;

CALL ImportField(120110078, ' .  ()', 'FinType_corr', ' .  ()', ' ', 1, 1201, 0, 1, '', 0, 17382, 0, 0, '') ;

--  , (1)
CALL ImportField(150110007, '', 'KESR', '', ' ', 1, 1501, 0, 0, '', 0, 18383, 0, 0, '') ;

CALL ImportField(150110010, '', 'SUBKESR', '', ' ', 1, 1501, 0, 0, '', 0, 18384, 0, 0, '') ;

CALL ImportField(150110015, ' . ', 'FINTYPECODE', ' . ', ' ', 1, 1501, 0, 0, ',', 0, 36853, 0, 0, '') ;

CALL ImportField(150110048, '()', 'IFSAGCode', '', ' ', 1, 1501, 0, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(150110054, ' .  ()', 'FINTYPE', ' . ', ' ', 1, 1501, 0, 1, ',', 0, 18387, 0, 0, '') ;

--  , (1)
CALL ImportField(160111025, '', 'KESR', '', 'KESR', 1, 1601, 1, 0, '', 0, 19024, 0, 0, '') ;

CALL ImportField(160111028, ' . ', 'FinTypeCode', ' . ', 'FinTypeCls', 1, 1601, 1, 0, ',', 0, 36853, 0, 0, '') ;

CALL ImportField(160111044, ' ', 'SubKESR', ' ', 'SubKESR', 1, 1601, 1, 0, '', 0, 19031, 0, 0, '') ;

CALL ImportField(160111045, ' ', 'RegionCls', '', 'RegionCls', 1, 1601, 1, 0, ',,', 0, 19032, 0, 0, '') ;

CALL ImportField(160111087, ' .  ()', 'FinType', ' . ', 'FinTypeClsCode', 1, 1601, 1, 1, ',', 0, 19029, 0, 0, '') ;

-- . - , (1)
CALL ImportField(160210015, '', 'KESR', '', ' ', 1, 1602, 0, 0, '', 0, 19024, 0, 0, '') ;

CALL ImportField(160210022, ' ', 'SubKESR', ' ', ' ', 1, 1602, 0, 0, '', 0, 19031, 0, 0, '') ;

CALL ImportField(160210025, ' . ', 'FinTypeCode', ' . ', ' ', 1, 1602, 0, 0, ',', 0, 36853, 0, 0, '') ;

CALL ImportField(160210047, ' .  ()', 'FinType', ' . ', ' ', 1, 1602, 0, 1, ',', 0, 19029, 0, 0, '') ;

-- , (1)
CALL ImportField(170110021, ' . ', 'FINTYPECODE', ' . ', 'FINTYPE', 1, 1701, 0, 0, ',', 0, 36853, 0, 0, '') ;

CALL ImportField(170110029, '', 'KESR', '', 'KESR', 1, 1701, 0, 0, '', 0, 19131, 0, 0, '') ;

CALL ImportField(170110049, ' ', 'SUBKESR', '', 'SUBKESR', 1, 1701, 0, 0, '', 0, 19132, 0, 0, '') ;

CALL ImportField(170110065, '( )', 'KDAGCode', '', ' ', 1, 1701, 0, 0, '', 0, 38908, 0, 0, '') ;

CALL ImportField(170110095, ' .  ()', 'FINTYPE', ' . ', 'FINTYPEKEY', 1, 1701, 0, 1, ',', 0, 19141, 0, 0, '') ;

-- (), (1)
CALL ImportField(170210030, '', 'KESR', '', ' ', 1, 1702, 0, 0, '', 0, 19131, 0, 0, '') ;

CALL ImportField(170210043, '', 'SubKESR', '', ' ', 1, 1702, 0, 0, '', 0, 19132, 0, 0, '') ;

CALL ImportField(170210047, ' . ', 'FinTypeCode', ' . ', ' ', 1, 1702, 0, 0, ',', 0, 36853, 0, 0, '') ;

CALL ImportField(170210053, ' .  ()', 'FinType', ' . ', ' ', 1, 1702, 0, 1, ',', 0, 19141, 0, 0, '') ;

--      , (1)
CALL ImportField(180910001, '', 'DestKESR', '  ', ' ', 1, 1809, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(180910002, '', 'DestCLSType', '   ', ' ', 1, 1809, 0, 0, '', 0, null, 0, 0, '') ;

--   , (1)
CALL ImportField(181610007, '', 'KESR', '', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181610034, ' ', 'SubKESR', '', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181611070, '', 'KESR', '', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181611073, ' ', 'SubKESR', '', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181611101, ' ', 'ClsType', '  (, , )', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0, '') ;

--   (), (1)
CALL ImportField(190011036, '', '{("")}', '', ' ', 1, 1900, 1, 0, '', 0, null, 0, 0, '') ;

--  (), (1)
CALL ImportField(190111018, '(  )', 'IFSAGCode', '', ' ', 1, 1901, 1, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(190111019, ' ', 'SUBKESR', ' ', 'DestSubKesr', 1, 1901, 1, 0, '', 0, 17416, 0, 0, '') ;

CALL ImportField(190111092, '  ', 'TransfertClsCode', '  ', 'TransfertClsValue', 1, 1901, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(190111100, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 1901, 1, 1, '', 0, 27835, 0, 0, '') ;

CALL ImportField(190111107, '', 'Kesr', '', 'DestKesr', 1, 1901, 1, 0, '', 0, 17415, 0, 0, '') ;

--    (), (1)
CALL ImportField(190211006, '(  )', 'IFSAGCode', '()', ' ', 1, 1902, 1, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(190211071, ' ', 'SUBKESR', ' ', 'DestSubKesr', 1, 1902, 1, 0, '', 0, 17416, 0, 0, '') ;

CALL ImportField(190211099, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 1902, 1, 1, '', 0, 27835, 0, 0, '') ;

CALL ImportField(190211105, '', 'Kesr', '', 'DestKesr', 1, 1902, 1, 0, '', 0, 17415, 0, 0, '') ;

--   (), (1)
CALL ImportField(190311070, ' ', 'SUBKESR', ' ', 'DestSubKesr', 1, 1903, 1, 0, '', 0, 17416, 0, 0, '') ;

CALL ImportField(190311077, '(  )', 'IFSAGCode', '()', ' ', 1, 1903, 1, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(190311100, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 1903, 1, 1, '', 0, 27835, 0, 0, '') ;

CALL ImportField(190311106, '', 'Kesr', '', 'DestKesr', 1, 1903, 1, 0, '', 0, 17415, 0, 0, '') ;

--    (), (1)
CALL ImportField(190611071, ' ', 'SUBKESR', ' ', 'DestSubKesr', 1, 1906, 1, 0, '', 0, 17416, 0, 0, '') ;

CALL ImportField(190611078, '(  )', 'IFSAGCode', '()', ' ', 1, 1906, 1, 0, '', 0, 38919, 0, 0, '') ;

CALL ImportField(190611102, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 1906, 1, 1, '', 0, 27835, 0, 0, '') ;

CALL ImportField(190611108, '', 'Kesr', '', 'DestKesr', 1, 1906, 1, 0, '', 0, 17415, 0, 0, '') ;

--   (), (1)
CALL ImportField(220011010, '', '{("")}', '', ' ', 1, 2200, 1, 0, '', 0, null, 0, 0, '') ;

--   (), (1)
CALL ImportField(220111016, '()', 'KDAGCode', '', 'KDAGCode', 1, 2201, 1, 0, '', 0, 38908, 0, 0, '') ;

CALL ImportField(220111080, '', 'Kesr', '', 'DestKesr', 1, 2201, 1, 0, '', 0, 17415, 0, 0, '') ;

CALL ImportField(220111081, '/ ', 'FCAccountName', '/ ', ' ', 1, 2201, 1, 0, '', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(250112004, '', 'KESR', '', 'KESR', 2, 2501, 2, 0, '', 0, 20226, 0, 0, '') ;

-- , +(2)
CALL ImportField(250210059, ' ', 'StateOrderDate', '', 'StateOrderDate', 2, 2502, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250210060, '  ', 'StateOrderReestrNumber', '', 'StateOrderReestrNumber', 2, 2502, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250210061, ' ', 'StateOrderInnerNumber', '', 'StateOrderInnerNumber', 2, 2502, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250210062, '    ', 'OldDocNumber', '', 'OldDocNumber', 2, 2502, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250210063, '', 'StateOrderCaption', '', 'StateOrderCaption', 2, 2502, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250212004, ' ', 'SubKESR', '', 'SubKESR', 2, 2502, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250212029, '', 'KESR', '', 'KESR', 2, 2502, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250212036, ' ()', 'DirectionCls', '', 'DirectionClsKey', 2, 2502, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(250212048, '  ', 'SummaYear3', '', 'SummaYear3', 2, 2502, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250212050, ' ', 'SubsidyClsCode', '', 'SubsidyClsCode', 2, 2502, 2, 0, '', 0, 26641, 0, 0, '') ;

CALL ImportField(250212051, '', 'DirectionClsCode', '', 'DirectionCls', 2, 2502, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250212056, '  ()', 'SubsidyCls', '', 'SubsidyCls', 2, 2502, 2, 1, '', 0, 27625, 0, 0, '') ;

CALL ImportField(250212057, '', 'ContractCostsClsCode', '', ' ', 2, 2502, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250212058, '', 'ContractCostsCls', '', ' ', 2, 2502, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(250212059, '  ', 'SummaOtherYears', '', 'SummaOtherYears', 2, 2502, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250212060, '  ', 'SummaYear4', '', 'SummaYear4', 2, 2502, 2, 0, '', 0, null, 0, 0, '') ;

--   , +(2)
CALL ImportField(250312011, '', 'KESR', '', 'KESR', 2, 2503, 2, 0, '', 0, 20226, 0, 0, '') ;

CALL ImportField(250312035, ' ', 'SubKESR', '', 'SubKESR', 2, 2503, 2, 0, '', 0, 20244, 0, 0, '') ;

CALL ImportField(250312051, '  ()', 'SubsidyCls', '', 'SubsidyCls', 2, 2503, 2, 1, '', 0, 27625, 0, 0, '') ;

CALL ImportField(250312052, '', 'ContractCostsCls', '', ' ', 2, 2503, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(250312053, '', 'ContractCostsClsCode', '', ' ', 2, 2503, 2, 0, '', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(250410099, '  ', 'ExecuterStoredProps', '', 'ExecuterStoredProps', 2, 2504, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250410100, '   ()', 'AutoSanction', '', 'AutoSanction', 2, 2504, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250410101, '  ', 'PurchaseCode', '  ', 'PurchaseCode', 2, 2504, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250410102, '  ', 'AutoSanctionCode', '', ' ', 2, 2504, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250410103, ' ', 'DocumentNumber', '', 'DocumentNumber', 2, 2504, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250410104, ' ', 'DocStateRef', '', 'DocStateRef', 2, 2504, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250410105, 'ID', 'ID', '', 'ID', 2, 2504, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(250410106, 'RealID', 'RealID', '', 'RealID', 2, 2504, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(250412009, ' ', 'SubsidyClsCode', '', 'SubsidyClsCode', 2, 2504, 2, 0, '', 0, 26641, 0, 0, '') ;

CALL ImportField(250412010, ' ', 'SubKESR', '', 'SubKESR', 2, 2504, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250412036, '', 'KESR', '', 'KESR', 2, 2504, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250412055, '  ()', 'SubsidyCls', '', 'SubsidyCls', 2, 2504, 2, 1, '', 0, 27625, 0, 0, '') ;

CALL ImportField(250412056, '', 'Note', '', 'Note', 2, 2504, 2, 0, '', 0, 20297, 0, 0, '') ;

CALL ImportField(250412057, '', 'ContractCostsCls', '', 'ContractCostsCls', 2, 2504, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250412058, '', 'ContractCostsClsCode', '', 'ContractCostsClsCode', 2, 2504, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250412059, '  ', 'SummaYear4', '', 'SummaYear4', 2, 2504, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250412060, '  ', 'SummaOtherYears', '', 'SummaOtherYears', 2, 2504, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250415001, ' (+)', 'TreeOwner0', '', 'TreeOwner0', 2, 2504, 5, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250415002, '', 'SUMMA', '', 'SUMMA', 2, 2504, 5, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250415003, '', 'Note', '', 'Note', 2, 2504, 5, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250415004, ' ', 'MEANSTYPE', ' ', 'MEANSTYPE', 2, 2504, 5, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250415005, '', 'KVSRCode', '', 'KVSR', 2, 2504, 5, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250415006, '', 'KVSR', '', 'KVSR', 2, 2504, 5, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(250415007, '', 'KVRCode', '', 'KVR', 2, 2504, 5, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250415008, '', 'KVR', '', 'KVR', 2, 2504, 5, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(250415009, '', 'KFSR', '', 'KFSR', 2, 2504, 5, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250415010, '', 'KESR', '', 'KESR', 2, 2504, 5, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250415011, '', 'KCSRCode', '', 'KCSR', 2, 2504, 5, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250415012, '', 'KCSR', '', 'KCSR', 2, 2504, 5, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(250415013, '', 'FinYear', '', 'FinYear', 2, 2504, 5, 0, '', 0, null, 0, 0, '') ;

--    , +(2)
CALL ImportField(300110013, ' ', 'REJECTCLS', ' ', 'REJECTCLS', 2, 3001, 0, 0, '', 0, 21288, 0, 0, '') ;

CALL ImportField(300110014, '  ()', 'REJECTCAUSE', '  ()', 'REJECTCAUSE', 2, 3001, 0, 0, '', 0, 21289, 0, 0, '') ;

CALL ImportField(300110033, '  ', 'PurchaseCode', '  ', 'PurchaseCode', 2, 3001, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300110034, ' ', 'AVersion', '', 'AVersion', 2, 3001, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300110035, '  /', 'ParentRef', '', 'PArentRef', 2, 3001, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300111008, '', 'SubKESR', '', 'SubKESR', 2, 3001, 1, 0, '', 0, 21039, 0, 0, '') ;

CALL ImportField(300111041, '', 'KESR', '', 'KESR', 2, 3001, 1, 0, '', 0, 21038, 0, 0, '') ;

CALL ImportField(300111045, ' . ', 'FinTypeCode', ' . ', 'FinType', 2, 3001, 1, 0, '', 0, 36853, 0, 0, '') ;

CALL ImportField(300111097, ' .  ()', 'FinType', ' . ', 'FinTypeKey', 2, 3001, 1, 1, '', 0, 21114, 0, 0, '') ;

CALL ImportField(300111100, '', 'ContractCostsCls', '', ' ', 2, 3001, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(300111101, '', 'ContractCostsClsCode', '', ' ', 2, 3001, 1, 0, '', 0, null, 0, 0, '') ;

-- , +(2)
CALL ImportField(300210001, ' ()', 'PurchaseRef', '', ' ', 2, 3002, 0, 0, '', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(300310018, ' ', 'RejectCls', '', 'RejectCls', 2, 3003, 0, 0, '', 0, 21387, 0, 0, '') ;

CALL ImportField(300310019, '  ()', 'RejectCause', '', 'RejectCause', 2, 3003, 0, 0, '', 0, 21388, 0, 0, '') ;

--  , +(2)
CALL ImportField(300410001, ' ()', 'SupplierRef', '', ' ', 2, 3004, 0, 0, '', 0, null, 0, 0, '') ;

-- -, +(2)
CALL ImportField(300510001, '', 'BudgetRef', '', 'BudgetRef', 2, 3005, 0, 1, '', 0, 21277, 0, 0, '') ;

CALL ImportField(300510002, ' ', 'RejectCls', '', 'RejectCls', 2, 3005, 0, 0, '', 0, 21288, 0, 0, '') ;

CALL ImportField(300510003, '  ()', 'RejectCause', '', 'RejectCause', 2, 3005, 0, 0, '', 0, 21289, 0, 0, '') ;

CALL ImportField(300510004, '', 'Org_Name', '', 'Org_Name', 2, 3005, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(300510005, '', 'Note', '', 'Note', 2, 3005, 0, 0, '', 0, 21310, 0, 0, '') ;

CALL ImportField(300510006, ' -  (+)', 'FacialAccClsCol', '', 'FacialAccClsCol', 2, 3005, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(300510007, ' ', 'FacialAccCls', '', 'FacialAccCls', 2, 3005, 0, 0, '', 0, 21279, 0, 0, '') ;

CALL ImportField(300510008, '   ', 'DocNumber', '   ', 'DocNumber', 2, 3005, 0, 0, '', 0, 21278, 0, 0, '') ;

CALL ImportField(300510009, ' ', 'AYear', '', 'AYear', 2, 3005, 0, 0, '', 0, 21284, 0, 0, '') ;

CALL ImportField(300510010, '', 'AcceptSumma', '', 'AcceptSumma', 2, 3005, 0, 0, '', 0, 21286, 0, 0, '') ;

CALL ImportField(300510011, '  ', 'AcceptDate', '', 'AcceptDate', 2, 3005, 0, 0, '', 0, 21282, 0, 0, '') ;

CALL ImportField(300510012, '   ', 'ReworkCause', '', 'ReworkCause', 2, 3005, 0, 0, '', 0, 25041, 0, 0, '') ;

CALL ImportField(300510013, '/  ( - )', 'FacialCode', '', ' ', 2, 3005, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300510014, ' - ', 'OrgRecipient', '', ' ', 2, 3005, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300510015, ' ', 'LastAdjustment', '', 'LastAdjustment', 2, 3005, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(300510016, ' ', 'AVersion', '', 'AVersion', 2, 3005, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300510017, '', 'RealID', '', 'RealID', 2, 3005, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300510018, 'ID', 'ID', '', 'ID', 2, 3005, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(300510019, '   ', 'SummaOtherYears', '', 'SummaOtherYears', 2, 3005, 0, 0, '', 0, null, 0, 0, '') ;

--  -, +(2)
CALL ImportField(300610023, ' ', 'ExportDate', '', ' ', 2, 3006, 0, 0, '', 0, 21311, 0, 0, '') ;

CALL ImportField(300610024, '/  ( - )', 'FacialCode', '', ' ', 2, 3006, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300610025, ' - ', 'OrgRecipient', '', ' ', 2, 3006, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300610049, '  ', 'PurchaseCode', '  ', 'PurchaseCode', 2, 3006, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300610050, ' ', 'AVersion', '', 'AVersion', 2, 3006, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300610051, '  /', 'ParentRef', '', 'ParentRef', 2, 3006, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300610052, ' ', 'PlanCaption', '', 'PlanCaption', 2, 3006, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300611005, '2', 'OKPD2', '', 'OKPD2', 2, 3006, 1, 0, '', 0, 37808, 0, 0, '') ;

CALL ImportField(300611008, '', 'KESR', '', 'KESR', 2, 3006, 1, 0, '', 0, 21038, 0, 0, '') ;

CALL ImportField(300611046, '', 'DirectionClsCode', '', ' ', 2, 3006, 1, 0, '', 0, 36861, 0, 0, '') ;

CALL ImportField(300611047, '/  ( - )', 'FacialCode', '', ' ', 2, 3006, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300611048, '( - )', 'FacialOrgName', '', ' ', 2, 3006, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300611050, '', 'ProductCollaps', '', ' ', 2, 3006, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300611051, ' ', 'subkesr', '', ' ', 2, 3006, 1, 0, '', 0, 21039, 0, 0, '') ;

CALL ImportField(300611052, ' ', 'SubsidyClsCode', '', ' ', 2, 3006, 1, 0, '', 0, 26641, 0, 0, '') ;

CALL ImportField(300611053, ' ()', 'DirectionCls', '', ' ', 2, 3006, 1, 1, '', 0, 21104, 0, 0, '') ;

CALL ImportField(300611062, '', 'ContractCostsCls', '', ' ', 2, 3006, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300611063, '', 'ContractCostsClsCode', '', ' ', 2, 3006, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300611064, '   ', 'SummaOtherYears', '', 'SummaOtherYears', 2, 3006, 1, 0, '', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(301010001, '', 'BudgetRef', '', 'BudgetRef', 2, 3010, 0, 1, '', 0, 21277, 0, 0, '') ;

CALL ImportField(301010007, ' ', 'RejectCls', '', 'RejectCls', 2, 3010, 0, 0, '', 0, 21288, 0, 0, '') ;

CALL ImportField(301010008, '  ()', 'RejectCause', '', 'RejectCause', 2, 3010, 0, 0, '', 0, 21289, 0, 0, '') ;

CALL ImportField(301010011, '', 'Org_Name', '', 'Org_Name', 2, 3010, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(301010012, '', 'Note', '', 'Note', 2, 3010, 0, 0, '', 0, 21310, 0, 0, '') ;

CALL ImportField(301010013, ' -  (+)', 'FacialAccClsCol', '', 'FacialAccClsCol', 2, 3010, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(301010014, ' ', 'FacialAccCls', '', 'FacialAccCls', 2, 3010, 0, 0, '', 0, 21279, 0, 0, '') ;

CALL ImportField(301010016, '   ', 'DocNumber', '   ', 'DocNumber', 2, 3010, 0, 0, '', 0, 21278, 0, 0, '') ;

CALL ImportField(301010017, ' ', 'AYear', '', 'AYear', 2, 3010, 0, 0, '', 0, 21284, 0, 0, '') ;

CALL ImportField(301010018, '', 'AcceptSumma', '', 'AcceptSumma', 2, 3010, 0, 0, '', 0, 21286, 0, 0, '') ;

CALL ImportField(301010019, '  ', 'AcceptDate', '', 'AcceptDate', 2, 3010, 0, 0, '', 0, 21282, 0, 0, '') ;

CALL ImportField(301010020, '   ', 'ReworkCause', '', 'ReworkCause', 2, 3010, 0, 0, '', 0, 25041, 0, 0, '') ;

CALL ImportField(301010022, '/  ( - )', 'FacialCode', '', ' ', 2, 3010, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301010023, ' - ', 'OrgRecipient', '', ' ', 2, 3010, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301010024, ' ', 'LastAdjustment', '', 'LastAdjustment', 2, 3010, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(301010028, ' ', 'AVersion', '', 'AVersion', 2, 3010, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301010030, '', 'RealID', '', 'RealID', 2, 3010, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301010031, 'ID', 'ID', '', 'ID', 2, 3010, 0, 1, '', 0, null, 0, 0, '') ;

--   , +(2)
CALL ImportField(301110001, '', 'BudgetRef', '', 'BudgetRef', 2, 3011, 0, 1, '', 0, 21277, 0, 0, '') ;

CALL ImportField(301110002, '-  ', 'YearAcceptSumma', '', 'YearAcceptSumma', 2, 3011, 0, 0, '', 0, 21307, 0, 0, '') ;

CALL ImportField(301110003, '  ', 'TenderTarget', '', 'TenderTarget', 2, 3011, 0, 0, '', 0, 21309, 0, 0, '') ;

CALL ImportField(301110007, ' ', 'RejectCls', '', 'RejectCls', 2, 3011, 0, 0, '', 0, 21288, 0, 0, '') ;

CALL ImportField(301110008, '  ()', 'RejectCause', '', 'RejectCause', 2, 3011, 0, 0, '', 0, 21289, 0, 0, '') ;

CALL ImportField(301110009, '     ', 'PeriodYear', '', 'PeriodYear', 2, 3011, 0, 0, '', 0, 21319, 0, 0, '') ;

CALL ImportField(301110010, '   ', 'PeriodVariant', '', 'PeriodVariant', 2, 3011, 0, 0, '', 0, 21283, 0, 0, '') ;

CALL ImportField(301110011, '', 'Org_Name', '', 'Org_Name', 2, 3011, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(301110012, '', 'Note', '', 'Note', 2, 3011, 0, 0, '', 0, 21310, 0, 0, '') ;

CALL ImportField(301110013, ' -  (+)', 'FacialAccClsCol', '', 'FacialAccClsCol', 2, 3011, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(301110014, ' ', 'FacialAccCls', '', 'FacialAccCls', 2, 3011, 0, 0, '', 0, 21279, 0, 0, '') ;

CALL ImportField(301110017, ' ', 'AYear', '', 'AYear', 2, 3011, 0, 0, '', 0, 21284, 0, 0, '') ;

CALL ImportField(301110018, '', 'AcceptSumma', '', 'AcceptSumma', 2, 3011, 0, 0, '', 0, 21286, 0, 0, '') ;

CALL ImportField(301110019, '  ', 'AcceptDate', '', 'AcceptDate', 2, 3011, 0, 0, '', 0, 21282, 0, 0, '') ;

CALL ImportField(301110020, '   ', 'ReworkCause', '', 'ReworkCause', 2, 3011, 0, 0, '', 0, 25041, 0, 0, '') ;

CALL ImportField(301110022, '/  ( - )', 'FacialCode', '', ' ', 2, 3011, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301110023, ' - ', 'OrgRecipient', '', ' ', 2, 3011, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301110024, ' ', 'LastAdjustment', '', 'LastAdjustment', 2, 3011, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(301110025, '   ', 'PeriodOther', '', 'PeriodOther', 2, 3011, 0, 0, '', 0, 21283, 0, 0, '') ;

CALL ImportField(301110026, '  ', 'PurchaseCode', '  ', 'PurchaseCode', 2, 3011, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301110028, ' ', 'AVersion', '', 'AVersion', 2, 3011, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301110029, '  /', 'ParentRef', '', 'ParentRef', 2, 3011, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301110049, ' ', 'PlanCaption', '', 'PlanCaption', 2, 3011, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301110050, ' ', 'PurchaseType', '', 'PurchaseType', 2, 3011, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301111001, '', 'Note', '', 'Note', 2, 3011, 1, 0, '', 0, 21054, 0, 0, '') ;

CALL ImportField(301111002, '', 'KESR', '', 'KESR', 2, 3011, 1, 0, '', 0, 21038, 0, 0, '') ;

CALL ImportField(301111003, '', 'KCSR', '', 'KCSRKey', 2, 3011, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(301111004, '', 'FactCLSCode', '', 'FactCLS', 2, 3011, 1, 0, '', 0, 36863, 0, 0, '') ;

CALL ImportField(301111005, ' -  (+)', 'FacialAccClsCol', '', 'FacialAccClsCol', 2, 3011, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(301111006, ' ', 'FacialAccCls', '', 'FacialAccCls', 2, 3011, 1, 0, '', 0, 21033, 0, 0, '') ;

CALL ImportField(301111007, '  ', 'AcceptSumma', '', 'AcceptSumma', 2, 3011, 1, 0, '', 0, 21090, 0, 0, '') ;

CALL ImportField(301111008, 'IV ', 'AcceptQuarter4', '', 'AcceptQuarter4', 2, 3011, 1, 0, '', 0, 21088, 0, 0, '') ;

CALL ImportField(301111009, 'III ', 'AcceptQuarter3', '', 'AcceptQuarter3', 2, 3011, 1, 0, '', 0, 21086, 0, 0, '') ;

CALL ImportField(301111010, 'II ', 'AcceptQuarter2', '', 'AcceptQuarter2', 2, 3011, 1, 0, '', 0, 21084, 0, 0, '') ;

CALL ImportField(301111011, 'I ', 'AcceptQuarter1', '', 'AcceptQuarter1', 2, 3011, 1, 0, '', 0, 21082, 0, 0, '') ;

CALL ImportField(301111012, '', 'AcceptMonth12', '', 'AcceptMonth12', 2, 3011, 1, 0, '', 0, 21080, 0, 0, '') ;

CALL ImportField(301111013, '', 'AcceptMonth11', '', 'AcceptMonth11', 2, 3011, 1, 0, '', 0, 21078, 0, 0, '') ;

CALL ImportField(301111014, '', 'AcceptMonth10', '', 'AcceptMonth10', 2, 3011, 1, 0, '', 0, 21076, 0, 0, '') ;

CALL ImportField(301111015, '', 'AcceptMonth09', '', 'AcceptMonth09', 2, 3011, 1, 0, '', 0, 21074, 0, 0, '') ;

CALL ImportField(301111016, '', 'AcceptMonth08', '', 'AcceptMonth08', 2, 3011, 1, 0, '', 0, 21072, 0, 0, '') ;

CALL ImportField(301111017, '', 'AcceptMonth07', '', 'AcceptMonth07', 2, 3011, 1, 0, '', 0, 21070, 0, 0, '') ;

CALL ImportField(301111018, '', 'AcceptMonth06', '', 'AcceptMonth06', 2, 3011, 1, 0, '', 0, 21068, 0, 0, '') ;

CALL ImportField(301111019, '', 'AcceptMonth05', '', 'AcceptMonth05', 2, 3011, 1, 0, '', 0, 21066, 0, 0, '') ;

CALL ImportField(301111020, '', 'AcceptMonth04', '', 'AcceptMonth04', 2, 3011, 1, 0, '', 0, 21064, 0, 0, '') ;

CALL ImportField(301111021, '', 'AcceptMonth03', '', 'AcceptMonth03', 2, 3011, 1, 0, '', 0, 21062, 0, 0, '') ;

CALL ImportField(301111022, '', 'AcceptMonth02', '', 'AcceptMonth02', 2, 3011, 1, 0, '', 0, 21060, 0, 0, '') ;

CALL ImportField(301111023, '', 'AcceptMonth01', '', 'AcceptMonth01', 2, 3011, 1, 0, '', 0, 21058, 0, 0, '') ;

CALL ImportField(301111024, '  (+)', 'TreeOwner0', ' ', 'TreeOwner0', 2, 3011, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301111025, '', 'KVSR', '', 'KVSR', 2, 3011, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(301111026, '', 'KFSR', '', 'KFSR', 2, 3011, 1, 0, '', 0, 21034, 0, 0, '') ;

CALL ImportField(301111027, '', 'KVR', '', 'KVR', 2, 3011, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(301111028, 'MEANSTYPECls', 'MEANSTYPECls', 'MEANSTYPECls', 'MEANSTYPECls', 2, 3011, 1, 0, '', 0, 21042, 0, 0, '') ;

CALL ImportField(301111029, '', 'KCSRCode', '', 'KCSR', 2, 3011, 1, 0, '', 0, 25462, 0, 0, '') ;

CALL ImportField(301111030, '', 'KVSRCode', '', 'KVSR', 2, 3011, 1, 0, '', 0, 25472, 0, 0, '') ;

CALL ImportField(301111031, '', 'KVRCode', '', 'KVR', 2, 3011, 1, 0, '', 0, 25467, 0, 0, '') ;

CALL ImportField(301111032, '  ', 'SummaYear2', '', 'SummaYear2', 2, 3011, 1, 0, '', 0, 26652, 0, 0, '') ;

CALL ImportField(301111033, '  ', 'SummaYear3', '', 'SummaYear3', 2, 3011, 1, 0, '', 0, 26653, 0, 0, '') ;

CALL ImportField(301111034, '', 'DirectionClsCode', '', ' ', 2, 3011, 1, 0, '', 0, 36861, 0, 0, '') ;

CALL ImportField(301111035, '/  ( - )', 'FacialCode', '', ' ', 2, 3011, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301111036, '( - )', 'FacialOrgName', '', ' ', 2, 3011, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(301111037, ' . ', 'FinTypeCode', '', ' ', 2, 3011, 1, 0, '', 0, 36853, 0, 0, '') ;

CALL ImportField(301111038, ' ', 'subkesr', '', ' ', 2, 3011, 1, 0, '', 0, 21039, 0, 0, '') ;

CALL ImportField(301111039, ' ', 'SubsidyClsCode', '', ' ', 2, 3011, 1, 0, '', 0, 26641, 0, 0, '') ;

CALL ImportField(301111040, ' ', 'FinSourceCls', '', 'FinSourceCls', 2, 3011, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301111041, ' .  ()', 'FinType', '', ' ', 2, 3011, 1, 1, '', 0, 21114, 0, 0, '') ;

CALL ImportField(301111042, ' ()', 'DirectionCls', '', ' ', 2, 3011, 1, 1, '', 0, 21104, 0, 0, '') ;

CALL ImportField(301111043, '', 'InvestObject', '', ' ', 2, 3011, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301111044, '', 'InvestObjectCode', '', ' ', 2, 3011, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301111045, ' ()', 'FactCls', '', 'FactClsKey', 2, 3011, 1, 0, '', 0, 21040, 0, 0, '') ;

CALL ImportField(301111046, '  ', 'TransfertClsCode', '  ', 'TransfertClsCode', 2, 3011, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301111047, '  ', 'BudAllocationClsCode', '', 'BudAllocationClsCode', 2, 3011, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301111048, '  ', 'PayPromiseClsCode', '', 'PayPromiseClsCode', 2, 3011, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301111049, '', 'ContractCostsCls', '', ' ', 2, 3011, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301111050, '', 'ContractCostsClsCode', '', ' ', 2, 3011, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301111051, '   ', 'SummaOtherYears', '', 'SummaOtherYears', 2, 3011, 1, 0, '', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(370110012, '', 'KESR', '', 'KESR', 2, 3701, 0, 0, '', 0, null, 0, 0, '') ;

--  , (1)
CALL ImportField(440110060, ' . ', 'FinTypeCode', ' . ', 'FINTYPE', 1, 4401, 0, 1, '', 0, 36853, 0, 0, '') ;

CALL ImportField(440111026, '', 'KESR', '', 'KESR', 1, 4401, 1, 1, '', 0, 21716, 0, 0, '') ;

CALL ImportField(440111067, ' .  ()', 'FinType', ' .  ()', 'FINTYPEKey', 1, 4401, 1, 1, '', 0, 36850, 0, 0, '') ;

--  ,, (1)
CALL ImportField(440310009, ' ', 'FACIALACCCLS', ' ', 'FacialAccCls', 1, 4403, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(440311026, '', 'KESR', '', 'KESR', 1, 4403, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(440311062, ' ', 'SubKESR', ' ', ' ', 1, 4403, 1, 1, '', 0, null, 0, 0, '') ;

--    , (1)
CALL ImportField(490110003, '', 'Note', '', 'Note', 1, 4901, 0, 0, '', 0, 22485, 0, 0, '') ;

CALL ImportField(490110023, ' ', 'IsSignEnd', '', ' ', 1, 4901, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(490110024, '   ', 'SchemeID', '', ' ', 1, 4901, 0, 1, '', 0, null, 0, 0, '') ;

--  / , (1)
CALL ImportField(520111008, ' . ', 'FINTYPECode', ' . ', 'FINTYPE', 1, 5201, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(520111011, '', 'KESR', '', 'KESR', 1, 5201, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(520111061, ' . ()', 'FINTYPE', ' . ()', 'FINTYPEKey', 1, 5201, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(520111066, '()', 'KDAGCode', '()', ' ', 1, 5201, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(520111072, ' ', 'Note', '  ', 'Note', 1, 5201, 1, 0, '', 0, 38765, 0, 0, '') ;

CALL ImportField(520111073, '', 'ContractCostsClsCode', '', ' ', 1, 5201, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(520111074, '', 'ContractCostsCls', '', ' ', 1, 5201, 1, 1, '', 0, null, 0, 0, '') ;

--    , (1)
CALL ImportField(550111058, '', 'KESR', '', 'KESR', 1, 5501, 1, 0, '', 0, 22919, 0, 0, '') ;

CALL ImportField(550111061, '()', 'IFSAGCode', '()', ' ', 1, 5501, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(550111065, '()', 'KDAGCode', '()', ' ', 1, 5501, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(550111074, '', 'SubKesr', '', 'SubKESR', 1, 5501, 1, 0, '', 0, 22927, 0, 0, '') ;

CALL ImportField(550111111, '.  ', 'BudgetPromise', '.  ', 'BUDGETPROMISE', 1, 5501, 1, 1, ',', 0, 25283, 0, 0, '') ;

CALL ImportField(550111168, '', 'ContractCostsCls', '', ' ', 1, 5501, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(550111169, '', 'ContractCostsClsCode', '', ' ', 1, 5501, 1, 0, '', 0, null, 0, 0, '') ;

--    , (1)
CALL ImportField(550210150, ' ', 'BudgetPromiseAgrSumma', ' ', 'BudgetPromiseAgrSumma', 1, 5502, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(550211058, '', 'KESR', '', 'KESR', 1, 5502, 1, 0, '', 0, 22919, 0, 0, '') ;

CALL ImportField(550211061, '()', 'IFSAGCode', '()', ' ', 1, 5502, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(550211065, '()', 'KDAGCode', '()', ' ', 1, 5502, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(550211074, '', 'SubKesr', '', 'SubKESR', 1, 5502, 1, 0, '', 0, 22927, 0, 0, '') ;

CALL ImportField(550211110, '.  ', 'BudgetPromise', '.  ', 'BUDGETPROMISE', 1, 5502, 1, 1, ',', 0, 25283, 0, 0, '') ;

CALL ImportField(550211147, '', 'ContractCostsCls', '', ' ', 1, 5502, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(550211148, '', 'ContractCostsClsCode', '', ' ', 1, 5502, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(550211149, ' ', 'BudgetPromiseAgrDate', ' ', 'BudgetPromiseAgrDate', 1, 5502, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(550211150, ' ', 'BudgetPromiseAgrNum', ' ', 'BudgetPromiseAgrNum', 1, 5502, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(550211151, '  .', 'BudgetPromiseAgrRNum', '  .', 'BudgetPromiseAgrReestrNum', 1, 5502, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(550211152, ' . ', 'BudgetPromiseSODate', ' . ', 'BudgetPromiseAgrDate', 1, 5502, 1, 1, '', 0, 19799, 0, 0, '') ;

CALL ImportField(550211153, '. . ', 'BudgetPromiseSONote', '. . ', 'BudgetPromiseAgrNote', 1, 5502, 1, 1, '', 0, 19821, 0, 0, '') ;

CALL ImportField(550211154, ' . ', 'BudgetPromiseSONum', ' . ', 'BudgetPromiseAgrNum', 1, 5502, 1, 1, '', 0, 19798, 0, 0, '') ;

CALL ImportField(550211155, '  . ', 'BudgetPromiseSORNum', '  . ', 'BudgetPromiseAgrReestrNum', 1, 5502, 1, 1, '', 0, 19830, 0, 0, '') ;

CALL ImportField(550211156, ' . ', 'BudgetPromiseSOSumma', ' . ', ' ', 1, 5502, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(550211157, ' ( . -)', 'BudgetPromiseSumma', ' ', 'BudgetPromiseSumma', 1, 5502, 1, 1, '', 0, 20242, 0, 0, '') ;

--    , (1)
CALL ImportField(550311034, '()', 'IFSAGCode', '', ' ', 1, 5503, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(550311038, '()', 'KDAGCode', '', ' ', 1, 5503, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(550311064, '', 'ContractCostsCls', '', ' ', 1, 5503, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(550311065, '', 'ContractCostsClsCode', '', ' ', 1, 5503, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(550312015, '()', 'IFSAGCode', '', ' ', 1, 5503, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(550312019, '()', 'KDAGCode', '', ' ', 1, 5503, 2, 0, '', 0, null, 0, 0, '') ;

--  , (1)
CALL ImportField(960210011, ' . ', 'FINTYPE', ' . ', ' ', 1, 9602, 0, 0, '', 0, 17114, 0, 0, '') ;

--    , +(2)
CALL ImportField(970110001, '', 'ID', '', ' ', 2, 9701, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(970110002, '', 'Code', '', ' ', 2, 9701, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(970110003, '', 'Name', '', ' ', 2, 9701, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(970110004, '', 'BudgetRef', '', ' ', 2, 9701, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(970110005, '   ', 'StartDate', '', ' ', 2, 9701, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(970110006, ' ', 'DeleteDate', '', ' ', 2, 9701, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(970110007, ' ', 'CreateDate', '', ' ', 2, 9701, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(970110008, ' ', 'UpdateDate', '', ' ', 2, 9701, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(970110009, '', 'CreaterUser', '', ' ', 2, 9701, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(970110010, '', 'UpdaterUser', '', ' ', 2, 9701, 0, 1, '', 0, null, 0, 0, '') ;

--    , +(2)
CALL ImportField(970210001, '', 'ID', '', ' ', 2, 9702, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(970210002, '', 'Code', '', ' ', 2, 9702, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(970210003, '', 'Name', '', ' ', 2, 9702, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(970210004, '', 'BudgetRef', '', ' ', 2, 9702, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(970210005, '   ', 'StartDate', '', ' ', 2, 9702, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(970210006, ' ', 'DeleteDate', '', ' ', 2, 9702, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(970210007, ' ', 'CreateDate', '', ' ', 2, 9702, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(970210008, ' ', 'UpdateDate', '', ' ', 2, 9702, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(970210009, '', 'CreaterUser', '', ' ', 2, 9702, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(970210010, '', 'UpdaterUser', '', ' ', 2, 9702, 0, 1, '', 0, null, 0, 0, '') ;

-- , +(2)
CALL ImportField(980910008, '', 'KESR', '', ' ', 2, 9809, 0, 0, '', 0, 16835, 0, 0, '') ;

CALL ImportField(980910009, ' ()', 'KVSR', '', ' ', 2, 9809, 0, 0, '', 0, 16830, 0, 0, '') ;

CALL ImportField(980910010, ' ', 'MAINDESCRIPTIONCODE', '', ' ', 2, 9809, 0, 0, '', 0, 16832, 0, 0, '') ;

CALL ImportField(980910017, '', 'KVSRCODE', '', ' ', 2, 9809, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(980910019, '', 'KD_LEVEL', '', ' ', 2, 9809, 0, 0, '', 0, 24895, 0, 0, '') ;

CALL ImportField(980910025, ' ()', 'ANALYTICALGROUPKD', '', ' ', 2, 9809, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(980910026, '', 'ANALYTICALGROUPKDCODE', '', ' ', 2, 9809, 0, 1, '', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(984110016, ' . ', 'FINTYPE', ' . ', ' ', 2, 9841, 0, 0, '', 0, 17141, 0, 0, '') ;

CALL ImportField(984110023, '', 'KESR', '', ' ', 2, 9841, 0, 0, '', 0, 17140, 0, 0, '') ;

--    , (1)
CALL ImportField(985210018, '', 'KVSRCODE', '', ' ', 1, 9852, 0, 0, '', 0, null, 0, 0, '') ;

--    , +(2)
CALL ImportField(985210010, '', 'KESR', '', ' ', 2, 9852, 0, 0, '', 0, 17054, 0, 0, '') ;

CALL ImportField(985210011, ' ()', 'KVSR', '', ' ', 2, 9852, 0, 0, '', 0, 17049, 0, 0, '') ;

CALL ImportField(985210025, ' ()', 'ANALYTICALGROUPIFS', '', ' ', 2, 9852, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(985210026, '', 'ANALYTICALGROUPIFSCODE', '', ' ', 2, 9852, 0, 1, '', 0, null, 0, 0, '') ;

--  , (1)
CALL ImportField(986110012, '', 'KESR', '', ' ', 1, 9861, 0, 0, '', 0, 20702, 0, 0, '') ;

--  , +(2)
CALL ImportField(986510003, ' ', 'ECCLS', '', ' ', 2, 9865, 0, 0, '', 0, 21630, 0, 0, '') ;

-- , +(2)
CALL ImportField(987110012, ' ', 'BUHOPERATIONCLS', '', ' ', 2, 9871, 0, 0, '', 0, 21635, 0, 0, '') ;

CALL ImportField(987110021, '', 'ID', '', ' ', 2, 9871, 0, 0, '', 0, null, 0, 0, '') ;

--   , +(2)
CALL ImportField(988410021, '', 'TRANSFERKESR', '', ' ', 2, 9884, 0, 0, '', 0, 25339, 0, 0, '') ;

-- , (1)
CALL ImportField(989710005, '', 'CREATERUSER', '', ' ', 1, 9897, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(989710007, '', 'UPDATERUSER', '', ' ', 1, 9897, 0, 1, '', 0, null, 0, 0, '') ;

-- , +(2)
CALL ImportField(989710001, '', 'ID', '', ' ', 2, 9897, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(989710002, '', 'CODE', '', ' ', 2, 9897, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(989710003, '', 'NAME', '', ' ', 2, 9897, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(989710004, ' ', 'CREATEDATE', '', ' ', 2, 9897, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(989710006, ' ', 'UPDATEDATE', '', ' ', 2, 9897, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(989710008, ' ', 'STARTDATE', '', ' ', 2, 9897, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(989710009, ' ', 'DELETEDATE', '', ' ', 2, 9897, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(989710010, ' ', 'PurchaseType ', '', ' ', 2, 9897, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(989710011, '', 'Note', '', ' ', 2, 9897, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(989710012, '', 'BudgetRef', '', ' ', 2, 9897, 0, 0, '', 0, null, 0, 0, '') ;

--  , (1)
CALL ImportField(990310098, '   (  )', 'RecordOwnerOrgRef', '', ' ', 1, 9903, 0, 0, '', 0, 39263, 0, 0, '') ;

CALL ImportField(990310099, '   ()', 'RecordOwnerOrgINN', '', ' ', 1, 9903, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(990310100, '   ()', 'RecordOwnerOrgKPP', '', ' ', 1, 9903, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(990310101, '   ()', 'RecordOwnerOrgName', '', ' ', 1, 9903, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(990311029, ' .  ()', 'FinType', ' .  ()', 'FINTYPEKey', 1, 9903, 1, 0, '', 0, 17114, 0, 0, '') ;

CALL ImportField(990311098, ' . ', 'FinTypeCode', ' . ', 'FINTYPE', 1, 9903, 1, 0, '', 0, 36853, 0, 0, '') ;

CALL ImportField(990311102, '', 'ID', '', ' ', 1, 9903, 1, 0, '', 0, 17109, 0, 0, '') ;

CALL ImportField(990312046, '', 'KESR', '', ' ', 1, 9903, 2, 0, '', 0, 17140, 0, 0, '') ;

CALL ImportField(990312047, ' .  ()', 'FINTYPE', ' .  ()', 'FINTYPEKey', 1, 9903, 2, 0, '', 0, 17141, 0, 0, '') ;

CALL ImportField(990312101, ' . ', 'FinTypeCode', ' . ', 'FINTYPE', 1, 9903, 2, 0, '', 0, 36853, 0, 0, '') ;

--  , +(2)
CALL ImportField(990310102, ' ', 'BlockedDate', '', ' ', 2, 9903, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(990310103, ' ', 'BlockedCause', '', ' ', 2, 9903, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(990310104, ' ', 'UnBlockedDate', '', ' ', 2, 9903, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(990310105, ' ', 'UnBlockedCause', '', ' ', 2, 9903, 0, 0, '', 0, null, 0, 0, '') ;

--   , +(2)
CALL ImportField(990410001, '  ', 'FacialAccCls', '    ', 'FacialAccCls', 2, 9904, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(990410002, '', 'OrgINN', ' ', 'OrgINN', 2, 9904, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(990410003, '', 'OrgKPP', ' ', 'OrgKPP', 2, 9904, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(990410004, '', 'OrgName', ' ', 'OrgName', 2, 9904, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(990410005, '', 'Name', '', 'Name', 2, 9904, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(990410006, '', 'HoldRank', '', 'HoldRank', 2, 9904, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(990410007, ' ', 'PhoneNo', '', 'PhoneNo', 2, 9904, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(990410008, ' ', 'EMail', '   ', 'EMail', 2, 9904, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(990410009, '', 'Note', '', 'Note', 2, 9904, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(990410010, ' ', 'RejectCls', '', 'RejectCls', 2, 9904, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(990410011, ' ', 'RejectCause', '', 'RejectCause', 2, 9904, 0, 0, '', 0, null, 0, 0, '') ;

--  , (1)
CALL ImportField(991210007, ' \', 'isForBusiness', ' \', ' ', 1, 9912, 0, 0, '', 0, 17280, 0, 0, '') ;

--   , (1)
CALL ImportField(991411002, ' ', 'DataSectionType', ' ', ' ', 1, 9914, 1, 0, '', 0, null, 0, 0, '') ;

--   , (1)
CALL ImportField(991510005, '  ', 'DayKind', '  ', 'DayKind', 1, 9915, 0, 0, '', 0, 38954, 0, 0, '') ;

--  , (1)
CALL ImportField(991610065, ' \ , , \    \ ', '___', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0, '') ;

CALL InsertConst(32, 25, 3, ' \ , , \    \ ', '', 0, 0, 9916) ;

CALL ImportField(991610176, ' \  \ \', '___', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0, '') ;

CALL InsertConst(33, 316, 8, ' \  \ \', '', 0, 0, 9916) ;

CALL ImportField(991610177, ' \  \ \/', '___', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0, '') ;

CALL InsertConst(34, 316, 8, ' \  \ \/', '', 0, 0, 9916) ;

CALL ImportField(991610193, '    , \,       , ', '_', '', ' ', 1, 9916, 0, 1, '', 0, null, 0, 0, '') ;

CALL InsertConst(30, 45, 8, '    , \,       , ', '400-499,610-629', 0, 0, null) ;

CALL ImportField(991610202, ' \   ', '_', '', ' ', 1, 9916, 0, 1, '', 0, null, 0, 0, '') ;

CALL InsertConst(60, 9, 3, ' \   ', '', 0, 0, null) ;

CALL ImportField(991610203, ' \   ', '_', '', ' ', 1, 9916, 0, 1, '', 0, null, 0, 0, '') ;

CALL InsertConst(60, 10, 3, ' \   ', '', 0, 0, null) ;

CALL ImportField(991610211, ' \ , , \     ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0, '') ;

CALL InsertConst(32, 46, 3, ' \ , , \     ', '', 0, 0, 9916) ;

CALL ImportField(991610212, ' \ , , \    \() ', '___', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0, '') ;

CALL InsertConst(32, 45, 3, ' \ , , \    \() ', '', 0, 0, 9916) ;

CALL ImportField(991610218, '  \      ()', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0, '') ;

CALL InsertConst(-1, 82, 3, '  \      ()', '', 0, 0, 9916) ;

CALL ImportField(991610219, '  \      ( )', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0, '') ;

CALL InsertConst(527, 12, 8, '  \      ( )', '', 0, 0, 9916) ;

CALL ImportField(991610220, ' \ , , \ \\  , ', '____', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0, '') ;

CALL InsertConst(33, 276, 8, ' \ , , \ \\  , ', '', 0, 0, 9916) ;

CALL ImportField(991610221, '\ \     ', '__', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0, '') ;

CALL InsertConst(6, 3, 3, '\ \     ', '', 0, 0, 9916) ;

CALL ImportField(991610222, ' \ \ \', '___', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0, '') ;

CALL InsertConst(33, 556, 8, ' \ \ \', '', 0, 0, 9916) ;

CALL ImportField(991610223, ' \ \ \/', '___', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0, '') ;

CALL InsertConst(34, 556, 8, ' \ \ \/', '', 0, 0, 9916) ;

CALL ImportField(991610224, '\  ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null, 0, 0, '') ;

CALL InsertConst(-1, 19, 3, '\  ', '', 0, 1, 9916) ;

--   , (1)
CALL ImportField(992111006, ' .  ()', 'FINTYPE', ' .  ()', ' ', 1, 9921, 1, 0, '', 0, 17141, 0, 0, '') ;

CALL ImportField(992111021, '', 'KESR', '', ' ', 1, 9921, 1, 0, '', 0, 17140, 0, 0, '') ;

--   , (1)
CALL ImportField(992512001, '', 'KESR', '', ' ', 1, 9925, 2, 0, '', 0, 22627, 0, 0, '') ;

--    , (1)
CALL ImportField(992810004, ' ', 'CorrBel', '', ' ', 1, 9928, 0, 0, '', 0, null, 0, 0, '') ;

--     , (1)
CALL ImportField(992910006, '', 'KESR', '', ' ', 1, 9929, 0, 0, '', 0, null, 0, 0, '') ;

--    , +(2)
CALL ImportField(993010001, ' ', 'ID', '', ' ', 2, 9930, 0, 1, '', 0, 39171, 0, 0, '') ;

CALL ImportField(993010002, '', 'Name', '', ' ', 2, 9930, 0, 0, '', 0, 39177, 0, 0, '') ;

CALL ImportField(993010003, ' ', 'Code', '', ' ', 2, 9930, 0, 0, '', 0, 39172, 0, 0, '') ;

CALL ImportField(993010004, '', 'VisibleCode', '', ' ', 2, 9930, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(993010005, ' ', 'CreateDate', '', ' ', 2, 9930, 0, 0, '', 0, 39173, 0, 0, '') ;

CALL ImportField(993010006, ' ', 'UpdateDate', '', ' ', 2, 9930, 0, 1, '', 0, 39174, 0, 0, '') ;

CALL ImportField(993010007, '', 'CreaterUser', '', ' ', 2, 9930, 0, 1, '', 0, 39175, 0, 0, '') ;

CALL ImportField(993010008, ' ', 'UpdaterUer', '', ' ', 2, 9930, 0, 1, '', 0, 39176, 0, 0, '') ;

CALL ImportField(993010009, '', 'KFSR', '', ' ', 2, 9930, 0, 0, '', 0, 39181, 0, 0, '') ;

CALL ImportField(993010010, '', 'KCSR', '', ' ', 2, 9930, 0, 0, '', 0, 39182, 0, 0, '') ;

CALL ImportField(993010011, '', 'KVSR', '', ' ', 2, 9930, 0, 0, '', 0, 39183, 0, 0, '') ;

CALL ImportField(993010012, '', 'KVR', '', ' ', 2, 9930, 0, 0, '', 0, 39184, 0, 0, '') ;

CALL ImportField(993010013, '', 'KESR', '', ' ', 2, 9930, 0, 0, '', 0, 39185, 0, 0, '') ;

CALL ImportField(993010014, ' ', 'KD', '', ' ', 2, 9930, 0, 0, '', 0, 39186, 0, 0, '') ;

CALL ImportField(993010015, '   ', 'IFS', '', ' ', 2, 9930, 0, 0, '', 0, 39187, 0, 0, '') ;

CALL ImportField(993010016, '  ', 'TAXNOTE', '', ' ', 2, 9930, 0, 0, '', 0, 39188, 0, 0, '') ;

CALL ImportField(993010017, ' ', 'Autosanction', '', ' ', 2, 9930, 0, 0, '', 0, 39189, 0, 0, '') ;

CALL ImportField(993010018, ' ', 'ACC', '', ' ', 2, 9930, 0, 0, '', 0, 39190, 0, 0, '') ;

CALL ImportField(993010019, '', 'NOTE', '', ' ', 2, 9930, 0, 0, '', 0, 39191, 0, 0, '') ;

CALL ImportField(993010020, ' ', 'CLSTYPE', '', ' ', 2, 9930, 0, 0, '', 0, 39192, 0, 0, '') ;

CALL ImportField(993010021, '', 'BUDGETREF', '', ' ', 2, 9930, 0, 0, '', 0, 39178, 0, 0, '') ;

CALL ImportField(993010022, ' ', 'DOCTYPE', '', ' ', 2, 9930, 0, 1, '', 0, 39193, 0, 0, '') ;

CALL ImportField(993010023, '   ', 'STARTDATE', '', ' ', 2, 9930, 0, 0, '', 0, 39180, 0, 0, '') ;

CALL ImportField(993010024, ' ', 'DELETEDATE', '', ' ', 2, 9930, 0, 0, '', 0, 39179, 0, 0, '') ;

CALL ImportField(993010025, '  ', 'Promise', '', ' ', 2, 9930, 0, 0, '', 0, 39228, 0, 0, '') ;

--    , (1)
CALL ImportField(993110001, '', 'ID', '', ' ', 1, 9931, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(993110002, '', 'KFSR', '', ' ', 1, 9931, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(993110003, '', 'KVR', '', ' ', 1, 9931, 0, 0, '', 0, null, 0, 0, '') ;

--       
ALTER TRIGGER TR_INTCONST_BU_500 ENABLE
/

ALTER TRIGGER TR_VARCHARCONST_BU_500 ENABLE
/

ALTER TRIGGER TR_REALCONST_BU_500 ENABLE
/

DROP PROCEDURE ImportField
/

/*      */
ALTER TRIGGER TR_DOCUMENTFIELDS_BU_500 DISABLE
/

Update TB_DocumentFields df
set documentcls=doctyperef*100+detailnumber
where (detailnumber<100)and(documentcls is null)
 and(exists(select dc.id from documentcls dc where id=df.doctyperef*100+df.detailnumber))
/

ALTER TRIGGER TR_DOCUMENTFIELDS_BU_500 ENABLE
/

DROP PROCEDURE DeleteFields
/

DROP PROCEDURE InsertConst
/

DROP PROCEDURE DELETECONST
/




CREATE OR REPLACE PROCEDURE DOCLOCK_IMPORT(
  NAME_              VARCHAR2,
  LOCKMASK_          NUMBER,
  DOCREF_            NUMBER,
  DETAILNUM_         NUMBER,
  RUNPOS_            NUMBER,
  LOCKACTION_        NUMBER,
  USERIGHTS_        NUMBER,
  FORMULA_           VARCHAR2,
  FORDELETE_         NUMBER,
  ISSYSTEM_          NUMBER,
  NOTE_              VARCHAR2,
  FORINSERT_         NUMBER,
  VALIDATEMESSAGE_ VARCHAR2,
  VALIDATELEVEL_   NUMBER,
  VALIDATEFILTER_  VARCHAR2,
  ISBUDGET_ NUMBER)
IS
  DOCLOCKID$ Number(10);
BEGIN
   BEGIN
     SELECT ID
     INTO DOCLOCKID$
     FROM DOCLOCK
     WHERE (DOCREF = DOCREF_) AND(DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
   EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DOCLOCKID$ := NULL;  
   END;
   
   IF (DOCLOCKID$ is not null) THEN
     IF (ISSYSTEM_ = 3) THEN
       UPDATE DOCLOCK SET
         NAME = NAME_,
         LOCKMASK = LOCKMASK_,
         DOCREF = DOCREF_,
         DETAILNUM = DETAILNUM_,
         RUNPOS = RUNPOS_,
         LOCKACTION = LOCKACTION_,
         FORMULA = FORMULA_,
         FORDELETE = FORDELETE_,
         ISSYSTEM = ISSYSTEM_,
         NOTE = NOTE_,
         FORINSERT = FORINSERT_,
         VALIDATEMESSAGE = VALIDATEMESSAGE_,
         VALIDATELEVEL = VALIDATELEVEL_,
         VALIDATEFILTER = VALIDATEFILTER_,
         ISBUDGET = ISBUDGET_,
         USERIGHTS = USERIGHTS_
       WHERE ID = DOCLOCKID$;  
     ELSE
       UPDATE DOCLOCK SET
         NAME = NAME_,
         LOCKMASK = LOCKMASK_,
         DOCREF = DOCREF_,
         DETAILNUM = DETAILNUM_,
         RUNPOS = RUNPOS_,
         LOCKACTION = LOCKACTION_,
         FORMULA = FORMULA_,
         FORDELETE = FORDELETE_,
         ISSYSTEM = ISSYSTEM_,
         NOTE = NOTE_,
         FORINSERT = FORINSERT_,
         VALIDATEMESSAGE = VALIDATEMESSAGE_,
         VALIDATELEVEL = VALIDATELEVEL_,
         VALIDATEFILTER = VALIDATEFILTER_,
         ISBUDGET = ISBUDGET_
       WHERE ID = DOCLOCKID$;    
     END IF;  
   ELSE
     INSERT INTO DOCLOCK
       (ISBUDGET,NAME,LOCKMASK,DOCREF,DETAILNUM,RUNPOS,LOCKACTION,USERIGHTS,FORMULA,FORDELETE,ISSYSTEM,NOTE,FORINSERT,VALIDATEMESSAGE,VALIDATELEVEL,VALIDATEFILTER)
     VALUES
       (ISBUDGET_,NAME_,LOCKMASK_,DOCREF_,DETAILNUM_,RUNPOS_,LOCKACTION_,USERIGHTS_,FORMULA_,FORDELETE_,ISSYSTEM_,NOTE_,FORINSERT_,VALIDATEMESSAGE_,VALIDATELEVEL_,VALIDATEFILTER_);
   END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCKFIELDS_INSERTFIELD(
  NAME_      VARCHAR2,
  DOCREF_    NUMBER,
  DETAILNUM_ NUMBER,
  FIELDREF_  NUMBER,
  ISBUDGET_ NUMBER)
IS
  NID$ NUMBER(10);
  cnt$ number(10);
BEGIN
  BEGIN
    SELECT ID
    INTO NID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      NID$ := NULL;  
  END;

  IF (NID$ is not null) THEN
    CNT$ := 0;
    SELECT count(ID)
    into cnt$
    FROM DOCLOCKFIELDS
    WHERE (DOCLOCKREF = NID$) AND (FIELDREF = FIELDREF_) ;
    
    IF (cnt$ = 0) THEN
      INSERT INTO DOCLOCKFIELDS
        (DOCLOCKREF,FIELDREF,ISSYSTEM)
      VALUES
        (NID$,FIELDREF_,1);
    ELSE
      UPDATE DOCLOCKFIELDS SET
        ISSYSTEM = 1
      WHERE (DOCLOCKREF = NID$) AND (FIELDREF = FIELDREF_) ;
    END IF;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCK_DELETE(NAME_ VARCHAR2, DOCREF_ NUMBER, DETAILNUM_ NUMBER, ISBUDGET_ NUMBER) IS
   DOCLOCKID$ NUMBER(10);
BEGIN
  BEGIN
    SELECT ID
    INTO DOCLOCKID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      DOCLOCKID$ := NULL;
  END;

  IF (DOCLOCKID$ is not null) THEN
    DELETE FROM DOCLOCK
    WHERE ID = DOCLOCKID$;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCKFIELDS_DELETE(NAME_ VARCHAR2, DOCREF_ NUMBER, DETAILNUM_ NUMBER, CANCHANGEFIELDS_ NUMBER, ISBUDGET_ NUMBER) IS
   DOCLOCKID$ NUMBER(10);
BEGIN
  BEGIN
    SELECT ID
    INTO DOCLOCKID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION  
    WHEN NO_DATA_FOUND THEN
      DOCLOCKID$ := NULL;
  END;  

  IF (DOCLOCKID$ is not null) THEN
    DELETE FROM DOCLOCKFIELDS
    WHERE (DOCLOCKREF = DOCLOCKID$) AND ((ISSYSTEM = 1) OR ((ISSYSTEM = 0) AND (CANCHANGEFIELDS_ = 0) ));
  END IF;
END;
/

-- 
CALL DOCLOCK_DELETE('   ',304, 0, 1) ;

CALL DOCLOCK_DELETE('   ',1601, 1, 2) ;

CALL DOCLOCK_DELETE('     ,',1601, 1, 2) ;

CALL DOCLOCK_DELETE('      ',1601, 1, 1) ;

CALL DOCLOCK_DELETE('      ',1816, 0, 1) ;

CALL DOCLOCK_DELETE('     ',1816, 0, 1) ;

CALL DOCLOCK_DELETE('   ',1816, 0, 1) ;

CALL DOCLOCK_DELETE('     , ',1816, 0, 1) ;

CALL DOCLOCK_DELETE('   ',1816, 0, 1) ;

CALL DOCLOCK_DELETE('     , ',1816, 0, 1) ;

CALL DOCLOCK_DELETE('     ,  ',1816, 0, 1) ;

CALL DOCLOCK_DELETE('  ',2502, 0, 1) ;

CALL DOCLOCK_DELETE('  ',2502, 0, 1) ;

CALL DOCLOCK_DELETE('   ',2502, 0, 1) ;

CALL DOCLOCK_DELETE('  ',2502, 0, 2) ;

CALL DOCLOCK_DELETE('  ',2502, 0, 2) ;

CALL DOCLOCK_DELETE('  ',2502, 1, 1) ;

CALL DOCLOCK_DELETE('  ',2502, 1, 2) ;

CALL DOCLOCK_DELETE('   ',2502, 3, 1) ;

CALL DOCLOCK_DELETE('     ,',2502, 3, 1) ;

CALL DOCLOCK_DELETE('   ',2503, 2, 1) ;

CALL DOCLOCK_DELETE('     ,',2503, 2, 1) ;

CALL DOCLOCK_DELETE('123',2503, 2, 1) ;

CALL DOCLOCK_DELETE('  ',2504, 0, 1) ;

CALL DOCLOCK_DELETE('  ',2504, 0, 1) ;

CALL DOCLOCK_DELETE('   ',2504, 0, 1) ;

CALL DOCLOCK_DELETE('    ',2504, 4, 2) ;

CALL DOCLOCK_DELETE(' ',3011, 0, 1) ;

CALL DOCLOCK_DELETE('1',3011, 0, 1) ;

CALL DOCLOCK_DELETE('   ',4901, 0, 1) ;

CALL DOCLOCK_DELETE('     ',5201, 0, 1) ;

CALL DOCLOCK_DELETE('    ',9912, 0, 1) ;

CALL DOCLOCK_IMPORT('   ',0,200,1,0,11,0,'',0,1,'    ,      - \.',0,'        ',null,'(([960110035] between 010800 and 011099)
([960110021]=("_.",.[20011008])))',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 200, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',200,1,20011028,1) ;

CALL DOCLOCK_IMPORT('      ',0,200,1,0,11,0,'[20011012] = 0',0,1,'         , , , .    ,         ,      ',0,'       ',null,'(([988410025] = 0)  (.[20011018] = 0)  (.[20011024] = [988410026]))

(([988410022] = 0)  (.[20011020] = 0)  (.[20011020] = [988410022]))

(([988410023] = 0)  (.[20011019] = 0)  (.[20011023] = [988410024]))

(([988410018] = 0)  (.[20011022] = 0)  (.[20011025] = [988410019]))',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 200, 1, 0, 1) ;

--  "   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('      ',200,1,20011011,1) ;

CALL DOCLOCK_IMPORT('     ',0,200,1,0,11,0,'[20011012] = 2',0,3,'          .      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       .',0,'      ',null,'([988410006] = 0)  (.[20011017] = 0)  ([988410008] = .[20011026]) 
   ((("..",[988410006])=0)
   ((".",[988410006])=(".",.[20011017]))
   (((".",[988410006])=(".",.[20011017]))
     ((".",[988410006])=0))
   (("..",[988410006])=("..",.[20011017]))) 
(((".", .[20011017]) div 100000) between 218 and 219)  
(((".", .[20011017]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 200, 1, 0, 1) ;

--  "   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ',200,1,20011011,1) ;

CALL DOCLOCK_IMPORT('    ',0,200,1,0,11,0,'',0,3,'     ',0,'      ',null,'((.[20011012] = 0)  ([986810009] = 1)) 
((.[20011012] = 1)  ([986810008] = 1)) 
((.[20011012] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 200, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',200,1,20011021,1) ;

CALL DOCLOCK_IMPORT('   (2)',32768,201,1,0,3,0,'((([20111089] is not null)   (([20111085],(30,45,8),"9.9.9")))    ([20111085] between 500 and 599)     (([20111082] is not null)  (tonumber([020111083],1) <> 0))   )',0,1,'  " "  ,     .     ,            ( ),      , .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   (2)', 201, 1, 0, 1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',201,1,20111182,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',201,1,20111181,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',201,1,20111180,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',201,1,20111096,1) ;

CALL DOCLOCK_IMPORT('',0,201,1,0,15,1,'',0,1,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('', 201, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('',201,1,20111197,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('',201,1,20111196,1) ;

CALL DOCLOCK_IMPORT('',0,201,1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('', 201, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('',201,1,20111197,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('',201,1,20111196,1) ;

CALL DOCLOCK_IMPORT('',0,202,1,0,15,1,'',0,1,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('', 202, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('',202,1,20211114,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('',202,1,20211113,1) ;

CALL DOCLOCK_IMPORT('    ',0,202,1,0,11,0,'([20211096]=0) ((32,45,3) between 0 and 2)',0,3,'         ,    "() "',0,'    .      ,    "() "',null,'(((32,45,3) = 0)   ([980410006] like "?00") 
   (([980410006] like "??0")  (".KVR[CODE].{COUNTNOTNULL(CODE)}",
  (''CODE like "''+ [980410006] div 1 +''_"''))>1))
 (((32,45,3) = 1)  ([980410006] like "??0")   ([980410006] like "?00")) 
 (((32,45,3) = 2)  ([980410006] like "?00")  ([980410006] <> "000"))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 202, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',202,1,20211021,1) ;

CALL DOCLOCK_IMPORT('',0,202,1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('', 202, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('',202,1,20211114,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('',202,1,20211113,1) ;

CALL DOCLOCK_IMPORT('     ',32768,204,-1,0,3,0,'((32, 43, 3) = 0)  ((32, 43, 3) = 2)',0,3,'     ,   ,     ',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 204, -1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',204,-1,20411059,1) ;

CALL DOCLOCK_IMPORT('',0,204,1,0,15,1,'',0,1,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('', 204, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('',204,1,20411123,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('',204,1,20411122,1) ;

CALL DOCLOCK_IMPORT('',0,204,1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('', 204, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('',204,1,20411123,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('',204,1,20411122,1) ;

CALL DOCLOCK_IMPORT('',0,205,1,0,15,1,'',0,1,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('', 205, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('',205,1,20511110,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('',205,1,20511109,1) ;

CALL DOCLOCK_IMPORT('',0,205,1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('', 205, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('',205,1,20511110,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('',205,1,20511109,1) ;

CALL DOCLOCK_IMPORT('   (2)',32768,206,1,0,3,0,'((([20611096] is not null)  (([20611092],(30,45,8),"9.9.9")))      ([20611092] between 500 and 599)    (([20611089] is not null)  (tonumber([20611090],1) <> 0))   )',0,1,'  " "  ,     .     ,            ( ),      , .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   (2)', 206, 1, 0, 1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',206,1,20611182,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',206,1,20611181,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',206,1,20611180,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',206,1,20611103,1) ;

CALL DOCLOCK_IMPORT('   (2)',32768,208,1,0,3,0,'((([20811170] is not null)  (([20811167],(30,45,8),"9.9.9")))    ([20811167] between 500 and 599)    (([20811163] is not null)  (tonumber([20811164],1) <> 0))   )',0,1,'  " "  ,     .     ,            ( ),      , .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   (2)', 208, 1, 0, 1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',208,1,20811182,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',208,1,20811181,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',208,1,20811180,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',208,1,20811179,1) ;

CALL DOCLOCK_IMPORT('      ',0,209,2,0,11,0,'[20912032] = 0',0,1,'         , , , .    ,         ,      ',0,'       ',null,'(([988410025] = 0)  (.[20912039] = 0)  (.[20912020] = [988410026]))

(([988410022] = 0)  (.[20912018] = 0)  (.[20912018] = [988410022]))

(([988410023] = 0)  (.[20912038] = 0)  (.[20912019] = [988410024]))

(([988410018] = 0)  (.[20912037] = 0)  (.[20912016] = [988410019]))',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 209, 2, 0, 1) ;

--  "   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('      ',209,2,20912035,1) ;

CALL DOCLOCK_IMPORT('    ',0,209,2,0,11,0,'',0,3,'     ',0,'      ',null,'((.[20011012] = 0)  ([986810009] = 1)) 
((.[20011012] = 1)  ([986810008] = 1)) 
((.[20011012] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 209, 2, 0, 1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD('    ',209,2,20912017,1) ;

CALL DOCLOCK_IMPORT('',0,210,1,0,15,1,'',0,1,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('', 210, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('',210,1,21011048,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('',210,1,21011047,1) ;

CALL DOCLOCK_IMPORT('',0,210,1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('', 210, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('',210,1,21011048,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('',210,1,21011047,1) ;

CALL DOCLOCK_IMPORT('    ',0,210,2,0,11,0,'',0,3,'     ',0,'      ',null,'((.[20011012] = 0)  ([986810009] = 1)) 
((.[20011012] = 1)  ([986810008] = 1)) 
((.[20011012] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 210, 2, 0, 1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD('    ',210,2,21012015,1) ;

CALL DOCLOCK_IMPORT('      ',0,210,2,0,11,0,'[21010005] = 0',0,1,'         , , , .    ,         ,      ',0,'       ',null,'(([988410025] = 0)  (.[21012020] = 0)  (.[21012021] = [988410026]))

(([988410022] = 0)  (.[21012017] = 0)  (.[21012017] = [988410022]))

(([988410023] = 0)  (.[21012018] = 0)  (.[21012019] = [988410024]))

(([988410018] = 0)  (.[21012013] = 0)  (.[21012014] = [988410019]))',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 210, 2, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('      ',210,2,21012045,1) ;

CALL DOCLOCK_IMPORT('    ',0,211,2,0,11,0,'',0,3,'     ',0,'      ',null,'((.[20011012] = 0)  ([986810009] = 1)) 
((.[20011012] = 1)  ([986810008] = 1)) 
((.[20011012] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 211, 2, 0, 1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD('    ',211,2,21112016,1) ;

CALL DOCLOCK_IMPORT('      ',0,211,2,0,11,0,'[21112003] = 0',0,1,'         , , , .    ,         ,      ',0,'       ',null,'(([988410025] = 0)  (.[21112031] = 0)  (.[21112019] = [988410026]))

(([988410022] = 0)  (.[21112017] = 0)  (.[21112017] = [988410022]))

(([988410023] = 0)  (.[21112030] = 0)  (.[21112018] = [988410024]))

(([988410018] = 0)  (.[21112032] = 0)  (.[21112015] = [988410019]))',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 211, 2, 0, 1) ;

--  "   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('      ',211,2,21112028,1) ;

CALL DOCLOCK_IMPORT('    ',0,212,2,0,11,0,'',0,3,'     ',0,'      ',null,'((.[20011012] = 0)  ([986810009] = 1)) 
((.[20011012] = 1)  ([986810008] = 1)) 
((.[20011012] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 212, 2, 0, 1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD('    ',212,2,21212016,1) ;

CALL DOCLOCK_IMPORT('     (3)',0,300,0,0,11,0,'(("/._",[30010021]) = 1)   (("/.",[30010021]) = 0)   (("/._",[30010021]) = 0)  (("/.",[30010021]) = 0)  (("/.",[30010021])=0)',0,1,'         /,   /c,      ()     ',0,'         ()  ',null,'((".",[984110031]) between 011000 and 011099) 
((".",[984110031]) between 010100 and 010199)',1) ;

CALL DOCLOCKFIELDS_DELETE('     (3)', 300, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     (3)',300,0,30010008,1) ;

CALL DOCLOCK_IMPORT('     ,',0,300,1,0,11,0,'',0,1,'  ,      ,  =0 (    )        "",   -   ""',0,'       ""          ""  ',null,'(((.[30011019]=2)  
((.[30011019]=1)  (("_.",.[30011041])=0)))  
 ([988410016] = 0))

((.[30011019]=0)  ([988410016] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('     ,', 300, 1, 0, 1) ;

--  "   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ,',300,1,30011018,1) ;

CALL DOCLOCK_IMPORT('      ',0,300,1,0,11,0,'[30011019] = 0',0,1,'         , , , .    ,         ,      ',0,'       ',null,'(([988410025] = 0)  (.[30011026] = 0)  (.[30011033] = [988410026]))

(([988410022] = 0)  (.[30011029] = 0)  (.[30011029] = [988410022]))

(([988410023] = 0)  (.[30011028] = 0)  (.[30011032] = [988410024]))

(([988410018] = 0)  (.[30011027] = 0)  (.[30011031] = [988410019]))',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 300, 1, 0, 1) ;

--  "   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('      ',300,1,30011018,1) ;

CALL DOCLOCK_IMPORT('     ',0,300,1,0,11,0,'([30011019] = 2)   ((( <> 305)  ( <> 302))    (("_..",[30010008]) between 010800 and 011099))',0,3,'          ,    / , ()         /.      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       .',0,'      ',null,'([988410006] = 0)  (.[30011025] = 0)  (.[30011034] = [988410008])
 ((("..",[988410006])=0)
   ((".",[988410006])=(".",.[30011025]))
   (((".",[988410006])=(".",.[30011025]))
     ((".",[988410006])=0))
   (("..",[988410006])=("..",.[30011025])))
 (((".", .[30011025]) div 100000) between 218 and 219) 
 (((".", .[30011025]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 300, 1, 0, 1) ;

--  "   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ',300,1,30011018,1) ;

CALL DOCLOCK_IMPORT('    ',0,300,1,0,11,0,'',0,3,'     ',0,'      ',null,'((.[30011019] = 0)  ([986810009] = 1)) 
((.[30011019] = 1)  ([986810008] = 1)) 
((.[30011019] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 300, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',300,1,30011030,1) ;

CALL DOCLOCK_IMPORT('  ',32768,300,1,0,3,0,'([30011019] = 1) (("_..",[30011041])=0)',0,1,'  "  "   ',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 300, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',300,1,30011020,1) ;

CALL DOCLOCK_IMPORT('    .  ',0,301,1,0,11,0,'[30110110] = 2',0,3,'          .      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       .',0,'      ',null,'([988410006] = 0)  (.[30111122] = 0)  (.[30111130] = [988410008])
 ((("..",[988410006])=0)
   ((".",[988410006])=(".",.[30111122]))
   (((".",[988410006])=(".",.[30111122]))
     ((".",[988410006])=0))
   (("..",[988410006])=("..",.[30111122])))
 (((".", .[30111122]) div 100000) between 218 and 219)
 (((".", .[30111122]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('    .  ', 301, 1, 0, 1) ;

--  "   ."
CALL DOCLOCKFIELDS_INSERTFIELD('    .  ',301,1,30111136,1) ;

CALL DOCLOCK_IMPORT('    .   ',0,301,1,0,11,0,'[30111051] = 0',0,1,'         , , , .    ,         ,      ',0,'        ',null,'(([988410025] = 0)  (.[30111020] = 0)  (.[30111143] = [988410026]))

(([988410022] = 0)  (.[30111018] = 0)  (.[30111018] = [988410022]))

(([988410023] = 0)  (.[30111016] = 0)  (.[30111142] = [988410024]))

(([988410018] = 0)  (.[30111019] = 0)  (.[30111140] = [988410019]))',1) ;

CALL DOCLOCKFIELDS_DELETE('    .   ', 301, 1, 0, 1) ;

--  "   ."
CALL DOCLOCKFIELDS_INSERTFIELD('    .   ',301,1,30111136,1) ;

CALL DOCLOCK_IMPORT('    ',0,301,1,0,11,0,'',0,3,'     ',0,'      ',null,'((.[30011019] = 0)  ([986810009] = 1)) 
((.[30011019] = 1)  ([986810008] = 1)) 
((.[30011019] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 301, 1, 0, 1) ;

--  " -( -)"
CALL DOCLOCKFIELDS_INSERTFIELD('    ',301,1,30111017,1) ;

CALL DOCLOCK_IMPORT('  ',32768,301,1,0,3,0,'([30110110] = 1) (("_..",[30111119])=0)',0,1,'  "   .", "   ."   ',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 301, 1, 0, 1) ;

--  "   -"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',301,1,30111138,1) ;

--  "   ."
CALL DOCLOCKFIELDS_INSERTFIELD('  ',301,1,30111137,1) ;

CALL DOCLOCK_IMPORT('   ',0,302,0,0,11,0,'',0,3,'     ',0,'          ',null,'([993010022] = )  ([993010020] = .[30210113])  ([993010017] = 1)',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 302, 0, 0, 1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',302,0,30210161,1) ;

CALL DOCLOCK_IMPORT('   ',32768,306,0,0,3,0,'([30610152])',0,3,'  " "  ,     ',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 306, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',306,0,30610010,1) ;

CALL DOCLOCK_IMPORT('     (,)',0,308,1,0,11,0,'',0,1,'          "",   -   ""',0,'       ""          ""  ',null,'(((.[30811007]=2)
((.[30811007]=1)  (("_.",.[30811094])=0)))
 ([988410016] = 0))

((.[30811007]=0)  ([988410016] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('     (,)', 308, 1, 0, 1) ;

--  "   "
CALL DOCLOCKFIELDS_INSERTFIELD('     (,)',308,1,30811063,1) ;

CALL DOCLOCK_IMPORT('    .   ',0,308,1,0,11,0,'[30811003] = 0',0,1,'         , , , .    ,         ,      ',0,'        ',null,'(([988410025] = 0)  (.[30811073] = 0)  (.[30811074] = [988410026]))

(([988410022] = 0)  (.[30811070] = 0)  (.[30811070] = [988410022]))

(([988410023] = 0)  (.[30811071] = 0)  (.[30811072] = [988410024]))

(([988410018] = 0)  (.[30811067] = 0)  (.[30811068] = [988410019]))',1) ;

CALL DOCLOCKFIELDS_DELETE('    .   ', 308, 1, 0, 1) ;

--  "   "
CALL DOCLOCKFIELDS_INSERTFIELD('    .   ',308,1,30811063,1) ;

CALL DOCLOCK_IMPORT('    .  ',0,308,1,0,11,0,'[30811003] = 2',0,1,'          .      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       .',0,'      ',null,'([988410006] = 0)  (.[30811019] = 0)  (.[30811093] = [988410008]) 
 ((("..",[988410006])=0)
   ((".",[988410006])=(".",.[30811019]))
   (((".",[988410006])=(".",.[30811019]))
     ((".",[988410006])=0))
   (("..",[988410006])=("..",.[30811019])))
 (((".", .[30811019]) div 100000) between 218 and 219)
 (((".", .[30811019]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('    .  ', 308, 1, 0, 1) ;

--  "   "
CALL DOCLOCKFIELDS_INSERTFIELD('    .  ',308,1,30811063,1) ;

CALL DOCLOCK_IMPORT('    ',0,308,1,0,11,0,'',0,3,'     ',0,'      ',null,'((.[30810070] = 0)  ([986810009] = 1)) 
((.[30810070] = 1)  ([986810008] = 1)) 
((.[30810070] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 308, 1, 0, 1) ;

--  " ( )"
CALL DOCLOCKFIELDS_INSERTFIELD('    ',308,1,30811069,1) ;

CALL DOCLOCK_IMPORT('   (2)',32768,323,-1,0,3,0,' ((([32311149] is not null)   (([32311143],(30,45,8),"9.9.9")))    ([32311143] between 500 and 599)     (([32311139] is not null)  (tonumber([32311140],1) <> 0))   )',0,1,'  " "  ,     .     ,            ( ),      , .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   (2)', 323, -1, 0, 1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',323,-1,32311162,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',323,-1,32311161,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',323,-1,32311160,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',323,-1,32311159,1) ;

CALL DOCLOCK_IMPORT('   ',0,323,1,0,11,0,'',0,1,'    ,      - \.',0,'        ',null,'(([960110035] between 010800 and 011099)
([960110021]=("_.",.[32311012])))',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 323, 1, 0, 1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',323,1,32311163,1) ;

CALL DOCLOCK_IMPORT('   (2)',32768,324,-1,0,3,0,'((([32411190] is not null)   (([32411183],(30,45,8),"9.9.9")))    ([32411183] between 500 and 599)     (([32411178] is not null)  (tonumber([32411179],1) <> 0))   )',0,1,'  " "  ,     .     ,            ( ),      , .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   (2)', 324, -1, 0, 1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',324,-1,32411203,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',324,-1,32411202,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',324,-1,32411201,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   (2)',324,-1,32411200,1) ;

CALL DOCLOCK_IMPORT('   ',0,324,1,0,11,0,'',0,1,'    ,      - \.',0,'        ',null,'(([960110035] between 010800 and 011099)
([960110021]=("_.",.[32411026])))',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 324, 1, 0, 1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',324,1,32411204,1) ;

CALL DOCLOCK_IMPORT('      ',0,801,1,0,11,0,'[80111052] = 0',0,1,'         , , , .    ,         ,      ',0,'       ',null,'(([988410025] = 0)  (.[80111026] = 0)  (.[80111060] = [988410026]))

(([988410022] = 0)  (.[80111024] = 0)  (.[80111024] = [988410022]))

(([988410023] = 0)  (.[80111025] = 0)  (.[80111059] = [988410024]))

(([988410018] = 0)  (.[80111022] = 0)  (.[80111058] = [988410019]))',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 801, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('      ',801,1,80111055,1) ;

CALL DOCLOCK_IMPORT('    ',0,801,1,0,11,0,'',0,3,'     ',0,'      ',null,'((.[80111052] = 0)  ([986810009] = 1)) 
((.[80111052] = 1)  ([986810008] = 1)) 
((.[80111052] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 801, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',801,1,80111023,1) ;

CALL DOCLOCK_IMPORT('     ',0,900,1,0,11,0,'([90011001] = 2) (([90011001] = 1) ("_.",[90011006])=0)',0,3,'  ,      ,  =0 (    )           ""',0,'       ""   ',null,'[988410016] = 0',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 900, 1, 0, 1) ;

--  "   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ',900,1,90011002,1) ;

CALL DOCLOCK_IMPORT('     ',0,900,1,0,11,0,'([90011001] = 2)  (( <> 903)    (("_..",[90011008]) between 010800 and 011099))',0,3,'          ,  / , ()   (09.03)   .      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       .',0,'      ',null,'([988410006] = 0)  (.[90011004] = 0)  (.[90011005] = [988410008]) 
 ((("..",[988410006])=0)
   ((".",[988410006])=(".",.[90011004]))
   (((".",[988410006])=(".",.[90011004]))
     ((".",[988410006])=0))
   (("..",[988410006])=("..",.[90011004])))
 (((".", .[90011004]) div 100000) between 218 and 219) 
 (((".", .[90011004]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 900, 1, 0, 1) ;

--  "   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ',900,1,90011002,1) ;

CALL DOCLOCK_IMPORT('  ',32768,900,1,0,3,0,'([90011001] = 1) (("_..",[90011006])=0)',0,1,'  "  "   ',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 900, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',900,1,90011003,1) ;

CALL DOCLOCK_IMPORT('    ',0,903,1,0,11,0,'',0,3,'     ',0,'      ',null,'((.[90311035] = 0)  ([986810009] = 1)) 
((.[90311035] = 1)  ([986810008] = 1)) 
((.[90311035] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 903, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',903,1,90311030,1) ;

CALL DOCLOCK_IMPORT('    ',0,905,0,0,11,0,'',0,1,'     ',0,'      ',null,'((.[090510029] = 0)  ([986810009] = 1)) 
((.[090510029] = 1)  ([986810008] = 1)) 
((.[090510029] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 905, 0, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',905,0,90510046,1) ;

CALL DOCLOCK_IMPORT('    ',0,906,0,0,11,0,'',0,1,'     ',0,'      ',null,'[986810007] = 1',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 906, 0, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',906,0,90610082,1) ;

CALL DOCLOCK_IMPORT('      ',0,906,1,0,11,0,'',0,1,'       ',0,'      ',null,'[986810007] = 1',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 906, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('      ',906,1,90611088,1) ;

CALL DOCLOCK_IMPORT('    ',0,907,0,0,11,0,'',0,1,'     ',0,'      ',null,'((.[90710036] = 0)  ([986810009] = 1)) 
((.[90710036] = 1)  ([986810008] = 1)) 
((.[90710036] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 907, 0, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',907,0,90710058,1) ;

CALL DOCLOCK_IMPORT('    ',0,1201,0,0,11,0,'',0,3,'     ',0,'      ',null,'((.[120110017] = 0)  ([986810009] = 1)) 
((.[120110017] = 1)  ([986810008] = 1)) 
((.[120110017] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 1201, 0, 0, 1) ;

--  "( )"
CALL DOCLOCKFIELDS_INSERTFIELD('    ',1201,0,120110009,1) ;

CALL DOCLOCK_IMPORT('  .   ',0,1201,0,0,11,0,'',0,3,'     ',0,'      ',null,'((.[120110031] = 0)  ([986810009] = 1)) 
((.[120110031] = 1)  ([986810008] = 1)) 
((.[120110031] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('  .   ', 1201, 0, 0, 1) ;

--  "( )"
CALL DOCLOCKFIELDS_INSERTFIELD('  .   ',1201,0,120110023,1) ;

CALL DOCLOCK_IMPORT('  ',131072,1601,-1,0,7,0,'',1,3,'   .   ,   .           .',2,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 1601, -1, 0, 1) ;

CALL DOCLOCK_IMPORT(' ',131072,1601,-1,0,6,0,'',1,1,'  .       .',2,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE(' ', 1601, -1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',1601,-1,160110016,1) ;

--  "/"
CALL DOCLOCKFIELDS_INSERTFIELD(' ',1601,-1,160110003,1) ;

--  " /"
CALL DOCLOCKFIELDS_INSERTFIELD(' ',1601,-1,160110002,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',1601,-1,160110051,1) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD(' ',1601,-1,160110050,1) ;

CALL DOCLOCK_IMPORT(' ,   ',131076,1601,-1,0,4,2,'',0,2,'     ,   .       . ,     .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE(' ,   ', 1601, -1, 1, 1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',1601,-1,160111052,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',1601,-1,160111053,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',1601,-1,160111026,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',1601,-1,160111029,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',1601,-1,160111044,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',1601,-1,160111018,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',1601,-1,160111045,1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',1601,-1,160111017,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',1601,-1,160111030,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',1601,-1,160111027,1) ;

--  " . "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',1601,-1,160111028,1) ;

--  "/"
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',1601,-1,160110003,1) ;

--  " /"
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',1601,-1,160110002,1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',1601,-1,160110001,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',1601,-1,160110051,1) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',1601,-1,160110050,1) ;

CALL DOCLOCK_IMPORT(' ',131076,1601,0,0,4,2,'',0,1,'  .       .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE(' ', 1601, 0, 0, 1) ;

--  "/"
CALL DOCLOCKFIELDS_INSERTFIELD(' ',1601,0,160110003,1) ;

--  " /"
CALL DOCLOCKFIELDS_INSERTFIELD(' ',1601,0,160110002,1) ;

CALL DOCLOCK_IMPORT(' ',131076,1601,0,0,4,2,'',0,1,'  .       .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE(' ', 1601, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',1601,0,160110051,1) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD(' ',1601,0,160110050,1) ;

CALL DOCLOCK_IMPORT('      ',0,1601,1,0,11,0,'',0,1,'         , , , .    ,         ,      ',0,'       ',null,'(([988410025] = 0)  (.[160111021] = 0)  (.[160111076] = [988410026]))

(([988410022] = 0)  (.[160111022] = 0)  (.[160111022] = [988410022]))

(([988410023] = 0)  (.[160111024] = 0)  (.[160111075] = [988410024]))

(([988410018] = 0)  (.[160111023] = 0)  (.[160111074] = [988410019]))',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 1601, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('      ',1601,1,160111072,1) ;

CALL DOCLOCK_IMPORT('   ',0,1601,1,0,11,0,'("_.",[160111019])   ("_.",[160111019])',0,1,' (   , , )          .     \   .   \      .',0,'         ',null,'(("_...",.[160111019]) between 10000  10499)

(((".",[988910008]) between 10100  10199)

([988910008] = ("_.",.[160111019]))
 ((("_.",.[160111019])<>0)
      (("_.",.[160111019])=0)
     ((".",[988910008])= ("_.",.[160111019])))
)',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 1601, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',1601,1,160111078,1) ;

CALL DOCLOCK_IMPORT('     ,',0,1601,1,0,11,0,'("_._",[160111019])   ("_._",[160111019])   ("_.",[160111019])',0,3,',        =- \,  =. ',0,'         ',null,'([988910008] = ("_.",.[160111019])     
 (((".",[988910008]) between 10100  10199)
 ((".",[988910008]) between 11000  11099)))
   
(( ("_._",.[160111019])
 ([988910010] = 0))

(("_._",.[160111019])
 ([988910010] <> 0)))',1) ;

CALL DOCLOCKFIELDS_DELETE('     ,', 1601, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ,',1601,1,160111078,1) ;

CALL DOCLOCK_IMPORT('    ',0,1601,1,0,11,0,'',0,3,'     ',0,'      ',null,'([986810009])',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 1601, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',1601,1,160111025,1) ;

CALL DOCLOCK_IMPORT('    ',0,1809,0,0,11,0,'([180910002] is null)',0,3,'     ',0,'      ',null,'((.[180910002] = 0)  ([986810009] = 1))    
((.[180910002] = 1)  ([986810008] = 1)) 
((.[180910002] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 1809, 0, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',1809,0,180910001,1) ;

CALL DOCLOCK_IMPORT('    ',0,1816,0,0,11,0,'',0,3,'     ',0,'      ',null,'((.[181610098] = 0)  ([986810009] = 1)) 
((.[181610098] = 1)  ([986810008] = 1)) 
((.[181610098] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 1816, 0, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',1816,0,181610007,1) ;

CALL DOCLOCK_IMPORT('    ',0,1816,1,0,11,0,'',0,3,'     ',0,'      ',null,'((.[181611101] = 0)  ([986810009] = 1)) 
((.[181611101] = 1)  ([986810008] = 1)) 
((.[181611101] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 1816, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',1816,1,181611070,1) ;

CALL DOCLOCK_IMPORT('    ',0,1900,1,0,11,0,'',0,3,'     ',0,'      ',null,'((.[190011001] = 0)  ([986810009] = 1)) 
((.[190011001] = 1)  ([986810008] = 1)) 
((.[190011001] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 1900, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',1900,1,190011036,1) ;

CALL DOCLOCK_IMPORT('    ',0,2201,1,0,11,0,'',0,3,'     ',0,'      ',null,'((.[220111061] = 0)  ([986810009] = 1)) 
((.[220111061] = 1)  ([986810008] = 1)) 
((.[220111061] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 2201, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',2201,1,220111080,1) ;

CALL DOCLOCK_IMPORT('     ',0,2201,1,0,11,0,'',0,3,'          .      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       .',0,'      ',null,'([988410006] = 0)  (.[220111046] = 0)  (.[220111012] = [988410008])
 ((("..",[988410006])=0)
   ((".",[988410006])=(".",.[220111046]))
   (((".",[988410006])=(".",.[220111046]))
     ((".",[988410006])=0))
   (("..",[988410006])=("..",.[220111046])))
 (((".", .[220111046]) div 100000) between 218 and 219) 
 (((".", .[220111046]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 2201, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',2201,1,220111064,1) ;

CALL DOCLOCK_IMPORT('    ',0,2501,2,0,11,0,'',0,3,'     ',0,'      ',null,'([986810009])',2) ;

CALL DOCLOCKFIELDS_DELETE('    ', 2501, 2, 0, 2) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',2501,2,250112004,2) ;

CALL DOCLOCK_IMPORT('  ',0,2502,0,0,9,0,'[250210038] <= [250210035]',0,3,'',0,'              ',0,'',2) ;

CALL DOCLOCKFIELDS_DELETE('  ', 2502, 0, 0, 2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2502,0,250210035,2) ;

CALL DOCLOCK_IMPORT('  ',0,2502,0,0,9,0,'([250210038] <= [250210035])  ([250210035] is null)',0,3,'',0,'              ',0,'',2) ;

CALL DOCLOCKFIELDS_DELETE('  ', 2502, 0, 0, 2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2502,0,250210038,2) ;

CALL DOCLOCK_IMPORT('  ',0,2502,0,0,12,1,'',0,3,'',0,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE('  ', 2502, 0, 0, 2) ;

--  " . "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2502,0,250210003,2) ;

CALL DOCLOCK_IMPORT('  ',0,2502,0,0,12,1,'',0,3,'',0,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE('  ', 2502, 0, 0, 2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2502,0,250210059,2) ;

CALL DOCLOCK_IMPORT('   ',0,2502,0,0,12,1,'',0,3,'',0,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE('   ', 2502, 0, 0, 2) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',2502,0,250210060,2) ;

CALL DOCLOCK_IMPORT('  ',0,2502,0,0,12,1,'',0,3,'',0,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE('  ', 2502, 0, 0, 2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2502,0,250210061,2) ;

CALL DOCLOCK_IMPORT('    ',0,2502,0,0,12,1,'',0,3,'',0,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE('    ', 2502, 0, 0, 2) ;

--  "    "
CALL DOCLOCKFIELDS_INSERTFIELD('    ',2502,0,250210062,2) ;

CALL DOCLOCK_IMPORT(' ',0,2502,0,0,12,1,'',0,3,'',0,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE(' ', 2502, 0, 0, 2) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ',2502,0,250210063,2) ;

CALL DOCLOCK_IMPORT('  ',0,2502,1,0,9,0,'[250211009] <= [250211006]',0,3,'',0,'              ',0,'',2) ;

CALL DOCLOCKFIELDS_DELETE('  ', 2502, 1, 0, 2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2502,1,250211006,2) ;

CALL DOCLOCK_IMPORT('    ',0,2502,1,0,9,0,'([250211009] <= [250211006])  ([250211006] is null)',0,3,'',0,'              ',0,'',2) ;

CALL DOCLOCKFIELDS_DELETE('    ', 2502, 1, 0, 2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('    ',2502,1,250211009,2) ;

CALL DOCLOCK_IMPORT('   ',0,2502,2,0,11,0,'("_.",[250212035])   ("_.",[250212035])',0,1,' (   , , )          .     \   .   \      .',0,'         ',null,'(("_...",.[250212035]) between 10000  10499)

(((".",[988910008]) between 10100  10199)

([988910008] = ("_.",.[250212035]))
 ((("_.",.[250212035])<>0)
      (("_.",.[250212035])=0)
     ((".",[988910008])= ("_.",.[250212035])))
)',2) ;

CALL DOCLOCKFIELDS_DELETE('   ', 2502, 2, 0, 2) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',2502,2,250212056,2) ;

CALL DOCLOCK_IMPORT('     ,',0,2502,2,0,11,0,'("_._",[250212035])   ("_._",[250212035])   ("_.",[250212035])',0,3,',        =- \,  =. ',0,'         ',null,'([988910008] = ("_.",.[250212035])
 (((".",[988910008]) between 10100  10199)
 ((".",[988910008]) between 11000  11099)))
   
(( ("_._",.[250212035])
 ([988910010] = 0))

(("_._",.[250212035])
 ([988910010] <> 0)))',2) ;

CALL DOCLOCKFIELDS_DELETE('     ,', 2502, 2, 0, 2) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ,',2502,2,250212056,2) ;

CALL DOCLOCK_IMPORT('    ',0,2502,2,0,11,0,'',0,3,'     ',0,'      ',null,'([986810009])',2) ;

CALL DOCLOCKFIELDS_DELETE('    ', 2502, 2, 0, 2) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',2502,2,250212029,2) ;

CALL DOCLOCK_IMPORT('   ',0,2503,2,0,11,0,'("_.",[250312005])   ("_.",[250312005])',0,1,' (   , , )          .     \   .   \      .',0,'         ',null,'(("_...",.[250312005]) between 10000  10499)

(((".",[988910008]) between 10100  10199)

([988910008] = ("_.",.[250312005]))
 ((("_.",.[250312005])<>0)
      (("_.",.[250312005])=0)
     ((".",[988910008])= ("_.",.[250312005])))
)',2) ;

CALL DOCLOCKFIELDS_DELETE('   ', 2503, 2, 0, 2) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',2503,2,250312051,2) ;

CALL DOCLOCK_IMPORT('     ,',0,2503,2,0,11,0,'("_._",[250312005])   ("_._",[250312005])   ("_.",[250312005])',0,3,',        =- \,  =. ',0,'         ',null,'([988910008] = ("_.",.[250312005])
 (((".",[988910008]) between 10100  10199)
 ((".",[988910008]) between 11000  11099)))
   
(( ("_._",.[250312005])
 ([988910010] = 0))

(("_._",.[250312005])
 ([988910010] <> 0)))',2) ;

CALL DOCLOCKFIELDS_DELETE('     ,', 2503, 2, 0, 2) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ,',2503,2,250312051,2) ;

CALL DOCLOCK_IMPORT('    ',0,2503,2,0,11,0,'',0,3,'     ',0,'      ',null,'([986810009])',2) ;

CALL DOCLOCKFIELDS_DELETE('    ', 2503, 2, 0, 2) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',2503,2,250312011,2) ;

CALL DOCLOCK_IMPORT('   36  ',0,2504,0,0,10,0,'[250410101] like "____________________________________"  [250410101] = ""',0,3,'     36   ( ,  )',0,'     36   ( ,  )',0,'',2) ;

CALL DOCLOCKFIELDS_DELETE('   36  ', 2504, 0, 0, 2) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('   36  ',2504,0,250410101,2) ;

CALL DOCLOCK_IMPORT('  ',0,2504,0,0,10,0,'[250410086] <= [250410083]',0,3,'',0,'              ',0,'',2) ;

CALL DOCLOCKFIELDS_DELETE('  ', 2504, 0, 0, 2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2504,0,250410083,2) ;

CALL DOCLOCK_IMPORT('  ',0,2504,0,0,10,0,'([250410086] <= [250410083])  ([250410083] is null)',0,3,'',0,'              ',0,'',2) ;

CALL DOCLOCKFIELDS_DELETE('  ', 2504, 0, 0, 2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2504,0,250410086,2) ;

CALL DOCLOCK_IMPORT('   ',0,2504,0,0,11,0,'',0,3,'     ',0,'           ',null,'([993010022] = )  ([993010020] = [993010020])  ([993010017] = 1)',2) ;

CALL DOCLOCKFIELDS_DELETE('   ', 2504, 0, 0, 2) ;

--  "   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',2504,0,250410100,2) ;

CALL DOCLOCK_IMPORT('    ',0,2504,1,0,10,0,'[250411008] <= [250411005]',0,3,'',0,'               ',0,'',2) ;

CALL DOCLOCKFIELDS_DELETE('    ', 2504, 1, 0, 2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('    ',2504,1,250411005,2) ;

CALL DOCLOCK_IMPORT('    ',0,2504,1,0,10,0,'([250411008] <= [250411005])  ([250411005] is null)',0,3,'',0,'              ',0,'',2) ;

CALL DOCLOCKFIELDS_DELETE('    ', 2504, 1, 0, 2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('    ',2504,1,250411008,2) ;

CALL DOCLOCK_IMPORT('   ',0,2504,2,0,11,0,'("_.",[250412043])   ("_.",[250412043])',0,1,' (   , , )          .     \   .   \      .',0,'         ',null,'(("_...",.[250412043]) between 10000  10499)

(((".",[988910008]) between 10100  10199)

([988910008] = ("_.",.[250412043]))
 ((("_.",.[250412043])<>0)
      (("_.",.[250412043])=0)
     ((".",[988910008])= ("_.",.[250412043])))
)',2) ;

CALL DOCLOCKFIELDS_DELETE('   ', 2504, 2, 0, 2) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',2504,2,250412055,2) ;

CALL DOCLOCK_IMPORT('     ,',0,2504,2,0,11,0,'("_._",[250412043])   ("_._",[250412043])   ("_.",[250412043])',0,3,',        =- \,  =. ',0,'         ',null,'([988910008] = ("_.",.[250412043])
 (((".",[988910008]) between 10100  10199)
 ((".",[988910008]) between 11000  11099)))
   
(( ("_._",.[250412043])
 ([988910010] = 0))

(("_._",.[250412043])
 ([988910010] <> 0)))',2) ;

CALL DOCLOCKFIELDS_DELETE('     ,', 2504, 2, 0, 2) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ,',2504,2,250412055,2) ;

CALL DOCLOCK_IMPORT('    ',0,2504,2,0,11,0,'',0,3,'     ',0,'      ',null,'([986810009])',2) ;

CALL DOCLOCKFIELDS_DELETE('    ', 2504, 2, 0, 2) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',2504,2,250412036,2) ;

CALL DOCLOCK_IMPORT('    ',0,2504,5,0,11,0,'',0,3,'     ',0,'      ',null,'([986810009])',2) ;

CALL DOCLOCKFIELDS_DELETE('    ', 2504, 5, 0, 2) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',2504,5,250415010,2) ;

CALL DOCLOCK_IMPORT('   36  ',0,3001,0,0,10,0,'[300110033] like "____________________________________"  [300110033] = ""',0,3,'     36   ( ,  )',0,'     36   ( ,  )',0,'',2) ;

CALL DOCLOCKFIELDS_DELETE('   36  ', 3001, 0, 0, 2) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('   36  ',3001,0,300110033,2) ;

CALL DOCLOCK_IMPORT('    ',0,3001,1,0,11,0,'',0,3,'     ',0,'      ',null,'([986810009])',2) ;

CALL DOCLOCKFIELDS_DELETE('    ', 3001, 1, 0, 2) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',3001,1,300111041,2) ;

CALL DOCLOCK_IMPORT(' ,   ',65540,3005,-1,0,4,1,'',0,2,'     ,   .       . ,     .',0,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE(' ,   ', 3005, -1, 1, 2) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',3005,-1,300510005,2) ;

CALL DOCLOCK_IMPORT(' ',65540,3005,-1,0,4,1,'',0,1,'  .       .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE(' ', 3005, -1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',3005,-1,300510011,1) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD(' ',3005,-1,300510003,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',3005,-1,300510002,1) ;

CALL DOCLOCK_IMPORT('  ',64,3005,-1,0,8,1,'',1,1,'         .       .',1,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 3005, -1, 0, 1) ;

CALL DOCLOCK_IMPORT('  ',2,3005,-1,0,8,1,'',1,1,'     ,   .       .',2,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 3005, -1, 0, 1) ;

CALL DOCLOCK_IMPORT('  ',65536,3005,-1,0,7,0,'',1,3,'   .   ,   .           .',2,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE('  ', 3005, -1, 0, 2) ;

CALL DOCLOCK_IMPORT(' ',65536,3005,-1,0,6,0,'',1,1,'  .       .',2,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE(' ', 3005, -1, 0, 2) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',3005,-1,300510011,2) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD(' ',3005,-1,300510003,2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',3005,-1,300510002,2) ;

CALL DOCLOCK_IMPORT(' ',65540,3005,-1,0,4,1,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE(' ', 3005, -1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',3005,-1,300510011,1) ;

CALL DOCLOCK_IMPORT('   36  ',0,3006,0,0,10,0,'[300610049] like "____________________________________"  [300610049] = ""',0,3,'     36   ( ,  )',0,'     36   ( ,  )',0,'',2) ;

CALL DOCLOCKFIELDS_DELETE('   36  ', 3006, 0, 0, 2) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('   36  ',3006,0,300610049,2) ;

CALL DOCLOCK_IMPORT('    -',0,3006,0,0,10,0,'([300610051] is not null)  ([300610017] < 2017)',0,3,'',0,'    -',0,'',2) ;

CALL DOCLOCKFIELDS_DELETE('    -', 3006, 0, 0, 2) ;

--  "  /"
CALL DOCLOCKFIELDS_INSERTFIELD('    -',3006,0,300610051,2) ;

CALL DOCLOCK_IMPORT(' ',65540,3006,0,0,4,1,' ([300610051])',0,1,'  .       .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE(' ', 3006, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',3006,0,300610019,1) ;

CALL DOCLOCK_IMPORT(' ',65540,3006,0,0,4,1,' ([300610051])',0,1,'  .       .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE(' ', 3006, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',3006,0,300610019,1) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD(' ',3006,0,300610008,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',3006,0,300610007,1) ;

CALL DOCLOCK_IMPORT('    ',0,3006,1,0,11,0,'',0,3,'     ',0,'      ',null,'([986810009])',2) ;

CALL DOCLOCKFIELDS_DELETE('    ', 3006, 1, 0, 2) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',3006,1,300611008,2) ;

CALL DOCLOCK_IMPORT('  ',64,3010,-1,0,8,1,'',1,1,'         .       .',1,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 3010, -1, 0, 1) ;

CALL DOCLOCK_IMPORT(' ,   ',65540,3010,-1,0,4,1,'',0,2,'     ,   .       . ,     .',0,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE(' ,   ', 3010, -1, 1, 2) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',3010,-1,301010012,2) ;

CALL DOCLOCK_IMPORT('  ',2,3010,-1,0,8,1,'',1,1,'     ,   .       .',2,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 3010, -1, 0, 1) ;

CALL DOCLOCK_IMPORT('  ',65536,3010,-1,0,7,0,'',1,3,'   .   ,   .           .',2,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE('  ', 3010, -1, 0, 2) ;

CALL DOCLOCK_IMPORT(' ',65536,3010,-1,0,6,0,'',1,1,'  .       .',2,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE(' ', 3010, -1, 0, 2) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',3010,-1,301010019,2) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD(' ',3010,-1,301010008,2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',3010,-1,301010007,2) ;

CALL DOCLOCK_IMPORT(' ',65540,3010,0,0,4,1,'',0,1,'  .       .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE(' ', 3010, 0, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',3010,0,301010019,1) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD(' ',3010,0,301010008,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',3010,0,301010007,1) ;

CALL DOCLOCK_IMPORT(' ',65540,3010,0,0,4,1,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE(' ', 3010, 0, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',3010,0,301010019,1) ;

CALL DOCLOCK_IMPORT(' ',65540,3011,-1,0,4,1,'',0,1,'  .       .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE(' ', 3011, -1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',3011,-1,301110019,1) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD(' ',3011,-1,301110008,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',3011,-1,301110007,1) ;

CALL DOCLOCK_IMPORT('  ',64,3011,-1,0,8,1,'',1,1,'         .       .',1,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 3011, -1, 0, 1) ;

CALL DOCLOCK_IMPORT(' ,   ',65540,3011,-1,0,4,1,'',0,2,'     ,   .       . ,     .',0,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE(' ,   ', 3011, -1, 1, 2) ;

--  "   "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',3011,-1,301110020,2) ;

CALL DOCLOCK_IMPORT('  ',2,3011,-1,0,8,1,'',1,1,'     ,   .       .',2,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 3011, -1, 0, 1) ;

CALL DOCLOCK_IMPORT('  ',65536,3011,-1,0,7,0,'',1,3,'   .   ,   .           .',2,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE('  ', 3011, -1, 0, 2) ;

CALL DOCLOCK_IMPORT(' ',65536,3011,-1,0,6,0,'',1,1,'  .       .',2,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE(' ', 3011, -1, 0, 2) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',3011,-1,301110019,2) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD(' ',3011,-1,301110008,2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',3011,-1,301110007,2) ;

CALL DOCLOCK_IMPORT('     ',0,3011,0,0,10,0,'[301110010] <> 6  [301110025] = 0  [301110010] = 6',0,3,' "   "       ,    "   "   "".',0,'    ""  "   "    ',0,'',2) ;

CALL DOCLOCKFIELDS_DELETE('     ', 3011, 0, 0, 2) ;

--  "   "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',3011,0,301110010,2) ;

CALL DOCLOCK_IMPORT('    ',0,3011,0,0,10,0,'[301110010] = 6  [301110025] <> 0  [301110010] <> 6',0,3,' "   "       ,    "   "   "".',0,'   "   "  ""  "   "     ',0,'',2) ;

CALL DOCLOCKFIELDS_DELETE('    ', 3011, 0, 0, 2) ;

CALL DOCLOCK_IMPORT('   36  ',0,3011,0,0,10,0,'[301110026] like "____________________________________"  [301110026] = ""',0,3,'     36   ( ,  )',0,'     36   ( ,  )',0,'',2) ;

CALL DOCLOCKFIELDS_DELETE('   36  ', 3011, 0, 0, 2) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('   36  ',3011,0,301110026,2) ;

CALL DOCLOCK_IMPORT('     ',0,3011,0,0,10,0,'[301110029] is not null',0,3,'',0,'     ',0,'',2) ;

CALL DOCLOCKFIELDS_DELETE('     ', 3011, 0, 0, 2) ;

--  "  /"
CALL DOCLOCKFIELDS_INSERTFIELD('     ',3011,0,301110029,2) ;

CALL DOCLOCK_IMPORT('    ',32768,3011,0,0,3,0,'[301110050] <> 0',0,3,' "     "       ',0,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE('    ', 3011, 0, 0, 2) ;

--  "     "
CALL DOCLOCKFIELDS_INSERTFIELD('    ',3011,0,301110009,2) ;

CALL DOCLOCK_IMPORT('   ',32768,3011,0,0,3,0,'[301110010] <> 6',0,3,' "   "       ,    "   "   "".',0,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE('   ', 3011, 0, 0, 2) ;

--  "   "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',3011,0,301110025,2) ;

CALL DOCLOCK_IMPORT(' ',65540,3011,0,0,4,1,'',0,1,'  .       .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE(' ', 3011, 0, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',3011,0,301110019,1) ;

CALL DOCLOCK_IMPORT('    ',0,3011,1,0,11,0,'',0,3,'     ',0,'      ',null,'([986810009])',2) ;

CALL DOCLOCKFIELDS_DELETE('    ', 3011, 1, 0, 2) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',3011,1,301111002,2) ;

CALL DOCLOCK_IMPORT('  ',2,4801,-1,0,8,2,'',1,1,'     ,   .       .',2,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 4801, -1, 0, 1) ;

CALL DOCLOCK_IMPORT(' ',32768,4901,0,0,3,0,'[490110012] = 0',0,3,'',2,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE(' ', 4901, 0, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ',4901,0,490110003,1) ;

CALL DOCLOCK_IMPORT('  ',0,5201,0,0,10,0,'(([520110052] = 4)    (("_._",[520110033])   ("_._",[520110033])   ("_.",[520110033])))   (([520110052] = 3)    (("_.",[520110033])  ("_.",[520110033])   ))   (([520110052] = 0)  ([520110052] = 1)  ([520110052] = 2))',0,3,'',0,'       ',0,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 5201, 0, 0, 1) ;

--  " . "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',5201,0,520110052,1) ;

CALL DOCLOCK_IMPORT('    ',0,5201,1,0,11,0,'',0,3,'     ',0,'      ',null,'((.[520111071] = 0)  ([986810009] = 1)) 
((.[520111071] = 1)  ([986810008] = 1)) 
((.[520111071] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 5201, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',5201,1,520111011,1) ;

CALL DOCLOCK_IMPORT('      ',0,5201,1,0,11,0,'[520111071] = 0',0,1,'         , , , .    ,         ,      ',0,'       ',null,'(([988410025] = 0)  (.[520111015] = 0)  (.[520111016] = [988410026]))

(([988410022] = 0)  (.[520111012] = 0)  (.[520111012] = [988410022]))

(([988410023] = 0)  (.[520111013] = 0)  (.[520111014] = [988410024]))

(([988410018] = 0)  (.[520111009] = 0)  (.[520111010] = [988410019]))',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 5201, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('      ',5201,1,520111052,1) ;

CALL DOCLOCK_IMPORT('     ',0,5201,1,0,11,0,'[520111071] = 2',0,3,'          .      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       .',0,'      ',null,'([988410006] = 0)  (.[520111064] = 0)  ([988410008] = .[520111070]) 
   ((("..",[988410006])=0)
   ((".",[988410006])=(".",.[520111064]))
   (((".",[988410006])=(".",.[520111064]))
     ((".",[988410006])=0))
   (("..",[988410006])=("..",.[520111064]))) 
(((".", .[520111064]) div 100000) between 218 and 219) 
(((".", .[520111064]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 5201, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',5201,1,520111052,1) ;

CALL DOCLOCK_IMPORT(' ',65536,5501,-1,0,8,2,'',0,1,'  .       ',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE(' ', 5501, -1, 0, 1) ;

CALL DOCLOCK_IMPORT('    ',0,5501,1,0,11,0,'',0,3,'     ',0,'      ',null,'((.[550111066] = 0)  ([986810009] = 1)) 
((.[550111066] = 1)  ([986810008] = 1)) 
((.[550111066] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 5501, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',5501,1,550111058,1) ;

CALL DOCLOCK_IMPORT('     ,',0,5501,1,0,11,0,'(([550111066] = 1)  (("_.",[550111088])=0))',0,1,'  ,      ,  =0 (    )        "",   -   ""',0,'       ""          ""  ',null,'([988410016] = 0)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ,', 5501, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('     ,',5501,1,550111144,1) ;

CALL DOCLOCK_IMPORT('      ',0,5501,1,0,11,0,'[550111066] = 0',0,3,'         , , , .    ,         ,      ',0,'       ',null,'(([988410025] = 0)  (.[550111054] = 0)  (.[550111148] = [988410026]))

(([988410022] = 0)  (.[550111055] = 0)  (.[550111055] = [988410022]))

(([988410023] = 0)  (.[550111057] = 0)  (.[550111147] = [988410024]))

(([988410018] = 0)  (.[550111056] = 0)  (.[550111146] = [988410019]))',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 5501, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('      ',5501,1,550111144,1) ;

CALL DOCLOCK_IMPORT('     ',0,5501,1,0,11,0,'([550111066] = 2)  ((("_..",[550111052]) between 010800 and 011099))',0,3,'          ,    / , ().      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       . ',0,'      ',null,'([988410006] = 0)  (.[550111090] = 0)  (.[550111156] = [988410008]) 
 ((("..",[988410006])=0)
   ((".",[988410006])=(".",.[550111090]))
   (((".",[988410006])=(".",.[550111090]))
     ((".",[988410006])=0))
   (("..",[988410006])=("..",.[550111090])))
 (((".", .[550111090]) div 100000) between 218 and 219) 
  (((".", .[550111090]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 5501, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',5501,1,550111144,1) ;

CALL DOCLOCK_IMPORT(' ',65536,5502,-1,0,8,2,'',0,1,'  .       .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE(' ', 5502, -1, 0, 1) ;

CALL DOCLOCK_IMPORT('     ,',0,5502,1,0,11,0,'',0,1,'  ,      ,  =0 (    )        "",   -   ""',0,'       ""          ""  ',null,'(((.[550211066] = 2)  
((.[550211066] = 1)  (("_.",.[550211088])=0)))  
 ([988410016] = 0))

((.[550211066]=0)  ([988410016] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('     ,', 5502, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('     ,',5502,1,550211125,1) ;

CALL DOCLOCK_IMPORT('      ',0,5502,1,0,11,0,'[550211066]  =  0',0,3,'         , , , .    ,         ,      ',0,'       ',null,'(([988410025] = 0)  (.[550211054] = 0)  (.[550211129] = [988410026]))

(([988410022] = 0)  (.[550211055] = 0)  (.[550211055] = [988410022]))

(([988410023] = 0)  (.[550211057] = 0)  (.[550211128] = [988410024]))

(([988410018] = 0)  (.[550211056] = 0)  (.[550211127] = [988410019]))',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 5502, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('      ',5502,1,550211125,1) ;

CALL DOCLOCK_IMPORT('     ',0,5502,1,0,11,0,'([550211066] = 2)  ((("_..",[550211052]) between 010800 and 011099))',0,3,'          ,    / , ().      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       . ',0,'      ',null,'([988410006] = 0)  (.[550211090] = 0)  (.[550211135] = [988410008]) 
 ((("..",[988410006])=0)
   ((".",[988410006])=(".",.[550211090]))
   (((".",[988410006])=(".",.[550211090]))
     ((".",[988410006])=0))
   (("..",[988410006])=("..",.[550211090])))
 (((".", .[550211090]) div 100000) between 218 and 219) 
  (((".", .[550211090]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 5502, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',5502,1,550211125,1) ;

CALL DOCLOCK_IMPORT('    ',0,5502,1,0,11,0,'',0,3,'     ',0,'      ',null,'((.[550211066] = 0)  ([986810009] = 1)) 
((.[550211066] = 1)  ([986810008] = 1)) 
((.[550211066] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 5502, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',5502,1,550211058,1) ;

CALL DOCLOCK_IMPORT('    ',0,5503,1,0,11,0,'',0,3,'     ',0,'      ',null,'(.[550311008] = 4)

(
((.[550311008] = 0)  ([986810009] = 1)) 
((.[550311008] = 1)  ([986810008] = 1)) 
((.[550311008] = 2)  ([986810007] = 1))
)',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 5503, 1, 0, 1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD('    ',5503,1,550311015,1) ;

CALL DOCLOCK_IMPORT('     ,',0,5503,1,0,11,0,'',0,1,'  ,      ,  =0 (    )        "",   -   ""',0,'       ""          ""  ',null,'(((.[550311008] = 2)  
((.[550311008] = 1)  (("_.",.[550311023])=0)))  
 ([988410016] = 0))

((.[550311008]=0)  ([988410016] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('     ,', 5503, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('     ,',5503,1,550311025,1) ;

CALL DOCLOCK_IMPORT('      ',0,5503,1,0,11,0,'[550311008] = 0',0,1,'         , , , .    ,         ,      ',0,'       ',null,'(([988410025] = 0)  (.[550311011] = 0)  (.[550311042] = [988410026]))

(([988410022] = 0)  (.[550311012] = 0)  (.[550311012] = [988410022]))

(([988410023] = 0)  (.[550311014] = 0)  (.[550311041] = [988410024]))

(([988410018] = 0)  (.[550311013] = 0)  (.[550311036] = [988410019]))',1) ;

CALL DOCLOCKFIELDS_DELETE('      ', 5503, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('      ',5503,1,550311025,1) ;

CALL DOCLOCK_IMPORT('     ',0,5503,1,0,11,0,'[550311008] = 2',0,1,'          ,    /          /.      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       .',0,'      ',null,'([988410006] = 0)  (.[550311022] = 0)  (.[550311022] = [988410006])
 ((("..",[988410006])=0)
   ((".",[988410006])=(".",.[550311022]))
   (((".",[988410006])=(".",.[550311022]))
     ((".",[988410006])=0))
   (("..",[988410006])=("..",.[550311022])))
 (((".", .[550311022]) div 100000) between 218 and 219) 
 (((".", .[550311022]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 5503, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',5503,1,550311025,1) ;

CALL DOCLOCK_IMPORT('     ',0,9903,0,0,10,0,'(([990310057] >= 020000)  ([990310057] < 030000))  ([990310098] = 0)',0,3,',      (  02.xx.xx).       .',0,'        (   02.xx.xx)',0,'',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 9903, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',9903,0,990310057,1) ;

CALL DOCLOCK_IMPORT('   ',0,9903,0,0,9,4,'[990310098] <> 0',0,1,',     ',0,'   ',0,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 9903, 0, 0, 1) ;

--  "   (  )"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',9903,0,990310098,1) ;

CALL DOCLOCK_IMPORT('   ',0,9903,0,0,9,4,'([990310098] = 0)  ([990310098] = ("..", ))',0,1,',     ',0,'   ',0,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 9903, 0, 0, 1) ;

--  "   (  )"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',9903,0,990310098,1) ;

CALL DOCLOCK_IMPORT('   ( )',0,9903,0,0,11,4,'',0,1,'   -      ',0,'   ',null,'([988310002] >= 020000)  ([988310002] <= 029999)',1) ;

CALL DOCLOCKFIELDS_DELETE('   ( )', 9903, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ( )',9903,0,990310057,1) ;

CALL DOCLOCK_IMPORT(' /    ',0,9912,0,0,11,0,'',0,1,' \ - /  \      .       ""/" "  / "",       " , "/"  /"/" /" - / ", "',0,'    - /         /    .',null,'((([984110031]=("..",.[991210001]))
    ([984110031]=("/.",.[991210014])))
 (([984110003]=0)([984110003]=.[991210001]))
 ((((.[991210017]<>0)(.[991210019]<>0)(.[991210007]<>0))([984110041]<>0))
   (([984110042]<>0)
   ((.[991210006]<>0)(.[991210008]<>0)))
  ))
([984110021]=0)',1) ;

CALL DOCLOCKFIELDS_DELETE(' /    ', 9912, 0, 0, 1) ;

--  "/ "
CALL DOCLOCKFIELDS_INSERTFIELD(' /    ',9912,0,991210018,1) ;

CALL DOCLOCK_IMPORT('    ',0,9930,0,0,11,0,'',0,3,'     ',0,'      ',null,'((.[993010020] = 0)  ([986810009] = 1)) 
((.[993010020] = 1)  ([986810008] = 1)) 
((.[993010020] = 2)  ([986810007] = 1))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 9930, 0, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',9930,0,993010013,1) ;

DROP PROCEDURE DOCLOCK_IMPORT      
/

DROP PROCEDURE DocLockFields_InsertField
/

DROP PROCEDURE DOCLOCK_DELETE
/

DROP PROCEDURE DOCLOCKFIELDS_DELETE
/

CREATE OR REPLACE PROCEDURE LINKTYPE_DELETE(
  NAME_         VARCHAR2,
  TEMPLATECLS_  NUMBER,
  PARENTDOCCLS_ NUMBER,
  CHILDDOCCLS_  NUMBER) IS
BEGIN
  FOR tab_rec in (SELECT id FROM LINKTYPE LT
  WHERE (((NAME_ <> '') or (NAME_ is not null)) and (LT.NAME = NAME_)) or 
    (((NAME_ = '') or (NAME_ is null)) and (LT.TEMPLATECLS = TEMPLATECLS_ AND LT.PARENTDOCCLS = PARENTDOCCLS_ AND LT.CHILDDOCCLS = CHILDDOCCLS_)))    
  LOOP
    UPDATE STATE_JUMPCONTROL SET
      REFERENCEREF = NULL
    WHERE REFERENCEREF = tab_rec.id;
    DELETE FROM REPLACEMENTCLSDETAIL WHERE LINKID IN (SELECT ID FROM LINKRECORDS
      WHERE LINKTYPEREF = tab_rec.id);
    DELETE FROM LINKRECORDS
      WHERE LINKTYPEREF = tab_rec.id;
    DELETE FROM LINKTYPE LT
      WHERE LT.ID = tab_rec.id;
  END LOOP;     
END;
/

CREATE OR REPLACE PROCEDURE LINKTYPE_IMPORT(
   ID_                    NUMBER,
   NAME_                  VARCHAR2,
   TEMPLATECLS_           NUMBER,
   PARENTDOCCLS_          NUMBER,
   CHILDDOCCLS_           NUMBER,
   LINKCOMMENT_           VARCHAR2,
   BLOCKPARENT_           NUMBER,
   BLOCKCHILD_            NUMBER,
   CANDELBLOCKPARENT_     NUMBER,
   CANDELBLOCKCHILD_      NUMBER,
   PARENTPICTURETYPE_     NUMBER,
   PARENTPICTURENAME_     VARCHAR2,
   CHILDPICTURETYPE_      NUMBER,
   CHILDPICTURENAME_      VARCHAR2,
   PICTURECOLLECTIONNAME_ VARCHAR2,
   URMUSE_                NUMBER,
   DELMACROSNAME_         VARCHAR2,
   NEEDDELCHILD_          NUMBER,
   LINKKIND_              NUMBER
) IS
   CNT$ NUMBER(10);
BEGIN
   /*          ,     */
   /*  ,   , ,  ,     */
   IF (
   ((TEMPLATECLS_ is not null)and(TEMPLATECLS_<>0))or(Name_ is not null))   
   THEN
     FOR tab_rec in(SELECT id FROM LINKTYPE LT WHERE 
		 (id<>ID_)	
         and(((TEMPLATECLS_ is not null)and(TEMPLATECLS_<>0)and(LT.TEMPLATECLS = TEMPLATECLS_)
         and (LT.PARENTDOCCLS = PARENTDOCCLS_) and (LT.CHILDDOCCLS = CHILDDOCCLS_))
         or((Name_ is not null)and(lt.Name=Name_))))
     LOOP
        /*             */    
        DELETE FROM LINKRECORDS WHERE LINKTYPEREF = -10;  
        DELETE FROM TB_LINKTYPE WHERE ID = -10;
        DELETE FROM DOCUMENTCLS WHERE ID = -10;
        DELETE FROM DOCUMENTTYPES WHERE ID = -10;
        INSERT INTO DOCUMENTTYPES(ID, PROGINDEX) VALUES(-10, -10);
        INSERT INTO DOCUMENTCLS(ID, DOCTYPE, TABLENAME, TABLENAMEURM, PRIMARYKEYNAME, PRIMARYKEYNAMEURM)
           VALUES(-10, -10, ' ', ' ', ' ', ' ');
        INSERT INTO LINKTYPE(ID, PARENTDOCCLS, CHILDDOCCLS, NAME) VALUES(-10, -10, -10, ' ');
        UPDATE STATE_JUMPCONTROL SET
           REFERENCEREF = -10
        WHERE
           REFERENCEREF = tab_rec.id;
        UPDATE LINKRECORDS SET
           LINKTYPEREF = -10
        WHERE
           LINKTYPEREF = tab_rec.id;
        DELETE FROM TB_LINKTYPE WHERE ID = tab_rec.Id;
     END LOOP;
   end if;
   /*      */ 
   SELECT count(*) into CNT$
      FROM LINKTYPE LT WHERE LT.ID = ID_;
   IF (CNT$ = 0)    
   THEN
      INSERT INTO LINKTYPE
       (ID,NAME,TEMPLATECLS,PARENTDOCCLS, CHILDDOCCLS, LINKCOMMENT, BLOCKPARENT,BLOCKCHILD,CANDELBLOCKPARENT,
        CANDELBLOCKCHILD, PARENTPICTURETYPE,PARENTPICTURENAME,CHILDPICTURETYPE,CHILDPICTURENAME,
        PICTURECOLLECTIONNAME,URMUSE,DELMACROSNAME,NEEDDELCHILD,LINKKIND)
      VALUES
       (ID_,NAME_,TEMPLATECLS_, PARENTDOCCLS_, CHILDDOCCLS_, LINKCOMMENT_, BLOCKPARENT_,BLOCKCHILD_,CANDELBLOCKPARENT_,
        CANDELBLOCKCHILD_, PARENTPICTURETYPE_,PARENTPICTURENAME_,CHILDPICTURETYPE_,CHILDPICTURENAME_,
        PICTURECOLLECTIONNAME_,URMUSE_,DELMACROSNAME_,NEEDDELCHILD_,LINKKIND_);
   ELSE
      UPDATE LINKTYPE SET
         NAME = NAME_,
         TEMPLATECLS = TEMPLATECLS_,
         PARENTDOCCLS = PARENTDOCCLS_,
         CHILDDOCCLS = CHILDDOCCLS_,
         LINKCOMMENT = LINKCOMMENT_,
         BLOCKPARENT = BLOCKPARENT_,
         BLOCKCHILD = BLOCKCHILD_,
         CANDELBLOCKPARENT = CANDELBLOCKPARENT_,
         CANDELBLOCKCHILD = CANDELBLOCKCHILD_,
         PARENTPICTURETYPE = PARENTPICTURETYPE_,
         PARENTPICTURENAME = PARENTPICTURENAME_,
         CHILDPICTURETYPE = CHILDPICTURETYPE_,
         CHILDPICTURENAME = CHILDPICTURENAME_,
         PICTURECOLLECTIONNAME = PICTURECOLLECTIONNAME_,
         URMUSE = URMUSE_,
         DELMACROSNAME = DELMACROSNAME_,
         NEEDDELCHILD = NEEDDELCHILD_,
         LINKKIND = LINKKIND_
      WHERE ID = ID_;
   END IF;      
   
   /*      ,      */
   UPDATE STATE_JUMPCONTROL SET
     REFERENCEREF = ID_
   WHERE
     REFERENCEREF = -10;
   UPDATE LINKRECORDS SET
      LINKTYPEREF = ID_
   WHERE
      LINKTYPEREF = -10;
   /*   */  
   DELETE FROM TB_LINKTYPE WHERE ID = -10;
   DELETE FROM DOCUMENTCLS WHERE ID = -10;
   DELETE FROM DOCUMENTTYPES WHERE ID = -10;
END;
/

--  
CALL LINKTYPE_IMPORT(20200200,'__->_',null,20801,20701,'         ',1,1,0,1,1,'',1,'','1616',0,'',0,0) ;

CALL LINKTYPE_IMPORT(34901700,'2',null,30800,490200,'     ',0,0,0,0,2,'',1,'','1616',1,'',0,1) ;

CALL LINKTYPE_IMPORT(34902300,'',null,30800,490300,'     ',0,0,1,1,2,'_',1,'','1616',0,'',0,3) ;

CALL LINKTYPE_IMPORT(252500900,'__',null,250300,250300,'       ',1,0,0,0,1,'',1,'','1616',0,'',0,0) ;

CALL LINKTYPE_IMPORT(252501000,'__',null,250300,250300,'        ',1,0,0,0,1,'',1,'','1616',0,'',0,0) ;

CALL LINKTYPE_IMPORT(520900100,' - ',null,520100,90300,'',0,0,0,0,1,'',1,'','',1,'',0,0) ;

CALL LINKTYPE_IMPORT(520900200,' - ',null,520101,90301,'',0,0,0,0,1,'',1,'','',1,'',0,0) ;

CALL LINKTYPE_IMPORT(555501200,'___',null,550101,550101,'    ,    ""',0,0,1,1,1,'',1,'','',0,'',0,0) ;

CALL LINKTYPE_IMPORT(520300800,' - ',null,520101,32201,'        ',0,0,0,0,1,'',1,'','',1,'',0,0) ;

CALL LINKTYPE_IMPORT(520300900,' - ',null,520100,32200,'       ',0,0,0,0,1,'',1,'','',1,'',0,0) ;

CALL LINKTYPE_IMPORT(34903100,'->',null,30700,490300,'     ',0,0,1,1,2,'_',1,'','1616',0,'',0,3) ;

CALL LINKTYPE_IMPORT(494900200,'->',null,490300,490300,'     ',0,0,1,1,2,'_',1,'','1616',0,'',0,3) ;

CALL LINKTYPE_IMPORT(20204800,'__->__',null,20800,20900,'',1,0,0,1,1,'',1,'','1616',0,'',0,0) ;

CALL LINKTYPE_IMPORT(20204700,'__->_',null,20801,20901,'',1,0,0,1,1,'',1,'','1616',0,'',0,0) ;

CALL LINKTYPE_IMPORT(302500100,'  -> ',null,300600,250400,'  -  ',1,0,0,0,1,'',1,'','1616',1,'',0,0) ;

CALL LINKTYPE_IMPORT(252501100,' -> ',null,250400,250300,'    ',1,0,0,0,1,'',1,'','1616',1,'',0,0) ;

CALL LINKTYPE_IMPORT(20300200,'->',null,20100,32300,'       ',1,0,0,0,1,'',1,'','1616',1,'',1,0) ;

CALL LINKTYPE_IMPORT(520900300,' - ',null,520100,90301,'      ',0,0,0,0,1,'',1,'','',1,'',0,0) ;

CALL LINKTYPE_IMPORT(304900700,'',null,300500,490200,'',0,0,0,0,2,'',1,'','1616',1,'',0,1) ;

CALL LINKTYPE_IMPORT(304900800,'',null,301000,490200,'  ',0,0,0,0,2,'',1,'','1616',1,'',0,1) ;

CALL LINKTYPE_IMPORT(304900900,'',null,301100,490200,'  ',0,0,0,0,2,'',1,'','1616',1,'',0,1) ;

DROP PROCEDURE LINKTYPE_DELETE
/

DROP PROCEDURE LINKTYPE_IMPORT
/

CREATE OR REPLACE PROCEDURE STATICLINK_DELETE(ID_ NUMBER) IS
BEGIN
  DELETE FROM STATICLINKS SL
  WHERE SL.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE STATICLINK_IMPORT(
  ID_             NUMBER,
  NAME_           VARCHAR2,
  PARENTFIELDREF_ NUMBER,
  CHILDFIELDREF_  NUMBER,
  LINKKIND_      NUMBER,
  ParentDelAction_ NUMBER
) IS
  FINDID$ NUMBER;
  FINDNEWID$ NUMBER;
  IDExists$ NUMBER;
BEGIN
  /*     ID,    CHILDFIELDREF,PARENTFIELDREF. 
   ,     ,    ID.       ID  , 
   (  )     id ,      */
  BEGIN
    SELECT
      SL.ID
    INTO FINDID$
    FROM 
      STATICLINKS SL
    WHERE (SL.CHILDFIELDREF = CHILDFIELDREF_) AND (SL.PARENTFIELDREF = PARENTFIELDREF_) AND (SL.ID <> ID_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      FINDID$ := NULL;
  END;
  
  IF (FINDID$ IS NOT NULL) THEN
  /*   ID         */

    SELECT COUNT (ID)
      INTO IDExists$
      FROM STATE_JUMPCONTROL
    WHERE (STATICLINKREF = FINDID$);

    IF (IDExists$ > 0) THEN

      BEGIN
        SELECT
          SL.ID
        INTO FINDNEWID$
        FROM 
          STATICLINKS SL
        WHERE (SL.ID = ID_);
      EXCEPTION
        WHEN NO_DATA_FOUND THEN
          FINDNEWID$ := NULL;
      END;
 
      IF (FINDNEWID$ IS NULL) THEN
        INSERT INTO STATICLINKS
         (ID,NAME,PARENTFIELDREF,CHILDFIELDREF,LINKKIND,ParentDelAction)
        VALUES
          (ID_,NAME_,CHILDFIELDREF_,PARENTFIELDREF_,1,ParentDelAction_);
      END IF;        
      UPDATE STATE_JUMPCONTROL
        SET STATICLINKREF = ID_
      WHERE (STATICLINKREF = FINDID$);

      DELETE FROM STATICLINKS  
      WHERE ID=FINDID$;
    ELSE   
      BEGIN
        SELECT
          SL.ID
        INTO FINDNEWID$
        FROM
          STATICLINKS SL
        WHERE (SL.ID = ID_);
      EXCEPTION
        WHEN NO_DATA_FOUND THEN
          FINDNEWID$ := NULL;
      END;
      IF (FINDNEWID$ IS NULL) THEN
        UPDATE STATICLINKS
        SET ID=ID_
        WHERE ID=FINDID$;
      ELSE
        DELETE FROM STATICLINKS
        WHERE ID=FINDID$;
      END IF;
    END IF;
      
  END IF; /*  id  */
  
  /*       ( ), 
   ,            CHILDFIELDREF.
   ,        1( )*/
  IF (LINKKIND_=0) THEN
    UPDATE STATICLINKS
    SET LINKKIND=1  
    WHERE (CHILDFIELDREF = CHILDFIELDREF_) AND (ID <> ID_) AND (LINKKIND=0);
  END IF;    
  
  /*        id.  ,   .  ,   */
  BEGIN
    SELECT SL.ID
      INTO FINDID$
      FROM
        STATICLINKS SL
      WHERE
        (SL.ID = ID_);
  EXCEPTION
      WHEN NO_DATA_FOUND THEN
        FINDID$ := NULL;
  END;
  IF (FINDID$ IS NOT NULL) THEN
    UPDATE STATICLINKS SET
      NAME           = NAME_,
      PARENTFIELDREF = PARENTFIELDREF_,
      CHILDFIELDREF  = CHILDFIELDREF_,
      LINKKIND       = LINKKIND_,
      ParentDelAction = ParentDelAction_
      WHERE ID = ID_;
  ELSE
    INSERT INTO STATICLINKS
     (ID,NAME,PARENTFIELDREF,CHILDFIELDREF,LINKKIND,ParentDelAction)
    VALUES
      (ID_,NAME_,PARENTFIELDREF_,CHILDFIELDREF_,LINKKIND_,ParentDelAction_);
  END IF;      

END;
/

--  
CALL STATICLINK_DELETE(990200600) ;

CALL STATICLINK_DELETE(990201300) ;

CALL STATICLINK_DELETE(990202700) ;

CALL STATICLINK_DELETE(990203400) ;

CALL STATICLINK_DELETE(999900400) ;

CALL STATICLINK_DELETE(999903600) ;

CALL STATICLINK_DELETE(990210600) ;

CALL STATICLINK_DELETE(965200800) ;

CALL STATICLINK_IMPORT(990901600,'_.1.KESR()->.ID',986810006,90311030,0,0) ;

CALL STATICLINK_IMPORT(980228400,'_.1.KVRCORR()->.ID',980410002,20111064,1,0) ;

CALL STATICLINK_IMPORT(990230000,'.1.->.ID',986810006,20011021,0,1) ;

CALL STATICLINK_IMPORT(990336300,'.1.->.ID',986810006,30011030,0,1) ;

CALL STATICLINK_IMPORT(982502100,'.2.SUBKESR->.ID',980810002,250212004,0,1) ;

CALL STATICLINK_IMPORT(982502000,'.2.REGION->.ID',981210005,250212005,0,1) ;

CALL STATICLINK_IMPORT(982502200,'.2.MEANSTYPE->.ID',984910002,250212025,0,1) ;

CALL STATICLINK_IMPORT(982501500,'.2.KVSR->.ID',980310002,250212026,0,1) ;

CALL STATICLINK_IMPORT(982501400,'.2.KVR->.ID',980410002,250212027,0,1) ;

CALL STATICLINK_IMPORT(982501600,'.2.KFSR->.ID',980210004,250212028,0,1) ;

CALL STATICLINK_IMPORT(992500500,'.2.KESR->.ID',986810006,250212029,0,1) ;

CALL STATICLINK_IMPORT(982501700,'.2.KCSR->.ID',980510002,250212030,0,1) ;

CALL STATICLINK_IMPORT(982501300,'.2.FINSOURCE->.ID',981310002,250212032,0,1) ;

CALL STATICLINK_IMPORT(982501800,'.2.FACIALACC_CLS->.ID',984110021,250212035,0,0) ;

CALL STATICLINK_IMPORT(992500600,'.2.DIRECTIONCLS->.ID',986910002,250212036,0,1) ;

CALL STATICLINK_IMPORT(992500700,'.2.BUHOPERATIONCLS->.ID',987110021,250212037,0,1) ;

CALL STATICLINK_IMPORT(982504700,'.2.SUBKESR->.ID',980810002,250412010,0,1) ;

CALL STATICLINK_IMPORT(982504600,'.2.REGION->.ID',981210005,250412011,0,1) ;

CALL STATICLINK_IMPORT(982505400,'.5.MEANSTYPE->.ID',984910002,250415004,0,1) ;

CALL STATICLINK_IMPORT(982504800,'.2.MEANSTYPE->.ID',984910002,250412030,0,1) ;

CALL STATICLINK_IMPORT(982505100,'.5.KVSR->.ID',980310002,250415006,0,1) ;

CALL STATICLINK_IMPORT(982504100,'.2.KVSR->.ID',980310002,250412032,0,1) ;

CALL STATICLINK_IMPORT(982505000,'.5.KVR->.ID',980410002,250415008,0,1) ;

CALL STATICLINK_IMPORT(982504000,'.2.KVR->.ID',980410002,250412034,0,1) ;

CALL STATICLINK_IMPORT(982505200,'.5.KFSR->.ID',980210004,250415009,0,1) ;

CALL STATICLINK_IMPORT(982504200,'.2.KFSR->.ID',980210004,250412035,0,1) ;

CALL STATICLINK_IMPORT(992501800,'.5.KESR->.ID',986810006,250415010,0,1) ;

CALL STATICLINK_IMPORT(992501500,'.2.KESR->.ID',986810006,250412036,0,1) ;

CALL STATICLINK_IMPORT(982505300,'.5.KCSR->.ID',980510002,250415012,0,1) ;

CALL STATICLINK_IMPORT(982504300,'.2.KCSR->.ID',980510002,250412038,0,1) ;

CALL STATICLINK_IMPORT(982503900,'.2.FINSOURCE->.ID',981310002,250412040,0,1) ;

CALL STATICLINK_IMPORT(982504400,'.2.FACIALACC_CLS->.ID',984110021,250412043,0,0) ;

CALL STATICLINK_IMPORT(982503800,'.3.FACIALACC_CLS->.ID',984110021,250413008,0,0) ;

CALL STATICLINK_IMPORT(962501100,'.EXECUTERINN->.ID',960110033,250410049,0,0) ;

CALL STATICLINK_IMPORT(992501700,'.2.BUHOPERATIONCLS->.ID',987110021,250412045,0,1) ;

CALL STATICLINK_IMPORT(995200800,'.1.KESR()->.ID',986810006,520111011,0,0) ;

CALL STATICLINK_IMPORT(962500200,'.EXECUTER_REF->.ID',960110033,250410089,0,0) ;

CALL STATICLINK_IMPORT(995504100,'.1.KESR()->.ID',986810006,550311015,0,0) ;

CALL STATICLINK_IMPORT(982506500,'.DOCTYPE->.ID',981110005,250410094,0,0) ;

CALL STATICLINK_IMPORT(990230400,'_.2.KESR()->.ID',986810006,20912017,0,1) ;

CALL STATICLINK_IMPORT(990230500,'_.2.KESR()->.ID',986810006,21112016,0,1) ;

CALL STATICLINK_IMPORT(991800200,'.KESR()->.ID',986810006,181610007,0,0) ;

CALL STATICLINK_IMPORT(990230600,'_.2.KESR()->.ID',986810006,21212016,0,1) ;

CALL STATICLINK_IMPORT(991800300,'.1.KESR()->.ID',986810006,181611070,0,0) ;

CALL STATICLINK_IMPORT(965200900,'.NameJudicialAgencyRef()->.Id',960110033,520110055,0,0) ;

CALL STATICLINK_IMPORT(992502200,'.2.SUBSIDYCLS->.ID',988910006,250212056,0,0) ;

CALL STATICLINK_IMPORT(992502100,'.2.SUBSIDYCLS->.ID',988910006,250312051,0,0) ;

CALL STATICLINK_IMPORT(992502300,'.2.SUBSIDYCLS->.ID',988910006,250412055,0,0) ;

CALL STATICLINK_IMPORT(963000000,'.SupplierRef()->.ID',960110033,300410001,0,0) ;

CALL STATICLINK_IMPORT(992203400,'_.1.KESR()->.ID',986810006,220111080,0,0) ;

CALL STATICLINK_IMPORT(991912300,'.1.->.ID',986810006,190011036,0,1) ;

CALL STATICLINK_IMPORT(979900000,'.ANALYTICALGROUPIFS->.ID',970210001,985210025,0,0) ;

CALL STATICLINK_IMPORT(979800000,'.ANALYTICALGROUPKD->.ID',970110001,980910025,0,0) ;

CALL STATICLINK_IMPORT(991800400,'.DESTKESR->.ID',986810006,180910001,0,0) ;

CALL STATICLINK_IMPORT(999903700,'.KESR()->.ID',986810006,993010013,0,0) ;

CALL STATICLINK_IMPORT(990336400,'.AUTOSANCTION()->.ID',993010001,30210161,0,0) ;

CALL STATICLINK_IMPORT(969901200,'_.RECORDOWNERORGREF->.ID',960110033,990310098,0,0) ;

CALL STATICLINK_IMPORT(990907800,'_.KESR()->.ID',986810006,90510046,0,0) ;

CALL STATICLINK_IMPORT(990908000,'_.KESR()->.ID',986810006,90610082,0,0) ;

CALL STATICLINK_IMPORT(990908100,'_.KESR()->.ID',986810006,90710058,0,0) ;

CALL STATICLINK_IMPORT(990908200,'_.1.KESR()->.ID',986810006,90611088,0,0) ;

CALL STATICLINK_IMPORT(992502400,'.AUTOSANCTION()->.ID',993010001,250410100,0,0) ;

CALL STATICLINK_IMPORT(993001300,'.BUDGETREF->.ID',987810006,301010001,0,0) ;

CALL STATICLINK_IMPORT(993001400,'.REJECTCLS()->.ID',985010005,301010007,0,0) ;

CALL STATICLINK_IMPORT(983002600,'.FACIALACCCLS->.ID',984110021,301010014,0,0) ;

CALL STATICLINK_IMPORT(993001800,'.BUDGETREF->.ID',987810006,301110001,0,0) ;

CALL STATICLINK_IMPORT(993002000,'.1.KESR->.ID',986810006,301111002,0,0) ;

CALL STATICLINK_IMPORT(983003500,'.1.KCSR->.ID',980510002,301111003,0,0) ;

CALL STATICLINK_IMPORT(983003700,'.1.FACIALACCCLS->.ID',984110021,301111006,0,0) ;

CALL STATICLINK_IMPORT(993001900,'.REJECTCLS()->.ID',985010005,301110007,0,0) ;

CALL STATICLINK_IMPORT(983003600,'.FACIALACCCLS->.ID',984110021,301110014,0,0) ;

CALL STATICLINK_IMPORT(983003800,'.1.KVSR->.ID',980310002,301111025,0,0) ;

CALL STATICLINK_IMPORT(983003900,'.1.KFSR->.ID',980210004,301111026,0,0) ;

CALL STATICLINK_IMPORT(983004000,'.1.KVR->.ID',980410002,301111027,0,0) ;

CALL STATICLINK_IMPORT(983004100,'.1.MEANSTYPECLS->.ID',984910002,301111028,0,0) ;

CALL STATICLINK_IMPORT(983004200,'.1.SUBKESR->.ID',980810002,301111038,0,0) ;

CALL STATICLINK_IMPORT(993002100,'.1.FINSOURCECLS->.ID',985210008,301111040,0,0) ;

CALL STATICLINK_IMPORT(983004300,'.1.FINTYPE->.ID',982710006,301111041,0,0) ;

CALL STATICLINK_IMPORT(993002200,'.1.DIRECTIONCLS->.ID',986910002,301111042,0,0) ;

CALL STATICLINK_IMPORT(983004400,'.1.FACTCLS->.ID',982810005,301111045,0,0) ;

CALL STATICLINK_IMPORT(993002300,'-.BUDGETREF->.ID',987810006,300510001,0,0) ;

CALL STATICLINK_IMPORT(993002400,'-.REJECTCLS()->.ID',985010005,300510002,0,0) ;

CALL STATICLINK_IMPORT(983004500,'-.FACIALACCCLS->.ID',984110021,300510007,0,0) ;

CALL STATICLINK_IMPORT(303000000,'.ParentRef->.ID',301110029,301010031,1,0) ;

CALL STATICLINK_IMPORT(303000100,' -.ParentRef->-.ID',300610051,300510018,1,0) ;

DROP PROCEDURE STATICLINK_DELETE
/

DROP PROCEDURE STATICLINK_IMPORT
/

CREATE OR REPLACE PROCEDURE FILTERS_DELETE(ID_ NUMBER) IS
BEGIN
  DELETE FROM STATE_JUMPCONTROL
  WHERE STATE_JUMPCONTROL.FILTERCODE = ID_;
  UPDATE STATE_ACTIONJUMPS SAJ
  SET SAJ.FILTERCODE = NULL, SAJ.OPTIONS = NULL
  WHERE SAJ.FILTERCODE = ID_;
  DELETE FROM State_Filter SF
  WHERE SF.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE FILTERS_IMPORT(
  ID_ NUMBER,
  Name_ VARCHAR2,
  Note_ VARCHAR2,
  FilterValue_ VARCHAR2,
  FilterFormat_ NUMBER,
  FilterActive_ NUMBER,
  IsBudget_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM State_Filter
  WHERE (ID = ID_);
  IF (IDExists$ = 0) THEN
  INSERT INTO State_Filter
    (ID,NAME,Note,FilterValue,FilterFormat,FilterActive,IsBudget)
  VALUES
    (ID_,NAME_,Note_,FilterValue_,FilterFormat_,FilterActive_,IsBudget_);
  ELSE
    UPDATE State_Filter SET
      NAME = NAME_,
      Note = Note_,
      FilterValue = FilterValue_,
      FilterFormat = FilterFormat_,
      FilterActive = FilterActive_,
      IsBudget = IsBudget_
    WHERE ID = ID_;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FILTERS_IMPORTURM(
  ID_ NUMBER,
  Name_ VARCHAR2,
  Note_ VARCHAR2,
  FilterValueURM_ VARCHAR2,
  FilterFormat_ NUMBER,
  FilterActive_ NUMBER,
  IsBudget_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM State_Filter
  WHERE (ID = ID_);
  IF (IDExists$ = 0) THEN
  INSERT INTO State_Filter
    (ID,NAME,Note,FilterValueURM,FilterFormat,FilterActive,IsBudget)
  VALUES
    (ID_,NAME_,Note_,FilterValueURM_,FilterFormat_,FilterActive_,IsBudget_);
  ELSE
    UPDATE State_Filter SET
      NAME = NAME_,
      Note = Note_,
      FilterValueURM = FilterValueURM_,
      FilterFormat = FilterFormat_,
      FilterActive = FilterActive_,
      IsBudget = IsBudget_
    WHERE ID = ID_;
  END IF;
END;
/

-- 
CALL FILTERS_DELETE(9050100) ;

DROP PROCEDURE FILTERS_DELETE
/

DROP PROCEDURE FILTERS_IMPORT
/

DROP PROCEDURE FILTERS_IMPORTURM
/

CREATE OR REPLACE PROCEDURE STATUSICONS_IMPORT(
  ID_ NUMBER,
  NOTE_ VARCHAR2,
  DOCREF_ NUMBER,
  DETAILNUM_ NUMBER,
  ICONNAME_ VARCHAR2,
  ISSYSTEM_ NUMBER,
  ICONPOS_ NUMBER,
  RUNPOS_ NUMBER,
  RESERVEPOS_ NUMBER,
  ICONHINT_ VARCHAR2,
  ICONKIND_ NUMBER,
  LOCKMASK_ NUMBER,
  FORMULA_ VARCHAR2,
  ISBUDGET_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM STATUSICONS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE STATUSICONS SET
      NOTE = NOTE_,
      DOCREF = DOCREF_,
      DETAILNUM = DETAILNUM_,
      ICONNAME = ICONNAME_,
      ISSYSTEM = ISSYSTEM_,
      ICONPOS = ICONPOS_,
      RUNPOS = RUNPOS_,
      RESERVEPOS = RESERVEPOS_,
      ICONHINT = ICONHINT_,
      ICONKIND = ICONKIND_,
      LOCKMASK = LOCKMASK_,
      ISBUDGET = ISBUDGET_,
      FORMULA = FORMULA_
    WHERE ID = ID_;
  ELSE
    INSERT INTO STATUSICONS
      (ISBUDGET, ID, NOTE, DOCREF, DETAILNUM, ICONNAME, ISSYSTEM, ICONPOS, RUNPOS, RESERVEPOS, ICONHINT, ICONKIND, LOCKMASK, FORMULA)
    VALUES
      (ISBUDGET_, ID_, NOTE_, DOCREF_, DETAILNUM_, ICONNAME_, ISSYSTEM_, ICONPOS_, RUNPOS_, RESERVEPOS_, ICONHINT_, ICONKIND_, LOCKMASK_, FORMULA_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE STATUSICONS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM STATUSICONS SI
  WHERE SI.ID = ID_;
END;
/

--  
CALL STATUSICONS_IMPORT(39873,'',302,0,'',1,2,4,1,'     ',0,0,'([30210135])',1) ;

CALL STATUSICONS_IMPORT(13828,'',302,0,'',1,5,5,1,' ',0,0,'[30210134] = 11',1) ;

CALL STATUSICONS_IMPORT(39874,'',304,0,'',1,2,4,1,'     ',0,0,'([30410040])',1) ;

CALL STATUSICONS_IMPORT(39110,'',4901,0,'',1,2,0,0,' ',0,0,'([490110024])  ([490110023] = 1)',1) ;

CALL STATUSICONS_IMPORT(39161,'',4901,0,'',1,2,0,0,' ',0,0,'([490110024])  ([490110023] = 0)  ([490110012] = 2)',1) ;

DROP PROCEDURE STATUSICONS_IMPORT
/

DROP PROCEDURE STATUSICONS_DELETE
/


CREATE OR REPLACE PROCEDURE ENUMS_IMPORT(NAME_ VARCHAR2,FACIALACCCLS_ NUMBER) IS
  IDEXISTS$ NUMBER;
BEGIN
  SELECT COUNT(ID) INTO IDEXISTS$ FROM ENUMS WHERE NAME = NAME_;
  IF (IDEXISTS$ > 1) THEN
      DELETE FROM ENUMS E1
      WHERE (E1.NAME = NAME_) AND (E1.ID > (SELECT MIN(E2.ID) FROM ENUMS E2 WHERE E2.NAME = NAME_));
  END IF;
  IF (IDEXISTS$ > 0) THEN
    UPDATE ENUMS SET
      FACIALACCCLS = FACIALACCCLS_,
      ISSYSTEM = 1
    WHERE NAME = NAME_;
  ELSE
    INSERT INTO ENUMS
      (NAME,FACIALACCCLS,ISSYSTEM)    
    VALUES
      (NAME_,FACIALACCCLS_,1);
  END IF;    
END;
/

CREATE OR REPLACE PROCEDURE ENUMVALUES_IMPORT(ENUMNAME_ VARCHAR2,NAME_ VARCHAR2,VAL_ NUMBER) IS
  IDENUM$ NUMBER;
  IDEXISTS$ NUMBER;
BEGIN
  BEGIN
    SELECT ID INTO IDENUM$ FROM ENUMS WHERE NAME = ENUMNAME_;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      IDENUM$ := NULL;
  END;  
  IF (IDENUM$ IS NOT NULL) THEN
    SELECT COUNT(ID) INTO IDEXISTS$ FROM ENUMVALUES WHERE ENUMREF = IDENUM$ AND VAL = VAL_;
    IF (IDEXISTS$ > 1) THEN
      DELETE FROM ENUMVALUES EV1
      WHERE (EV1.ENUMREF = IDENUM$) AND (EV1.VAL = VAL_) AND
        (EV1.ID > (SELECT MIN(EV2.ID) FROM ENUMVALUES EV2 WHERE EV2.ENUMREF = IDENUM$ AND EV2.VAL = VAL_));
    END IF;
    IF (IDEXISTS$ > 0) THEN
      UPDATE ENUMVALUES SET
        NAME = NAME_
      WHERE ENUMREF = IDENUM$ AND VAL = VAL_;
    ELSE
      INSERT INTO ENUMVALUES
        (VAL,NAME,ENUMREF)  
      VALUES
        (VAL_,NAME_,IDENUM$);
    END IF;    
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE ENUMS_DELETE(NAME_ VARCHAR2) IS
BEGIN
  DELETE FROM ENUMS WHERE NAME = NAME_;
END;
/

CREATE OR REPLACE PROCEDURE ENUMVALUES_DELETE(ENUMNAME_ VARCHAR2,VAL_ NUMBER) IS
  IDENUM$ NUMBER;
BEGIN
  BEGIN
    SELECT ID INTO IDENUM$ FROM ENUMS WHERE NAME = ENUMNAME_;
  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       IDENUM$ := NULL;  
  END;
  IF (IDENUM$ IS NOT NULL) THEN
    DELETE FROM ENUMVALUES WHERE (VAL = VAL_) AND (ENUMREF = IDENUM$);
  END IF;  
END;
/

-- 
CALL ENUMVALUES_IMPORT('',' -',241) ;

CALL ENUMVALUES_IMPORT('','-',240) ;

CALL ENUMVALUES_IMPORT('',' ',242) ;

CALL ENUMVALUES_IMPORT('','  ',243) ;

CALL ENUMVALUES_IMPORT('','=  ',22) ;

CALL ENUMVALUES_IMPORT('','=  ',23) ;

CALL ENUMVALUES_IMPORT('','=   ',24) ;

CALL ENUMVALUES_IMPORT('','=    ',25) ;

CALL ENUMVALUES_IMPORT('','00= ',26) ;

CALL ENUMS_IMPORT('',null) ;

CALL ENUMVALUES_IMPORT('','',0) ;

CALL ENUMVALUES_IMPORT('','   ',1) ;

CALL ENUMVALUES_IMPORT('','',2) ;

CALL ENUMVALUES_IMPORT('','',3) ;

CALL ENUMVALUES_IMPORT('','  ',4) ;

CALL ENUMVALUES_IMPORT('','   ',5) ;

CALL ENUMVALUES_IMPORT('','',6) ;

DROP PROCEDURE ENUMS_IMPORT
/

DROP PROCEDURE ENUMVALUES_IMPORT
/

DROP PROCEDURE ENUMS_DELETE
/

DROP PROCEDURE ENUMVALUES_DELETE
/

--      
INSERT INTO DFUCHANGELOG (VersionID, BEGINUPDATECODE, ENDUPDATECODE, LASTUPDATEDFU, ISBUDGET, INCLUDEDEL, INCLUDEBLOCKS, INCLUDEDOCS, SCRIPTCREATOR, SCRIPTCREATEDATE, NOTE) VALUES (1506, 110000, 120000, TO_DATE('14.11.2016 19:20:28', 'DD.MM.YYYY HH24:MI:SS'), 1, 1, ',    ,  , ,  , ,  , , ', '00.00, 01.01, 02.00, 02.01, 02.02, 02.03, 02.04, 02.05, 02.06, 02.07, 02.08, 02.09, 02.10, 02.11, 02.12, 03.00, 03.01, 03.02, 03.03, 03.04, 03.05, 03.06, 03.07, 03.08, 03.11, 03.12, 03.14, 03.15, 03.16, 03.22, 03.23, 03.24, 04.01, 05.01, 07.01, 07.02, 07.03, 08.01, 08.02, 08.03, 08.04, 09.00, 09.01, 09.02, 09.03, 09.05, 09.06, 09.07, 12.01, 15.01, 16.01, 16.02, 17.01, 17.02, 18.05, 18.07, 18.09, 18.10, 18.12, 18.13, 18.14, 18.15, 18.16, 19.00, 19.01, 19.02, 19.03, 19.06, 22.00, 22.01, 25.01, 25.02, 25.03, 25.04, 28.01, 28.02, 30.01, 30.02, 30.03, 30.04, 30.05, 30.06, 30.10, 30.11, 36.10, 37.01, 39.01, 44.01, 44.03, 48.01, 49.01, 49.02, 49.03, 51.01, 52.01, 53.01, 53.02, 55.01, 55.02, 55.03, 96.01, 96.02, 96.03, 96.04, 97.01, 97.02, 98.02, 98.03, 98.04, 98.05, 98.06, 98.08, 98.09, 98.10, 98.11, 98.12, 98.13, 98.14, 98.15, 98.16, 98.17, 98.18, 98.20, 98.21, 98.22, 98.23, 98.26, 98.27, 98.28, 98.29, 98.34, 98.35, 98.41, 98.42, 98.43, 98.44, 98.45, 98.46, 98.47, 98.48, 98.49, 98.50, 98.51, 98.52, 98.53, 98.54, 98.57, 98.58, 98.59, 98.60, 98.61, 98.62, 98.63, 98.64, 98.65, 98.67, 98.68, 98.69, 98.70, 98.71, 98.72, 98.78, 98.79, 98.80, 98.81, 98.82, 98.83, 98.84, 98.85, 98.86, 98.87, 98.88, 98.89, 98.90, 98.91, 98.92, 98.94, 98.95, 98.97, 98.99, 99.03, 99.04, 99.05, 99.08, 99.12, 99.13, 99.14, 99.15, 99.16, 99.17, 99.18, 99.19, 99.20, 99.21, 99.22, 99.23, 99.24, 99.25, 99.26, 99.27, 99.28, 99.29, 99.30, 99.31', 'MALINOVKIN/malinovkin', TO_DATE('15.11.2016 18:17:31', 'DD.MM.YYYY HH24:MI:SS'), '') ;

COMMIT WORK
/



-- #########################################################
-- #########################################################
-- DBVersion.sql
-- #########################################################
-- #########################################################

INSERT INTO DataBaseVersion(VERSION, Major, Minor, AComment)
  VALUES ('12.00.00', 1200, 00, ' 12.0')
/

COMMIT WORK
/

-- #########################################################
-- #########################################################
-- Index_Fix.sql
-- #########################################################
-- #########################################################

--      INDX
DECLARE
  CURSOR C$ IS
    select INDEX_NAME from DBA_INDEXES
    where OWNER = SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA')
      and TABLESPACE_NAME <> 'INDX'
      and INDEX_TYPE LIKE '%NORMAL%';
  CNT$ NUMBER(10);    
BEGIN
  BEGIN
    select count(*) into CNT$ from V$TABLESPACE
    where name = 'INDX';
  EXCEPTION
    WHEN OTHERS THEN
      CNT$ := 1;
  END;
  IF CNT$ = 1 THEN
    FOR R$ IN C$ LOOP
      EXECUTE IMMEDIATE 'ALTER INDEX ' || R$.INDEX_NAME || ' REBUILD TABLESPACE INDX';
    END LOOP;
  END IF;
END;
/

-- #########################################################
-- #########################################################
-- compile_scr.sql
-- #########################################################
-- #########################################################

--      , 
--  -  
--  DBMS_UTILITY.COMPILE_SCHEMA(user, TRUE);

DECLARE
  CURSOR C$ IS
    SELECT 'ALTER ' || object_type || ' ' || owner || '.' || object_name || ' COMPILE' AS str,
      object_type, object_name
    FROM SYS.ALL_OBJECTS
    WHERE owner = SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA')
      AND object_type IN ('VIEW', 'PROCEDURE', 'TRIGGER')
      AND status = 'INVALID'
      AND object_name not like 'BIN$%'
    ORDER BY DECODE(object_type, 'VIEW', 1, 'PROCEDURE', 2, 'TRIGGER', 3), object_name;
  S VARCHAR2(100);
BEGIN
  FOR R$ IN C$ LOOP
    BEGIN
      S := R$.object_type || ' ' || R$.object_name;
      EXECUTE IMMEDIATE R$.str;
    EXCEPTION
      WHEN OTHERS THEN 
        --DBMS_OUTPUT.PUT_LINE(S);
        RAISE_APPLICATION_ERROR(-20000, '    ' || S);
    END;
  END LOOP;
END;
/

-- #########################################################
-- #########################################################
-- dbms_stats_scr.sql
-- #########################################################
-- #########################################################

ALTER SESSION SET NLS_NUMERIC_CHARACTERS='.,'
/

BEGIN
  DBMS_STATS.GATHER_SCHEMA_STATS(
    SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA'),
    DBMS_STATS.AUTO_SAMPLE_SIZE,
    false,
    'FOR ALL COLUMNS SIZE AUTO',
    cascade=>TRUE
  );
END;
/

exit
